Interface ImageKitClient
-
- All Implemented Interfaces:
public interface ImageKitClientA client for interacting with the Image Kit REST API synchronously. You can also switch to asynchronous execution via the async method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceImageKitClient.WithRawResponseA view of ImageKitClient that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ImageKitClientAsyncasync()Returns a version of this client that uses asynchronous execution. abstract ImageKitClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ImageKitClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CustomMetadataFieldServicecustomMetadataFields()abstract FileServicefiles()abstract SavedExtensionServicesavedExtensions()abstract AssetServiceassets()abstract CacheServicecache()abstract FolderServicefolders()abstract AccountServiceaccounts()abstract BetaServicebeta()abstract WebhookServicewebhooks()abstract HelperServicehelper()abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
async
abstract ImageKitClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract ImageKitClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ImageKitClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
abstract CustomMetadataFieldService customMetadataFields()
-
files
abstract FileService files()
-
savedExtensions
abstract SavedExtensionService savedExtensions()
-
assets
abstract AssetService assets()
-
cache
abstract CacheService cache()
-
folders
abstract FolderService folders()
-
accounts
abstract AccountService accounts()
-
beta
abstract BetaService beta()
-
webhooks
abstract WebhookService webhooks()
-
helper
abstract HelperService helper()
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-