Interface ImageKitClientAsync
-
- All Implemented Interfaces:
public interface ImageKitClientAsyncA client for interacting with the Image Kit REST API asynchronously. You can also switch to synchronous execution via the sync method.
This client performs best when you create a single instance and reuse it for all interactions with the REST API. This is because each client holds its own connection pool and thread pools. Reusing connections and threads reduces latency and saves memory. The client also handles rate limiting per client. This means that creating and using multiple instances at the same time will not respect rate limits.
The threads and connections that are held will be released automatically if they remain idle. But if you are writing an application that needs to aggressively release unused resources, then you may call close.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceImageKitClientAsync.WithRawResponseA view of ImageKitClientAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract ImageKitClientsync()Returns a version of this client that uses synchronous execution. abstract ImageKitClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract ImageKitClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CustomMetadataFieldServiceAsynccustomMetadataFields()abstract FileServiceAsyncfiles()abstract SavedExtensionServiceAsyncsavedExtensions()abstract AssetServiceAsyncassets()abstract CacheServiceAsynccache()abstract FolderServiceAsyncfolders()abstract AccountServiceAsyncaccounts()abstract BetaServiceAsyncbeta()abstract WebhookServiceAsyncwebhooks()abstract HelperServicehelper()abstract Unitclose()Closes this client, relinquishing any underlying resources. -
-
Method Detail
-
sync
abstract ImageKitClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
abstract ImageKitClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract ImageKitClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
abstract CustomMetadataFieldServiceAsync customMetadataFields()
-
files
abstract FileServiceAsync files()
-
savedExtensions
abstract SavedExtensionServiceAsync savedExtensions()
-
assets
abstract AssetServiceAsync assets()
-
cache
abstract CacheServiceAsync cache()
-
folders
abstract FolderServiceAsync folders()
-
accounts
abstract AccountServiceAsync accounts()
-
beta
abstract BetaServiceAsync beta()
-
webhooks
abstract WebhookServiceAsync webhooks()
-
helper
abstract HelperService helper()
-
close
abstract Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-