Package io.imagekit.client
Interface ImageKitClientAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface ImageKitClientAsync.WithRawResponseA view of ImageKitClientAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract ImageKitClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract CustomMetadataFieldServiceAsync.WithRawResponsecustomMetadataFields()abstract FileServiceAsync.WithRawResponsefiles()abstract SavedExtensionServiceAsync.WithRawResponsesavedExtensions()abstract AssetServiceAsync.WithRawResponseassets()abstract CacheServiceAsync.WithRawResponsecache()abstract FolderServiceAsync.WithRawResponsefolders()abstract AccountServiceAsync.WithRawResponseaccounts()abstract BetaServiceAsync.WithRawResponsebeta()abstract WebhookServiceAsync.WithRawResponsewebhooks()-
-
Method Detail
-
withOptions
abstract ImageKitClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
abstract CustomMetadataFieldServiceAsync.WithRawResponse customMetadataFields()
-
files
abstract FileServiceAsync.WithRawResponse files()
-
savedExtensions
abstract SavedExtensionServiceAsync.WithRawResponse savedExtensions()
-
assets
abstract AssetServiceAsync.WithRawResponse assets()
-
cache
abstract CacheServiceAsync.WithRawResponse cache()
-
folders
abstract FolderServiceAsync.WithRawResponse folders()
-
accounts
abstract AccountServiceAsync.WithRawResponse accounts()
-
beta
abstract BetaServiceAsync.WithRawResponse beta()
-
webhooks
abstract WebhookServiceAsync.WithRawResponse webhooks()
-
-
-
-