Class ImageKitClientAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.client.ImageKitClientAsync
public final class ImageKitClientAsyncImpl implements ImageKitClientAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classImageKitClientAsyncImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description ImageKitClientAsyncImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description ImageKitClientsync()Returns a version of this client that uses synchronous execution. ImageKitClientAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ImageKitClientAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomMetadataFieldServiceAsynccustomMetadataFields()FileServiceAsyncfiles()SavedExtensionServiceAsyncsavedExtensions()AssetServiceAsyncassets()CacheServiceAsynccache()FolderServiceAsyncfolders()AccountServiceAsyncaccounts()BetaServiceAsyncbeta()WebhookServiceAsyncwebhooks()HelperServicehelper()Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
ImageKitClientAsyncImpl
ImageKitClientAsyncImpl(ClientOptions clientOptions)
-
-
Method Detail
-
sync
ImageKitClient sync()
Returns a version of this client that uses synchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
ImageKitClientAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ImageKitClientAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
CustomMetadataFieldServiceAsync customMetadataFields()
-
files
FileServiceAsync files()
-
savedExtensions
SavedExtensionServiceAsync savedExtensions()
-
assets
AssetServiceAsync assets()
-
cache
CacheServiceAsync cache()
-
folders
FolderServiceAsync folders()
-
accounts
AccountServiceAsync accounts()
-
beta
BetaServiceAsync beta()
-
webhooks
WebhookServiceAsync webhooks()
-
helper
HelperService helper()
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-