Package io.imagekit.client
Class ImageKitClientAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.client.ImageKitClientAsync.WithRawResponse
public final class ImageKitClientAsyncImpl.WithRawResponseImpl implements ImageKitClientAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ImageKitClientAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomMetadataFieldServiceAsync.WithRawResponsecustomMetadataFields()FileServiceAsync.WithRawResponsefiles()SavedExtensionServiceAsync.WithRawResponsesavedExtensions()AssetServiceAsync.WithRawResponseassets()CacheServiceAsync.WithRawResponsecache()FolderServiceAsync.WithRawResponsefolders()AccountServiceAsync.WithRawResponseaccounts()BetaServiceAsync.WithRawResponsebeta()WebhookServiceAsync.WithRawResponsewebhooks()-
-
Method Detail
-
withOptions
ImageKitClientAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
CustomMetadataFieldServiceAsync.WithRawResponse customMetadataFields()
-
savedExtensions
SavedExtensionServiceAsync.WithRawResponse savedExtensions()
-
assets
AssetServiceAsync.WithRawResponse assets()
-
folders
FolderServiceAsync.WithRawResponse folders()
-
accounts
AccountServiceAsync.WithRawResponse accounts()
-
webhooks
WebhookServiceAsync.WithRawResponse webhooks()
-
-
-
-