Class ImageKitClientImpl
-
- All Implemented Interfaces:
-
io.imagekit.client.ImageKitClient
public final class ImageKitClientImpl implements ImageKitClient
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classImageKitClientImpl.WithRawResponseImpl
-
Constructor Summary
Constructors Constructor Description ImageKitClientImpl(ClientOptions clientOptions)
-
Method Summary
Modifier and Type Method Description ImageKitClientAsyncasync()Returns a version of this client that uses asynchronous execution. ImageKitClient.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ImageKitClientwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomMetadataFieldServicecustomMetadataFields()FileServicefiles()SavedExtensionServicesavedExtensions()AssetServiceassets()CacheServicecache()FolderServicefolders()AccountServiceaccounts()BetaServicebeta()WebhookServicewebhooks()HelperServicehelper()Unitclose()Closes this client, relinquishing any underlying resources. -
-
Constructor Detail
-
ImageKitClientImpl
ImageKitClientImpl(ClientOptions clientOptions)
-
-
Method Detail
-
async
ImageKitClientAsync async()
Returns a version of this client that uses asynchronous execution.
The returned client shares its resources, like its connection pool and thread pools, with this client.
-
withRawResponse
ImageKitClient.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ImageKitClient withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
CustomMetadataFieldService customMetadataFields()
-
files
FileService files()
-
savedExtensions
SavedExtensionService savedExtensions()
-
assets
AssetService assets()
-
cache
CacheService cache()
-
folders
FolderService folders()
-
accounts
AccountService accounts()
-
beta
BetaService beta()
-
webhooks
WebhookService webhooks()
-
helper
HelperService helper()
-
close
Unit close()
Closes this client, relinquishing any underlying resources.
This is purposefully not inherited from AutoCloseable because the client is long-lived and usually should not be synchronously closed via try-with-resources.
It's also usually not necessary to call this method at all. the default HTTP client automatically releases threads and connections if they remain idle, but if you are writing an application that needs to aggressively release unused resources, then you may call this method.
-
-
-
-