Package io.imagekit.client
Class ImageKitClientImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.client.ImageKitClient.WithRawResponse
public final class ImageKitClientImpl.WithRawResponseImpl implements ImageKitClient.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description ImageKitClient.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomMetadataFieldService.WithRawResponsecustomMetadataFields()FileService.WithRawResponsefiles()SavedExtensionService.WithRawResponsesavedExtensions()AssetService.WithRawResponseassets()CacheService.WithRawResponsecache()FolderService.WithRawResponsefolders()AccountService.WithRawResponseaccounts()BetaService.WithRawResponsebeta()WebhookService.WithRawResponsewebhooks()-
-
Method Detail
-
withOptions
ImageKitClient.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
customMetadataFields
CustomMetadataFieldService.WithRawResponse customMetadataFields()
-
files
FileService.WithRawResponse files()
-
savedExtensions
SavedExtensionService.WithRawResponse savedExtensions()
-
assets
AssetService.WithRawResponse assets()
-
cache
CacheService.WithRawResponse cache()
-
folders
FolderService.WithRawResponse folders()
-
accounts
AccountService.WithRawResponse accounts()
-
beta
BetaService.WithRawResponse beta()
-
webhooks
WebhookService.WithRawResponse webhooks()
-
-
-
-