Class ImageKitOkHttpClientAsync.Builder
-
- All Implemented Interfaces:
public final class ImageKitOkHttpClientAsync.BuilderA builder for ImageKitOkHttpClientAsync.
-
-
Method Summary
-
-
Method Detail
-
dispatcherExecutorService
final ImageKitOkHttpClientAsync.Builder dispatcherExecutorService(ExecutorService dispatcherExecutorService)
The executor service to use for running HTTP requests.
Defaults to OkHttp's default executor service.
This class takes ownership of the executor service and shuts it down when closed.
-
dispatcherExecutorService
final ImageKitOkHttpClientAsync.Builder dispatcherExecutorService(Optional<ExecutorService> dispatcherExecutorService)
Alias for calling Builder.dispatcherExecutorService with
dispatcherExecutorService.orElse(null).
-
proxy
final ImageKitOkHttpClientAsync.Builder proxy(Proxy proxy)
-
proxy
final ImageKitOkHttpClientAsync.Builder proxy(Optional<Proxy> proxy)
Alias for calling Builder.proxy with
proxy.orElse(null).
-
proxyAuthenticator
final ImageKitOkHttpClientAsync.Builder proxyAuthenticator(ProxyAuthenticator proxyAuthenticator)
Provides credentials when an HTTP proxy responds with
407 Proxy Authentication Required.
-
proxyAuthenticator
final ImageKitOkHttpClientAsync.Builder proxyAuthenticator(Optional<ProxyAuthenticator> proxyAuthenticator)
Alias for calling Builder.proxyAuthenticator with
proxyAuthenticator.orElse(null).
-
maxIdleConnections
final ImageKitOkHttpClientAsync.Builder maxIdleConnections(Integer maxIdleConnections)
The maximum number of idle connections kept by the underlying OkHttp connection pool.
If this is set, then keepAliveDuration must also be set.
If unset, then OkHttp's default is used.
-
maxIdleConnections
final ImageKitOkHttpClientAsync.Builder maxIdleConnections(Integer maxIdleConnections)
Alias for Builder.maxIdleConnections.
This unboxed primitive overload exists for backwards compatibility.
-
maxIdleConnections
final ImageKitOkHttpClientAsync.Builder maxIdleConnections(Optional<Integer> maxIdleConnections)
Alias for calling Builder.maxIdleConnections with
maxIdleConnections.orElse(null).
-
keepAliveDuration
final ImageKitOkHttpClientAsync.Builder keepAliveDuration(Duration keepAliveDuration)
The keep-alive duration for idle connections in the underlying OkHttp connection pool.
If this is set, then maxIdleConnections must also be set.
If unset, then OkHttp's default is used.
-
keepAliveDuration
final ImageKitOkHttpClientAsync.Builder keepAliveDuration(Optional<Duration> keepAliveDuration)
Alias for calling Builder.keepAliveDuration with
keepAliveDuration.orElse(null).
-
sslSocketFactory
final ImageKitOkHttpClientAsync.Builder sslSocketFactory(SSLSocketFactory sslSocketFactory)
The socket factory used to secure HTTPS connections.
If this is set, then trustManager must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
sslSocketFactory
final ImageKitOkHttpClientAsync.Builder sslSocketFactory(Optional<SSLSocketFactory> sslSocketFactory)
Alias for calling Builder.sslSocketFactory with
sslSocketFactory.orElse(null).
-
trustManager
final ImageKitOkHttpClientAsync.Builder trustManager(X509TrustManager trustManager)
The trust manager used to secure HTTPS connections.
If this is set, then sslSocketFactory must also be set.
If unset, then the system default is used. Most applications should not call this method, and instead use the system default. The default include special optimizations that can be lost if the implementation is modified.
-
trustManager
final ImageKitOkHttpClientAsync.Builder trustManager(Optional<X509TrustManager> trustManager)
Alias for calling Builder.trustManager with
trustManager.orElse(null).
-
hostnameVerifier
final ImageKitOkHttpClientAsync.Builder hostnameVerifier(HostnameVerifier hostnameVerifier)
The verifier used to confirm that response certificates apply to requested hostnames for HTTPS connections.
If unset, then a default hostname verifier is used.
-
hostnameVerifier
final ImageKitOkHttpClientAsync.Builder hostnameVerifier(Optional<HostnameVerifier> hostnameVerifier)
Alias for calling Builder.hostnameVerifier with
hostnameVerifier.orElse(null).
-
checkJacksonVersionCompatibility
final ImageKitOkHttpClientAsync.Builder checkJacksonVersionCompatibility(Boolean checkJacksonVersionCompatibility)
Whether to throw an exception if any of the Jackson versions detected at runtime are incompatible with the SDK's minimum supported Jackson version (2.13.4).
Defaults to true. Use extreme caution when disabling this option. There is no guarantee that the SDK will work correctly when using an incompatible Jackson version.
-
jsonMapper
final ImageKitOkHttpClientAsync.Builder jsonMapper(JsonMapper jsonMapper)
The Jackson JSON mapper to use for serializing and deserializing JSON.
Defaults to io.imagekit.core.jsonMapper. The default is usually sufficient and rarely needs to be overridden.
-
sleeper
final ImageKitOkHttpClientAsync.Builder sleeper(Sleeper sleeper)
The interface to use for delaying execution, like during retries.
This is primarily useful for using fake delays in tests.
Defaults to real execution delays.
This class takes ownership of the sleeper and closes it when closed.
-
clock
final ImageKitOkHttpClientAsync.Builder clock(Clock clock)
The clock to use for operations that require timing, like retries.
This is primarily useful for using a fake clock in tests.
Defaults to Clock.systemUTC.
-
baseUrl
final ImageKitOkHttpClientAsync.Builder baseUrl(String baseUrl)
The base URL to use for every request.
Defaults to the production environment:
https://api.imagekit.io.
-
baseUrl
final ImageKitOkHttpClientAsync.Builder baseUrl(Optional<String> baseUrl)
Alias for calling Builder.baseUrl with
baseUrl.orElse(null).
-
responseValidation
final ImageKitOkHttpClientAsync.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon every response before returning it.Setting this to
trueis not forwards compatible with new types from the API for existing fields.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final ImageKitOkHttpClientAsync.Builder timeout(Timeout timeout)
Sets the maximum time allowed for various parts of an HTTP call's lifecycle, excluding retries.
Defaults to Timeout.default.
-
timeout
final ImageKitOkHttpClientAsync.Builder timeout(Duration timeout)
Sets the maximum time allowed for a complete HTTP call, not including retries.
See Timeout.request for more details.
For fine-grained control, pass a Timeout object.
-
maxRetries
final ImageKitOkHttpClientAsync.Builder maxRetries(Integer maxRetries)
The maximum number of times to retry failed requests, with a short exponential backoff between requests.
Only the following error types are retried:
Connection errors (for example, due to a network connectivity problem)
408 Request Timeout
409 Conflict
429 Rate Limit
5xx Internal
The API may also explicitly instruct the SDK to retry or not retry a request.
Defaults to 2.
-
logLevel
final ImageKitOkHttpClientAsync.Builder logLevel(LogLevel logLevel)
The level at which to log request and response information.
fromEnv will set the level from environment variables. See LogLevel.fromEnv.
Defaults to LogLevel.fromEnv.
-
privateKey
final ImageKitOkHttpClientAsync.Builder privateKey(String privateKey)
Your ImageKit private API key (starts with
private_). You can find this in the ImageKit dashboard.
-
password
final ImageKitOkHttpClientAsync.Builder password(String password)
ImageKit uses your API key as username and ignores the password. The SDK sets a dummy value. You can ignore this field.
Defaults to
"do_not_set".
-
password
final ImageKitOkHttpClientAsync.Builder password(Optional<String> password)
Alias for calling Builder.password with
password.orElse(null).
-
webhookSecret
final ImageKitOkHttpClientAsync.Builder webhookSecret(String webhookSecret)
Your ImageKit webhook secret for verifying webhook signatures (starts with
whsec_). You can find this in the ImageKit dashboard. Only required if you are using webhooks.
-
webhookSecret
final ImageKitOkHttpClientAsync.Builder webhookSecret(Optional<String> webhookSecret)
Alias for calling Builder.webhookSecret with
webhookSecret.orElse(null).
-
headers
final ImageKitOkHttpClientAsync.Builder headers(Headers headers)
-
putHeader
final ImageKitOkHttpClientAsync.Builder putHeader(String name, String value)
-
putHeaders
final ImageKitOkHttpClientAsync.Builder putHeaders(String name, Iterable<String> values)
-
putAllHeaders
final ImageKitOkHttpClientAsync.Builder putAllHeaders(Headers headers)
-
putAllHeaders
final ImageKitOkHttpClientAsync.Builder putAllHeaders(Map<String, Iterable<String>> headers)
-
replaceHeaders
final ImageKitOkHttpClientAsync.Builder replaceHeaders(String name, String value)
-
replaceHeaders
final ImageKitOkHttpClientAsync.Builder replaceHeaders(String name, Iterable<String> values)
-
replaceAllHeaders
final ImageKitOkHttpClientAsync.Builder replaceAllHeaders(Headers headers)
-
replaceAllHeaders
final ImageKitOkHttpClientAsync.Builder replaceAllHeaders(Map<String, Iterable<String>> headers)
-
removeHeaders
final ImageKitOkHttpClientAsync.Builder removeHeaders(String name)
-
removeAllHeaders
final ImageKitOkHttpClientAsync.Builder removeAllHeaders(Set<String> names)
-
queryParams
final ImageKitOkHttpClientAsync.Builder queryParams(QueryParams queryParams)
-
queryParams
final ImageKitOkHttpClientAsync.Builder queryParams(Map<String, Iterable<String>> queryParams)
-
putQueryParam
final ImageKitOkHttpClientAsync.Builder putQueryParam(String key, String value)
-
putQueryParams
final ImageKitOkHttpClientAsync.Builder putQueryParams(String key, Iterable<String> values)
-
putAllQueryParams
final ImageKitOkHttpClientAsync.Builder putAllQueryParams(QueryParams queryParams)
-
putAllQueryParams
final ImageKitOkHttpClientAsync.Builder putAllQueryParams(Map<String, Iterable<String>> queryParams)
-
replaceQueryParams
final ImageKitOkHttpClientAsync.Builder replaceQueryParams(String key, String value)
-
replaceQueryParams
final ImageKitOkHttpClientAsync.Builder replaceQueryParams(String key, Iterable<String> values)
-
replaceAllQueryParams
final ImageKitOkHttpClientAsync.Builder replaceAllQueryParams(QueryParams queryParams)
-
replaceAllQueryParams
final ImageKitOkHttpClientAsync.Builder replaceAllQueryParams(Map<String, Iterable<String>> queryParams)
-
removeQueryParams
final ImageKitOkHttpClientAsync.Builder removeQueryParams(String key)
-
removeAllQueryParams
final ImageKitOkHttpClientAsync.Builder removeAllQueryParams(Set<String> keys)
-
fromEnv
final ImageKitOkHttpClientAsync.Builder fromEnv()
Updates configuration using system properties and environment variables.
-
build
final ImageKitClientAsync build()
Returns an immutable instance of ImageKitClientAsync.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-