Package io.imagekit.client
See: Description
-
Interface Summary Interface Description WithRawResponse A view of ImageKitClient that provides access to raw HTTP responses for each method. ImageKitClient A client for interacting with the Image Kit REST API synchronously. WithRawResponse A view of ImageKitClientAsync that provides access to raw HTTP responses for each method. ImageKitClientAsync A client for interacting with the Image Kit REST API asynchronously. -
Class Summary Class Description WithRawResponseImpl ImageKitClientAsyncImpl WithRawResponseImpl ImageKitClientImpl