Enum LogLevel

  • All Implemented Interfaces:
    java.io.Serializable , kotlin.Comparable

    
    public enum LogLevel
    extends Enum<LogLevel>
                        

    The level at which to log request and response information.

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public class LogLevel.Companion
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
      OFF

      No logging.

      INFO

      Minimal request and response summary logs. No headers or bodies are logged.

      ERROR

      INFO logs plus details about request failures.

      DEBUG

      Full request and response logs. Sensitive headers are redacted, but sensitive data in request and response bodies may still be visible.

    • Method Summary

      Modifier and Type Method Description
      final Boolean shouldLog(LogLevel level) Returns whether this level is at or higher than the given level.
      final LogLevel valueOf(String value) Returns the enum constant of this type with the specified name.
      final Array<LogLevel> values() Returns an array containing the constants of this enum type, in the order they're declared.
      final EnumEntries<LogLevel> getEntries() The level at which to log request and response information.
      • Methods inherited from class kotlin.Enum

        getName, getOrdinal
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Constructor Detail

    • Method Detail

      • valueOf

         final LogLevel valueOf(String value)

        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)

      • values

         final Array<LogLevel> values()

        Returns an array containing the constants of this enum type, in the order they're declared.

        This method may be used to iterate over the constants.