Package io.imagekit.core
Class RequestOptions.Builder
-
- All Implemented Interfaces:
public final class RequestOptions.Builder
-
-
Method Summary
Modifier and Type Method Description final RequestOptions.BuilderresponseValidation(Boolean responseValidation)Whether to call validateon the response before returning it.final RequestOptions.Buildertimeout(Timeout timeout)final RequestOptions.Buildertimeout(Duration timeout)final RequestOptionsbuild()-
-
Method Detail
-
responseValidation
final RequestOptions.Builder responseValidation(Boolean responseValidation)
Whether to call
validateon the response before returning it.Setting this to
trueis not forwards compatible with new types from the API for existing fields.Defaults to false, which means the shape of the response will not be validated upfront. Instead, validation will only occur for the parts of the response that are accessed.
-
timeout
final RequestOptions.Builder timeout(Timeout timeout)
-
timeout
final RequestOptions.Builder timeout(Duration timeout)
-
build
final RequestOptions build()
-
-
-
-