Package io.imagekit.core
Class UnwrapWebhookParams
-
- All Implemented Interfaces:
public final class UnwrapWebhookParams
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUnwrapWebhookParams.BuilderA builder for UnwrapWebhookParams.
-
Method Summary
Modifier and Type Method Description final Stringbody()The raw JSON body of the webhook request. final Optional<Headers>headers()The headers from the webhook request. final Optional<String>secret()The secret used to verify the webhook signature. final UnwrapWebhookParams.BuildertoBuilder()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UnwrapWebhookParams.Builderbuilder()Returns a mutable builder for constructing an instance of UnwrapWebhookParams. -
-
Method Detail
-
toBuilder
final UnwrapWebhookParams.Builder toBuilder()
-
builder
final static UnwrapWebhookParams.Builder builder()
Returns a mutable builder for constructing an instance of UnwrapWebhookParams.
The following fields are required:
.body()
-
-
-
-