Package io.imagekit.core.http
See: Description
-
Interface Summary Interface Description Handler A class for handling streaming events. AsyncStreamResponse A class providing access to an API response as an asynchronous stream of chunks of type T, where each chunk can be individually processed as soon as it arrives instead of waiting on the full response. HttpClient HttpRequestBody Handler HttpResponse HttpResponseFor ProxyAuthenticator Provides credentials when an HTTP proxy responds with 407 Proxy Authentication Required.StreamResponse -
Class Summary Class Description Builder Headers Builder HttpRequest Builder A builder for LoggingHttpClient. LoggingHttpClient A wrapper HttpClient around httpClient that logs request and response information. Builder QueryParams Builder RetryingHttpClient -
Enum Summary Enum Description HttpMethod -
Object Summary Object Description Companion