Package io.imagekit.errors
Class ImageKitRetryableException
-
- All Implemented Interfaces:
-
java.io.Serializable
public final class ImageKitRetryableException extends ImageKitException
Exception that indicates a transient error that can be retried.
When this exception is thrown during an HTTP request, the SDK will automatically retry the request up to the maximum number of retries.
-
-
Constructor Summary
Constructors Constructor Description ImageKitRetryableException(String message, Throwable cause)ImageKitRetryableException(String message)ImageKitRetryableException()
-
Method Summary
Modifier and Type Method Description -
Methods inherited from class kotlin.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Constructor Detail
-
ImageKitRetryableException
ImageKitRetryableException(String message, Throwable cause)
- Parameters:
message- A descriptive error messagecause- The underlying cause of this exception, if any
-
ImageKitRetryableException
ImageKitRetryableException(String message)
- Parameters:
message- A descriptive error message
-
ImageKitRetryableException
ImageKitRetryableException()
-
-
-
-