Package io.imagekit.errors
See: Description
-
Class Summary Class Description Builder A builder for BadRequestException. BadRequestException ImageKitException ImageKitInvalidDataException ImageKitIoException ImageKitRetryableException Exception that indicates a transient error that can be retried. ImageKitServiceException ImageKitWebhookException Builder A builder for InternalServerException. InternalServerException Builder A builder for NotFoundException. NotFoundException Builder A builder for PermissionDeniedException. PermissionDeniedException Builder A builder for RateLimitException. RateLimitException Builder A builder for UnauthorizedException. UnauthorizedException Builder A builder for UnexpectedStatusCodeException. UnexpectedStatusCodeException Builder A builder for UnprocessableEntityException. UnprocessableEntityException