Interface HelperService

  • All Implemented Interfaces:

    
    public interface HelperService
    
                        

    Helper service interface for ImageKit SDK operations like URL building, transformation string generation, and authentication parameter generation.

    You should not instantiate this service directly, and instead use it via the client:

    ImageKitClient client = ImageKitOkHttpClient.builder()
        .privateKey("private_key_xxx")
        .build();
    
    String url = client.helper().buildUrl(srcOptions);
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description