Class BaseOverlay.Builder
-
- All Implemented Interfaces:
public final class BaseOverlay.BuilderA builder for BaseOverlay.
-
-
Method Summary
Modifier and Type Method Description final BaseOverlay.BuilderlayerMode(BaseOverlay.LayerMode layerMode)Controls how the layer blends with the base image or underlying content. final BaseOverlay.BuilderlayerMode(JsonField<BaseOverlay.LayerMode> layerMode)Sets Builder.layerMode to an arbitrary JSON value. final BaseOverlay.Builderposition(OverlayPosition position)Specifies the overlay's position relative to the parent asset. final BaseOverlay.Builderposition(JsonField<OverlayPosition> position)Sets Builder.position to an arbitrary JSON value. final BaseOverlay.Buildertiming(OverlayTiming timing)Specifies timing information for the overlay (only applicable if the base asset is a video). final BaseOverlay.Buildertiming(JsonField<OverlayTiming> timing)Sets Builder.timing to an arbitrary JSON value. final BaseOverlay.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BaseOverlay.BuilderputAdditionalProperty(String key, JsonValue value)final BaseOverlay.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BaseOverlay.BuilderremoveAdditionalProperty(String key)final BaseOverlay.BuilderremoveAllAdditionalProperties(Set<String> keys)final BaseOverlaybuild()Returns an immutable instance of BaseOverlay. -
-
Method Detail
-
layerMode
final BaseOverlay.Builder layerMode(BaseOverlay.LayerMode layerMode)
Controls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
layerMode
final BaseOverlay.Builder layerMode(JsonField<BaseOverlay.LayerMode> layerMode)
Sets Builder.layerMode to an arbitrary JSON value.
You should usually call Builder.layerMode with a well-typed LayerMode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
position
final BaseOverlay.Builder position(OverlayPosition position)
Specifies the overlay's position relative to the parent asset. See Position of Layer.
-
position
final BaseOverlay.Builder position(JsonField<OverlayPosition> position)
Sets Builder.position to an arbitrary JSON value.
You should usually call Builder.position with a well-typed OverlayPosition value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timing
final BaseOverlay.Builder timing(OverlayTiming timing)
Specifies timing information for the overlay (only applicable if the base asset is a video). See Position of Layer.
-
timing
final BaseOverlay.Builder timing(JsonField<OverlayTiming> timing)
Sets Builder.timing to an arbitrary JSON value.
You should usually call Builder.timing with a well-typed OverlayTiming value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BaseOverlay.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BaseOverlay.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BaseOverlay.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BaseOverlay.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BaseOverlay.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BaseOverlay build()
Returns an immutable instance of BaseOverlay.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-