Package io.imagekit.models
Enum BaseOverlay.LayerMode.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum BaseOverlay.LayerMode.Known extends Enum<BaseOverlay.LayerMode.Known>
An enum containing LayerMode's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<BaseOverlay.LayerMode.Known>entries
-
Method Summary
Modifier and Type Method Description final BaseOverlay.LayerMode.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<BaseOverlay.LayerMode.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<BaseOverlay.LayerMode.Known>getEntries()An enum containing LayerMode's known values. -
-
Method Detail
-
valueOf
final BaseOverlay.LayerMode.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<BaseOverlay.LayerMode.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<BaseOverlay.LayerMode.Known> getEntries()
An enum containing LayerMode's known values.
-
-
-
-