Package io.imagekit.models
Class CustomMetadata
-
- All Implemented Interfaces:
public final class CustomMetadataA key-value data associated with the asset.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadata.BuilderA builder for CustomMetadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final CustomMetadata.BuildertoBuilder()final CustomMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomMetadata.Builder toBuilder()
-
validate
final CustomMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CustomMetadata.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadata.
-
-
-
-