Package io.imagekit.models
Class EmbeddedMetadata
-
- All Implemented Interfaces:
public final class EmbeddedMetadataConsolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classEmbeddedMetadata.BuilderA builder for EmbeddedMetadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final EmbeddedMetadata.BuildertoBuilder()final EmbeddedMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static EmbeddedMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of EmbeddedMetadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final EmbeddedMetadata.Builder toBuilder()
-
validate
final EmbeddedMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static EmbeddedMetadata.Builder builder()
Returns a mutable builder for constructing an instance of EmbeddedMetadata.
-
-
-
-