Package io.imagekit.models
Class ExtensionConfig.AiTasks
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtensionConfig.AiTasks.BuilderA builder for AiTasks.
public final classExtensionConfig.AiTasks.Task
-
Method Summary
Modifier and Type Method Description final JsonValue_name()Specifies the AI tasks extension for automated image analysis using AI models. final List<ExtensionConfig.AiTasks.Task>tasks()Array of task objects defining AI operations to perform on the asset. final JsonField<List<ExtensionConfig.AiTasks.Task>>_tasks()Returns the raw JSON value of tasks. final Map<String, JsonValue>_additionalProperties()final ExtensionConfig.AiTasks.BuildertoBuilder()final ExtensionConfig.AiTasksvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtensionConfig.AiTasks.Builderbuilder()Returns a mutable builder for constructing an instance of AiTasks. -
-
Method Detail
-
_name
final JsonValue _name()
Specifies the AI tasks extension for automated image analysis using AI models.
Expected to always return the following:
JsonValue.from("ai-tasks")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
tasks
final List<ExtensionConfig.AiTasks.Task> tasks()
Array of task objects defining AI operations to perform on the asset.
-
_tasks
final JsonField<List<ExtensionConfig.AiTasks.Task>> _tasks()
Returns the raw JSON value of tasks.
Unlike tasks, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtensionConfig.AiTasks.Builder toBuilder()
-
validate
final ExtensionConfig.AiTasks validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExtensionConfig.AiTasks.Builder builder()
Returns a mutable builder for constructing an instance of AiTasks.
The following fields are required:
.tasks()
-
-
-
-