Class ExtensionConfig.AiTasks.Task.SelectMetadata.Builder
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks.Task.SelectMetadata.BuilderA builder for SelectMetadata.
-
-
Method Summary
-
-
Method Detail
-
field
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder field(String field)
Name of the custom metadata field to set. The field must exist in your account.
-
field
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder field(JsonField<String> field)
Sets Builder.field to an arbitrary JSON value.
You should usually call Builder.field with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
instruction
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder instruction(String instruction)
The question or instruction for the AI to analyze the image.
-
instruction
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder instruction(JsonField<String> instruction)
Sets Builder.instruction to an arbitrary JSON value.
You should usually call Builder.instruction with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("select_metadata")This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxSelections
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder maxSelections(Long maxSelections)
Maximum number of values to select from the vocabulary.
-
maxSelections
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder maxSelections(JsonField<Long> maxSelections)
Sets Builder.maxSelections to an arbitrary JSON value.
You should usually call Builder.maxSelections with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minSelections
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder minSelections(Long minSelections)
Minimum number of values to select from the vocabulary.
-
minSelections
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder minSelections(JsonField<Long> minSelections)
Sets Builder.minSelections to an arbitrary JSON value.
You should usually call Builder.minSelections with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
vocabulary
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder vocabulary(List<ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary> vocabulary)
An array of possible values matching the custom metadata field type. If not provided for SingleSelect or MultiSelect field types, all values from the custom metadata field definition will be used. When providing large vocabularies (above 30 items), the AI may not strictly adhere to the list.
-
vocabulary
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder vocabulary(JsonField<List<ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary>> vocabulary)
Sets Builder.vocabulary to an arbitrary JSON value.
You should usually call Builder.vocabulary with a well-typed
List<Vocabulary>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVocabulary
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder addVocabulary(ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary vocabulary)
Adds a single Vocabulary to Builder.vocabulary.
-
addVocabulary
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder addVocabulary(String string)
Alias for calling addVocabulary with
Vocabulary.ofString(string).
-
addVocabulary
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder addVocabulary(Double number)
Alias for calling addVocabulary with
Vocabulary.ofNumber(number).
-
addVocabulary
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder addVocabulary(Boolean bool)
Alias for calling addVocabulary with
Vocabulary.ofBool(bool).
-
additionalProperties
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExtensionConfig.AiTasks.Task.SelectMetadata.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExtensionConfig.AiTasks.Task.SelectMetadata build()
Returns an immutable instance of SelectMetadata.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.field() .instruction()
-
-
-
-