Package io.imagekit.models
Class ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary.VisitorAn interface that defines how to map each variant of Vocabulary to a value of type T.
-
Method Summary
-
-
Method Detail
-
accept
final <T extends Any> T accept(ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = vocabulary.accept(new Vocabulary.Visitor<Optional<String>>() { @Override public Optional<String> visitString(String string) { return Optional.of(string.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofString
final static ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary ofString(String string)
-
ofNumber
final static ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary ofNumber(Double number)
-
ofBool
final static ExtensionConfig.AiTasks.Task.SelectMetadata.Vocabulary ofBool(Boolean bool)
-
-
-
-