Class ExtensionConfig.AiTasks.Task.YesNo.Builder
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks.Task.YesNo.BuilderA builder for YesNo.
-
-
Method Summary
-
-
Method Detail
-
instruction
final ExtensionConfig.AiTasks.Task.YesNo.Builder instruction(String instruction)
The yes/no question for the AI to answer about the image.
-
instruction
final ExtensionConfig.AiTasks.Task.YesNo.Builder instruction(JsonField<String> instruction)
Sets Builder.instruction to an arbitrary JSON value.
You should usually call Builder.instruction with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ExtensionConfig.AiTasks.Task.YesNo.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("yes_no")This method is primarily for setting the field to an undocumented or not yet supported value.
-
onNo
final ExtensionConfig.AiTasks.Task.YesNo.Builder onNo(ExtensionConfig.AiTasks.Task.YesNo.OnNo onNo)
Actions to execute if the AI answers no.
-
onNo
final ExtensionConfig.AiTasks.Task.YesNo.Builder onNo(JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnNo> onNo)
Sets Builder.onNo to an arbitrary JSON value.
You should usually call Builder.onNo with a well-typed OnNo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
onUnknown
final ExtensionConfig.AiTasks.Task.YesNo.Builder onUnknown(ExtensionConfig.AiTasks.Task.YesNo.OnUnknown onUnknown)
Actions to execute if the AI cannot determine the answer.
-
onUnknown
final ExtensionConfig.AiTasks.Task.YesNo.Builder onUnknown(JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnUnknown> onUnknown)
Sets Builder.onUnknown to an arbitrary JSON value.
You should usually call Builder.onUnknown with a well-typed OnUnknown value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
onYes
final ExtensionConfig.AiTasks.Task.YesNo.Builder onYes(ExtensionConfig.AiTasks.Task.YesNo.OnYes onYes)
Actions to execute if the AI answers yes.
-
onYes
final ExtensionConfig.AiTasks.Task.YesNo.Builder onYes(JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnYes> onYes)
Sets Builder.onYes to an arbitrary JSON value.
You should usually call Builder.onYes with a well-typed OnYes value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExtensionConfig.AiTasks.Task.YesNo.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExtensionConfig.AiTasks.Task.YesNo.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExtensionConfig.AiTasks.Task.YesNo.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExtensionConfig.AiTasks.Task.YesNo.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExtensionConfig.AiTasks.Task.YesNo.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExtensionConfig.AiTasks.Task.YesNo build()
Returns an immutable instance of YesNo.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.instruction()
-
-
-
-