Package io.imagekit.models
Class ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.ValueValue to set for the custom metadata field. The value type should match the custom metadata field type.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value.VisitorAn interface that defines how to map each variant of Value to a value of type T.
public final classExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value.MetadataValueItem
-
Method Summary
-
-
Method Detail
-
mixed
final Optional<List<ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value.MetadataValueItem>> mixed()
-
asMixed
final List<ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value.MetadataValueItem> asMixed()
-
accept
final <T extends Any> T accept(ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = value.accept(new Value.Visitor<Optional<String>>() { @Override public Optional<String> visitString(String string) { return Optional.of(string.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofString
final static ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value ofString(String string)
-
ofNumber
final static ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value ofNumber(Double number)
-
ofBool
final static ExtensionConfig.AiTasks.Task.YesNo.OnNo.SetMetadata.Value ofBool(Boolean bool)
-
-
-
-