Class ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.BuilderA builder for SetMetadata.
public final classExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.ValueValue to set for the custom metadata field. The value type should match the custom metadata field type.
-
Method Summary
Modifier and Type Method Description final Stringfield()Name of the custom metadata field to set. final ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Valuevalue()Value to set for the custom metadata field. final JsonField<String>_field()Returns the raw JSON value of field. final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Value>_value()Returns the raw JSON value of value. final Map<String, JsonValue>_additionalProperties()final ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.BuildertoBuilder()final ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of SetMetadata. -
-
Method Detail
-
value
final ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Value value()
Value to set for the custom metadata field. The value type should match the custom metadata field type.
-
_field
final JsonField<String> _field()
Returns the raw JSON value of field.
Unlike field, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Builder toBuilder()
-
validate
final ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExtensionConfig.AiTasks.Task.YesNo.OnYes.SetMetadata.Builder builder()
Returns a mutable builder for constructing an instance of SetMetadata.
The following fields are required:
.field() .value()
-
-
-
-