Class ExtensionConfig.AutoTaggingExtension
-
- All Implemented Interfaces:
public final class ExtensionConfig.AutoTaggingExtension
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtensionConfig.AutoTaggingExtension.BuilderA builder for AutoTaggingExtension.
public final classExtensionConfig.AutoTaggingExtension.NameSpecifies the auto-tagging extension used.
-
Method Summary
Modifier and Type Method Description final LongmaxTags()Maximum number of tags to attach to the asset. final LongminConfidence()Minimum confidence level for tags to be considered valid. final ExtensionConfig.AutoTaggingExtension.Namename()Specifies the auto-tagging extension used. final JsonField<Long>_maxTags()Returns the raw JSON value of maxTags. final JsonField<Long>_minConfidence()Returns the raw JSON value of minConfidence. final JsonField<ExtensionConfig.AutoTaggingExtension.Name>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final ExtensionConfig.AutoTaggingExtension.BuildertoBuilder()final ExtensionConfig.AutoTaggingExtensionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtensionConfig.AutoTaggingExtension.Builderbuilder()Returns a mutable builder for constructing an instance of AutoTaggingExtension. -
-
Method Detail
-
minConfidence
final Long minConfidence()
Minimum confidence level for tags to be considered valid.
-
name
final ExtensionConfig.AutoTaggingExtension.Name name()
Specifies the auto-tagging extension used.
-
_maxTags
final JsonField<Long> _maxTags()
Returns the raw JSON value of maxTags.
Unlike maxTags, this method doesn't throw if the JSON field has an unexpected type.
-
_minConfidence
final JsonField<Long> _minConfidence()
Returns the raw JSON value of minConfidence.
Unlike minConfidence, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<ExtensionConfig.AutoTaggingExtension.Name> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtensionConfig.AutoTaggingExtension.Builder toBuilder()
-
validate
final ExtensionConfig.AutoTaggingExtension validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ExtensionConfig.AutoTaggingExtension.Builder builder()
Returns a mutable builder for constructing an instance of AutoTaggingExtension.
The following fields are required:
.maxTags() .minConfidence() .name()
-
-
-
-