Class ExtensionConfig.RemoveBg.Options.Builder
-
- All Implemented Interfaces:
public final class ExtensionConfig.RemoveBg.Options.BuilderA builder for Options.
-
-
Method Summary
-
-
Method Detail
-
addShadow
final ExtensionConfig.RemoveBg.Options.Builder addShadow(Boolean addShadow)
Whether to add an artificial shadow to the result. Default is false. Note: Adding shadows is currently only supported for car photos.
-
addShadow
final ExtensionConfig.RemoveBg.Options.Builder addShadow(JsonField<Boolean> addShadow)
Sets Builder.addShadow to an arbitrary JSON value.
You should usually call Builder.addShadow with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bgColor
final ExtensionConfig.RemoveBg.Options.Builder bgColor(String bgColor)
Specifies a solid color background using hex code (e.g., "81d4fa", "fff") or color name (e.g., "green"). If this parameter is set,
bg_image_urlmust be empty.
-
bgColor
final ExtensionConfig.RemoveBg.Options.Builder bgColor(JsonField<String> bgColor)
Sets Builder.bgColor to an arbitrary JSON value.
You should usually call Builder.bgColor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bgImageUrl
final ExtensionConfig.RemoveBg.Options.Builder bgImageUrl(String bgImageUrl)
Sets a background image from a URL. If this parameter is set,
bg_colormust be empty.
-
bgImageUrl
final ExtensionConfig.RemoveBg.Options.Builder bgImageUrl(JsonField<String> bgImageUrl)
Sets Builder.bgImageUrl to an arbitrary JSON value.
You should usually call Builder.bgImageUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
semitransparency
final ExtensionConfig.RemoveBg.Options.Builder semitransparency(Boolean semitransparency)
Allows semi-transparent regions in the result. Default is true. Note: Semitransparency is currently only supported for car windows.
-
semitransparency
final ExtensionConfig.RemoveBg.Options.Builder semitransparency(JsonField<Boolean> semitransparency)
Sets Builder.semitransparency to an arbitrary JSON value.
You should usually call Builder.semitransparency with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ExtensionConfig.RemoveBg.Options.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ExtensionConfig.RemoveBg.Options.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ExtensionConfig.RemoveBg.Options.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ExtensionConfig.RemoveBg.Options.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ExtensionConfig.RemoveBg.Options.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ExtensionConfig.RemoveBg.Options build()
Returns an immutable instance of Options.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-