Class GetImageAttributesOptions

  • All Implemented Interfaces:

    
    public final class GetImageAttributesOptions
    
                        

    Options for generating responsive image attributes including src, srcSet, and sizes for HTML <img> elements. This schema extends SrcOptions to add support for responsive image generation with breakpoints.