Class ImageOverlay.Builder
-
- All Implemented Interfaces:
public final class ImageOverlay.BuilderA builder for ImageOverlay.
-
-
Method Summary
Modifier and Type Method Description final ImageOverlay.BuilderlayerMode(BaseOverlay.LayerMode layerMode)Controls how the layer blends with the base image or underlying content. final ImageOverlay.BuilderlayerMode(JsonField<BaseOverlay.LayerMode> layerMode)Sets Builder.layerMode to an arbitrary JSON value. final ImageOverlay.Builderposition(OverlayPosition position)Specifies the overlay's position relative to the parent asset. final ImageOverlay.Builderposition(JsonField<OverlayPosition> position)Sets Builder.position to an arbitrary JSON value. final ImageOverlay.Buildertiming(OverlayTiming timing)Specifies timing information for the overlay (only applicable if the base asset is a video). final ImageOverlay.Buildertiming(JsonField<OverlayTiming> timing)Sets Builder.timing to an arbitrary JSON value. final ImageOverlay.Builderinput(String input)Specifies the relative path to the image used as an overlay. final ImageOverlay.Builderinput(JsonField<String> input)Sets Builder.input to an arbitrary JSON value. final ImageOverlay.Buildertype(JsonValue type)Sets the field to an arbitrary JSON value. final ImageOverlay.Builderencoding(ImageOverlay.Encoding encoding)The input path can be included in the layer as either i-{input}orie-{base64_encoded_input}.final ImageOverlay.Builderencoding(JsonField<ImageOverlay.Encoding> encoding)Sets Builder.encoding to an arbitrary JSON value. final ImageOverlay.Buildertransformation(List<Transformation> transformation)Array of transformations to be applied to the overlay image. final ImageOverlay.Buildertransformation(JsonField<List<Transformation>> transformation)Sets Builder.transformation to an arbitrary JSON value. final ImageOverlay.BuilderaddTransformation(Transformation transformation)Adds a single Transformation to Builder.transformation. final ImageOverlay.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final ImageOverlay.BuilderputAdditionalProperty(String key, JsonValue value)final ImageOverlay.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final ImageOverlay.BuilderremoveAdditionalProperty(String key)final ImageOverlay.BuilderremoveAllAdditionalProperties(Set<String> keys)final ImageOverlaybuild()Returns an immutable instance of ImageOverlay. -
-
Method Detail
-
layerMode
final ImageOverlay.Builder layerMode(BaseOverlay.LayerMode layerMode)
Controls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
layerMode
final ImageOverlay.Builder layerMode(JsonField<BaseOverlay.LayerMode> layerMode)
Sets Builder.layerMode to an arbitrary JSON value.
You should usually call Builder.layerMode with a well-typed BaseOverlay.LayerMode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
position
final ImageOverlay.Builder position(OverlayPosition position)
Specifies the overlay's position relative to the parent asset. See Position of Layer.
-
position
final ImageOverlay.Builder position(JsonField<OverlayPosition> position)
Sets Builder.position to an arbitrary JSON value.
You should usually call Builder.position with a well-typed OverlayPosition value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timing
final ImageOverlay.Builder timing(OverlayTiming timing)
Specifies timing information for the overlay (only applicable if the base asset is a video). See Position of Layer.
-
timing
final ImageOverlay.Builder timing(JsonField<OverlayTiming> timing)
Sets Builder.timing to an arbitrary JSON value.
You should usually call Builder.timing with a well-typed OverlayTiming value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
input
final ImageOverlay.Builder input(String input)
Specifies the relative path to the image used as an overlay.
-
input
final ImageOverlay.Builder input(JsonField<String> input)
Sets Builder.input to an arbitrary JSON value.
You should usually call Builder.input with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final ImageOverlay.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("image")This method is primarily for setting the field to an undocumented or not yet supported value.
-
encoding
final ImageOverlay.Builder encoding(ImageOverlay.Encoding encoding)
The input path can be included in the layer as either
i-{input}orie-{base64_encoded_input}. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (ie-{base64}), set this parameter tobase64. To always use plain text (i-{input}), set it toplain.Regardless of the encoding method:
Leading and trailing slashes are removed.
Remaining slashes within the path are replaced with
@@when using plain text.
-
encoding
final ImageOverlay.Builder encoding(JsonField<ImageOverlay.Encoding> encoding)
Sets Builder.encoding to an arbitrary JSON value.
You should usually call Builder.encoding with a well-typed Encoding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transformation
final ImageOverlay.Builder transformation(List<Transformation> transformation)
Array of transformations to be applied to the overlay image. Supported transformations depends on the base/parent asset. See overlays on Images and Videos.
-
transformation
final ImageOverlay.Builder transformation(JsonField<List<Transformation>> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed
List<Transformation>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTransformation
final ImageOverlay.Builder addTransformation(Transformation transformation)
Adds a single Transformation to Builder.transformation.
-
additionalProperties
final ImageOverlay.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ImageOverlay.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ImageOverlay.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ImageOverlay.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ImageOverlay.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ImageOverlay build()
Returns an immutable instance of ImageOverlay.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.input()
-
-
-
-