Interface Overlay.Visitor

  • All Implemented Interfaces:

    
    public interface Overlay.Visitor<T extends Object>
    
                        

    An interface that defines how to map each variant of Overlay to a value of type T.