Class OverlayPosition
-
- All Implemented Interfaces:
public final class OverlayPosition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOverlayPosition.BuilderA builder for OverlayPosition.
public final classOverlayPosition.AnchorPointSets the anchor point on the base asset from which the overlay offset is calculated. The default value is
top_left. Maps tolapin the URL. Can only be used with one or more ofx,y,xCenter, oryCenter.public final classOverlayPosition.FocusSpecifies the position of the overlay relative to the parent image or video. If one or more of
x,y,xCenter, oryCenterparameters are specified, this parameter is ignored. Maps tolfoin the URL.public final classOverlayPosition.XSpecifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxin the URL. Learn about Arithmetic expressions.public final classOverlayPosition.XCenterSpecifies the x-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxcin the URL. Cannot be used together withx, but can be used withy. Learn about Arithmetic expressions.public final classOverlayPosition.YSpecifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolyin the URL. Learn about Arithmetic expressions.public final classOverlayPosition.YCenterSpecifies the y-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolycin the URL. Cannot be used together withy, but can be used withx. Learn about Arithmetic expressions.
-
Method Summary
Modifier and Type Method Description final Optional<OverlayPosition.AnchorPoint>anchorPoint()Sets the anchor point on the base asset from which the overlay offset is calculated. final Optional<OverlayPosition.Focus>focus()Specifies the position of the overlay relative to the parent image or video. final Optional<OverlayPosition.X>x()Specifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. final Optional<OverlayPosition.XCenter>xCenter()Specifies the x-coordinate on the base asset where the overlay's center will be positioned. final Optional<OverlayPosition.Y>y()Specifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. final Optional<OverlayPosition.YCenter>yCenter()Specifies the y-coordinate on the base asset where the overlay's center will be positioned. final JsonField<OverlayPosition.AnchorPoint>_anchorPoint()Returns the raw JSON value of anchorPoint. final JsonField<OverlayPosition.Focus>_focus()Returns the raw JSON value of focus. final JsonField<OverlayPosition.X>_x()Returns the raw JSON value of x. final JsonField<OverlayPosition.XCenter>_xCenter()Returns the raw JSON value of xCenter. final JsonField<OverlayPosition.Y>_y()Returns the raw JSON value of y. final JsonField<OverlayPosition.YCenter>_yCenter()Returns the raw JSON value of yCenter. final Map<String, JsonValue>_additionalProperties()final OverlayPosition.BuildertoBuilder()final OverlayPositionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayPosition.Builderbuilder()Returns a mutable builder for constructing an instance of OverlayPosition. -
-
Method Detail
-
anchorPoint
final Optional<OverlayPosition.AnchorPoint> anchorPoint()
Sets the anchor point on the base asset from which the overlay offset is calculated. The default value is
top_left. Maps tolapin the URL. Can only be used with one or more ofx,y,xCenter, oryCenter.
-
focus
final Optional<OverlayPosition.Focus> focus()
Specifies the position of the overlay relative to the parent image or video. If one or more of
x,y,xCenter, oryCenterparameters are specified, this parameter is ignored. Maps tolfoin the URL.
-
x
final Optional<OverlayPosition.X> x()
Specifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxin the URL. Learn about Arithmetic expressions.
-
xCenter
final Optional<OverlayPosition.XCenter> xCenter()
Specifies the x-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxcin the URL. Cannot be used together withx, but can be used withy. Learn about Arithmetic expressions.
-
y
final Optional<OverlayPosition.Y> y()
Specifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolyin the URL. Learn about Arithmetic expressions.
-
yCenter
final Optional<OverlayPosition.YCenter> yCenter()
Specifies the y-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolycin the URL. Cannot be used together withy, but can be used withx. Learn about Arithmetic expressions.
-
_anchorPoint
final JsonField<OverlayPosition.AnchorPoint> _anchorPoint()
Returns the raw JSON value of anchorPoint.
Unlike anchorPoint, this method doesn't throw if the JSON field has an unexpected type.
-
_focus
final JsonField<OverlayPosition.Focus> _focus()
Returns the raw JSON value of focus.
Unlike focus, this method doesn't throw if the JSON field has an unexpected type.
-
_x
final JsonField<OverlayPosition.X> _x()
Returns the raw JSON value of x.
Unlike x, this method doesn't throw if the JSON field has an unexpected type.
-
_xCenter
final JsonField<OverlayPosition.XCenter> _xCenter()
Returns the raw JSON value of xCenter.
Unlike xCenter, this method doesn't throw if the JSON field has an unexpected type.
-
_y
final JsonField<OverlayPosition.Y> _y()
Returns the raw JSON value of y.
Unlike y, this method doesn't throw if the JSON field has an unexpected type.
-
_yCenter
final JsonField<OverlayPosition.YCenter> _yCenter()
Returns the raw JSON value of yCenter.
Unlike yCenter, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OverlayPosition.Builder toBuilder()
-
validate
final OverlayPosition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OverlayPosition.Builder builder()
Returns a mutable builder for constructing an instance of OverlayPosition.
-
-
-
-