Class OverlayPosition.Builder
-
- All Implemented Interfaces:
public final class OverlayPosition.BuilderA builder for OverlayPosition.
-
-
Method Summary
Modifier and Type Method Description final OverlayPosition.BuilderanchorPoint(OverlayPosition.AnchorPoint anchorPoint)Sets the anchor point on the base asset from which the overlay offset is calculated. final OverlayPosition.BuilderanchorPoint(JsonField<OverlayPosition.AnchorPoint> anchorPoint)Sets Builder.anchorPoint to an arbitrary JSON value. final OverlayPosition.Builderfocus(OverlayPosition.Focus focus)Specifies the position of the overlay relative to the parent image or video. final OverlayPosition.Builderfocus(JsonField<OverlayPosition.Focus> focus)Sets Builder.focus to an arbitrary JSON value. final OverlayPosition.Builderx(OverlayPosition.X x)Specifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. final OverlayPosition.Builderx(JsonField<OverlayPosition.X> x)Sets Builder.x to an arbitrary JSON value. final OverlayPosition.Builderx(Double number)Alias for calling x with X.ofNumber(number).final OverlayPosition.Builderx(String string)Alias for calling x with X.ofString(string).final OverlayPosition.BuilderxCenter(OverlayPosition.XCenter xCenter)Specifies the x-coordinate on the base asset where the overlay's center will be positioned. final OverlayPosition.BuilderxCenter(JsonField<OverlayPosition.XCenter> xCenter)Sets Builder.xCenter to an arbitrary JSON value. final OverlayPosition.BuilderxCenter(Double number)Alias for calling xCenter with XCenter.ofNumber(number).final OverlayPosition.BuilderxCenter(String string)Alias for calling xCenter with XCenter.ofString(string).final OverlayPosition.Buildery(OverlayPosition.Y y)Specifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. final OverlayPosition.Buildery(JsonField<OverlayPosition.Y> y)Sets Builder.y to an arbitrary JSON value. final OverlayPosition.Buildery(Double number)Alias for calling y with Y.ofNumber(number).final OverlayPosition.Buildery(String string)Alias for calling y with Y.ofString(string).final OverlayPosition.BuilderyCenter(OverlayPosition.YCenter yCenter)Specifies the y-coordinate on the base asset where the overlay's center will be positioned. final OverlayPosition.BuilderyCenter(JsonField<OverlayPosition.YCenter> yCenter)Sets Builder.yCenter to an arbitrary JSON value. final OverlayPosition.BuilderyCenter(Double number)Alias for calling yCenter with YCenter.ofNumber(number).final OverlayPosition.BuilderyCenter(String string)Alias for calling yCenter with YCenter.ofString(string).final OverlayPosition.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final OverlayPosition.BuilderputAdditionalProperty(String key, JsonValue value)final OverlayPosition.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final OverlayPosition.BuilderremoveAdditionalProperty(String key)final OverlayPosition.BuilderremoveAllAdditionalProperties(Set<String> keys)final OverlayPositionbuild()Returns an immutable instance of OverlayPosition. -
-
Method Detail
-
anchorPoint
final OverlayPosition.Builder anchorPoint(OverlayPosition.AnchorPoint anchorPoint)
Sets the anchor point on the base asset from which the overlay offset is calculated. The default value is
top_left. Maps tolapin the URL. Can only be used with one or more ofx,y,xCenter, oryCenter.
-
anchorPoint
final OverlayPosition.Builder anchorPoint(JsonField<OverlayPosition.AnchorPoint> anchorPoint)
Sets Builder.anchorPoint to an arbitrary JSON value.
You should usually call Builder.anchorPoint with a well-typed AnchorPoint value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
focus
final OverlayPosition.Builder focus(OverlayPosition.Focus focus)
Specifies the position of the overlay relative to the parent image or video. If one or more of
x,y,xCenter, oryCenterparameters are specified, this parameter is ignored. Maps tolfoin the URL.
-
focus
final OverlayPosition.Builder focus(JsonField<OverlayPosition.Focus> focus)
Sets Builder.focus to an arbitrary JSON value.
You should usually call Builder.focus with a well-typed Focus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
x
final OverlayPosition.Builder x(OverlayPosition.X x)
Specifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxin the URL. Learn about Arithmetic expressions.
-
x
final OverlayPosition.Builder x(JsonField<OverlayPosition.X> x)
Sets Builder.x to an arbitrary JSON value.
You should usually call Builder.x with a well-typed X value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
x
final OverlayPosition.Builder x(Double number)
Alias for calling x with
X.ofNumber(number).
-
x
final OverlayPosition.Builder x(String string)
Alias for calling x with
X.ofString(string).
-
xCenter
final OverlayPosition.Builder xCenter(OverlayPosition.XCenter xCenter)
Specifies the x-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxcin the URL. Cannot be used together withx, but can be used withy. Learn about Arithmetic expressions.
-
xCenter
final OverlayPosition.Builder xCenter(JsonField<OverlayPosition.XCenter> xCenter)
Sets Builder.xCenter to an arbitrary JSON value.
You should usually call Builder.xCenter with a well-typed XCenter value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
xCenter
final OverlayPosition.Builder xCenter(Double number)
Alias for calling xCenter with
XCenter.ofNumber(number).
-
xCenter
final OverlayPosition.Builder xCenter(String string)
Alias for calling xCenter with
XCenter.ofString(string).
-
y
final OverlayPosition.Builder y(OverlayPosition.Y y)
Specifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolyin the URL. Learn about Arithmetic expressions.
-
y
final OverlayPosition.Builder y(JsonField<OverlayPosition.Y> y)
Sets Builder.y to an arbitrary JSON value.
You should usually call Builder.y with a well-typed Y value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
y
final OverlayPosition.Builder y(Double number)
Alias for calling y with
Y.ofNumber(number).
-
y
final OverlayPosition.Builder y(String string)
Alias for calling y with
Y.ofString(string).
-
yCenter
final OverlayPosition.Builder yCenter(OverlayPosition.YCenter yCenter)
Specifies the y-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolycin the URL. Cannot be used together withy, but can be used withx. Learn about Arithmetic expressions.
-
yCenter
final OverlayPosition.Builder yCenter(JsonField<OverlayPosition.YCenter> yCenter)
Sets Builder.yCenter to an arbitrary JSON value.
You should usually call Builder.yCenter with a well-typed YCenter value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
yCenter
final OverlayPosition.Builder yCenter(Double number)
Alias for calling yCenter with
YCenter.ofNumber(number).
-
yCenter
final OverlayPosition.Builder yCenter(String string)
Alias for calling yCenter with
YCenter.ofString(string).
-
additionalProperties
final OverlayPosition.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final OverlayPosition.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final OverlayPosition.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final OverlayPosition.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final OverlayPosition.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final OverlayPosition build()
Returns an immutable instance of OverlayPosition.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-