Package io.imagekit.models
Enum OverlayPosition.Focus.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum OverlayPosition.Focus.Known extends Enum<OverlayPosition.Focus.Known>
An enum containing Focus's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<OverlayPosition.Focus.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description CENTERTOPLEFTBOTTOMRIGHTTOP_LEFTTOP_RIGHTBOTTOM_LEFTBOTTOM_RIGHT
-
Method Summary
Modifier and Type Method Description final OverlayPosition.Focus.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<OverlayPosition.Focus.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<OverlayPosition.Focus.Known>getEntries()An enum containing Focus's known values. -
-
Method Detail
-
valueOf
final OverlayPosition.Focus.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<OverlayPosition.Focus.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<OverlayPosition.Focus.Known> getEntries()
An enum containing Focus's known values.
-
-
-
-