Package io.imagekit.models
Class OverlayPosition.X
-
- All Implemented Interfaces:
public final class OverlayPosition.XSpecifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxin the URL. Learn about Arithmetic expressions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOverlayPosition.X.VisitorAn interface that defines how to map each variant of X to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(OverlayPosition.X.Visitor<T> visitor)final OverlayPosition.Xvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayPosition.XofNumber(Double number)final static OverlayPosition.XofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(OverlayPosition.X.Visitor<T> visitor)
-
validate
final OverlayPosition.X validate()
-
ofNumber
final static OverlayPosition.X ofNumber(Double number)
-
ofString
final static OverlayPosition.X ofString(String string)
-
-
-
-