Class OverlayPosition.XCenter
-
- All Implemented Interfaces:
public final class OverlayPosition.XCenterSpecifies the x-coordinate on the base asset where the overlay's center will be positioned. It also accepts arithmetic expressions such as
bw_mul_0.4orbw_sub_cw. Maps tolxcin the URL. Cannot be used together withx, but can be used withy. Learn about Arithmetic expressions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOverlayPosition.XCenter.VisitorAn interface that defines how to map each variant of XCenter to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(OverlayPosition.XCenter.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final OverlayPosition.XCentervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayPosition.XCenterofNumber(Double number)final static OverlayPosition.XCenterofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(OverlayPosition.XCenter.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = xCenter.accept(new XCenter.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final OverlayPosition.XCenter validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static OverlayPosition.XCenter ofNumber(Double number)
-
ofString
final static OverlayPosition.XCenter ofString(String string)
-
-
-
-