Package io.imagekit.models
Class OverlayPosition.Y
-
- All Implemented Interfaces:
public final class OverlayPosition.YSpecifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. It also accepts arithmetic expressions such as
bh_mul_0.4orbh_sub_ch. Maps tolyin the URL. Learn about Arithmetic expressions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOverlayPosition.Y.VisitorAn interface that defines how to map each variant of Y to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(OverlayPosition.Y.Visitor<T> visitor)final OverlayPosition.Yvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayPosition.YofNumber(Double number)final static OverlayPosition.YofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(OverlayPosition.Y.Visitor<T> visitor)
-
validate
final OverlayPosition.Y validate()
-
ofNumber
final static OverlayPosition.Y ofNumber(Double number)
-
ofString
final static OverlayPosition.Y ofString(String string)
-
-
-
-