Class OverlayTiming

    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      public final class OverlayTiming.Builder

      A builder for OverlayTiming.

      public final class OverlayTiming.Duration

      Specifies the duration (in seconds) during which the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to ldu in the URL.

      public final class OverlayTiming.End

      Specifies the end time (in seconds) for when the overlay should disappear from the base video. If both end and duration are provided, duration is ignored. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to leo in the URL.

      public final class OverlayTiming.Start

      Specifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to lso in the URL.

    • Field Summary

      Fields 
      Modifier and Type Field Description
    • Constructor Summary

      Constructors 
      Constructor Description
    • Enum Constant Summary

      Enum Constants 
      Enum Constant Description
    • Constructor Detail

    • Method Detail

      • duration

         final Optional<OverlayTiming.Duration> duration()

        Specifies the duration (in seconds) during which the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to ldu in the URL.

      • end

         final Optional<OverlayTiming.End> end()

        Specifies the end time (in seconds) for when the overlay should disappear from the base video. If both end and duration are provided, duration is ignored. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to leo in the URL.

      • start

         final Optional<OverlayTiming.Start> start()

        Specifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to lso in the URL.

      • validate

         final OverlayTiming validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.