Class OverlayTiming.Duration
-
- All Implemented Interfaces:
public final class OverlayTiming.DurationSpecifies the duration (in seconds) during which the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps tolduin the URL.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOverlayTiming.Duration.VisitorAn interface that defines how to map each variant of Duration to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(OverlayTiming.Duration.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final OverlayTiming.Durationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayTiming.DurationofNumber(Double number)final static OverlayTiming.DurationofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(OverlayTiming.Duration.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = duration.accept(new Duration.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final OverlayTiming.Duration validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static OverlayTiming.Duration ofNumber(Double number)
-
ofString
final static OverlayTiming.Duration ofString(String string)
-
-
-
-