Package io.imagekit.models
Interface OverlayTiming.Duration.Visitor
-
- All Implemented Interfaces:
public interface OverlayTiming.Duration.Visitor<T extends Object>
-
-
Method Summary
-
-
Method Detail
-
visitNumber
abstract T visitNumber(Double number)
-
visitString
abstract T visitString(String string)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Duration to a value of type T.
An instance of Duration can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-