Class OverlayTiming.Start

  • All Implemented Interfaces:

    
    public final class OverlayTiming.Start
    
                        

    Specifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g., 20 or 20.50) and arithmetic expressions such as bdu_mul_0.4 or bdu_sub_idu. Applies only if the base asset is a video. Maps to lso in the URL.