Class ResponsiveImageAttributes.Builder
-
- All Implemented Interfaces:
public final class ResponsiveImageAttributes.BuilderA builder for ResponsiveImageAttributes.
-
-
Method Summary
-
-
Method Detail
-
src
final ResponsiveImageAttributes.Builder src(String src)
URL for the largest candidate (assigned to plain
src).
-
src
final ResponsiveImageAttributes.Builder src(JsonField<String> src)
Sets Builder.src to an arbitrary JSON value.
You should usually call Builder.src with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sizes
final ResponsiveImageAttributes.Builder sizes(String sizes)
sizesreturned (or synthesised as100vw). The value for the HTMLsizesattribute.
-
sizes
final ResponsiveImageAttributes.Builder sizes(JsonField<String> sizes)
Sets Builder.sizes to an arbitrary JSON value.
You should usually call Builder.sizes with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
srcSet
final ResponsiveImageAttributes.Builder srcSet(String srcSet)
Candidate set with
worxdescriptors. Multiple image URLs separated by commas, each with a descriptor.
-
srcSet
final ResponsiveImageAttributes.Builder srcSet(JsonField<String> srcSet)
Sets Builder.srcSet to an arbitrary JSON value.
You should usually call Builder.srcSet with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final ResponsiveImageAttributes.Builder width(Double width)
Width as a number (if
widthwas provided in the input options).
-
width
final ResponsiveImageAttributes.Builder width(JsonField<Double> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final ResponsiveImageAttributes.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final ResponsiveImageAttributes.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final ResponsiveImageAttributes.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final ResponsiveImageAttributes.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final ResponsiveImageAttributes.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final ResponsiveImageAttributes build()
Returns an immutable instance of ResponsiveImageAttributes.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.src()
-
-
-
-