Class SavedExtension
-
- All Implemented Interfaces:
public final class SavedExtensionSaved extension object containing extension configuration.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSavedExtension.BuilderA builder for SavedExtension.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique identifier of the saved extension. final Optional<ExtensionConfig>config()Configuration object for an extension (base extensions only, not saved extension references). final Optional<OffsetDateTime>createdAt()Timestamp when the saved extension was created. final Optional<String>description()Description of the saved extension. final Optional<String>name()Name of the saved extension. final Optional<OffsetDateTime>updatedAt()Timestamp when the saved extension was last updated. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<ExtensionConfig>_config()Returns the raw JSON value of config. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final SavedExtension.BuildertoBuilder()final SavedExtensionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SavedExtension.Builderbuilder()Returns a mutable builder for constructing an instance of SavedExtension. -
-
Method Detail
-
config
final Optional<ExtensionConfig> config()
Configuration object for an extension (base extensions only, not saved extension references).
-
createdAt
final Optional<OffsetDateTime> createdAt()
Timestamp when the saved extension was created.
-
description
final Optional<String> description()
Description of the saved extension.
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Timestamp when the saved extension was last updated.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<ExtensionConfig> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SavedExtension.Builder toBuilder()
-
validate
final SavedExtension validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SavedExtension.Builder builder()
Returns a mutable builder for constructing an instance of SavedExtension.
-
-
-
-