Class SelectedFieldsSchema

  • All Implemented Interfaces:

    
    public final class SelectedFieldsSchema
    
                        

    This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.

    Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.