Class SolidColorOverlay.Builder
-
- All Implemented Interfaces:
public final class SolidColorOverlay.BuilderA builder for SolidColorOverlay.
-
-
Method Summary
-
-
Method Detail
-
layerMode
final SolidColorOverlay.Builder layerMode(BaseOverlay.LayerMode layerMode)
Controls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
layerMode
final SolidColorOverlay.Builder layerMode(JsonField<BaseOverlay.LayerMode> layerMode)
Sets Builder.layerMode to an arbitrary JSON value.
You should usually call Builder.layerMode with a well-typed BaseOverlay.LayerMode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
position
final SolidColorOverlay.Builder position(OverlayPosition position)
Specifies the overlay's position relative to the parent asset. See Position of Layer.
-
position
final SolidColorOverlay.Builder position(JsonField<OverlayPosition> position)
Sets Builder.position to an arbitrary JSON value.
You should usually call Builder.position with a well-typed OverlayPosition value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timing
final SolidColorOverlay.Builder timing(OverlayTiming timing)
Specifies timing information for the overlay (only applicable if the base asset is a video). See Position of Layer.
-
timing
final SolidColorOverlay.Builder timing(JsonField<OverlayTiming> timing)
Sets Builder.timing to an arbitrary JSON value.
You should usually call Builder.timing with a well-typed OverlayTiming value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
color
final SolidColorOverlay.Builder color(String color)
Specifies the color of the block using an RGB hex code (e.g.,
FF0000), an RGBA code (e.g.,FFAABB50), or a color name (e.g.,red). If an 8-character value is provided, the last two characters represent the opacity level (from00for 0.00 to99for 0.99).
-
color
final SolidColorOverlay.Builder color(JsonField<String> color)
Sets Builder.color to an arbitrary JSON value.
You should usually call Builder.color with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final SolidColorOverlay.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("solidColor")This method is primarily for setting the field to an undocumented or not yet supported value.
-
transformation
final SolidColorOverlay.Builder transformation(List<SolidColorOverlayTransformation> transformation)
Control width and height of the solid color overlay. Supported transformations depend on the base/parent asset. See overlays on Images and Videos.
-
transformation
final SolidColorOverlay.Builder transformation(JsonField<List<SolidColorOverlayTransformation>> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed
List<SolidColorOverlayTransformation>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTransformation
final SolidColorOverlay.Builder addTransformation(SolidColorOverlayTransformation transformation)
Adds a single SolidColorOverlayTransformation to Builder.transformation.
-
additionalProperties
final SolidColorOverlay.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SolidColorOverlay.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SolidColorOverlay.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SolidColorOverlay.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SolidColorOverlay.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SolidColorOverlay build()
Returns an immutable instance of SolidColorOverlay.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.color()
-
-
-
-