Class SolidColorOverlayTransformation.Builder
-
- All Implemented Interfaces:
public final class SolidColorOverlayTransformation.BuilderA builder for SolidColorOverlayTransformation.
-
-
Method Summary
-
-
Method Detail
-
alpha
final SolidColorOverlayTransformation.Builder alpha(Double alpha)
Specifies the transparency level of the overlaid solid color layer. Supports integers from
1to9.
-
alpha
final SolidColorOverlayTransformation.Builder alpha(JsonField<Double> alpha)
Sets Builder.alpha to an arbitrary JSON value.
You should usually call Builder.alpha with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
background
final SolidColorOverlayTransformation.Builder background(String background)
Specifies the background color of the solid color overlay. Accepts an RGB hex code (e.g.,
FF0000), an RGBA code (e.g.,FFAABB50), or a color name.
-
background
final SolidColorOverlayTransformation.Builder background(JsonField<String> background)
Sets Builder.background to an arbitrary JSON value.
You should usually call Builder.background with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gradient
final SolidColorOverlayTransformation.Builder gradient(SolidColorOverlayTransformation.Gradient gradient)
Creates a linear gradient with two colors. Pass
truefor a default gradient, or provide a string for a custom gradient. Only works if the base asset is an image. See gradient.
-
gradient
final SolidColorOverlayTransformation.Builder gradient(JsonField<SolidColorOverlayTransformation.Gradient> gradient)
Sets Builder.gradient to an arbitrary JSON value.
You should usually call Builder.gradient with a well-typed Gradient value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gradient
final SolidColorOverlayTransformation.Builder gradient(String string)
Alias for calling gradient with
Gradient.ofString(string).
-
gradientTrue
final SolidColorOverlayTransformation.Builder gradientTrue()
Alias for calling gradient with
Gradient.ofTrue().
-
height
final SolidColorOverlayTransformation.Builder height(SolidColorOverlayTransformation.Height height)
Controls the height of the solid color overlay. Accepts a numeric value or an arithmetic expression. Learn about arithmetic expressions.
-
height
final SolidColorOverlayTransformation.Builder height(JsonField<SolidColorOverlayTransformation.Height> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Height value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final SolidColorOverlayTransformation.Builder height(Double number)
Alias for calling height with
Height.ofNumber(number).
-
height
final SolidColorOverlayTransformation.Builder height(String string)
Alias for calling height with
Height.ofString(string).
-
radius
final SolidColorOverlayTransformation.Builder radius(SolidColorOverlayTransformation.Radius radius)
Specifies the corner radius of the solid color overlay.
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
-
radius
final SolidColorOverlayTransformation.Builder radius(JsonField<SolidColorOverlayTransformation.Radius> radius)
Sets Builder.radius to an arbitrary JSON value.
You should usually call Builder.radius with a well-typed Radius value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
radius
final SolidColorOverlayTransformation.Builder radius(Double number)
Alias for calling radius with
Radius.ofNumber(number).
-
radius
final SolidColorOverlayTransformation.Builder radius(String string)
Alias for calling radius with
Radius.ofString(string).
-
radiusMax
final SolidColorOverlayTransformation.Builder radiusMax()
Alias for calling radius with
Radius.ofMax().
-
width
final SolidColorOverlayTransformation.Builder width(SolidColorOverlayTransformation.Width width)
Controls the width of the solid color overlay. Accepts a numeric value or an arithmetic expression (e.g.,
bw_mul_0.2orbh_div_2). Learn about arithmetic expressions.
-
width
final SolidColorOverlayTransformation.Builder width(JsonField<SolidColorOverlayTransformation.Width> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Width value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final SolidColorOverlayTransformation.Builder width(Double number)
Alias for calling width with
Width.ofNumber(number).
-
width
final SolidColorOverlayTransformation.Builder width(String string)
Alias for calling width with
Width.ofString(string).
-
additionalProperties
final SolidColorOverlayTransformation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SolidColorOverlayTransformation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SolidColorOverlayTransformation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SolidColorOverlayTransformation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SolidColorOverlayTransformation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SolidColorOverlayTransformation build()
Returns an immutable instance of SolidColorOverlayTransformation.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-