Package io.imagekit.models
Class SolidColorOverlayTransformation.Height
-
- All Implemented Interfaces:
public final class SolidColorOverlayTransformation.HeightControls the height of the solid color overlay. Accepts a numeric value or an arithmetic expression. Learn about arithmetic expressions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSolidColorOverlayTransformation.Height.VisitorAn interface that defines how to map each variant of Height to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(SolidColorOverlayTransformation.Height.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final SolidColorOverlayTransformation.Heightvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SolidColorOverlayTransformation.HeightofNumber(Double number)final static SolidColorOverlayTransformation.HeightofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(SolidColorOverlayTransformation.Height.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = height.accept(new Height.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final SolidColorOverlayTransformation.Height validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static SolidColorOverlayTransformation.Height ofNumber(Double number)
-
ofString
final static SolidColorOverlayTransformation.Height ofString(String string)
-
-
-
-