Package io.imagekit.models
Class SolidColorOverlayTransformation.Width
-
- All Implemented Interfaces:
public final class SolidColorOverlayTransformation.WidthControls the width of the solid color overlay. Accepts a numeric value or an arithmetic expression (e.g.,
bw_mul_0.2orbh_div_2). Learn about arithmetic expressions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSolidColorOverlayTransformation.Width.VisitorAn interface that defines how to map each variant of Width to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(SolidColorOverlayTransformation.Width.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final SolidColorOverlayTransformation.Widthvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SolidColorOverlayTransformation.WidthofNumber(Double number)final static SolidColorOverlayTransformation.WidthofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(SolidColorOverlayTransformation.Width.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = width.accept(new Width.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final SolidColorOverlayTransformation.Width validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static SolidColorOverlayTransformation.Width ofNumber(Double number)
-
ofString
final static SolidColorOverlayTransformation.Width ofString(String string)
-
-
-
-