Class SrcOptions.QueryParameters

  • All Implemented Interfaces:

    
    public final class SrcOptions.QueryParameters
    
                        

    These are additional query parameters that you want to add to the final URL. They can be any query parameters and not necessarily related to ImageKit. This is especially useful if you want to add a versioning parameter to your URLs.