Class SubtitleOverlayTransformation
-
- All Implemented Interfaces:
public final class SubtitleOverlayTransformationSubtitle styling options. Learn more from the docs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSubtitleOverlayTransformation.BuilderA builder for SubtitleOverlayTransformation.
public final classSubtitleOverlayTransformation.TypographySets the typography style of the subtitle text. Supports values are
bfor bold,ifor italics, andb_ifor bold with italics.
-
Method Summary
Modifier and Type Method Description final Optional<String>background()Specifies the subtitle background color using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50). final Optional<String>color()Sets the font color of the subtitle text using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50). final Optional<String>fontFamily()Sets the font family of subtitle text. final Optional<String>fontOutline()Sets the font outline of the subtitle text. final Optional<String>fontShadow()Sets the font shadow for the subtitle text. final Optional<Double>fontSize()Sets the font size of subtitle text. final Optional<SubtitleOverlayTransformation.Typography>typography()Sets the typography style of the subtitle text. final JsonField<String>_background()Returns the raw JSON value of background. final JsonField<String>_color()Returns the raw JSON value of color. final JsonField<String>_fontFamily()Returns the raw JSON value of fontFamily. final JsonField<String>_fontOutline()Returns the raw JSON value of fontOutline. final JsonField<String>_fontShadow()Returns the raw JSON value of fontShadow. final JsonField<Double>_fontSize()Returns the raw JSON value of fontSize. final JsonField<SubtitleOverlayTransformation.Typography>_typography()Returns the raw JSON value of typography. final Map<String, JsonValue>_additionalProperties()final SubtitleOverlayTransformation.BuildertoBuilder()final SubtitleOverlayTransformationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SubtitleOverlayTransformation.Builderbuilder()Returns a mutable builder for constructing an instance of SubtitleOverlayTransformation. -
-
Method Detail
-
background
final Optional<String> background()
Specifies the subtitle background color using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
-
color
final Optional<String> color()
Sets the font color of the subtitle text using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
-
fontFamily
final Optional<String> fontFamily()
Sets the font family of subtitle text. Refer to the supported fonts documented in the ImageKit transformations guide.
-
fontOutline
final Optional<String> fontOutline()
Sets the font outline of the subtitle text. Requires the outline width (an integer) and the outline color (as an RGB color code, RGBA color code, or standard web color name) separated by an underscore. Example:
fol-2_blue(outline width of 2px and outline color blue),fol-2_A1CCDD(outline width of 2px and outline color#A1CCDD) andfol-2_A1CCDD50(outline width of 2px and outline color#A1CCDDat 50% opacity).
-
fontShadow
final Optional<String> fontShadow()
Sets the font shadow for the subtitle text. Requires the shadow color (as an RGB color code, RGBA color code, or standard web color name) and shadow indent (an integer) separated by an underscore. Example:
fsh-blue_2(shadow color blue, indent of 2px),fsh-A1CCDD_3(shadow color#A1CCDD, indent of 3px),fsh-A1CCDD50_3(shadow color#A1CCDDat 50% opacity, indent of 3px).
-
typography
final Optional<SubtitleOverlayTransformation.Typography> typography()
Sets the typography style of the subtitle text. Supports values are
bfor bold,ifor italics, andb_ifor bold with italics.
-
_background
final JsonField<String> _background()
Returns the raw JSON value of background.
Unlike background, this method doesn't throw if the JSON field has an unexpected type.
-
_color
final JsonField<String> _color()
Returns the raw JSON value of color.
Unlike color, this method doesn't throw if the JSON field has an unexpected type.
-
_fontFamily
final JsonField<String> _fontFamily()
Returns the raw JSON value of fontFamily.
Unlike fontFamily, this method doesn't throw if the JSON field has an unexpected type.
-
_fontOutline
final JsonField<String> _fontOutline()
Returns the raw JSON value of fontOutline.
Unlike fontOutline, this method doesn't throw if the JSON field has an unexpected type.
-
_fontShadow
final JsonField<String> _fontShadow()
Returns the raw JSON value of fontShadow.
Unlike fontShadow, this method doesn't throw if the JSON field has an unexpected type.
-
_fontSize
final JsonField<Double> _fontSize()
Returns the raw JSON value of fontSize.
Unlike fontSize, this method doesn't throw if the JSON field has an unexpected type.
-
_typography
final JsonField<SubtitleOverlayTransformation.Typography> _typography()
Returns the raw JSON value of typography.
Unlike typography, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SubtitleOverlayTransformation.Builder toBuilder()
-
validate
final SubtitleOverlayTransformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SubtitleOverlayTransformation.Builder builder()
Returns a mutable builder for constructing an instance of SubtitleOverlayTransformation.
-
-
-
-