Class SubtitleOverlayTransformation.Builder
-
- All Implemented Interfaces:
public final class SubtitleOverlayTransformation.BuilderA builder for SubtitleOverlayTransformation.
-
-
Method Summary
-
-
Method Detail
-
background
final SubtitleOverlayTransformation.Builder background(String background)
Specifies the subtitle background color using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
-
background
final SubtitleOverlayTransformation.Builder background(JsonField<String> background)
Sets Builder.background to an arbitrary JSON value.
You should usually call Builder.background with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
color
final SubtitleOverlayTransformation.Builder color(String color)
Sets the font color of the subtitle text using a standard color name, an RGB color code (e.g., FF0000), or an RGBA color code (e.g., FFAABB50).
-
color
final SubtitleOverlayTransformation.Builder color(JsonField<String> color)
Sets Builder.color to an arbitrary JSON value.
You should usually call Builder.color with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontFamily
final SubtitleOverlayTransformation.Builder fontFamily(String fontFamily)
Sets the font family of subtitle text. Refer to the supported fonts documented in the ImageKit transformations guide.
-
fontFamily
final SubtitleOverlayTransformation.Builder fontFamily(JsonField<String> fontFamily)
Sets Builder.fontFamily to an arbitrary JSON value.
You should usually call Builder.fontFamily with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontOutline
final SubtitleOverlayTransformation.Builder fontOutline(String fontOutline)
Sets the font outline of the subtitle text. Requires the outline width (an integer) and the outline color (as an RGB color code, RGBA color code, or standard web color name) separated by an underscore. Example:
fol-2_blue(outline width of 2px and outline color blue),fol-2_A1CCDD(outline width of 2px and outline color#A1CCDD) andfol-2_A1CCDD50(outline width of 2px and outline color#A1CCDDat 50% opacity).
-
fontOutline
final SubtitleOverlayTransformation.Builder fontOutline(JsonField<String> fontOutline)
Sets Builder.fontOutline to an arbitrary JSON value.
You should usually call Builder.fontOutline with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontShadow
final SubtitleOverlayTransformation.Builder fontShadow(String fontShadow)
Sets the font shadow for the subtitle text. Requires the shadow color (as an RGB color code, RGBA color code, or standard web color name) and shadow indent (an integer) separated by an underscore. Example:
fsh-blue_2(shadow color blue, indent of 2px),fsh-A1CCDD_3(shadow color#A1CCDD, indent of 3px),fsh-A1CCDD50_3(shadow color#A1CCDDat 50% opacity, indent of 3px).
-
fontShadow
final SubtitleOverlayTransformation.Builder fontShadow(JsonField<String> fontShadow)
Sets Builder.fontShadow to an arbitrary JSON value.
You should usually call Builder.fontShadow with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontSize
final SubtitleOverlayTransformation.Builder fontSize(Double fontSize)
Sets the font size of subtitle text.
-
fontSize
final SubtitleOverlayTransformation.Builder fontSize(JsonField<Double> fontSize)
Sets Builder.fontSize to an arbitrary JSON value.
You should usually call Builder.fontSize with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
typography
final SubtitleOverlayTransformation.Builder typography(SubtitleOverlayTransformation.Typography typography)
Sets the typography style of the subtitle text. Supports values are
bfor bold,ifor italics, andb_ifor bold with italics.
-
typography
final SubtitleOverlayTransformation.Builder typography(JsonField<SubtitleOverlayTransformation.Typography> typography)
Sets Builder.typography to an arbitrary JSON value.
You should usually call Builder.typography with a well-typed Typography value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final SubtitleOverlayTransformation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final SubtitleOverlayTransformation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final SubtitleOverlayTransformation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final SubtitleOverlayTransformation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final SubtitleOverlayTransformation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final SubtitleOverlayTransformation build()
Returns an immutable instance of SubtitleOverlayTransformation.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-