Class TextOverlayTransformation
-
- All Implemented Interfaces:
public final class TextOverlayTransformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTextOverlayTransformation.BuilderA builder for TextOverlayTransformation.
public final classTextOverlayTransformation.FlipFlip/mirror the text horizontally, vertically, or in both directions. Acceptable values:
h(horizontal),v(vertical),h_v(horizontal and vertical), orv_h.public final classTextOverlayTransformation.FontSizeSpecifies the font size of the overlaid text. Accepts a numeric value or an arithmetic expression.
public final classTextOverlayTransformation.InnerAlignmentSpecifies the inner alignment of the text when width is more than the text length.
public final classTextOverlayTransformation.LineHeightSpecifies the line height for multi-line text overlays. It will come into effect only if the text wraps over multiple lines. Accepts either an integer value or an arithmetic expression.
public final classTextOverlayTransformation.PaddingSpecifies the padding around the overlaid text. Can be provided as a single positive integer or multiple values separated by underscores (following CSS shorthand order). Arithmetic expressions are also accepted.
public final classTextOverlayTransformation.RadiusSpecifies the corner radius:
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
public final classTextOverlayTransformation.RotationSpecifies the rotation angle of the text overlay. Accepts a numeric value for clockwise rotation or a string prefixed with "N" for counter-clockwise rotation.
public final classTextOverlayTransformation.WidthSpecifies the maximum width (in pixels) of the overlaid text. The text wraps automatically, and arithmetic expressions (e.g.,
bw_mul_0.2orbh_div_2) are supported. Useful when used in conjunction with thebackground. Learn about Arithmetic expressions.
-
Method Summary
Modifier and Type Method Description final Optional<Double>alpha()Specifies the transparency level of the text overlay. final Optional<String>background()Specifies the background color of the text overlay. final Optional<TextOverlayTransformation.Flip>flip()Flip/mirror the text horizontally, vertically, or in both directions. final Optional<String>fontColor()Specifies the font color of the overlaid text. final Optional<String>fontFamily()Specifies the font family of the overlaid text. final Optional<TextOverlayTransformation.FontSize>fontSize()Specifies the font size of the overlaid text. final Optional<TextOverlayTransformation.InnerAlignment>innerAlignment()Specifies the inner alignment of the text when width is more than the text length. final Optional<TextOverlayTransformation.LineHeight>lineHeight()Specifies the line height for multi-line text overlays. final Optional<TextOverlayTransformation.Padding>padding()Specifies the padding around the overlaid text. final Optional<TextOverlayTransformation.Radius>radius()Specifies the corner radius: Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
final Optional<TextOverlayTransformation.Rotation>rotation()Specifies the rotation angle of the text overlay. final Optional<String>typography()Specifies the typography style of the text. final Optional<TextOverlayTransformation.Width>width()Specifies the maximum width (in pixels) of the overlaid text. final JsonField<Double>_alpha()Returns the raw JSON value of alpha. final JsonField<String>_background()Returns the raw JSON value of background. final JsonField<TextOverlayTransformation.Flip>_flip()Returns the raw JSON value of flip. final JsonField<String>_fontColor()Returns the raw JSON value of fontColor. final JsonField<String>_fontFamily()Returns the raw JSON value of fontFamily. final JsonField<TextOverlayTransformation.FontSize>_fontSize()Returns the raw JSON value of fontSize. final JsonField<TextOverlayTransformation.InnerAlignment>_innerAlignment()Returns the raw JSON value of innerAlignment. final JsonField<TextOverlayTransformation.LineHeight>_lineHeight()Returns the raw JSON value of lineHeight. final JsonField<TextOverlayTransformation.Padding>_padding()Returns the raw JSON value of padding. final JsonField<TextOverlayTransformation.Radius>_radius()Returns the raw JSON value of radius. final JsonField<TextOverlayTransformation.Rotation>_rotation()Returns the raw JSON value of rotation. final JsonField<String>_typography()Returns the raw JSON value of typography. final JsonField<TextOverlayTransformation.Width>_width()Returns the raw JSON value of width. final Map<String, JsonValue>_additionalProperties()final TextOverlayTransformation.BuildertoBuilder()final TextOverlayTransformationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TextOverlayTransformation.Builderbuilder()Returns a mutable builder for constructing an instance of TextOverlayTransformation. -
-
Method Detail
-
alpha
final Optional<Double> alpha()
Specifies the transparency level of the text overlay. Accepts integers from
1to9.
-
background
final Optional<String> background()
Specifies the background color of the text overlay. Accepts an RGB hex code, an RGBA code, or a color name.
-
flip
final Optional<TextOverlayTransformation.Flip> flip()
Flip/mirror the text horizontally, vertically, or in both directions. Acceptable values:
h(horizontal),v(vertical),h_v(horizontal and vertical), orv_h.
-
fontColor
final Optional<String> fontColor()
Specifies the font color of the overlaid text. Accepts an RGB hex code (e.g.,
FF0000), an RGBA code (e.g.,FFAABB50), or a color name.
-
fontFamily
final Optional<String> fontFamily()
Specifies the font family of the overlaid text. Choose from the supported fonts list or use a custom font. See Supported fonts and Custom font.
-
fontSize
final Optional<TextOverlayTransformation.FontSize> fontSize()
Specifies the font size of the overlaid text. Accepts a numeric value or an arithmetic expression.
-
innerAlignment
final Optional<TextOverlayTransformation.InnerAlignment> innerAlignment()
Specifies the inner alignment of the text when width is more than the text length.
-
lineHeight
final Optional<TextOverlayTransformation.LineHeight> lineHeight()
Specifies the line height for multi-line text overlays. It will come into effect only if the text wraps over multiple lines. Accepts either an integer value or an arithmetic expression.
-
padding
final Optional<TextOverlayTransformation.Padding> padding()
Specifies the padding around the overlaid text. Can be provided as a single positive integer or multiple values separated by underscores (following CSS shorthand order). Arithmetic expressions are also accepted.
-
radius
final Optional<TextOverlayTransformation.Radius> radius()
Specifies the corner radius:
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
-
rotation
final Optional<TextOverlayTransformation.Rotation> rotation()
Specifies the rotation angle of the text overlay. Accepts a numeric value for clockwise rotation or a string prefixed with "N" for counter-clockwise rotation.
-
typography
final Optional<String> typography()
Specifies the typography style of the text. Supported values:
Single styles:
b(bold),i(italic),strikethrough.Combinations: Any combination separated by underscores, e.g.,
b_i,b_i_strikethrough.
-
width
final Optional<TextOverlayTransformation.Width> width()
Specifies the maximum width (in pixels) of the overlaid text. The text wraps automatically, and arithmetic expressions (e.g.,
bw_mul_0.2orbh_div_2) are supported. Useful when used in conjunction with thebackground. Learn about Arithmetic expressions.
-
_alpha
final JsonField<Double> _alpha()
Returns the raw JSON value of alpha.
Unlike alpha, this method doesn't throw if the JSON field has an unexpected type.
-
_background
final JsonField<String> _background()
Returns the raw JSON value of background.
Unlike background, this method doesn't throw if the JSON field has an unexpected type.
-
_flip
final JsonField<TextOverlayTransformation.Flip> _flip()
Returns the raw JSON value of flip.
Unlike flip, this method doesn't throw if the JSON field has an unexpected type.
-
_fontColor
final JsonField<String> _fontColor()
Returns the raw JSON value of fontColor.
Unlike fontColor, this method doesn't throw if the JSON field has an unexpected type.
-
_fontFamily
final JsonField<String> _fontFamily()
Returns the raw JSON value of fontFamily.
Unlike fontFamily, this method doesn't throw if the JSON field has an unexpected type.
-
_fontSize
final JsonField<TextOverlayTransformation.FontSize> _fontSize()
Returns the raw JSON value of fontSize.
Unlike fontSize, this method doesn't throw if the JSON field has an unexpected type.
-
_innerAlignment
final JsonField<TextOverlayTransformation.InnerAlignment> _innerAlignment()
Returns the raw JSON value of innerAlignment.
Unlike innerAlignment, this method doesn't throw if the JSON field has an unexpected type.
-
_lineHeight
final JsonField<TextOverlayTransformation.LineHeight> _lineHeight()
Returns the raw JSON value of lineHeight.
Unlike lineHeight, this method doesn't throw if the JSON field has an unexpected type.
-
_padding
final JsonField<TextOverlayTransformation.Padding> _padding()
Returns the raw JSON value of padding.
Unlike padding, this method doesn't throw if the JSON field has an unexpected type.
-
_radius
final JsonField<TextOverlayTransformation.Radius> _radius()
Returns the raw JSON value of radius.
Unlike radius, this method doesn't throw if the JSON field has an unexpected type.
-
_rotation
final JsonField<TextOverlayTransformation.Rotation> _rotation()
Returns the raw JSON value of rotation.
Unlike rotation, this method doesn't throw if the JSON field has an unexpected type.
-
_typography
final JsonField<String> _typography()
Returns the raw JSON value of typography.
Unlike typography, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<TextOverlayTransformation.Width> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TextOverlayTransformation.Builder toBuilder()
-
validate
final TextOverlayTransformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TextOverlayTransformation.Builder builder()
Returns a mutable builder for constructing an instance of TextOverlayTransformation.
-
-
-