Class TextOverlayTransformation.Builder
-
- All Implemented Interfaces:
public final class TextOverlayTransformation.BuilderA builder for TextOverlayTransformation.
-
-
Method Summary
-
-
Method Detail
-
alpha
final TextOverlayTransformation.Builder alpha(Double alpha)
Specifies the transparency level of the text overlay. Accepts integers from
1to9.
-
alpha
final TextOverlayTransformation.Builder alpha(JsonField<Double> alpha)
Sets Builder.alpha to an arbitrary JSON value.
You should usually call Builder.alpha with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
background
final TextOverlayTransformation.Builder background(String background)
Specifies the background color of the text overlay. Accepts an RGB hex code, an RGBA code, or a color name.
-
background
final TextOverlayTransformation.Builder background(JsonField<String> background)
Sets Builder.background to an arbitrary JSON value.
You should usually call Builder.background with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
flip
final TextOverlayTransformation.Builder flip(TextOverlayTransformation.Flip flip)
Flip/mirror the text horizontally, vertically, or in both directions. Acceptable values:
h(horizontal),v(vertical),h_v(horizontal and vertical), orv_h.
-
flip
final TextOverlayTransformation.Builder flip(JsonField<TextOverlayTransformation.Flip> flip)
Sets Builder.flip to an arbitrary JSON value.
You should usually call Builder.flip with a well-typed Flip value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontColor
final TextOverlayTransformation.Builder fontColor(String fontColor)
Specifies the font color of the overlaid text. Accepts an RGB hex code (e.g.,
FF0000), an RGBA code (e.g.,FFAABB50), or a color name.
-
fontColor
final TextOverlayTransformation.Builder fontColor(JsonField<String> fontColor)
Sets Builder.fontColor to an arbitrary JSON value.
You should usually call Builder.fontColor with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontFamily
final TextOverlayTransformation.Builder fontFamily(String fontFamily)
Specifies the font family of the overlaid text. Choose from the supported fonts list or use a custom font. See Supported fonts and Custom font.
-
fontFamily
final TextOverlayTransformation.Builder fontFamily(JsonField<String> fontFamily)
Sets Builder.fontFamily to an arbitrary JSON value.
You should usually call Builder.fontFamily with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontSize
final TextOverlayTransformation.Builder fontSize(TextOverlayTransformation.FontSize fontSize)
Specifies the font size of the overlaid text. Accepts a numeric value or an arithmetic expression.
-
fontSize
final TextOverlayTransformation.Builder fontSize(JsonField<TextOverlayTransformation.FontSize> fontSize)
Sets Builder.fontSize to an arbitrary JSON value.
You should usually call Builder.fontSize with a well-typed FontSize value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fontSize
final TextOverlayTransformation.Builder fontSize(Double number)
Alias for calling fontSize with
FontSize.ofNumber(number).
-
fontSize
final TextOverlayTransformation.Builder fontSize(String string)
Alias for calling fontSize with
FontSize.ofString(string).
-
innerAlignment
final TextOverlayTransformation.Builder innerAlignment(TextOverlayTransformation.InnerAlignment innerAlignment)
Specifies the inner alignment of the text when width is more than the text length.
-
innerAlignment
final TextOverlayTransformation.Builder innerAlignment(JsonField<TextOverlayTransformation.InnerAlignment> innerAlignment)
Sets Builder.innerAlignment to an arbitrary JSON value.
You should usually call Builder.innerAlignment with a well-typed InnerAlignment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lineHeight
final TextOverlayTransformation.Builder lineHeight(TextOverlayTransformation.LineHeight lineHeight)
Specifies the line height for multi-line text overlays. It will come into effect only if the text wraps over multiple lines. Accepts either an integer value or an arithmetic expression.
-
lineHeight
final TextOverlayTransformation.Builder lineHeight(JsonField<TextOverlayTransformation.LineHeight> lineHeight)
Sets Builder.lineHeight to an arbitrary JSON value.
You should usually call Builder.lineHeight with a well-typed LineHeight value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
lineHeight
final TextOverlayTransformation.Builder lineHeight(Double number)
Alias for calling lineHeight with
LineHeight.ofNumber(number).
-
lineHeight
final TextOverlayTransformation.Builder lineHeight(String string)
Alias for calling lineHeight with
LineHeight.ofString(string).
-
padding
final TextOverlayTransformation.Builder padding(TextOverlayTransformation.Padding padding)
Specifies the padding around the overlaid text. Can be provided as a single positive integer or multiple values separated by underscores (following CSS shorthand order). Arithmetic expressions are also accepted.
-
padding
final TextOverlayTransformation.Builder padding(JsonField<TextOverlayTransformation.Padding> padding)
Sets Builder.padding to an arbitrary JSON value.
You should usually call Builder.padding with a well-typed Padding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
padding
final TextOverlayTransformation.Builder padding(Double number)
Alias for calling padding with
Padding.ofNumber(number).
-
padding
final TextOverlayTransformation.Builder padding(String string)
Alias for calling padding with
Padding.ofString(string).
-
radius
final TextOverlayTransformation.Builder radius(TextOverlayTransformation.Radius radius)
Specifies the corner radius:
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
-
radius
final TextOverlayTransformation.Builder radius(JsonField<TextOverlayTransformation.Radius> radius)
Sets Builder.radius to an arbitrary JSON value.
You should usually call Builder.radius with a well-typed Radius value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
radius
final TextOverlayTransformation.Builder radius(Double number)
Alias for calling radius with
Radius.ofNumber(number).
-
radius
final TextOverlayTransformation.Builder radius(String string)
Alias for calling radius with
Radius.ofString(string).
-
radiusMax
final TextOverlayTransformation.Builder radiusMax()
Alias for calling radius with
Radius.ofMax().
-
rotation
final TextOverlayTransformation.Builder rotation(TextOverlayTransformation.Rotation rotation)
Specifies the rotation angle of the text overlay. Accepts a numeric value for clockwise rotation or a string prefixed with "N" for counter-clockwise rotation.
-
rotation
final TextOverlayTransformation.Builder rotation(JsonField<TextOverlayTransformation.Rotation> rotation)
Sets Builder.rotation to an arbitrary JSON value.
You should usually call Builder.rotation with a well-typed Rotation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rotation
final TextOverlayTransformation.Builder rotation(Double number)
Alias for calling rotation with
Rotation.ofNumber(number).
-
rotation
final TextOverlayTransformation.Builder rotation(String string)
Alias for calling rotation with
Rotation.ofString(string).
-
typography
final TextOverlayTransformation.Builder typography(String typography)
Specifies the typography style of the text. Supported values:
Single styles:
b(bold),i(italic),strikethrough.Combinations: Any combination separated by underscores, e.g.,
b_i,b_i_strikethrough.
-
typography
final TextOverlayTransformation.Builder typography(JsonField<String> typography)
Sets Builder.typography to an arbitrary JSON value.
You should usually call Builder.typography with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final TextOverlayTransformation.Builder width(TextOverlayTransformation.Width width)
Specifies the maximum width (in pixels) of the overlaid text. The text wraps automatically, and arithmetic expressions (e.g.,
bw_mul_0.2orbh_div_2) are supported. Useful when used in conjunction with thebackground. Learn about Arithmetic expressions.
-
width
final TextOverlayTransformation.Builder width(JsonField<TextOverlayTransformation.Width> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Width value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final TextOverlayTransformation.Builder width(Double number)
Alias for calling width with
Width.ofNumber(number).
-
width
final TextOverlayTransformation.Builder width(String string)
Alias for calling width with
Width.ofString(string).
-
additionalProperties
final TextOverlayTransformation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final TextOverlayTransformation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final TextOverlayTransformation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final TextOverlayTransformation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final TextOverlayTransformation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final TextOverlayTransformation build()
Returns an immutable instance of TextOverlayTransformation.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-