Class TextOverlayTransformation.LineHeight

  • All Implemented Interfaces:

    
    public final class TextOverlayTransformation.LineHeight
    
                        

    Specifies the line height for multi-line text overlays. It will come into effect only if the text wraps over multiple lines. Accepts either an integer value or an arithmetic expression.