Package io.imagekit.models
Class TextOverlayTransformation.Rotation
-
- All Implemented Interfaces:
public final class TextOverlayTransformation.RotationSpecifies the rotation angle of the text overlay. Accepts a numeric value for clockwise rotation or a string prefixed with "N" for counter-clockwise rotation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTextOverlayTransformation.Rotation.VisitorAn interface that defines how to map each variant of Rotation to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(TextOverlayTransformation.Rotation.Visitor<T> visitor)final TextOverlayTransformation.Rotationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TextOverlayTransformation.RotationofNumber(Double number)final static TextOverlayTransformation.RotationofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(TextOverlayTransformation.Rotation.Visitor<T> visitor)
-
validate
final TextOverlayTransformation.Rotation validate()
-
ofNumber
final static TextOverlayTransformation.Rotation ofNumber(Double number)
-
ofString
final static TextOverlayTransformation.Rotation ofString(String string)
-
-
-
-