Class Transformation

  • All Implemented Interfaces:

    
    public final class Transformation
    
                        

    The SDK provides easy-to-use names for transformations. These names are converted to the corresponding transformation string before being added to the URL. SDKs are updated regularly to support new transformations. If you want to use a transformation that is not supported by the SDK, You can use the raw parameter to pass the transformation string directly. See the Transformations documentation.