Class Transformation.AiDropShadow

  • All Implemented Interfaces:

    
    public final class Transformation.AiDropShadow
    
                        

    Adds an AI-based drop shadow around a foreground object on a transparent or removed background. Optionally, control the direction, elevation, and saturation of the light source (e.g., az-45 to change light direction). Pass true for the default drop shadow, or provide a string for a custom drop shadow. Supported inside overlay. See AI Drop Shadow.