Class Transformation.AiVariation

  • All Implemented Interfaces:
    io.imagekit.core.Enum

    
    public final class Transformation.AiVariation
     implements Enum
                        

    Generates a variation of an image using AI. This produces a new image with slight variations from the original, such as changes in color, texture, and other visual elements, while preserving the structure and essence of the original image. Not supported inside overlay. See AI Generate Variations.