Class Transformation.Builder
-
- All Implemented Interfaces:
public final class Transformation.BuilderA builder for Transformation.
-
-
Method Summary
Modifier and Type Method Description final Transformation.BuilderaiChangeBackground(String aiChangeBackground)Uses AI to change the background. final Transformation.BuilderaiChangeBackground(JsonField<String> aiChangeBackground)Sets Builder.aiChangeBackground to an arbitrary JSON value. final Transformation.BuilderaiDropShadow(Transformation.AiDropShadow aiDropShadow)Adds an AI-based drop shadow around a foreground object on a transparent or removed background. final Transformation.BuilderaiDropShadow(JsonField<Transformation.AiDropShadow> aiDropShadow)Sets Builder.aiDropShadow to an arbitrary JSON value. final Transformation.BuilderaiDropShadow(String string)Alias for calling aiDropShadow with AiDropShadow.ofString(string).final Transformation.BuilderaiDropShadowTrue()Alias for calling aiDropShadow with AiDropShadow.ofTrue().final Transformation.BuilderaiEdit(String aiEdit)Uses AI to edit images based on a text prompt. final Transformation.BuilderaiEdit(JsonField<String> aiEdit)Sets Builder.aiEdit to an arbitrary JSON value. final Transformation.BuilderaiRemoveBackground(Transformation.AiRemoveBackground aiRemoveBackground)Applies ImageKit's in-house background removal. final Transformation.BuilderaiRemoveBackground(JsonField<Transformation.AiRemoveBackground> aiRemoveBackground)Sets Builder.aiRemoveBackground to an arbitrary JSON value. final Transformation.BuilderaiRemoveBackgroundExternal(Transformation.AiRemoveBackgroundExternal aiRemoveBackgroundExternal)Uses third-party background removal. final Transformation.BuilderaiRemoveBackgroundExternal(JsonField<Transformation.AiRemoveBackgroundExternal> aiRemoveBackgroundExternal)Sets Builder.aiRemoveBackgroundExternal to an arbitrary JSON value. final Transformation.BuilderaiRetouch(Transformation.AiRetouch aiRetouch)Performs AI-based retouching to improve faces or product shots. final Transformation.BuilderaiRetouch(JsonField<Transformation.AiRetouch> aiRetouch)Sets Builder.aiRetouch to an arbitrary JSON value. final Transformation.BuilderaiUpscale(Transformation.AiUpscale aiUpscale)Upscales images beyond their original dimensions using AI. final Transformation.BuilderaiUpscale(JsonField<Transformation.AiUpscale> aiUpscale)Sets Builder.aiUpscale to an arbitrary JSON value. final Transformation.BuilderaiVariation(Transformation.AiVariation aiVariation)Generates a variation of an image using AI. final Transformation.BuilderaiVariation(JsonField<Transformation.AiVariation> aiVariation)Sets Builder.aiVariation to an arbitrary JSON value. final Transformation.BuilderaspectRatio(Transformation.AspectRatio aspectRatio)Specifies the aspect ratio for the output, e.g., "ar-4-3". final Transformation.BuilderaspectRatio(JsonField<Transformation.AspectRatio> aspectRatio)Sets Builder.aspectRatio to an arbitrary JSON value. final Transformation.BuilderaspectRatio(Double number)Alias for calling aspectRatio with AspectRatio.ofNumber(number).final Transformation.BuilderaspectRatio(String string)Alias for calling aspectRatio with AspectRatio.ofString(string).final Transformation.BuilderaudioCodec(Transformation.AudioCodec audioCodec)Specifies the audio codec, e.g. final Transformation.BuilderaudioCodec(JsonField<Transformation.AudioCodec> audioCodec)Sets Builder.audioCodec to an arbitrary JSON value. final Transformation.Builderbackground(String background)Specifies the background to be used in conjunction with certain cropping strategies when resizing an image. final Transformation.Builderbackground(JsonField<String> background)Sets Builder.background to an arbitrary JSON value. final Transformation.Builderblur(Double blur)Specifies the Gaussian blur level. final Transformation.Builderblur(JsonField<Double> blur)Sets Builder.blur to an arbitrary JSON value. final Transformation.Builderborder(String border)Adds a border to the output media. final Transformation.Builderborder(JsonField<String> border)Sets Builder.border to an arbitrary JSON value. final Transformation.Buildercolorize(String colorize)Applies a color tint to the image. final Transformation.Buildercolorize(JsonField<String> colorize)Sets Builder.colorize to an arbitrary JSON value. final Transformation.BuildercolorProfile(Boolean colorProfile)Indicates whether the output image should retain the original color profile. final Transformation.BuildercolorProfile(JsonField<Boolean> colorProfile)Sets Builder.colorProfile to an arbitrary JSON value. final Transformation.BuildercolorReplace(String colorReplace)Replaces colors in the image. final Transformation.BuildercolorReplace(JsonField<String> colorReplace)Sets Builder.colorReplace to an arbitrary JSON value. final Transformation.BuildercontrastStretch(Transformation.ContrastStretch contrastStretch)Automatically enhances the contrast of an image (contrast stretch). final Transformation.BuildercontrastStretch(JsonField<Transformation.ContrastStretch> contrastStretch)Sets Builder.contrastStretch to an arbitrary JSON value. final Transformation.Buildercrop(Transformation.Crop crop)Crop modes for image resizing. final Transformation.Buildercrop(JsonField<Transformation.Crop> crop)Sets Builder.crop to an arbitrary JSON value. final Transformation.BuildercropMode(Transformation.CropMode cropMode)Additional crop modes for image resizing. final Transformation.BuildercropMode(JsonField<Transformation.CropMode> cropMode)Sets Builder.cropMode to an arbitrary JSON value. final Transformation.BuilderdefaultImage(String defaultImage)Specifies a fallback image if the resource is not found, e.g., a URL or file path. final Transformation.BuilderdefaultImage(JsonField<String> defaultImage)Sets Builder.defaultImage to an arbitrary JSON value. final Transformation.Builderdistort(String distort)Distorts the shape of an image. final Transformation.Builderdistort(JsonField<String> distort)Sets Builder.distort to an arbitrary JSON value. final Transformation.Builderdpr(Double dpr)Accepts values between 0. final Transformation.Builderdpr(JsonField<Double> dpr)Sets Builder.dpr to an arbitrary JSON value. final Transformation.Builderduration(Transformation.Duration duration)Specifies the duration (in seconds) for trimming videos, e.g. final Transformation.Builderduration(JsonField<Transformation.Duration> duration)Sets Builder.duration to an arbitrary JSON value. final Transformation.Builderduration(Double number)Alias for calling duration with Duration.ofNumber(number).final Transformation.Builderduration(String string)Alias for calling duration with Duration.ofString(string).final Transformation.BuilderendOffset(Transformation.EndOffset endOffset)Specifies the end offset (in seconds) for trimming videos, e.g. final Transformation.BuilderendOffset(JsonField<Transformation.EndOffset> endOffset)Sets Builder.endOffset to an arbitrary JSON value. final Transformation.BuilderendOffset(Double number)Alias for calling endOffset with EndOffset.ofNumber(number).final Transformation.BuilderendOffset(String string)Alias for calling endOffset with EndOffset.ofString(string).final Transformation.Builderflip(Transformation.Flip flip)Flips or mirrors an image either horizontally, vertically, or both. final Transformation.Builderflip(JsonField<Transformation.Flip> flip)Sets Builder.flip to an arbitrary JSON value. final Transformation.Builderfocus(String focus)Refines padding and cropping behavior for pad resize, maintain ratio, and extract crop modes. final Transformation.Builderfocus(JsonField<String> focus)Sets Builder.focus to an arbitrary JSON value. final Transformation.Builderformat(Transformation.Format format)Specifies the output format for images or videos, e.g. final Transformation.Builderformat(JsonField<Transformation.Format> format)Sets Builder.format to an arbitrary JSON value. final Transformation.Buildergradient(Transformation.Gradient gradient)Creates a linear gradient with two colors. final Transformation.Buildergradient(JsonField<Transformation.Gradient> gradient)Sets Builder.gradient to an arbitrary JSON value. final Transformation.Buildergradient(String string)Alias for calling gradient with Gradient.ofString(string).final Transformation.BuildergradientTrue()Alias for calling gradient with Gradient.ofTrue().final Transformation.Buildergrayscale(Transformation.Grayscale grayscale)Enables a grayscale effect for images. final Transformation.Buildergrayscale(JsonField<Transformation.Grayscale> grayscale)Sets Builder.grayscale to an arbitrary JSON value. final Transformation.Builderheight(Transformation.Height height)Specifies the height of the output. final Transformation.Builderheight(JsonField<Transformation.Height> height)Sets Builder.height to an arbitrary JSON value. final Transformation.Builderheight(Double number)Alias for calling height with Height.ofNumber(number).final Transformation.Builderheight(String string)Alias for calling height with Height.ofString(string).final Transformation.Builderlossless(Boolean lossless)Specifies whether the output image (in JPEG or PNG) should be compressed losslessly. final Transformation.Builderlossless(JsonField<Boolean> lossless)Sets Builder.lossless to an arbitrary JSON value. final Transformation.Buildermetadata(Boolean metadata)By default, ImageKit removes all metadata during automatic image compression. final Transformation.Buildermetadata(JsonField<Boolean> metadata)Sets Builder.metadata to an arbitrary JSON value. final Transformation.Buildernamed(String named)Named transformation reference. final Transformation.Buildernamed(JsonField<String> named)Sets Builder.named to an arbitrary JSON value. final Transformation.Builderopacity(Double opacity)Specifies the opacity level of the output image. final Transformation.Builderopacity(JsonField<Double> opacity)Sets Builder.opacity to an arbitrary JSON value. final Transformation.Builderoriginal(Boolean original)If set to true, serves the original file without applying any transformations. final Transformation.Builderoriginal(JsonField<Boolean> original)Sets Builder.original to an arbitrary JSON value. final Transformation.Builderoverlay(Overlay overlay)Specifies an overlay to be applied on the parent image or video. final Transformation.Builderoverlay(JsonField<Overlay> overlay)Sets Builder.overlay to an arbitrary JSON value. final Transformation.Builderoverlay(TextOverlay text)Alias for calling overlay with Overlay.ofText(text).final Transformation.Builderoverlay(ImageOverlay image)Alias for calling overlay with Overlay.ofImage(image).final Transformation.Builderoverlay(VideoOverlay video)Alias for calling overlay with Overlay.ofVideo(video).final Transformation.Builderoverlay(SubtitleOverlay subtitle)Alias for calling overlay with Overlay.ofSubtitle(subtitle).final Transformation.Builderoverlay(SolidColorOverlay solidColor)Alias for calling overlay with Overlay.ofSolidColor(solidColor).final Transformation.BuildertextOverlay(String text)Alias for calling overlay with the following: TextOverlay.builder() .text(text) .build()final Transformation.BuilderimageOverlay(String input)Alias for calling overlay with the following: ImageOverlay.builder() .input(input) .build()final Transformation.BuildervideoOverlay(String input)Alias for calling overlay with the following: VideoOverlay.builder() .input(input) .build()final Transformation.BuildersubtitleOverlay(String input)Alias for calling overlay with the following: SubtitleOverlay.builder() .input(input) .build()final Transformation.BuildersolidColorOverlay(String color)Alias for calling overlay with the following: SolidColorOverlay.builder() .color(color) .build()final Transformation.Builderpage(Transformation.Page page)Extracts a specific page or frame from multi-page or layered files (PDF, PSD, AI). final Transformation.Builderpage(JsonField<Transformation.Page> page)Sets Builder.page to an arbitrary JSON value. final Transformation.Builderpage(Double number)Alias for calling page with Page.ofNumber(number).final Transformation.Builderpage(String string)Alias for calling page with Page.ofString(string).final Transformation.Builderprogressive(Boolean progressive)Specifies whether the output JPEG image should be rendered progressively. final Transformation.Builderprogressive(JsonField<Boolean> progressive)Sets Builder.progressive to an arbitrary JSON value. final Transformation.Builderquality(Double quality)Specifies the quality of the output image for lossy formats such as JPEG, WebP, and AVIF. final Transformation.Builderquality(JsonField<Double> quality)Sets Builder.quality to an arbitrary JSON value. final Transformation.Builderradius(Transformation.Radius radius)Specifies the corner radius for rounded corners. final Transformation.Builderradius(JsonField<Transformation.Radius> radius)Sets Builder.radius to an arbitrary JSON value. final Transformation.Builderradius(Double number)Alias for calling radius with Radius.ofNumber(number).final Transformation.Builderradius(String string)Alias for calling radius with Radius.ofString(string).final Transformation.BuilderradiusMax()Alias for calling radius with Radius.ofMax().final Transformation.Builderraw(String raw)Pass any transformation not directly supported by the SDK. final Transformation.Builderraw(JsonField<String> raw)Sets Builder.raw to an arbitrary JSON value. final Transformation.Builderrotation(Transformation.Rotation rotation)Specifies the rotation angle in degrees. final Transformation.Builderrotation(JsonField<Transformation.Rotation> rotation)Sets Builder.rotation to an arbitrary JSON value. final Transformation.Builderrotation(Double number)Alias for calling rotation with Rotation.ofNumber(number).final Transformation.Builderrotation(String string)Alias for calling rotation with Rotation.ofString(string).final Transformation.Buildershadow(Transformation.Shadow shadow)Adds a shadow beneath solid objects in an image with a transparent background. final Transformation.Buildershadow(JsonField<Transformation.Shadow> shadow)Sets Builder.shadow to an arbitrary JSON value. final Transformation.Buildershadow(String string)Alias for calling shadow with Shadow.ofString(string).final Transformation.BuildershadowTrue()Alias for calling shadow with Shadow.ofTrue().final Transformation.Buildersharpen(Transformation.Sharpen sharpen)Sharpens the input image, highlighting edges and finer details. final Transformation.Buildersharpen(JsonField<Transformation.Sharpen> sharpen)Sets Builder.sharpen to an arbitrary JSON value. final Transformation.Buildersharpen(Double number)Alias for calling sharpen with Sharpen.ofNumber(number).final Transformation.BuildersharpenTrue()Alias for calling sharpen with Sharpen.ofTrue().final Transformation.BuilderstartOffset(Transformation.StartOffset startOffset)Specifies the start offset (in seconds) for trimming videos, e.g. final Transformation.BuilderstartOffset(JsonField<Transformation.StartOffset> startOffset)Sets Builder.startOffset to an arbitrary JSON value. final Transformation.BuilderstartOffset(Double number)Alias for calling startOffset with StartOffset.ofNumber(number).final Transformation.BuilderstartOffset(String string)Alias for calling startOffset with StartOffset.ofString(string).final Transformation.BuilderstreamingResolutions(List<StreamingResolution> streamingResolutions)An array of resolutions for adaptive bitrate streaming, e.g. final Transformation.BuilderstreamingResolutions(JsonField<List<StreamingResolution>> streamingResolutions)Sets Builder.streamingResolutions to an arbitrary JSON value. final Transformation.BuilderaddStreamingResolution(StreamingResolution streamingResolution)Adds a single StreamingResolution to streamingResolutions. final Transformation.Buildertrim(Transformation.Trim trim)Useful for images with a solid or nearly solid background and a central object. final Transformation.Buildertrim(JsonField<Transformation.Trim> trim)Sets Builder.trim to an arbitrary JSON value. final Transformation.Buildertrim(Double number)Alias for calling trim with Trim.ofNumber(number).final Transformation.BuildertrimTrue()Alias for calling trim with Trim.ofTrue().final Transformation.BuilderunsharpMask(Transformation.UnsharpMask unsharpMask)Applies Unsharp Masking (USM), an image sharpening technique. final Transformation.BuilderunsharpMask(JsonField<Transformation.UnsharpMask> unsharpMask)Sets Builder.unsharpMask to an arbitrary JSON value. final Transformation.BuilderunsharpMask(String string)Alias for calling unsharpMask with UnsharpMask.ofString(string).final Transformation.BuilderunsharpMaskTrue()Alias for calling unsharpMask with UnsharpMask.ofTrue().final Transformation.BuildervideoCodec(Transformation.VideoCodec videoCodec)Specifies the video codec, e.g. final Transformation.BuildervideoCodec(JsonField<Transformation.VideoCodec> videoCodec)Sets Builder.videoCodec to an arbitrary JSON value. final Transformation.Builderwidth(Transformation.Width width)Specifies the width of the output. final Transformation.Builderwidth(JsonField<Transformation.Width> width)Sets Builder.width to an arbitrary JSON value. final Transformation.Builderwidth(Double number)Alias for calling width with Width.ofNumber(number).final Transformation.Builderwidth(String string)Alias for calling width with Width.ofString(string).final Transformation.Builderx(Transformation.X x)Focus using cropped image coordinates - X coordinate. final Transformation.Builderx(JsonField<Transformation.X> x)Sets Builder.x to an arbitrary JSON value. final Transformation.Builderx(Double number)Alias for calling x with X.ofNumber(number).final Transformation.Builderx(String string)Alias for calling x with X.ofString(string).final Transformation.BuilderxCenter(Transformation.XCenter xCenter)Focus using cropped image coordinates - X center coordinate. final Transformation.BuilderxCenter(JsonField<Transformation.XCenter> xCenter)Sets Builder.xCenter to an arbitrary JSON value. final Transformation.BuilderxCenter(Double number)Alias for calling xCenter with XCenter.ofNumber(number).final Transformation.BuilderxCenter(String string)Alias for calling xCenter with XCenter.ofString(string).final Transformation.Buildery(Transformation.Y y)Focus using cropped image coordinates - Y coordinate. final Transformation.Buildery(JsonField<Transformation.Y> y)Sets Builder.y to an arbitrary JSON value. final Transformation.Buildery(Double number)Alias for calling y with Y.ofNumber(number).final Transformation.Buildery(String string)Alias for calling y with Y.ofString(string).final Transformation.BuilderyCenter(Transformation.YCenter yCenter)Focus using cropped image coordinates - Y center coordinate. final Transformation.BuilderyCenter(JsonField<Transformation.YCenter> yCenter)Sets Builder.yCenter to an arbitrary JSON value. final Transformation.BuilderyCenter(Double number)Alias for calling yCenter with YCenter.ofNumber(number).final Transformation.BuilderyCenter(String string)Alias for calling yCenter with YCenter.ofString(string).final Transformation.Builderzoom(Double zoom)Accepts a numeric value that determines how much to zoom in or out of the cropped area. final Transformation.Builderzoom(JsonField<Double> zoom)Sets Builder.zoom to an arbitrary JSON value. final Transformation.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Transformation.BuilderputAdditionalProperty(String key, JsonValue value)final Transformation.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Transformation.BuilderremoveAdditionalProperty(String key)final Transformation.BuilderremoveAllAdditionalProperties(Set<String> keys)final Transformationbuild()Returns an immutable instance of Transformation. -
-
Method Detail
-
aiChangeBackground
final Transformation.Builder aiChangeBackground(String aiChangeBackground)
Uses AI to change the background. Provide a text prompt or a base64-encoded prompt, e.g.,
prompt-snow roadorprompte-[urlencoded_base64_encoded_text]. Not supported inside overlay. See AI Change Background.
-
aiChangeBackground
final Transformation.Builder aiChangeBackground(JsonField<String> aiChangeBackground)
Sets Builder.aiChangeBackground to an arbitrary JSON value.
You should usually call Builder.aiChangeBackground with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiDropShadow
final Transformation.Builder aiDropShadow(Transformation.AiDropShadow aiDropShadow)
Adds an AI-based drop shadow around a foreground object on a transparent or removed background. Optionally, control the direction, elevation, and saturation of the light source (e.g.,
az-45to change light direction). Passtruefor the default drop shadow, or provide a string for a custom drop shadow. Supported inside overlay. See AI Drop Shadow.
-
aiDropShadow
final Transformation.Builder aiDropShadow(JsonField<Transformation.AiDropShadow> aiDropShadow)
Sets Builder.aiDropShadow to an arbitrary JSON value.
You should usually call Builder.aiDropShadow with a well-typed AiDropShadow value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiDropShadow
final Transformation.Builder aiDropShadow(String string)
Alias for calling aiDropShadow with
AiDropShadow.ofString(string).
-
aiDropShadowTrue
final Transformation.Builder aiDropShadowTrue()
Alias for calling aiDropShadow with
AiDropShadow.ofTrue().
-
aiEdit
final Transformation.Builder aiEdit(String aiEdit)
Uses AI to edit images based on a text prompt. Provide a text prompt or a base64-encoded prompt, e.g.,
prompt-snow roadorprompte-[urlencoded_base64_encoded_text]. Not supported inside overlay. See AI Edit.
-
aiEdit
final Transformation.Builder aiEdit(JsonField<String> aiEdit)
Sets Builder.aiEdit to an arbitrary JSON value.
You should usually call Builder.aiEdit with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiRemoveBackground
final Transformation.Builder aiRemoveBackground(Transformation.AiRemoveBackground aiRemoveBackground)
Applies ImageKit's in-house background removal. Supported inside overlay. See AI Background Removal.
-
aiRemoveBackground
final Transformation.Builder aiRemoveBackground(JsonField<Transformation.AiRemoveBackground> aiRemoveBackground)
Sets Builder.aiRemoveBackground to an arbitrary JSON value.
You should usually call Builder.aiRemoveBackground with a well-typed AiRemoveBackground value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiRemoveBackgroundExternal
final Transformation.Builder aiRemoveBackgroundExternal(Transformation.AiRemoveBackgroundExternal aiRemoveBackgroundExternal)
Uses third-party background removal. Note: It is recommended to use aiRemoveBackground, ImageKit's in-house solution, which is more cost-effective. Supported inside overlay. See External Background Removal.
-
aiRemoveBackgroundExternal
final Transformation.Builder aiRemoveBackgroundExternal(JsonField<Transformation.AiRemoveBackgroundExternal> aiRemoveBackgroundExternal)
Sets Builder.aiRemoveBackgroundExternal to an arbitrary JSON value.
You should usually call Builder.aiRemoveBackgroundExternal with a well-typed AiRemoveBackgroundExternal value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiRetouch
final Transformation.Builder aiRetouch(Transformation.AiRetouch aiRetouch)
Performs AI-based retouching to improve faces or product shots. Not supported inside overlay. See AI Retouch.
-
aiRetouch
final Transformation.Builder aiRetouch(JsonField<Transformation.AiRetouch> aiRetouch)
Sets Builder.aiRetouch to an arbitrary JSON value.
You should usually call Builder.aiRetouch with a well-typed AiRetouch value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiUpscale
final Transformation.Builder aiUpscale(Transformation.AiUpscale aiUpscale)
Upscales images beyond their original dimensions using AI. Not supported inside overlay. See AI Upscale.
-
aiUpscale
final Transformation.Builder aiUpscale(JsonField<Transformation.AiUpscale> aiUpscale)
Sets Builder.aiUpscale to an arbitrary JSON value.
You should usually call Builder.aiUpscale with a well-typed AiUpscale value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aiVariation
final Transformation.Builder aiVariation(Transformation.AiVariation aiVariation)
Generates a variation of an image using AI. This produces a new image with slight variations from the original, such as changes in color, texture, and other visual elements, while preserving the structure and essence of the original image. Not supported inside overlay. See AI Generate Variations.
-
aiVariation
final Transformation.Builder aiVariation(JsonField<Transformation.AiVariation> aiVariation)
Sets Builder.aiVariation to an arbitrary JSON value.
You should usually call Builder.aiVariation with a well-typed AiVariation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aspectRatio
final Transformation.Builder aspectRatio(Transformation.AspectRatio aspectRatio)
Specifies the aspect ratio for the output, e.g., "ar-4-3". Typically used with either width or height (but not both). For example: aspectRatio =
4:3,4_3, or an expression likeiar_div_2. See Image resize and crop – Aspect ratio.
-
aspectRatio
final Transformation.Builder aspectRatio(JsonField<Transformation.AspectRatio> aspectRatio)
Sets Builder.aspectRatio to an arbitrary JSON value.
You should usually call Builder.aspectRatio with a well-typed AspectRatio value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
aspectRatio
final Transformation.Builder aspectRatio(Double number)
Alias for calling aspectRatio with
AspectRatio.ofNumber(number).
-
aspectRatio
final Transformation.Builder aspectRatio(String string)
Alias for calling aspectRatio with
AspectRatio.ofString(string).
-
audioCodec
final Transformation.Builder audioCodec(Transformation.AudioCodec audioCodec)
Specifies the audio codec, e.g.,
aac,opus, ornone. See Audio codec.
-
audioCodec
final Transformation.Builder audioCodec(JsonField<Transformation.AudioCodec> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed AudioCodec value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
background
final Transformation.Builder background(String background)
Specifies the background to be used in conjunction with certain cropping strategies when resizing an image.
A solid color: e.g.,
red,F3F3F3,AAFF0010. See Solid color background.Dominant color:
dominantextracts the dominant color from the image. See Dominant color background.Gradient:
gradient_dominantorgradient_dominant_2creates a gradient using the dominant colors. Optionally specify palette size (2 or 4), e.g.,gradient_dominant_4. See Gradient background.A blurred background: e.g.,
blurred,blurred_25_N15, etc. See Blurred background.Expand the image boundaries using generative fill:
genfill. Not supported inside overlay. Optionally, control the background scene by passing a text prompt:genfill[:-prompt-${text}]orgenfill[:-prompte-${urlencoded_base64_encoded_text}]. See Generative fill background.
-
background
final Transformation.Builder background(JsonField<String> background)
Sets Builder.background to an arbitrary JSON value.
You should usually call Builder.background with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
blur
final Transformation.Builder blur(Double blur)
Specifies the Gaussian blur level. Accepts an integer value between 1 and 100, or an expression like
bl-10. See Blur.
-
blur
final Transformation.Builder blur(JsonField<Double> blur)
Sets Builder.blur to an arbitrary JSON value.
You should usually call Builder.blur with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
border
final Transformation.Builder border(String border)
Adds a border to the output media. Accepts a string in the format
<border-width>_<hex-code>(e.g.,5_FFF000for a 5px yellow border), or an expression likeih_div_20_FF00FF. See Border.
-
border
final Transformation.Builder border(JsonField<String> border)
Sets Builder.border to an arbitrary JSON value.
You should usually call Builder.border with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
colorize
final Transformation.Builder colorize(String colorize)
Applies a color tint to the image. Accepts color and intensity as optional parameters.
co-color- Color to apply (e.g.,red,blue,FF0022). Default is gray color.in-intensity- Intensity of the color (0-100). Default is 35. See Colorize.
-
colorize
final Transformation.Builder colorize(JsonField<String> colorize)
Sets Builder.colorize to an arbitrary JSON value.
You should usually call Builder.colorize with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
colorProfile
final Transformation.Builder colorProfile(Boolean colorProfile)
Indicates whether the output image should retain the original color profile. See Color profile.
-
colorProfile
final Transformation.Builder colorProfile(JsonField<Boolean> colorProfile)
Sets Builder.colorProfile to an arbitrary JSON value.
You should usually call Builder.colorProfile with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
colorReplace
final Transformation.Builder colorReplace(String colorReplace)
Replaces colors in the image. Supports three formats:
toColor- Replace dominant color with the specified color.toColor_tolerance- Replace dominant color with specified tolerance (0-100).toColor_tolerance_fromColor- Replace a specific color with another within tolerance range. Colors can be hex codes (e.g.,FF0022) or names (e.g.,red,blue). See Color replacement.
-
colorReplace
final Transformation.Builder colorReplace(JsonField<String> colorReplace)
Sets Builder.colorReplace to an arbitrary JSON value.
You should usually call Builder.colorReplace with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
contrastStretch
final Transformation.Builder contrastStretch(Transformation.ContrastStretch contrastStretch)
Automatically enhances the contrast of an image (contrast stretch). See Contrast Stretch.
-
contrastStretch
final Transformation.Builder contrastStretch(JsonField<Transformation.ContrastStretch> contrastStretch)
Sets Builder.contrastStretch to an arbitrary JSON value.
You should usually call Builder.contrastStretch with a well-typed ContrastStretch value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
crop
final Transformation.Builder crop(Transformation.Crop crop)
Crop modes for image resizing. See Crop modes & focus.
-
crop
final Transformation.Builder crop(JsonField<Transformation.Crop> crop)
Sets Builder.crop to an arbitrary JSON value.
You should usually call Builder.crop with a well-typed Crop value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cropMode
final Transformation.Builder cropMode(Transformation.CropMode cropMode)
Additional crop modes for image resizing. See Crop modes & focus.
-
cropMode
final Transformation.Builder cropMode(JsonField<Transformation.CropMode> cropMode)
Sets Builder.cropMode to an arbitrary JSON value.
You should usually call Builder.cropMode with a well-typed CropMode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
defaultImage
final Transformation.Builder defaultImage(String defaultImage)
Specifies a fallback image if the resource is not found, e.g., a URL or file path. See Default image.
-
defaultImage
final Transformation.Builder defaultImage(JsonField<String> defaultImage)
Sets Builder.defaultImage to an arbitrary JSON value.
You should usually call Builder.defaultImage with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
distort
final Transformation.Builder distort(String distort)
Distorts the shape of an image. Supports two modes:
Perspective distortion:
p-x1_y1_x2_y2_x3_y3_x4_y4changes the position of the four corners starting clockwise from top-left.Arc distortion:
a-degreescurves the image upwards (positive values) or downwards (negative values). See Distort effect.
-
distort
final Transformation.Builder distort(JsonField<String> distort)
Sets Builder.distort to an arbitrary JSON value.
You should usually call Builder.distort with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
dpr
final Transformation.Builder dpr(Double dpr)
Accepts values between 0.1 and 5, or
autofor automatic device pixel ratio (DPR) calculation. Also accepts arithmetic expressions.Learn about Arithmetic expressions.
See DPR.
-
dpr
final Transformation.Builder dpr(JsonField<Double> dpr)
Sets Builder.dpr to an arbitrary JSON value.
You should usually call Builder.dpr with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final Transformation.Builder duration(Transformation.Duration duration)
Specifies the duration (in seconds) for trimming videos, e.g.,
5or10.5. Typically used with startOffset to indicate the length from the start offset. Arithmetic expressions are supported. See Trim videos – Duration.
-
duration
final Transformation.Builder duration(JsonField<Transformation.Duration> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Duration value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final Transformation.Builder duration(Double number)
Alias for calling duration with
Duration.ofNumber(number).
-
duration
final Transformation.Builder duration(String string)
Alias for calling duration with
Duration.ofString(string).
-
endOffset
final Transformation.Builder endOffset(Transformation.EndOffset endOffset)
Specifies the end offset (in seconds) for trimming videos, e.g.,
5or10.5. Typically used with startOffset to define a time window. Arithmetic expressions are supported. See Trim videos – End offset.
-
endOffset
final Transformation.Builder endOffset(JsonField<Transformation.EndOffset> endOffset)
Sets Builder.endOffset to an arbitrary JSON value.
You should usually call Builder.endOffset with a well-typed EndOffset value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endOffset
final Transformation.Builder endOffset(Double number)
Alias for calling endOffset with
EndOffset.ofNumber(number).
-
endOffset
final Transformation.Builder endOffset(String string)
Alias for calling endOffset with
EndOffset.ofString(string).
-
flip
final Transformation.Builder flip(Transformation.Flip flip)
Flips or mirrors an image either horizontally, vertically, or both. Acceptable values:
h(horizontal),v(vertical),h_v(horizontal and vertical), orv_h. See Flip.
-
flip
final Transformation.Builder flip(JsonField<Transformation.Flip> flip)
Sets Builder.flip to an arbitrary JSON value.
You should usually call Builder.flip with a well-typed Flip value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
focus
final Transformation.Builder focus(String focus)
Refines padding and cropping behavior for pad resize, maintain ratio, and extract crop modes. Supports manual positions and coordinate-based focus. With AI-based cropping, you can automatically keep key subjects in frame—such as faces or detected objects (e.g.,
fo-face,fo-person,fo-car)— while resizing.
-
focus
final Transformation.Builder focus(JsonField<String> focus)
Sets Builder.focus to an arbitrary JSON value.
You should usually call Builder.focus with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
format
final Transformation.Builder format(Transformation.Format format)
Specifies the output format for images or videos, e.g.,
jpg,png,webp,mp4, orauto. You can also passorigfor images to return the original format. ImageKit automatically delivers images and videos in the optimal format based on device support unless overridden by the dashboard settings or the format parameter. See Image format and Video format.
-
format
final Transformation.Builder format(JsonField<Transformation.Format> format)
Sets Builder.format to an arbitrary JSON value.
You should usually call Builder.format with a well-typed Format value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gradient
final Transformation.Builder gradient(Transformation.Gradient gradient)
Creates a linear gradient with two colors. Pass
truefor a default gradient, or provide a string for a custom gradient. See Gradient.
-
gradient
final Transformation.Builder gradient(JsonField<Transformation.Gradient> gradient)
Sets Builder.gradient to an arbitrary JSON value.
You should usually call Builder.gradient with a well-typed Gradient value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gradient
final Transformation.Builder gradient(String string)
Alias for calling gradient with
Gradient.ofString(string).
-
gradientTrue
final Transformation.Builder gradientTrue()
Alias for calling gradient with
Gradient.ofTrue().
-
grayscale
final Transformation.Builder grayscale(Transformation.Grayscale grayscale)
Enables a grayscale effect for images. See Grayscale.
-
grayscale
final Transformation.Builder grayscale(JsonField<Transformation.Grayscale> grayscale)
Sets Builder.grayscale to an arbitrary JSON value.
You should usually call Builder.grayscale with a well-typed Grayscale value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final Transformation.Builder height(Transformation.Height height)
Specifies the height of the output. If a value between 0 and 1 is provided, it is treated as a percentage (e.g.,
0.5represents 50% of the original height). You can also supply arithmetic expressions (e.g.,ih_mul_0.5). Height transformation – Images · Videos
-
height
final Transformation.Builder height(JsonField<Transformation.Height> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Height value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final Transformation.Builder height(Double number)
Alias for calling height with
Height.ofNumber(number).
-
height
final Transformation.Builder height(String string)
Alias for calling height with
Height.ofString(string).
-
lossless
final Transformation.Builder lossless(Boolean lossless)
Specifies whether the output image (in JPEG or PNG) should be compressed losslessly. See Lossless compression.
-
lossless
final Transformation.Builder lossless(JsonField<Boolean> lossless)
Sets Builder.lossless to an arbitrary JSON value.
You should usually call Builder.lossless with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final Transformation.Builder metadata(Boolean metadata)
By default, ImageKit removes all metadata during automatic image compression. Set this to true to preserve metadata. See Image metadata.
-
metadata
final Transformation.Builder metadata(JsonField<Boolean> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
named
final Transformation.Builder named(String named)
Named transformation reference. See Named transformations.
-
named
final Transformation.Builder named(JsonField<String> named)
Sets Builder.named to an arbitrary JSON value.
You should usually call Builder.named with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
opacity
final Transformation.Builder opacity(Double opacity)
Specifies the opacity level of the output image. See Opacity.
-
opacity
final Transformation.Builder opacity(JsonField<Double> opacity)
Sets Builder.opacity to an arbitrary JSON value.
You should usually call Builder.opacity with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
original
final Transformation.Builder original(Boolean original)
If set to true, serves the original file without applying any transformations. See Deliver original file as-is.
-
original
final Transformation.Builder original(JsonField<Boolean> original)
Sets Builder.original to an arbitrary JSON value.
You should usually call Builder.original with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
overlay
final Transformation.Builder overlay(Overlay overlay)
Specifies an overlay to be applied on the parent image or video. ImageKit supports overlays including images, text, videos, subtitles, and solid colors. See Overlay using layers.
-
overlay
final Transformation.Builder overlay(JsonField<Overlay> overlay)
Sets Builder.overlay to an arbitrary JSON value.
You should usually call Builder.overlay with a well-typed Overlay value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
overlay
final Transformation.Builder overlay(TextOverlay text)
Alias for calling overlay with
Overlay.ofText(text).
-
overlay
final Transformation.Builder overlay(ImageOverlay image)
Alias for calling overlay with
Overlay.ofImage(image).
-
overlay
final Transformation.Builder overlay(VideoOverlay video)
Alias for calling overlay with
Overlay.ofVideo(video).
-
overlay
final Transformation.Builder overlay(SubtitleOverlay subtitle)
Alias for calling overlay with
Overlay.ofSubtitle(subtitle).
-
overlay
final Transformation.Builder overlay(SolidColorOverlay solidColor)
Alias for calling overlay with
Overlay.ofSolidColor(solidColor).
-
textOverlay
final Transformation.Builder textOverlay(String text)
Alias for calling overlay with the following:
TextOverlay.builder() .text(text) .build()
-
imageOverlay
final Transformation.Builder imageOverlay(String input)
Alias for calling overlay with the following:
ImageOverlay.builder() .input(input) .build()
-
videoOverlay
final Transformation.Builder videoOverlay(String input)
Alias for calling overlay with the following:
VideoOverlay.builder() .input(input) .build()
-
subtitleOverlay
final Transformation.Builder subtitleOverlay(String input)
Alias for calling overlay with the following:
SubtitleOverlay.builder() .input(input) .build()
-
solidColorOverlay
final Transformation.Builder solidColorOverlay(String color)
Alias for calling overlay with the following:
SolidColorOverlay.builder() .color(color) .build()
-
page
final Transformation.Builder page(Transformation.Page page)
Extracts a specific page or frame from multi-page or layered files (PDF, PSD, AI). For example, specify by number (e.g.,
2), a range (e.g.,3-4for the 2nd and 3rd layers), or by name (e.g.,name-layer-4for a PSD layer). See Thumbnail extraction.
-
page
final Transformation.Builder page(JsonField<Transformation.Page> page)
Sets Builder.page to an arbitrary JSON value.
You should usually call Builder.page with a well-typed Page value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
page
final Transformation.Builder page(Double number)
Alias for calling page with
Page.ofNumber(number).
-
page
final Transformation.Builder page(String string)
Alias for calling page with
Page.ofString(string).
-
progressive
final Transformation.Builder progressive(Boolean progressive)
Specifies whether the output JPEG image should be rendered progressively. Progressive loading begins with a low-quality, pixelated version of the full image, which gradually improves to provide a faster perceived load time. See Progressive images.
-
progressive
final Transformation.Builder progressive(JsonField<Boolean> progressive)
Sets Builder.progressive to an arbitrary JSON value.
You should usually call Builder.progressive with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
quality
final Transformation.Builder quality(Double quality)
Specifies the quality of the output image for lossy formats such as JPEG, WebP, and AVIF. A higher quality value results in a larger file size with better quality, while a lower value produces a smaller file size with reduced quality. See Quality.
-
quality
final Transformation.Builder quality(JsonField<Double> quality)
Sets Builder.quality to an arbitrary JSON value.
You should usually call Builder.quality with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
radius
final Transformation.Builder radius(Transformation.Radius radius)
Specifies the corner radius for rounded corners.
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
-
radius
final Transformation.Builder radius(JsonField<Transformation.Radius> radius)
Sets Builder.radius to an arbitrary JSON value.
You should usually call Builder.radius with a well-typed Radius value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
radius
final Transformation.Builder radius(Double number)
Alias for calling radius with
Radius.ofNumber(number).
-
radius
final Transformation.Builder radius(String string)
Alias for calling radius with
Radius.ofString(string).
-
radiusMax
final Transformation.Builder radiusMax()
Alias for calling radius with
Radius.ofMax().
-
raw
final Transformation.Builder raw(String raw)
Pass any transformation not directly supported by the SDK. This transformation string is appended to the URL as provided.
-
raw
final Transformation.Builder raw(JsonField<String> raw)
Sets Builder.raw to an arbitrary JSON value.
You should usually call Builder.raw with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rotation
final Transformation.Builder rotation(Transformation.Rotation rotation)
Specifies the rotation angle in degrees. Positive values rotate the image clockwise; you can also use, for example,
N40for counterclockwise rotation orautoto use the orientation specified in the image's EXIF data. For videos, only the following values are supported: 0, 90, 180, 270, or 360. See Rotate.
-
rotation
final Transformation.Builder rotation(JsonField<Transformation.Rotation> rotation)
Sets Builder.rotation to an arbitrary JSON value.
You should usually call Builder.rotation with a well-typed Rotation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
rotation
final Transformation.Builder rotation(Double number)
Alias for calling rotation with
Rotation.ofNumber(number).
-
rotation
final Transformation.Builder rotation(String string)
Alias for calling rotation with
Rotation.ofString(string).
-
shadow
final Transformation.Builder shadow(Transformation.Shadow shadow)
Adds a shadow beneath solid objects in an image with a transparent background. For AI-based drop shadows, refer to aiDropShadow. Pass
truefor a default shadow, or provide a string for a custom shadow. See Shadow.
-
shadow
final Transformation.Builder shadow(JsonField<Transformation.Shadow> shadow)
Sets Builder.shadow to an arbitrary JSON value.
You should usually call Builder.shadow with a well-typed Shadow value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
shadow
final Transformation.Builder shadow(String string)
Alias for calling shadow with
Shadow.ofString(string).
-
shadowTrue
final Transformation.Builder shadowTrue()
Alias for calling shadow with
Shadow.ofTrue().
-
sharpen
final Transformation.Builder sharpen(Transformation.Sharpen sharpen)
Sharpens the input image, highlighting edges and finer details. Pass
truefor default sharpening, or provide a numeric value for custom sharpening. See Sharpen.
-
sharpen
final Transformation.Builder sharpen(JsonField<Transformation.Sharpen> sharpen)
Sets Builder.sharpen to an arbitrary JSON value.
You should usually call Builder.sharpen with a well-typed Sharpen value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sharpen
final Transformation.Builder sharpen(Double number)
Alias for calling sharpen with
Sharpen.ofNumber(number).
-
sharpenTrue
final Transformation.Builder sharpenTrue()
Alias for calling sharpen with
Sharpen.ofTrue().
-
startOffset
final Transformation.Builder startOffset(Transformation.StartOffset startOffset)
Specifies the start offset (in seconds) for trimming videos, e.g.,
5or10.5. Arithmetic expressions are also supported. See Trim videos – Start offset.
-
startOffset
final Transformation.Builder startOffset(JsonField<Transformation.StartOffset> startOffset)
Sets Builder.startOffset to an arbitrary JSON value.
You should usually call Builder.startOffset with a well-typed StartOffset value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startOffset
final Transformation.Builder startOffset(Double number)
Alias for calling startOffset with
StartOffset.ofNumber(number).
-
startOffset
final Transformation.Builder startOffset(String string)
Alias for calling startOffset with
StartOffset.ofString(string).
-
streamingResolutions
final Transformation.Builder streamingResolutions(List<StreamingResolution> streamingResolutions)
An array of resolutions for adaptive bitrate streaming, e.g., `240`, `360`, `480`, `720`, `1080`. See Adaptive Bitrate Streaming.
-
streamingResolutions
final Transformation.Builder streamingResolutions(JsonField<List<StreamingResolution>> streamingResolutions)
Sets Builder.streamingResolutions to an arbitrary JSON value.
You should usually call Builder.streamingResolutions with a well-typed
List<StreamingResolution>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStreamingResolution
final Transformation.Builder addStreamingResolution(StreamingResolution streamingResolution)
Adds a single StreamingResolution to streamingResolutions.
-
trim
final Transformation.Builder trim(Transformation.Trim trim)
Useful for images with a solid or nearly solid background and a central object. This parameter trims the background, leaving only the central object in the output image. See Trim edges.
-
trim
final Transformation.Builder trim(JsonField<Transformation.Trim> trim)
Sets Builder.trim to an arbitrary JSON value.
You should usually call Builder.trim with a well-typed Trim value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
trim
final Transformation.Builder trim(Double number)
Alias for calling trim with
Trim.ofNumber(number).
-
trimTrue
final Transformation.Builder trimTrue()
Alias for calling trim with
Trim.ofTrue().
-
unsharpMask
final Transformation.Builder unsharpMask(Transformation.UnsharpMask unsharpMask)
Applies Unsharp Masking (USM), an image sharpening technique. Pass
truefor a default unsharp mask, or provide a string for a custom unsharp mask. See Unsharp Mask.
-
unsharpMask
final Transformation.Builder unsharpMask(JsonField<Transformation.UnsharpMask> unsharpMask)
Sets Builder.unsharpMask to an arbitrary JSON value.
You should usually call Builder.unsharpMask with a well-typed UnsharpMask value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
unsharpMask
final Transformation.Builder unsharpMask(String string)
Alias for calling unsharpMask with
UnsharpMask.ofString(string).
-
unsharpMaskTrue
final Transformation.Builder unsharpMaskTrue()
Alias for calling unsharpMask with
UnsharpMask.ofTrue().
-
videoCodec
final Transformation.Builder videoCodec(Transformation.VideoCodec videoCodec)
Specifies the video codec, e.g.,
h264,vp9,av1, ornone. See Video codec.
-
videoCodec
final Transformation.Builder videoCodec(JsonField<Transformation.VideoCodec> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed VideoCodec value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final Transformation.Builder width(Transformation.Width width)
Specifies the width of the output. If a value between 0 and 1 is provided, it is treated as a percentage (e.g.,
0.4represents 40% of the original width). You can also supply arithmetic expressions (e.g.,iw_div_2). Width transformation – Images · Videos
-
width
final Transformation.Builder width(JsonField<Transformation.Width> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Width value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final Transformation.Builder width(Double number)
Alias for calling width with
Width.ofNumber(number).
-
width
final Transformation.Builder width(String string)
Alias for calling width with
Width.ofString(string).
-
x
final Transformation.Builder x(Transformation.X x)
Focus using cropped image coordinates - X coordinate. See Focus using cropped coordinates.
-
x
final Transformation.Builder x(JsonField<Transformation.X> x)
Sets Builder.x to an arbitrary JSON value.
You should usually call Builder.x with a well-typed X value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
x
final Transformation.Builder x(Double number)
Alias for calling x with
X.ofNumber(number).
-
x
final Transformation.Builder x(String string)
Alias for calling x with
X.ofString(string).
-
xCenter
final Transformation.Builder xCenter(Transformation.XCenter xCenter)
Focus using cropped image coordinates - X center coordinate. See Focus using cropped coordinates.
-
xCenter
final Transformation.Builder xCenter(JsonField<Transformation.XCenter> xCenter)
Sets Builder.xCenter to an arbitrary JSON value.
You should usually call Builder.xCenter with a well-typed XCenter value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
xCenter
final Transformation.Builder xCenter(Double number)
Alias for calling xCenter with
XCenter.ofNumber(number).
-
xCenter
final Transformation.Builder xCenter(String string)
Alias for calling xCenter with
XCenter.ofString(string).
-
y
final Transformation.Builder y(Transformation.Y y)
Focus using cropped image coordinates - Y coordinate. See Focus using cropped coordinates.
-
y
final Transformation.Builder y(JsonField<Transformation.Y> y)
Sets Builder.y to an arbitrary JSON value.
You should usually call Builder.y with a well-typed Y value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
y
final Transformation.Builder y(Double number)
Alias for calling y with
Y.ofNumber(number).
-
y
final Transformation.Builder y(String string)
Alias for calling y with
Y.ofString(string).
-
yCenter
final Transformation.Builder yCenter(Transformation.YCenter yCenter)
Focus using cropped image coordinates - Y center coordinate. See Focus using cropped coordinates.
-
yCenter
final Transformation.Builder yCenter(JsonField<Transformation.YCenter> yCenter)
Sets Builder.yCenter to an arbitrary JSON value.
You should usually call Builder.yCenter with a well-typed YCenter value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
yCenter
final Transformation.Builder yCenter(Double number)
Alias for calling yCenter with
YCenter.ofNumber(number).
-
yCenter
final Transformation.Builder yCenter(String string)
Alias for calling yCenter with
YCenter.ofString(string).
-
zoom
final Transformation.Builder zoom(Double zoom)
Accepts a numeric value that determines how much to zoom in or out of the cropped area. It should be used in conjunction with fo-face or fo-<object_name>. See Zoom.
-
zoom
final Transformation.Builder zoom(JsonField<Double> zoom)
Sets Builder.zoom to an arbitrary JSON value.
You should usually call Builder.zoom with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Transformation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Transformation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Transformation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Transformation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Transformation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Transformation build()
Returns an immutable instance of Transformation.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-