Package io.imagekit.models
Class Transformation.Duration
-
- All Implemented Interfaces:
public final class Transformation.DurationSpecifies the duration (in seconds) for trimming videos, e.g.,
5or10.5. Typically used with startOffset to indicate the length from the start offset. Arithmetic expressions are supported. See Trim videos – Duration.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Duration.VisitorAn interface that defines how to map each variant of Duration to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Duration.Visitor<T> visitor)final Transformation.Durationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.DurationofNumber(Double number)final static Transformation.DurationofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Duration.Visitor<T> visitor)
-
validate
final Transformation.Duration validate()
-
ofNumber
final static Transformation.Duration ofNumber(Double number)
-
ofString
final static Transformation.Duration ofString(String string)
-
-
-
-