Class Transformation.Flip
-
- All Implemented Interfaces:
-
io.imagekit.core.Enum
public final class Transformation.Flip implements EnumFlips or mirrors an image either horizontally, vertically, or both. Acceptable values:
h(horizontal),v(vertical),h_v(horizontal and vertical), orv_h. See Flip.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumTransformation.Flip.KnownAn enum containing Flip's known values.
public enumTransformation.Flip.ValueAn enum containing Flip's known values, as well as an _UNKNOWN member.
An instance of Flip can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static Transformation.FlipHpublic final static Transformation.FlipVpublic final static Transformation.FlipH_Vpublic final static Transformation.FlipV_H
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final Transformation.Flip.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final Transformation.Flip.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final Transformation.Flipvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.Flipof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final Transformation.Flip.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final Transformation.Flip.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final Transformation.Flip validate()
-
of
final static Transformation.Flip of(String value)
-
-
-
-