Class Transformation.Format

  • All Implemented Interfaces:
    io.imagekit.core.Enum

    
    public final class Transformation.Format
     implements Enum
                        

    Specifies the output format for images or videos, e.g., jpg, png, webp, mp4, or auto. You can also pass orig for images to return the original format. ImageKit automatically delivers images and videos in the optimal format based on device support unless overridden by the dashboard settings or the format parameter. See Image format and Video format.

    • Constructor Detail

    • Method Detail

      • _value

         final JsonField<String> _value()

        Returns this class instance's raw value.

        This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.

      • value

         final Transformation.Format.Value value()

        Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.

        Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.

      • known

         final Transformation.Format.Known known()

        Returns an enum member corresponding to this class instance's value.

        Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.

      • asString

         final String asString()

        Returns this class instance's primitive wire representation.

        This differs from the toString method because that method is primarily for debugging and generally doesn't throw.

      • validate

         final Transformation.Format validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.