Package io.imagekit.models
Class Transformation.Height
-
- All Implemented Interfaces:
public final class Transformation.HeightSpecifies the height of the output. If a value between 0 and 1 is provided, it is treated as a percentage (e.g.,
0.5represents 50% of the original height). You can also supply arithmetic expressions (e.g.,ih_mul_0.5). Height transformation – Images · Videos
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Height.VisitorAn interface that defines how to map each variant of Height to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Height.Visitor<T> visitor)final Transformation.Heightvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.HeightofNumber(Double number)final static Transformation.HeightofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Height.Visitor<T> visitor)
-
validate
final Transformation.Height validate()
-
ofNumber
final static Transformation.Height ofNumber(Double number)
-
ofString
final static Transformation.Height ofString(String string)
-
-
-
-