Class Transformation.Rotation
-
- All Implemented Interfaces:
public final class Transformation.RotationSpecifies the rotation angle in degrees. Positive values rotate the image clockwise; you can also use, for example,
N40for counterclockwise rotation orautoto use the orientation specified in the image's EXIF data. For videos, only the following values are supported: 0, 90, 180, 270, or 360. See Rotate.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Rotation.VisitorAn interface that defines how to map each variant of Rotation to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Rotation.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final Transformation.Rotationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.RotationofNumber(Double number)final static Transformation.RotationofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Rotation.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = rotation.accept(new Rotation.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final Transformation.Rotation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static Transformation.Rotation ofNumber(Double number)
-
ofString
final static Transformation.Rotation ofString(String string)
-
-
-
-