Class Transformation.Shadow

  • All Implemented Interfaces:

    
    public final class Transformation.Shadow
    
                        

    Adds a shadow beneath solid objects in an image with a transparent background. For AI-based drop shadows, refer to aiDropShadow. Pass true for a default shadow, or provide a string for a custom shadow. See Shadow.