Package io.imagekit.models
Class Transformation.StartOffset
-
- All Implemented Interfaces:
public final class Transformation.StartOffsetSpecifies the start offset (in seconds) for trimming videos, e.g.,
5or10.5. Arithmetic expressions are also supported. See Trim videos – Start offset.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.StartOffset.VisitorAn interface that defines how to map each variant of StartOffset to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.StartOffset.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final Transformation.StartOffsetvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.StartOffsetofNumber(Double number)final static Transformation.StartOffsetofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.StartOffset.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = startOffset.accept(new StartOffset.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final Transformation.StartOffset validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static Transformation.StartOffset ofNumber(Double number)
-
ofString
final static Transformation.StartOffset ofString(String string)
-
-
-
-