Package io.imagekit.models
Interface Transformation.StartOffset.Visitor
-
- All Implemented Interfaces:
public interface Transformation.StartOffset.Visitor<T extends Object>An interface that defines how to map each variant of StartOffset to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitNumber(Double number)abstract TvisitString(String string)Tunknown(JsonValue json)Maps an unknown variant of StartOffset to a value of type T. -
-
Method Detail
-
visitNumber
abstract T visitNumber(Double number)
-
visitString
abstract T visitString(String string)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of StartOffset to a value of type T.
An instance of StartOffset can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-