Class Transformation.Trim

  • All Implemented Interfaces:

    
    public final class Transformation.Trim
    
                        

    Useful for images with a solid or nearly solid background and a central object. This parameter trims the background, leaving only the central object in the output image. See Trim edges.