Package io.imagekit.models
Class Transformation.UnsharpMask
-
- All Implemented Interfaces:
public final class Transformation.UnsharpMaskApplies Unsharp Masking (USM), an image sharpening technique. Pass
truefor a default unsharp mask, or provide a string for a custom unsharp mask. See Unsharp Mask.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.UnsharpMask.VisitorAn interface that defines how to map each variant of UnsharpMask to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<JsonValue>true_()final Optional<String>string()final BooleanisTrue()final BooleanisString()final JsonValueasTrue()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.UnsharpMask.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final Transformation.UnsharpMaskvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.UnsharpMaskofTrue()final static Transformation.UnsharpMaskofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.UnsharpMask.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = unsharpMask.accept(new UnsharpMask.Visitor<Optional<String>>() { @Override public Optional<String> visitTrue(JsonValue true_) { return Optional.of(true_.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final Transformation.UnsharpMask validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofTrue
final static Transformation.UnsharpMask ofTrue()
-
ofString
final static Transformation.UnsharpMask ofString(String string)
-
-
-
-