Package io.imagekit.models
Class Transformation.Width
-
- All Implemented Interfaces:
public final class Transformation.WidthSpecifies the width of the output. If a value between 0 and 1 is provided, it is treated as a percentage (e.g.,
0.4represents 40% of the original width). You can also supply arithmetic expressions (e.g.,iw_div_2). Width transformation – Images · Videos
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Width.VisitorAn interface that defines how to map each variant of Width to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Width.Visitor<T> visitor)final Transformation.Widthvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.WidthofNumber(Double number)final static Transformation.WidthofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Width.Visitor<T> visitor)
-
validate
final Transformation.Width validate()
-
ofNumber
final static Transformation.Width ofNumber(Double number)
-
ofString
final static Transformation.Width ofString(String string)
-
-
-
-