Package io.imagekit.models
Class Transformation.XCenter
-
- All Implemented Interfaces:
public final class Transformation.XCenterFocus using cropped image coordinates - X center coordinate. See Focus using cropped coordinates.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.XCenter.VisitorAn interface that defines how to map each variant of XCenter to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.XCenter.Visitor<T> visitor)final Transformation.XCentervalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.XCenterofNumber(Double number)final static Transformation.XCenterofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.XCenter.Visitor<T> visitor)
-
validate
final Transformation.XCenter validate()
-
ofNumber
final static Transformation.XCenter ofNumber(Double number)
-
ofString
final static Transformation.XCenter ofString(String string)
-
-
-
-