Package io.imagekit.models
Class Transformation.Y
-
- All Implemented Interfaces:
public final class Transformation.YFocus using cropped image coordinates - Y coordinate. See Focus using cropped coordinates.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Y.VisitorAn interface that defines how to map each variant of Y to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Y.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final Transformation.Yvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.YofNumber(Double number)final static Transformation.YofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Y.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = y.accept(new Y.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final Transformation.Y validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static Transformation.Y ofNumber(Double number)
-
ofString
final static Transformation.Y ofString(String string)
-
-
-
-