Class VideoOverlay.Builder
-
- All Implemented Interfaces:
public final class VideoOverlay.BuilderA builder for VideoOverlay.
-
-
Method Summary
Modifier and Type Method Description final VideoOverlay.BuilderlayerMode(BaseOverlay.LayerMode layerMode)Controls how the layer blends with the base image or underlying content. final VideoOverlay.BuilderlayerMode(JsonField<BaseOverlay.LayerMode> layerMode)Sets Builder.layerMode to an arbitrary JSON value. final VideoOverlay.Builderposition(OverlayPosition position)Specifies the overlay's position relative to the parent asset. final VideoOverlay.Builderposition(JsonField<OverlayPosition> position)Sets Builder.position to an arbitrary JSON value. final VideoOverlay.Buildertiming(OverlayTiming timing)Specifies timing information for the overlay (only applicable if the base asset is a video). final VideoOverlay.Buildertiming(JsonField<OverlayTiming> timing)Sets Builder.timing to an arbitrary JSON value. final VideoOverlay.Builderinput(String input)Specifies the relative path to the video used as an overlay. final VideoOverlay.Builderinput(JsonField<String> input)Sets Builder.input to an arbitrary JSON value. final VideoOverlay.Buildertype(JsonValue type)Sets the field to an arbitrary JSON value. final VideoOverlay.Builderencoding(VideoOverlay.Encoding encoding)The input path can be included in the layer as either i-{input}orie-{base64_encoded_input}.final VideoOverlay.Builderencoding(JsonField<VideoOverlay.Encoding> encoding)Sets Builder.encoding to an arbitrary JSON value. final VideoOverlay.Buildertransformation(List<Transformation> transformation)Array of transformation to be applied to the overlay video. final VideoOverlay.Buildertransformation(JsonField<List<Transformation>> transformation)Sets Builder.transformation to an arbitrary JSON value. final VideoOverlay.BuilderaddTransformation(Transformation transformation)Adds a single Transformation to Builder.transformation. final VideoOverlay.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final VideoOverlay.BuilderputAdditionalProperty(String key, JsonValue value)final VideoOverlay.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final VideoOverlay.BuilderremoveAdditionalProperty(String key)final VideoOverlay.BuilderremoveAllAdditionalProperties(Set<String> keys)final VideoOverlaybuild()Returns an immutable instance of VideoOverlay. -
-
Method Detail
-
layerMode
final VideoOverlay.Builder layerMode(BaseOverlay.LayerMode layerMode)
Controls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
layerMode
final VideoOverlay.Builder layerMode(JsonField<BaseOverlay.LayerMode> layerMode)
Sets Builder.layerMode to an arbitrary JSON value.
You should usually call Builder.layerMode with a well-typed BaseOverlay.LayerMode value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
position
final VideoOverlay.Builder position(OverlayPosition position)
Specifies the overlay's position relative to the parent asset. See Position of Layer.
-
position
final VideoOverlay.Builder position(JsonField<OverlayPosition> position)
Sets Builder.position to an arbitrary JSON value.
You should usually call Builder.position with a well-typed OverlayPosition value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timing
final VideoOverlay.Builder timing(OverlayTiming timing)
Specifies timing information for the overlay (only applicable if the base asset is a video). See Position of Layer.
-
timing
final VideoOverlay.Builder timing(JsonField<OverlayTiming> timing)
Sets Builder.timing to an arbitrary JSON value.
You should usually call Builder.timing with a well-typed OverlayTiming value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
input
final VideoOverlay.Builder input(String input)
Specifies the relative path to the video used as an overlay.
-
input
final VideoOverlay.Builder input(JsonField<String> input)
Sets Builder.input to an arbitrary JSON value.
You should usually call Builder.input with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final VideoOverlay.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("video")This method is primarily for setting the field to an undocumented or not yet supported value.
-
encoding
final VideoOverlay.Builder encoding(VideoOverlay.Encoding encoding)
The input path can be included in the layer as either
i-{input}orie-{base64_encoded_input}. By default, the SDK determines the appropriate format automatically. To always use base64 encoding (ie-{base64}), set this parameter tobase64. To always use plain text (i-{input}), set it toplain.Regardless of the encoding method:
Leading and trailing slashes are removed.
Remaining slashes within the path are replaced with
@@when using plain text.
-
encoding
final VideoOverlay.Builder encoding(JsonField<VideoOverlay.Encoding> encoding)
Sets Builder.encoding to an arbitrary JSON value.
You should usually call Builder.encoding with a well-typed Encoding value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transformation
final VideoOverlay.Builder transformation(List<Transformation> transformation)
Array of transformation to be applied to the overlay video. Except
streamingResolutions, all other video transformations are supported. See Video transformations.
-
transformation
final VideoOverlay.Builder transformation(JsonField<List<Transformation>> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed
List<Transformation>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTransformation
final VideoOverlay.Builder addTransformation(Transformation transformation)
Adds a single Transformation to Builder.transformation.
-
additionalProperties
final VideoOverlay.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VideoOverlay.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VideoOverlay.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VideoOverlay.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VideoOverlay.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VideoOverlay build()
Returns an immutable instance of VideoOverlay.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.input()
-
-
-
-