Class RequestBandwidthEntry
-
- All Implemented Interfaces:
public final class RequestBandwidthEntry
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRequestBandwidthEntry.BuilderA builder for RequestBandwidthEntry.
-
Method Summary
Modifier and Type Method Description final DoublebandwidthBytes()Total bandwidth used in bytes. final DoublerequestCount()Number of requests. final JsonField<Double>_bandwidthBytes()Returns the raw JSON value of bandwidthBytes. final JsonField<Double>_requestCount()Returns the raw JSON value of requestCount. final Map<String, JsonValue>_additionalProperties()final RequestBandwidthEntry.BuildertoBuilder()final RequestBandwidthEntryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RequestBandwidthEntry.Builderbuilder()Returns a mutable builder for constructing an instance of RequestBandwidthEntry. -
-
Method Detail
-
bandwidthBytes
final Double bandwidthBytes()
Total bandwidth used in bytes.
-
requestCount
final Double requestCount()
Number of requests.
-
_bandwidthBytes
final JsonField<Double> _bandwidthBytes()
Returns the raw JSON value of bandwidthBytes.
Unlike bandwidthBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_requestCount
final JsonField<Double> _requestCount()
Returns the raw JSON value of requestCount.
Unlike requestCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RequestBandwidthEntry.Builder toBuilder()
-
validate
final RequestBandwidthEntry validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RequestBandwidthEntry.Builder builder()
Returns a mutable builder for constructing an instance of RequestBandwidthEntry.
The following fields are required:
.bandwidthBytes() .requestCount()
-
-
-
-