Class UsageAnalyticsResponse
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.BuilderA builder for UsageAnalyticsResponse.
public final classUsageAnalyticsResponse.BrowserCDN traffic grouped by browser.
public final classUsageAnalyticsResponse.CacheCDN cache hit, miss and error counts for the date range.
public final classUsageAnalyticsResponse.CountryCDN traffic grouped by country.
public final classUsageAnalyticsResponse.DeviceCDN traffic grouped by device and operating system (e.g.
Desktop - Apple Mac,Smartphone - Apple iPhone).public final classUsageAnalyticsResponse.ErrorReasonpublic final classUsageAnalyticsResponse.Extensionpublic final classUsageAnalyticsResponse.FormatCDN traffic grouped by response
Content-Type.public final classUsageAnalyticsResponse.StatusCodepublic final classUsageAnalyticsResponse.Top404Assetpublic final classUsageAnalyticsResponse.TopImagesTop image assets by traffic.
public final classUsageAnalyticsResponse.TopImageTransformsTop image transformation strings by traffic.
public final classUsageAnalyticsResponse.TopOtherAssetsTop non-image, non-video assets by traffic.
public final classUsageAnalyticsResponse.TopReferrersTop HTTP referrers by traffic.
public final classUsageAnalyticsResponse.TopUserAgentsTop user agents by traffic.
public final classUsageAnalyticsResponse.TopVideosTop video assets by traffic.
public final classUsageAnalyticsResponse.TopVideoTransformsTop video transformation strings by traffic.
public final classUsageAnalyticsResponse.UrlEndpointsCDN traffic grouped by configured URL endpoint. Traffic that does not match any named URL endpoint pattern is grouped under
Default.public final classUsageAnalyticsResponse.VideoProcessing
-
Method Summary
Modifier and Type Method Description final DoublebandwidthBytes()Total bandwidth, in bytes, utilized during the specified date range. final UsageAnalyticsResponse.Browserbrowser()CDN traffic grouped by browser. final UsageAnalyticsResponse.Cachecache()CDN cache hit, miss and error counts for the date range. final UsageAnalyticsResponse.Countrycountry()CDN traffic grouped by country. final UsageAnalyticsResponse.Devicedevice()CDN traffic grouped by device and operating system (e.g. final LocalDateendDate()End date of the computed analytics data. final List<UsageAnalyticsResponse.ErrorReason>errorReasons()Request count grouped by origin error reason. final List<UsageAnalyticsResponse.Extension>extensions()Raw per-extension operation counts for the date range. final UsageAnalyticsResponse.Formatformat()CDN traffic grouped by response Content-Type.final OffsetDateTimegeneratedAt()Date and time when the analytics data was computed. final DoublerequestCount()Total number of requests made during the specified date range. final LocalDatestartDate()Start date of the computed analytics data. final List<UsageAnalyticsResponse.StatusCode>statusCodes()Request count grouped by HTTP status code. final List<UsageAnalyticsResponse.Top404Asset>top404Assets()Top URLs that returned a 404 response. final UsageAnalyticsResponse.TopImagestopImages()Top image assets by traffic. final UsageAnalyticsResponse.TopImageTransformstopImageTransforms()Top image transformation strings by traffic. final UsageAnalyticsResponse.TopOtherAssetstopOtherAssets()Top non-image, non-video assets by traffic. final UsageAnalyticsResponse.TopReferrerstopReferrers()Top HTTP referrers by traffic. final UsageAnalyticsResponse.TopUserAgentstopUserAgents()Top user agents by traffic. final UsageAnalyticsResponse.TopVideostopVideos()Top video assets by traffic. final UsageAnalyticsResponse.TopVideoTransformstopVideoTransforms()Top video transformation strings by traffic. final UsageAnalyticsResponse.UrlEndpointsurlEndpoints()CDN traffic grouped by configured URL endpoint. final List<UsageAnalyticsResponse.VideoProcessing>videoProcessing()Raw observed video transcode output duration, in seconds, grouped by resolution and codec. final JsonField<Double>_bandwidthBytes()Returns the raw JSON value of bandwidthBytes. final JsonField<UsageAnalyticsResponse.Browser>_browser()Returns the raw JSON value of browser. final JsonField<UsageAnalyticsResponse.Cache>_cache()Returns the raw JSON value of cache. final JsonField<UsageAnalyticsResponse.Country>_country()Returns the raw JSON value of country. final JsonField<UsageAnalyticsResponse.Device>_device()Returns the raw JSON value of device. final JsonField<LocalDate>_endDate()Returns the raw JSON value of endDate. final JsonField<List<UsageAnalyticsResponse.ErrorReason>>_errorReasons()Returns the raw JSON value of errorReasons. final JsonField<List<UsageAnalyticsResponse.Extension>>_extensions()Returns the raw JSON value of extensions. final JsonField<UsageAnalyticsResponse.Format>_format()Returns the raw JSON value of format. final JsonField<OffsetDateTime>_generatedAt()Returns the raw JSON value of generatedAt. final JsonField<Double>_requestCount()Returns the raw JSON value of requestCount. final JsonField<LocalDate>_startDate()Returns the raw JSON value of startDate. final JsonField<List<UsageAnalyticsResponse.StatusCode>>_statusCodes()Returns the raw JSON value of statusCodes. final JsonField<List<UsageAnalyticsResponse.Top404Asset>>_top404Assets()Returns the raw JSON value of top404Assets. final JsonField<UsageAnalyticsResponse.TopImages>_topImages()Returns the raw JSON value of topImages. final JsonField<UsageAnalyticsResponse.TopImageTransforms>_topImageTransforms()Returns the raw JSON value of topImageTransforms. final JsonField<UsageAnalyticsResponse.TopOtherAssets>_topOtherAssets()Returns the raw JSON value of topOtherAssets. final JsonField<UsageAnalyticsResponse.TopReferrers>_topReferrers()Returns the raw JSON value of topReferrers. final JsonField<UsageAnalyticsResponse.TopUserAgents>_topUserAgents()Returns the raw JSON value of topUserAgents. final JsonField<UsageAnalyticsResponse.TopVideos>_topVideos()Returns the raw JSON value of topVideos. final JsonField<UsageAnalyticsResponse.TopVideoTransforms>_topVideoTransforms()Returns the raw JSON value of topVideoTransforms. final JsonField<UsageAnalyticsResponse.UrlEndpoints>_urlEndpoints()Returns the raw JSON value of urlEndpoints. final JsonField<List<UsageAnalyticsResponse.VideoProcessing>>_videoProcessing()Returns the raw JSON value of videoProcessing. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.BuildertoBuilder()final UsageAnalyticsResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Builderbuilder()Returns a mutable builder for constructing an instance of UsageAnalyticsResponse. -
-
Method Detail
-
bandwidthBytes
final Double bandwidthBytes()
Total bandwidth, in bytes, utilized during the specified date range.
-
browser
final UsageAnalyticsResponse.Browser browser()
CDN traffic grouped by browser.
-
cache
final UsageAnalyticsResponse.Cache cache()
CDN cache hit, miss and error counts for the date range.
-
country
final UsageAnalyticsResponse.Country country()
CDN traffic grouped by country.
-
device
final UsageAnalyticsResponse.Device device()
CDN traffic grouped by device and operating system (e.g.
Desktop - Apple Mac,Smartphone - Apple iPhone).
-
errorReasons
final List<UsageAnalyticsResponse.ErrorReason> errorReasons()
Request count grouped by origin error reason. This covers failed origin fetches, such as an asset not found at origin or an origin timeout. It is not the HTTP status code returned to the client, see
statusCodesfor that.
-
extensions
final List<UsageAnalyticsResponse.Extension> extensions()
Raw per-extension operation counts for the date range. These are raw operation counts, not billable extension units. For billable usage, use the
/v1/accounts/usageendpoint.
-
format
final UsageAnalyticsResponse.Format format()
CDN traffic grouped by response
Content-Type.
-
generatedAt
final OffsetDateTime generatedAt()
Date and time when the analytics data was computed. Use this to gauge how fresh the returned data is. The date and time is in ISO8601 format.
-
requestCount
final Double requestCount()
Total number of requests made during the specified date range.
-
statusCodes
final List<UsageAnalyticsResponse.StatusCode> statusCodes()
Request count grouped by HTTP status code.
-
top404Assets
final List<UsageAnalyticsResponse.Top404Asset> top404Assets()
Top URLs that returned a 404 response.
-
topImages
final UsageAnalyticsResponse.TopImages topImages()
Top image assets by traffic.
-
topImageTransforms
final UsageAnalyticsResponse.TopImageTransforms topImageTransforms()
Top image transformation strings by traffic.
-
topOtherAssets
final UsageAnalyticsResponse.TopOtherAssets topOtherAssets()
Top non-image, non-video assets by traffic.
-
topReferrers
final UsageAnalyticsResponse.TopReferrers topReferrers()
Top HTTP referrers by traffic.
-
topUserAgents
final UsageAnalyticsResponse.TopUserAgents topUserAgents()
Top user agents by traffic.
-
topVideos
final UsageAnalyticsResponse.TopVideos topVideos()
Top video assets by traffic.
-
topVideoTransforms
final UsageAnalyticsResponse.TopVideoTransforms topVideoTransforms()
Top video transformation strings by traffic.
-
urlEndpoints
final UsageAnalyticsResponse.UrlEndpoints urlEndpoints()
CDN traffic grouped by configured URL endpoint. Traffic that does not match any named URL endpoint pattern is grouped under
Default.
-
videoProcessing
final List<UsageAnalyticsResponse.VideoProcessing> videoProcessing()
Raw observed video transcode output duration, in seconds, grouped by resolution and codec. These are raw seconds, not billable Video Processing Units (VPU). For billable VPU totals, use the
/v1/accounts/usageendpoint.
-
_bandwidthBytes
final JsonField<Double> _bandwidthBytes()
Returns the raw JSON value of bandwidthBytes.
Unlike bandwidthBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_browser
final JsonField<UsageAnalyticsResponse.Browser> _browser()
Returns the raw JSON value of browser.
Unlike browser, this method doesn't throw if the JSON field has an unexpected type.
-
_cache
final JsonField<UsageAnalyticsResponse.Cache> _cache()
Returns the raw JSON value of cache.
Unlike cache, this method doesn't throw if the JSON field has an unexpected type.
-
_country
final JsonField<UsageAnalyticsResponse.Country> _country()
Returns the raw JSON value of country.
Unlike country, this method doesn't throw if the JSON field has an unexpected type.
-
_device
final JsonField<UsageAnalyticsResponse.Device> _device()
Returns the raw JSON value of device.
Unlike device, this method doesn't throw if the JSON field has an unexpected type.
-
_endDate
final JsonField<LocalDate> _endDate()
Returns the raw JSON value of endDate.
Unlike endDate, this method doesn't throw if the JSON field has an unexpected type.
-
_errorReasons
final JsonField<List<UsageAnalyticsResponse.ErrorReason>> _errorReasons()
Returns the raw JSON value of errorReasons.
Unlike errorReasons, this method doesn't throw if the JSON field has an unexpected type.
-
_extensions
final JsonField<List<UsageAnalyticsResponse.Extension>> _extensions()
Returns the raw JSON value of extensions.
Unlike extensions, this method doesn't throw if the JSON field has an unexpected type.
-
_format
final JsonField<UsageAnalyticsResponse.Format> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_generatedAt
final JsonField<OffsetDateTime> _generatedAt()
Returns the raw JSON value of generatedAt.
Unlike generatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_requestCount
final JsonField<Double> _requestCount()
Returns the raw JSON value of requestCount.
Unlike requestCount, this method doesn't throw if the JSON field has an unexpected type.
-
_startDate
final JsonField<LocalDate> _startDate()
Returns the raw JSON value of startDate.
Unlike startDate, this method doesn't throw if the JSON field has an unexpected type.
-
_statusCodes
final JsonField<List<UsageAnalyticsResponse.StatusCode>> _statusCodes()
Returns the raw JSON value of statusCodes.
Unlike statusCodes, this method doesn't throw if the JSON field has an unexpected type.
-
_top404Assets
final JsonField<List<UsageAnalyticsResponse.Top404Asset>> _top404Assets()
Returns the raw JSON value of top404Assets.
Unlike top404Assets, this method doesn't throw if the JSON field has an unexpected type.
-
_topImages
final JsonField<UsageAnalyticsResponse.TopImages> _topImages()
Returns the raw JSON value of topImages.
Unlike topImages, this method doesn't throw if the JSON field has an unexpected type.
-
_topImageTransforms
final JsonField<UsageAnalyticsResponse.TopImageTransforms> _topImageTransforms()
Returns the raw JSON value of topImageTransforms.
Unlike topImageTransforms, this method doesn't throw if the JSON field has an unexpected type.
-
_topOtherAssets
final JsonField<UsageAnalyticsResponse.TopOtherAssets> _topOtherAssets()
Returns the raw JSON value of topOtherAssets.
Unlike topOtherAssets, this method doesn't throw if the JSON field has an unexpected type.
-
_topReferrers
final JsonField<UsageAnalyticsResponse.TopReferrers> _topReferrers()
Returns the raw JSON value of topReferrers.
Unlike topReferrers, this method doesn't throw if the JSON field has an unexpected type.
-
_topUserAgents
final JsonField<UsageAnalyticsResponse.TopUserAgents> _topUserAgents()
Returns the raw JSON value of topUserAgents.
Unlike topUserAgents, this method doesn't throw if the JSON field has an unexpected type.
-
_topVideos
final JsonField<UsageAnalyticsResponse.TopVideos> _topVideos()
Returns the raw JSON value of topVideos.
Unlike topVideos, this method doesn't throw if the JSON field has an unexpected type.
-
_topVideoTransforms
final JsonField<UsageAnalyticsResponse.TopVideoTransforms> _topVideoTransforms()
Returns the raw JSON value of topVideoTransforms.
Unlike topVideoTransforms, this method doesn't throw if the JSON field has an unexpected type.
-
_urlEndpoints
final JsonField<UsageAnalyticsResponse.UrlEndpoints> _urlEndpoints()
Returns the raw JSON value of urlEndpoints.
Unlike urlEndpoints, this method doesn't throw if the JSON field has an unexpected type.
-
_videoProcessing
final JsonField<List<UsageAnalyticsResponse.VideoProcessing>> _videoProcessing()
Returns the raw JSON value of videoProcessing.
Unlike videoProcessing, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Builder toBuilder()
-
validate
final UsageAnalyticsResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Builder builder()
Returns a mutable builder for constructing an instance of UsageAnalyticsResponse.
The following fields are required:
.bandwidthBytes() .browser() .cache() .country() .device() .endDate() .errorReasons() .extensions() .format() .generatedAt() .requestCount() .startDate() .statusCodes() .top404Assets() .topImages() .topImageTransforms() .topOtherAssets() .topReferrers() .topUserAgents() .topVideos() .topVideoTransforms() .urlEndpoints() .videoProcessing()
-
-
-
-