Class UsageAnalyticsResponse.Browser.ByBandwidth.Builder
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.Browser.ByBandwidth.BuilderA builder for ByBandwidth.
-
-
Method Summary
-
-
Method Detail
-
bandwidthBytes
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder bandwidthBytes(Double bandwidthBytes)
Total bandwidth used in bytes.
-
bandwidthBytes
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder bandwidthBytes(JsonField<Double> bandwidthBytes)
Sets Builder.bandwidthBytes to an arbitrary JSON value.
You should usually call Builder.bandwidthBytes with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestCount
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder requestCount(Double requestCount)
Number of requests.
-
requestCount
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder requestCount(JsonField<Double> requestCount)
Sets Builder.requestCount to an arbitrary JSON value.
You should usually call Builder.requestCount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder name(String name)
Browser name (e.g.
Chrome).
-
name
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UsageAnalyticsResponse.Browser.ByBandwidth.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UsageAnalyticsResponse.Browser.ByBandwidth build()
Returns an immutable instance of ByBandwidth.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.bandwidthBytes() .requestCount() .name()
-
-
-
-