Class UsageAnalyticsResponse.Builder
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.BuilderA builder for UsageAnalyticsResponse.
-
-
Method Summary
-
-
Method Detail
-
bandwidthBytes
final UsageAnalyticsResponse.Builder bandwidthBytes(Double bandwidthBytes)
Total bandwidth, in bytes, utilized during the specified date range.
-
bandwidthBytes
final UsageAnalyticsResponse.Builder bandwidthBytes(JsonField<Double> bandwidthBytes)
Sets Builder.bandwidthBytes to an arbitrary JSON value.
You should usually call Builder.bandwidthBytes with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
browser
final UsageAnalyticsResponse.Builder browser(UsageAnalyticsResponse.Browser browser)
CDN traffic grouped by browser.
-
browser
final UsageAnalyticsResponse.Builder browser(JsonField<UsageAnalyticsResponse.Browser> browser)
Sets Builder.browser to an arbitrary JSON value.
You should usually call Builder.browser with a well-typed Browser value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
cache
final UsageAnalyticsResponse.Builder cache(UsageAnalyticsResponse.Cache cache)
CDN cache hit, miss and error counts for the date range.
-
cache
final UsageAnalyticsResponse.Builder cache(JsonField<UsageAnalyticsResponse.Cache> cache)
Sets Builder.cache to an arbitrary JSON value.
You should usually call Builder.cache with a well-typed Cache value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
country
final UsageAnalyticsResponse.Builder country(UsageAnalyticsResponse.Country country)
CDN traffic grouped by country.
-
country
final UsageAnalyticsResponse.Builder country(JsonField<UsageAnalyticsResponse.Country> country)
Sets Builder.country to an arbitrary JSON value.
You should usually call Builder.country with a well-typed Country value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
device
final UsageAnalyticsResponse.Builder device(UsageAnalyticsResponse.Device device)
CDN traffic grouped by device and operating system (e.g.
Desktop - Apple Mac,Smartphone - Apple iPhone).
-
device
final UsageAnalyticsResponse.Builder device(JsonField<UsageAnalyticsResponse.Device> device)
Sets Builder.device to an arbitrary JSON value.
You should usually call Builder.device with a well-typed Device value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
endDate
final UsageAnalyticsResponse.Builder endDate(LocalDate endDate)
End date of the computed analytics data.
-
endDate
final UsageAnalyticsResponse.Builder endDate(JsonField<LocalDate> endDate)
Sets Builder.endDate to an arbitrary JSON value.
You should usually call Builder.endDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
errorReasons
final UsageAnalyticsResponse.Builder errorReasons(List<UsageAnalyticsResponse.ErrorReason> errorReasons)
Request count grouped by origin error reason. This covers failed origin fetches, such as an asset not found at origin or an origin timeout. It is not the HTTP status code returned to the client, see
statusCodesfor that.
-
errorReasons
final UsageAnalyticsResponse.Builder errorReasons(JsonField<List<UsageAnalyticsResponse.ErrorReason>> errorReasons)
Sets Builder.errorReasons to an arbitrary JSON value.
You should usually call Builder.errorReasons with a well-typed
List<ErrorReason>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addErrorReason
final UsageAnalyticsResponse.Builder addErrorReason(UsageAnalyticsResponse.ErrorReason errorReason)
Adds a single ErrorReason to errorReasons.
-
extensions
final UsageAnalyticsResponse.Builder extensions(List<UsageAnalyticsResponse.Extension> extensions)
Raw per-extension operation counts for the date range. These are raw operation counts, not billable extension units. For billable usage, use the
/v1/accounts/usageendpoint.
-
extensions
final UsageAnalyticsResponse.Builder extensions(JsonField<List<UsageAnalyticsResponse.Extension>> extensions)
Sets Builder.extensions to an arbitrary JSON value.
You should usually call Builder.extensions with a well-typed
List<Extension>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExtension
final UsageAnalyticsResponse.Builder addExtension(UsageAnalyticsResponse.Extension extension)
Adds a single Extension to extensions.
-
format
final UsageAnalyticsResponse.Builder format(UsageAnalyticsResponse.Format format)
CDN traffic grouped by response
Content-Type.
-
format
final UsageAnalyticsResponse.Builder format(JsonField<UsageAnalyticsResponse.Format> format)
Sets Builder.format to an arbitrary JSON value.
You should usually call Builder.format with a well-typed Format value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
generatedAt
final UsageAnalyticsResponse.Builder generatedAt(OffsetDateTime generatedAt)
Date and time when the analytics data was computed. Use this to gauge how fresh the returned data is. The date and time is in ISO8601 format.
-
generatedAt
final UsageAnalyticsResponse.Builder generatedAt(JsonField<OffsetDateTime> generatedAt)
Sets Builder.generatedAt to an arbitrary JSON value.
You should usually call Builder.generatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
requestCount
final UsageAnalyticsResponse.Builder requestCount(Double requestCount)
Total number of requests made during the specified date range.
-
requestCount
final UsageAnalyticsResponse.Builder requestCount(JsonField<Double> requestCount)
Sets Builder.requestCount to an arbitrary JSON value.
You should usually call Builder.requestCount with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
startDate
final UsageAnalyticsResponse.Builder startDate(LocalDate startDate)
Start date of the computed analytics data.
-
startDate
final UsageAnalyticsResponse.Builder startDate(JsonField<LocalDate> startDate)
Sets Builder.startDate to an arbitrary JSON value.
You should usually call Builder.startDate with a well-typed LocalDate value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
statusCodes
final UsageAnalyticsResponse.Builder statusCodes(List<UsageAnalyticsResponse.StatusCode> statusCodes)
Request count grouped by HTTP status code.
-
statusCodes
final UsageAnalyticsResponse.Builder statusCodes(JsonField<List<UsageAnalyticsResponse.StatusCode>> statusCodes)
Sets Builder.statusCodes to an arbitrary JSON value.
You should usually call Builder.statusCodes with a well-typed
List<StatusCode>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addStatusCode
final UsageAnalyticsResponse.Builder addStatusCode(UsageAnalyticsResponse.StatusCode statusCode)
Adds a single StatusCode to statusCodes.
-
top404Assets
final UsageAnalyticsResponse.Builder top404Assets(List<UsageAnalyticsResponse.Top404Asset> top404Assets)
Top URLs that returned a 404 response.
-
top404Assets
final UsageAnalyticsResponse.Builder top404Assets(JsonField<List<UsageAnalyticsResponse.Top404Asset>> top404Assets)
Sets Builder.top404Assets to an arbitrary JSON value.
You should usually call Builder.top404Assets with a well-typed
List<Top404Asset>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTop404Asset
final UsageAnalyticsResponse.Builder addTop404Asset(UsageAnalyticsResponse.Top404Asset top404Asset)
Adds a single Top404Asset to top404Assets.
-
topImages
final UsageAnalyticsResponse.Builder topImages(UsageAnalyticsResponse.TopImages topImages)
Top image assets by traffic.
-
topImages
final UsageAnalyticsResponse.Builder topImages(JsonField<UsageAnalyticsResponse.TopImages> topImages)
Sets Builder.topImages to an arbitrary JSON value.
You should usually call Builder.topImages with a well-typed TopImages value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topImageTransforms
final UsageAnalyticsResponse.Builder topImageTransforms(UsageAnalyticsResponse.TopImageTransforms topImageTransforms)
Top image transformation strings by traffic.
-
topImageTransforms
final UsageAnalyticsResponse.Builder topImageTransforms(JsonField<UsageAnalyticsResponse.TopImageTransforms> topImageTransforms)
Sets Builder.topImageTransforms to an arbitrary JSON value.
You should usually call Builder.topImageTransforms with a well-typed TopImageTransforms value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topOtherAssets
final UsageAnalyticsResponse.Builder topOtherAssets(UsageAnalyticsResponse.TopOtherAssets topOtherAssets)
Top non-image, non-video assets by traffic.
-
topOtherAssets
final UsageAnalyticsResponse.Builder topOtherAssets(JsonField<UsageAnalyticsResponse.TopOtherAssets> topOtherAssets)
Sets Builder.topOtherAssets to an arbitrary JSON value.
You should usually call Builder.topOtherAssets with a well-typed TopOtherAssets value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topReferrers
final UsageAnalyticsResponse.Builder topReferrers(UsageAnalyticsResponse.TopReferrers topReferrers)
Top HTTP referrers by traffic.
-
topReferrers
final UsageAnalyticsResponse.Builder topReferrers(JsonField<UsageAnalyticsResponse.TopReferrers> topReferrers)
Sets Builder.topReferrers to an arbitrary JSON value.
You should usually call Builder.topReferrers with a well-typed TopReferrers value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topUserAgents
final UsageAnalyticsResponse.Builder topUserAgents(UsageAnalyticsResponse.TopUserAgents topUserAgents)
Top user agents by traffic.
-
topUserAgents
final UsageAnalyticsResponse.Builder topUserAgents(JsonField<UsageAnalyticsResponse.TopUserAgents> topUserAgents)
Sets Builder.topUserAgents to an arbitrary JSON value.
You should usually call Builder.topUserAgents with a well-typed TopUserAgents value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topVideos
final UsageAnalyticsResponse.Builder topVideos(UsageAnalyticsResponse.TopVideos topVideos)
Top video assets by traffic.
-
topVideos
final UsageAnalyticsResponse.Builder topVideos(JsonField<UsageAnalyticsResponse.TopVideos> topVideos)
Sets Builder.topVideos to an arbitrary JSON value.
You should usually call Builder.topVideos with a well-typed TopVideos value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
topVideoTransforms
final UsageAnalyticsResponse.Builder topVideoTransforms(UsageAnalyticsResponse.TopVideoTransforms topVideoTransforms)
Top video transformation strings by traffic.
-
topVideoTransforms
final UsageAnalyticsResponse.Builder topVideoTransforms(JsonField<UsageAnalyticsResponse.TopVideoTransforms> topVideoTransforms)
Sets Builder.topVideoTransforms to an arbitrary JSON value.
You should usually call Builder.topVideoTransforms with a well-typed TopVideoTransforms value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
urlEndpoints
final UsageAnalyticsResponse.Builder urlEndpoints(UsageAnalyticsResponse.UrlEndpoints urlEndpoints)
CDN traffic grouped by configured URL endpoint. Traffic that does not match any named URL endpoint pattern is grouped under
Default.
-
urlEndpoints
final UsageAnalyticsResponse.Builder urlEndpoints(JsonField<UsageAnalyticsResponse.UrlEndpoints> urlEndpoints)
Sets Builder.urlEndpoints to an arbitrary JSON value.
You should usually call Builder.urlEndpoints with a well-typed UrlEndpoints value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
videoProcessing
final UsageAnalyticsResponse.Builder videoProcessing(List<UsageAnalyticsResponse.VideoProcessing> videoProcessing)
Raw observed video transcode output duration, in seconds, grouped by resolution and codec. These are raw seconds, not billable Video Processing Units (VPU). For billable VPU totals, use the
/v1/accounts/usageendpoint.
-
videoProcessing
final UsageAnalyticsResponse.Builder videoProcessing(JsonField<List<UsageAnalyticsResponse.VideoProcessing>> videoProcessing)
Sets Builder.videoProcessing to an arbitrary JSON value.
You should usually call Builder.videoProcessing with a well-typed
List<VideoProcessing>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVideoProcessing
final UsageAnalyticsResponse.Builder addVideoProcessing(UsageAnalyticsResponse.VideoProcessing videoProcessing)
Adds a single VideoProcessing to Builder.videoProcessing.
-
additionalProperties
final UsageAnalyticsResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UsageAnalyticsResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UsageAnalyticsResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UsageAnalyticsResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UsageAnalyticsResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UsageAnalyticsResponse build()
Returns an immutable instance of UsageAnalyticsResponse.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.bandwidthBytes() .browser() .cache() .country() .device() .endDate() .errorReasons() .extensions() .format() .generatedAt() .requestCount() .startDate() .statusCodes() .top404Assets() .topImages() .topImageTransforms() .topOtherAssets() .topReferrers() .topUserAgents() .topVideos() .topVideoTransforms() .urlEndpoints() .videoProcessing()
-
-
-
-