Class UsageAnalyticsResponse.Cache
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.CacheCDN cache hit, miss and error counts for the date range.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.Cache.BuilderA builder for Cache.
-
Method Summary
Modifier and Type Method Description final DoubleerrorCount()Number of requests where the CDN encountered a cache error or exceeded capacity while serving the response. final DoublehitCount()Number of requests served from cache, including full hits and revalidated hits. final DoublemissCount()Number of requests that were not found in cache and had to be fetched from origin. final JsonField<Double>_errorCount()Returns the raw JSON value of errorCount. final JsonField<Double>_hitCount()Returns the raw JSON value of hitCount. final JsonField<Double>_missCount()Returns the raw JSON value of missCount. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.Cache.BuildertoBuilder()final UsageAnalyticsResponse.Cachevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Cache.Builderbuilder()Returns a mutable builder for constructing an instance of Cache. -
-
Method Detail
-
errorCount
final Double errorCount()
Number of requests where the CDN encountered a cache error or exceeded capacity while serving the response.
-
hitCount
final Double hitCount()
Number of requests served from cache, including full hits and revalidated hits.
-
missCount
final Double missCount()
Number of requests that were not found in cache and had to be fetched from origin.
-
_errorCount
final JsonField<Double> _errorCount()
Returns the raw JSON value of errorCount.
Unlike errorCount, this method doesn't throw if the JSON field has an unexpected type.
-
_hitCount
final JsonField<Double> _hitCount()
Returns the raw JSON value of hitCount.
Unlike hitCount, this method doesn't throw if the JSON field has an unexpected type.
-
_missCount
final JsonField<Double> _missCount()
Returns the raw JSON value of missCount.
Unlike missCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Cache.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.Cache validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Cache.Builder builder()
Returns a mutable builder for constructing an instance of Cache.
The following fields are required:
.errorCount() .hitCount() .missCount()
-
-
-
-