Class UsageAnalyticsResponse.Country
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.CountryCDN traffic grouped by country.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.Country.BuilderA builder for Country.
public final classUsageAnalyticsResponse.Country.ByBandwidthpublic final classUsageAnalyticsResponse.Country.ByRequest
-
Method Summary
Modifier and Type Method Description final List<UsageAnalyticsResponse.Country.ByBandwidth>byBandwidth()Top requesting countries sorted by total bandwidth utilized. final List<UsageAnalyticsResponse.Country.ByRequest>byRequests()Top requesting countries sorted by request count. final JsonField<List<UsageAnalyticsResponse.Country.ByBandwidth>>_byBandwidth()Returns the raw JSON value of byBandwidth. final JsonField<List<UsageAnalyticsResponse.Country.ByRequest>>_byRequests()Returns the raw JSON value of byRequests. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.Country.BuildertoBuilder()final UsageAnalyticsResponse.Countryvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Country.Builderbuilder()Returns a mutable builder for constructing an instance of Country. -
-
Method Detail
-
byBandwidth
final List<UsageAnalyticsResponse.Country.ByBandwidth> byBandwidth()
Top requesting countries sorted by total bandwidth utilized.
-
byRequests
final List<UsageAnalyticsResponse.Country.ByRequest> byRequests()
Top requesting countries sorted by request count.
-
_byBandwidth
final JsonField<List<UsageAnalyticsResponse.Country.ByBandwidth>> _byBandwidth()
Returns the raw JSON value of byBandwidth.
Unlike byBandwidth, this method doesn't throw if the JSON field has an unexpected type.
-
_byRequests
final JsonField<List<UsageAnalyticsResponse.Country.ByRequest>> _byRequests()
Returns the raw JSON value of byRequests.
Unlike byRequests, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Country.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.Country validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Country.Builder builder()
Returns a mutable builder for constructing an instance of Country.
The following fields are required:
.byBandwidth() .byRequests()
-
-
-
-