Class UsageAnalyticsResponse.Device
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.DeviceCDN traffic grouped by device and operating system (e.g.
Desktop - Apple Mac,Smartphone - Apple iPhone).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.Device.BuilderA builder for Device.
public final classUsageAnalyticsResponse.Device.ByBandwidthpublic final classUsageAnalyticsResponse.Device.ByRequest
-
Method Summary
Modifier and Type Method Description final List<UsageAnalyticsResponse.Device.ByBandwidth>byBandwidth()Top device/OS combinations sorted by bandwidth utilized. final List<UsageAnalyticsResponse.Device.ByRequest>byRequests()Top device/OS combinations sorted by request count. final JsonField<List<UsageAnalyticsResponse.Device.ByBandwidth>>_byBandwidth()Returns the raw JSON value of byBandwidth. final JsonField<List<UsageAnalyticsResponse.Device.ByRequest>>_byRequests()Returns the raw JSON value of byRequests. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.Device.BuildertoBuilder()final UsageAnalyticsResponse.Devicevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Device.Builderbuilder()Returns a mutable builder for constructing an instance of Device. -
-
Method Detail
-
byBandwidth
final List<UsageAnalyticsResponse.Device.ByBandwidth> byBandwidth()
Top device/OS combinations sorted by bandwidth utilized.
-
byRequests
final List<UsageAnalyticsResponse.Device.ByRequest> byRequests()
Top device/OS combinations sorted by request count.
-
_byBandwidth
final JsonField<List<UsageAnalyticsResponse.Device.ByBandwidth>> _byBandwidth()
Returns the raw JSON value of byBandwidth.
Unlike byBandwidth, this method doesn't throw if the JSON field has an unexpected type.
-
_byRequests
final JsonField<List<UsageAnalyticsResponse.Device.ByRequest>> _byRequests()
Returns the raw JSON value of byRequests.
Unlike byRequests, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Device.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.Device validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Device.Builder builder()
Returns a mutable builder for constructing an instance of Device.
The following fields are required:
.byBandwidth() .byRequests()
-
-
-
-