Class UsageAnalyticsResponse.Device.Builder
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.Device.BuilderA builder for Device.
-
-
Method Summary
-
-
Method Detail
-
byBandwidth
final UsageAnalyticsResponse.Device.Builder byBandwidth(List<UsageAnalyticsResponse.Device.ByBandwidth> byBandwidth)
Top device/OS combinations sorted by bandwidth utilized.
-
byBandwidth
final UsageAnalyticsResponse.Device.Builder byBandwidth(JsonField<List<UsageAnalyticsResponse.Device.ByBandwidth>> byBandwidth)
Sets Builder.byBandwidth to an arbitrary JSON value.
You should usually call Builder.byBandwidth with a well-typed
List<ByBandwidth>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addByBandwidth
final UsageAnalyticsResponse.Device.Builder addByBandwidth(UsageAnalyticsResponse.Device.ByBandwidth byBandwidth)
Adds a single ByBandwidth to Builder.byBandwidth.
-
byRequests
final UsageAnalyticsResponse.Device.Builder byRequests(List<UsageAnalyticsResponse.Device.ByRequest> byRequests)
Top device/OS combinations sorted by request count.
-
byRequests
final UsageAnalyticsResponse.Device.Builder byRequests(JsonField<List<UsageAnalyticsResponse.Device.ByRequest>> byRequests)
Sets Builder.byRequests to an arbitrary JSON value.
You should usually call Builder.byRequests with a well-typed
List<ByRequest>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addByRequest
final UsageAnalyticsResponse.Device.Builder addByRequest(UsageAnalyticsResponse.Device.ByRequest byRequest)
Adds a single ByRequest to byRequests.
-
additionalProperties
final UsageAnalyticsResponse.Device.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UsageAnalyticsResponse.Device.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UsageAnalyticsResponse.Device.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UsageAnalyticsResponse.Device.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UsageAnalyticsResponse.Device.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UsageAnalyticsResponse.Device build()
Returns an immutable instance of Device.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.byBandwidth() .byRequests()
-
-
-
-