Class UsageAnalyticsResponse.Extension
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.Extension
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.Extension.BuilderA builder for Extension.
-
Method Summary
Modifier and Type Method Description final Stringname()Extension identifier. final DoubleoperationCount()Number of times this extension ran during the date range. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Double>_operationCount()Returns the raw JSON value of operationCount. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.Extension.BuildertoBuilder()final UsageAnalyticsResponse.Extensionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Extension.Builderbuilder()Returns a mutable builder for constructing an instance of Extension. -
-
Method Detail
-
operationCount
final Double operationCount()
Number of times this extension ran during the date range.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_operationCount
final JsonField<Double> _operationCount()
Returns the raw JSON value of operationCount.
Unlike operationCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Extension.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.Extension validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Extension.Builder builder()
Returns a mutable builder for constructing an instance of Extension.
The following fields are required:
.name() .operationCount()
-
-
-
-