Class UsageAnalyticsResponse.Format.Builder
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.Format.BuilderA builder for Format.
-
-
Method Summary
-
-
Method Detail
-
byBandwidth
final UsageAnalyticsResponse.Format.Builder byBandwidth(List<UsageAnalyticsResponse.Format.ByBandwidth> byBandwidth)
Top content types sorted by bandwidth utilized.
-
byBandwidth
final UsageAnalyticsResponse.Format.Builder byBandwidth(JsonField<List<UsageAnalyticsResponse.Format.ByBandwidth>> byBandwidth)
Sets Builder.byBandwidth to an arbitrary JSON value.
You should usually call Builder.byBandwidth with a well-typed
List<ByBandwidth>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addByBandwidth
final UsageAnalyticsResponse.Format.Builder addByBandwidth(UsageAnalyticsResponse.Format.ByBandwidth byBandwidth)
Adds a single ByBandwidth to Builder.byBandwidth.
-
byRequests
final UsageAnalyticsResponse.Format.Builder byRequests(List<UsageAnalyticsResponse.Format.ByRequest> byRequests)
Top content types sorted by request count.
-
byRequests
final UsageAnalyticsResponse.Format.Builder byRequests(JsonField<List<UsageAnalyticsResponse.Format.ByRequest>> byRequests)
Sets Builder.byRequests to an arbitrary JSON value.
You should usually call Builder.byRequests with a well-typed
List<ByRequest>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addByRequest
final UsageAnalyticsResponse.Format.Builder addByRequest(UsageAnalyticsResponse.Format.ByRequest byRequest)
Adds a single ByRequest to byRequests.
-
additionalProperties
final UsageAnalyticsResponse.Format.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UsageAnalyticsResponse.Format.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UsageAnalyticsResponse.Format.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UsageAnalyticsResponse.Format.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UsageAnalyticsResponse.Format.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UsageAnalyticsResponse.Format build()
Returns an immutable instance of Format.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.byBandwidth() .byRequests()
-
-
-
-