Class UsageAnalyticsResponse.Format.ByRequest
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.Format.ByRequest
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.Format.ByRequest.BuilderA builder for ByRequest.
-
Method Summary
Modifier and Type Method Description final RequestBandwidthEntrytoRequestBandwidthEntry()final DoublebandwidthBytes()Total bandwidth used in bytes. final DoublerequestCount()Number of requests. final Stringname()MIME type (e.g. final JsonField<Double>_bandwidthBytes()Returns the raw JSON value of bandwidthBytes. final JsonField<Double>_requestCount()Returns the raw JSON value of requestCount. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.Format.ByRequest.BuildertoBuilder()final UsageAnalyticsResponse.Format.ByRequestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Format.ByRequest.Builderbuilder()Returns a mutable builder for constructing an instance of ByRequest. -
-
Method Detail
-
toRequestBandwidthEntry
final RequestBandwidthEntry toRequestBandwidthEntry()
-
bandwidthBytes
final Double bandwidthBytes()
Total bandwidth used in bytes.
-
requestCount
final Double requestCount()
Number of requests.
-
_bandwidthBytes
final JsonField<Double> _bandwidthBytes()
Returns the raw JSON value of bandwidthBytes.
Unlike bandwidthBytes, this method doesn't throw if the JSON field has an unexpected type.
-
_requestCount
final JsonField<Double> _requestCount()
Returns the raw JSON value of requestCount.
Unlike requestCount, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Format.ByRequest.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.Format.ByRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Format.ByRequest.Builder builder()
Returns a mutable builder for constructing an instance of ByRequest.
The following fields are required:
.bandwidthBytes() .requestCount() .name()
-
-
-
-