Class UsageAnalyticsResponse.Top404Asset
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.Top404Asset
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.Top404Asset.BuilderA builder for Top404Asset.
-
Method Summary
Modifier and Type Method Description final Stringname()URL that returned a 404 response. final DoublerequestCount()Number of requests to this URL that returned a 404 response. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Double>_requestCount()Returns the raw JSON value of requestCount. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.Top404Asset.BuildertoBuilder()final UsageAnalyticsResponse.Top404Assetvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.Top404Asset.Builderbuilder()Returns a mutable builder for constructing an instance of Top404Asset. -
-
Method Detail
-
requestCount
final Double requestCount()
Number of requests to this URL that returned a 404 response.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_requestCount
final JsonField<Double> _requestCount()
Returns the raw JSON value of requestCount.
Unlike requestCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.Top404Asset.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.Top404Asset validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.Top404Asset.Builder builder()
Returns a mutable builder for constructing an instance of Top404Asset.
The following fields are required:
.name() .requestCount()
-
-
-
-