Class UsageAnalyticsResponse.TopImageTransforms
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.TopImageTransformsTop image transformation strings by traffic.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.TopImageTransforms.BuilderA builder for TopImageTransforms.
public final classUsageAnalyticsResponse.TopImageTransforms.ByBandwidthpublic final classUsageAnalyticsResponse.TopImageTransforms.ByRequest
-
Method Summary
-
-
Method Detail
-
byBandwidth
final List<UsageAnalyticsResponse.TopImageTransforms.ByBandwidth> byBandwidth()
Top image transformation strings sorted by bandwidth utilized.
-
byRequests
final List<UsageAnalyticsResponse.TopImageTransforms.ByRequest> byRequests()
Top image transformation strings sorted by request count.
-
_byBandwidth
final JsonField<List<UsageAnalyticsResponse.TopImageTransforms.ByBandwidth>> _byBandwidth()
Returns the raw JSON value of byBandwidth.
Unlike byBandwidth, this method doesn't throw if the JSON field has an unexpected type.
-
_byRequests
final JsonField<List<UsageAnalyticsResponse.TopImageTransforms.ByRequest>> _byRequests()
Returns the raw JSON value of byRequests.
Unlike byRequests, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.TopImageTransforms.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.TopImageTransforms validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.TopImageTransforms.Builder builder()
Returns a mutable builder for constructing an instance of TopImageTransforms.
The following fields are required:
.byBandwidth() .byRequests()
-
-
-
-