Class UsageAnalyticsResponse.TopImages
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.TopImagesTop image assets by traffic.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.TopImages.BuilderA builder for TopImages.
public final classUsageAnalyticsResponse.TopImages.ByBandwidthpublic final classUsageAnalyticsResponse.TopImages.ByRequest
-
Method Summary
Modifier and Type Method Description final List<UsageAnalyticsResponse.TopImages.ByBandwidth>byBandwidth()Top image assets sorted by bandwidth utilized. final List<UsageAnalyticsResponse.TopImages.ByRequest>byRequests()Top image assets sorted by request count. final JsonField<List<UsageAnalyticsResponse.TopImages.ByBandwidth>>_byBandwidth()Returns the raw JSON value of byBandwidth. final JsonField<List<UsageAnalyticsResponse.TopImages.ByRequest>>_byRequests()Returns the raw JSON value of byRequests. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.TopImages.BuildertoBuilder()final UsageAnalyticsResponse.TopImagesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.TopImages.Builderbuilder()Returns a mutable builder for constructing an instance of TopImages. -
-
Method Detail
-
byBandwidth
final List<UsageAnalyticsResponse.TopImages.ByBandwidth> byBandwidth()
Top image assets sorted by bandwidth utilized.
-
byRequests
final List<UsageAnalyticsResponse.TopImages.ByRequest> byRequests()
Top image assets sorted by request count.
-
_byBandwidth
final JsonField<List<UsageAnalyticsResponse.TopImages.ByBandwidth>> _byBandwidth()
Returns the raw JSON value of byBandwidth.
Unlike byBandwidth, this method doesn't throw if the JSON field has an unexpected type.
-
_byRequests
final JsonField<List<UsageAnalyticsResponse.TopImages.ByRequest>> _byRequests()
Returns the raw JSON value of byRequests.
Unlike byRequests, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.TopImages.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.TopImages validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.TopImages.Builder builder()
Returns a mutable builder for constructing an instance of TopImages.
The following fields are required:
.byBandwidth() .byRequests()
-
-
-
-