Class UsageAnalyticsResponse.VideoProcessing
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.VideoProcessing
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageAnalyticsResponse.VideoProcessing.BuilderA builder for VideoProcessing.
-
Method Summary
Modifier and Type Method Description final Stringcodec()Video codec used for the output (e.g. final DoubledurationSeconds()Total output duration, in seconds, for this resolution and codec combination. final Stringresolution()Output resolution tier (e.g. final JsonField<String>_codec()Returns the raw JSON value of codec. final JsonField<Double>_durationSeconds()Returns the raw JSON value of durationSeconds. final JsonField<String>_resolution()Returns the raw JSON value of resolution. final Map<String, JsonValue>_additionalProperties()final UsageAnalyticsResponse.VideoProcessing.BuildertoBuilder()final UsageAnalyticsResponse.VideoProcessingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UsageAnalyticsResponse.VideoProcessing.Builderbuilder()Returns a mutable builder for constructing an instance of VideoProcessing. -
-
Method Detail
-
durationSeconds
final Double durationSeconds()
Total output duration, in seconds, for this resolution and codec combination.
-
resolution
final String resolution()
Output resolution tier (e.g.
SD,HD,4K).
-
_codec
final JsonField<String> _codec()
Returns the raw JSON value of codec.
Unlike codec, this method doesn't throw if the JSON field has an unexpected type.
-
_durationSeconds
final JsonField<Double> _durationSeconds()
Returns the raw JSON value of durationSeconds.
Unlike durationSeconds, this method doesn't throw if the JSON field has an unexpected type.
-
_resolution
final JsonField<String> _resolution()
Returns the raw JSON value of resolution.
Unlike resolution, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UsageAnalyticsResponse.VideoProcessing.Builder toBuilder()
-
validate
final UsageAnalyticsResponse.VideoProcessing validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UsageAnalyticsResponse.VideoProcessing.Builder builder()
Returns a mutable builder for constructing an instance of VideoProcessing.
The following fields are required:
.codec() .durationSeconds() .resolution()
-
-
-
-