Class UsageAnalyticsResponse.VideoProcessing.Builder
-
- All Implemented Interfaces:
public final class UsageAnalyticsResponse.VideoProcessing.BuilderA builder for VideoProcessing.
-
-
Method Summary
-
-
Method Detail
-
codec
final UsageAnalyticsResponse.VideoProcessing.Builder codec(String codec)
Video codec used for the output (e.g.
h264,av1).
-
codec
final UsageAnalyticsResponse.VideoProcessing.Builder codec(JsonField<String> codec)
Sets Builder.codec to an arbitrary JSON value.
You should usually call Builder.codec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
durationSeconds
final UsageAnalyticsResponse.VideoProcessing.Builder durationSeconds(Double durationSeconds)
Total output duration, in seconds, for this resolution and codec combination.
-
durationSeconds
final UsageAnalyticsResponse.VideoProcessing.Builder durationSeconds(JsonField<Double> durationSeconds)
Sets Builder.durationSeconds to an arbitrary JSON value.
You should usually call Builder.durationSeconds with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolution
final UsageAnalyticsResponse.VideoProcessing.Builder resolution(String resolution)
Output resolution tier (e.g.
SD,HD,4K).
-
resolution
final UsageAnalyticsResponse.VideoProcessing.Builder resolution(JsonField<String> resolution)
Sets Builder.resolution to an arbitrary JSON value.
You should usually call Builder.resolution with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UsageAnalyticsResponse.VideoProcessing.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UsageAnalyticsResponse.VideoProcessing.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UsageAnalyticsResponse.VideoProcessing.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UsageAnalyticsResponse.VideoProcessing.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UsageAnalyticsResponse.VideoProcessing.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UsageAnalyticsResponse.VideoProcessing build()
Returns an immutable instance of VideoProcessing.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.codec() .durationSeconds() .resolution()
-
-
-
-