Class InvalidationCreateParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class InvalidationCreateParams implements Params
This API will purge CDN cache and ImageKit.io's internal cache for a file. Note: Purge cache is an asynchronous process and it may take some time to reflect the changes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInvalidationCreateParams.BuilderA builder for InvalidationCreateParams.
public final classInvalidationCreateParams.Body
-
Method Summary
Modifier and Type Method Description final Stringurl()The full URL of the file to be purged. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final InvalidationCreateParams.BuildertoBuilder()final InvalidationCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static InvalidationCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of InvalidationCreateParams. -
-
Method Detail
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InvalidationCreateParams.Builder toBuilder()
-
_body
final InvalidationCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static InvalidationCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of InvalidationCreateParams.
The following fields are required:
.url()
-
-
-
-