Class InvalidationCreateResponse
-
- All Implemented Interfaces:
public final class InvalidationCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInvalidationCreateResponse.BuilderA builder for InvalidationCreateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>requestId()Unique identifier of the purge request. final JsonField<String>_requestId()Returns the raw JSON value of requestId. final Map<String, JsonValue>_additionalProperties()final InvalidationCreateResponse.BuildertoBuilder()final InvalidationCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InvalidationCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InvalidationCreateResponse. -
-
Method Detail
-
requestId
final Optional<String> requestId()
Unique identifier of the purge request. This can be used to check the status of the purge request.
-
_requestId
final JsonField<String> _requestId()
Returns the raw JSON value of requestId.
Unlike requestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InvalidationCreateResponse.Builder toBuilder()
-
validate
final InvalidationCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InvalidationCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of InvalidationCreateResponse.
-
-
-
-