Class CustomMetadataField.Builder
-
- All Implemented Interfaces:
public final class CustomMetadataField.BuilderA builder for CustomMetadataField.
-
-
Method Summary
-
-
Method Detail
-
id
final CustomMetadataField.Builder id(String id)
Unique identifier for the custom metadata field. Use this to update the field.
-
id
final CustomMetadataField.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
label
final CustomMetadataField.Builder label(String label)
Human readable name of the custom metadata field. This name is displayed as form field label to the users while setting field value on the asset in the media library UI.
-
label
final CustomMetadataField.Builder label(JsonField<String> label)
Sets Builder.label to an arbitrary JSON value.
You should usually call Builder.label with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final CustomMetadataField.Builder name(String name)
API name of the custom metadata field. This becomes the key while setting
customMetadata(key-value object) for an asset using upload or update API.
-
name
final CustomMetadataField.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schema
final CustomMetadataField.Builder schema(CustomMetadataField.Schema schema)
An object that describes the rules for the custom metadata field value.
-
schema
final CustomMetadataField.Builder schema(JsonField<CustomMetadataField.Schema> schema)
Sets Builder.schema to an arbitrary JSON value.
You should usually call Builder.schema with a well-typed Schema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CustomMetadataField.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomMetadataField.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomMetadataField.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomMetadataField.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomMetadataField.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomMetadataField build()
Returns an immutable instance of CustomMetadataField.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .label() .name() .schema()
-
-
-
-