Class CustomMetadataField.Schema
-
- All Implemented Interfaces:
public final class CustomMetadataField.SchemaAn object that describes the rules for the custom metadata field value.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataField.Schema.BuilderA builder for Schema.
public final classCustomMetadataField.Schema.TypeType of the custom metadata field.
public final classCustomMetadataField.Schema.DefaultValueThe default value for this custom metadata field. Data type of default value depends on the field type.
public final classCustomMetadataField.Schema.MaxValueMaximum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.public final classCustomMetadataField.Schema.MinValueMinimum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.public final classCustomMetadataField.Schema.SelectOption
-
Method Summary
Modifier and Type Method Description final CustomMetadataField.Schema.Typetype()Type of the custom metadata field. final Optional<CustomMetadataField.Schema.DefaultValue>defaultValue()The default value for this custom metadata field. final Optional<Boolean>isValueRequired()Specifies if the this custom metadata field is required or not. final Optional<Double>maxLength()Maximum length of string. final Optional<CustomMetadataField.Schema.MaxValue>maxValue()Maximum value of the field. final Optional<Double>minLength()Minimum length of string. final Optional<CustomMetadataField.Schema.MinValue>minValue()Minimum value of the field. final Optional<List<CustomMetadataField.Schema.SelectOption>>selectOptions()An array of allowed values when field type is SingleSelectorMultiSelect.final JsonField<CustomMetadataField.Schema.Type>_type()Returns the raw JSON value of type. final JsonField<CustomMetadataField.Schema.DefaultValue>_defaultValue()Returns the raw JSON value of defaultValue. final JsonField<Boolean>_isValueRequired()Returns the raw JSON value of isValueRequired. final JsonField<Double>_maxLength()Returns the raw JSON value of maxLength. final JsonField<CustomMetadataField.Schema.MaxValue>_maxValue()Returns the raw JSON value of maxValue. final JsonField<Double>_minLength()Returns the raw JSON value of minLength. final JsonField<CustomMetadataField.Schema.MinValue>_minValue()Returns the raw JSON value of minValue. final JsonField<List<CustomMetadataField.Schema.SelectOption>>_selectOptions()Returns the raw JSON value of selectOptions. final Map<String, JsonValue>_additionalProperties()final CustomMetadataField.Schema.BuildertoBuilder()final CustomMetadataField.Schemavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataField.Schema.Builderbuilder()Returns a mutable builder for constructing an instance of Schema. -
-
Method Detail
-
type
final CustomMetadataField.Schema.Type type()
Type of the custom metadata field.
-
defaultValue
final Optional<CustomMetadataField.Schema.DefaultValue> defaultValue()
The default value for this custom metadata field. Data type of default value depends on the field type.
-
isValueRequired
final Optional<Boolean> isValueRequired()
Specifies if the this custom metadata field is required or not.
-
maxLength
final Optional<Double> maxLength()
Maximum length of string. Only set if
typeis set toTextorTextarea.
-
maxValue
final Optional<CustomMetadataField.Schema.MaxValue> maxValue()
Maximum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.
-
minLength
final Optional<Double> minLength()
Minimum length of string. Only set if
typeis set toTextorTextarea.
-
minValue
final Optional<CustomMetadataField.Schema.MinValue> minValue()
Minimum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.
-
selectOptions
final Optional<List<CustomMetadataField.Schema.SelectOption>> selectOptions()
An array of allowed values when field type is
SingleSelectorMultiSelect.
-
_type
final JsonField<CustomMetadataField.Schema.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_defaultValue
final JsonField<CustomMetadataField.Schema.DefaultValue> _defaultValue()
Returns the raw JSON value of defaultValue.
Unlike defaultValue, this method doesn't throw if the JSON field has an unexpected type.
-
_isValueRequired
final JsonField<Boolean> _isValueRequired()
Returns the raw JSON value of isValueRequired.
Unlike isValueRequired, this method doesn't throw if the JSON field has an unexpected type.
-
_maxLength
final JsonField<Double> _maxLength()
Returns the raw JSON value of maxLength.
Unlike maxLength, this method doesn't throw if the JSON field has an unexpected type.
-
_maxValue
final JsonField<CustomMetadataField.Schema.MaxValue> _maxValue()
Returns the raw JSON value of maxValue.
Unlike maxValue, this method doesn't throw if the JSON field has an unexpected type.
-
_minLength
final JsonField<Double> _minLength()
Returns the raw JSON value of minLength.
Unlike minLength, this method doesn't throw if the JSON field has an unexpected type.
-
_minValue
final JsonField<CustomMetadataField.Schema.MinValue> _minValue()
Returns the raw JSON value of minValue.
Unlike minValue, this method doesn't throw if the JSON field has an unexpected type.
-
_selectOptions
final JsonField<List<CustomMetadataField.Schema.SelectOption>> _selectOptions()
Returns the raw JSON value of selectOptions.
Unlike selectOptions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomMetadataField.Schema.Builder toBuilder()
-
validate
final CustomMetadataField.Schema validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CustomMetadataField.Schema.Builder builder()
Returns a mutable builder for constructing an instance of Schema.
The following fields are required:
.type()
-
-
-
-