Class CustomMetadataField.Schema.Builder
-
- All Implemented Interfaces:
public final class CustomMetadataField.Schema.BuilderA builder for Schema.
-
-
Method Summary
-
-
Method Detail
-
type
final CustomMetadataField.Schema.Builder type(CustomMetadataField.Schema.Type type)
Type of the custom metadata field.
-
type
final CustomMetadataField.Schema.Builder type(JsonField<CustomMetadataField.Schema.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
defaultValue
final CustomMetadataField.Schema.Builder defaultValue(CustomMetadataField.Schema.DefaultValue defaultValue)
The default value for this custom metadata field. Data type of default value depends on the field type.
-
defaultValue
final CustomMetadataField.Schema.Builder defaultValue(JsonField<CustomMetadataField.Schema.DefaultValue> defaultValue)
Sets Builder.defaultValue to an arbitrary JSON value.
You should usually call Builder.defaultValue with a well-typed DefaultValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
defaultValue
final CustomMetadataField.Schema.Builder defaultValue(String string)
Alias for calling defaultValue with
DefaultValue.ofString(string).
-
defaultValue
final CustomMetadataField.Schema.Builder defaultValue(Double number)
Alias for calling defaultValue with
DefaultValue.ofNumber(number).
-
defaultValue
final CustomMetadataField.Schema.Builder defaultValue(Boolean bool)
Alias for calling defaultValue with
DefaultValue.ofBool(bool).
-
defaultValueOfMixed
final CustomMetadataField.Schema.Builder defaultValueOfMixed(List<CustomMetadataField.Schema.DefaultValue.DefaultValueItem> mixed)
Alias for calling defaultValue with
DefaultValue.ofMixed(mixed).
-
isValueRequired
final CustomMetadataField.Schema.Builder isValueRequired(Boolean isValueRequired)
Specifies if the this custom metadata field is required or not.
-
isValueRequired
final CustomMetadataField.Schema.Builder isValueRequired(JsonField<Boolean> isValueRequired)
Sets Builder.isValueRequired to an arbitrary JSON value.
You should usually call Builder.isValueRequired with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxLength
final CustomMetadataField.Schema.Builder maxLength(Double maxLength)
Maximum length of string. Only set if
typeis set toTextorTextarea.
-
maxLength
final CustomMetadataField.Schema.Builder maxLength(JsonField<Double> maxLength)
Sets Builder.maxLength to an arbitrary JSON value.
You should usually call Builder.maxLength with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxValue
final CustomMetadataField.Schema.Builder maxValue(CustomMetadataField.Schema.MaxValue maxValue)
Maximum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.
-
maxValue
final CustomMetadataField.Schema.Builder maxValue(JsonField<CustomMetadataField.Schema.MaxValue> maxValue)
Sets Builder.maxValue to an arbitrary JSON value.
You should usually call Builder.maxValue with a well-typed MaxValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxValue
final CustomMetadataField.Schema.Builder maxValue(String string)
Alias for calling maxValue with
MaxValue.ofString(string).
-
maxValue
final CustomMetadataField.Schema.Builder maxValue(Double number)
Alias for calling maxValue with
MaxValue.ofNumber(number).
-
minLength
final CustomMetadataField.Schema.Builder minLength(Double minLength)
Minimum length of string. Only set if
typeis set toTextorTextarea.
-
minLength
final CustomMetadataField.Schema.Builder minLength(JsonField<Double> minLength)
Sets Builder.minLength to an arbitrary JSON value.
You should usually call Builder.minLength with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minValue
final CustomMetadataField.Schema.Builder minValue(CustomMetadataField.Schema.MinValue minValue)
Minimum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.
-
minValue
final CustomMetadataField.Schema.Builder minValue(JsonField<CustomMetadataField.Schema.MinValue> minValue)
Sets Builder.minValue to an arbitrary JSON value.
You should usually call Builder.minValue with a well-typed MinValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minValue
final CustomMetadataField.Schema.Builder minValue(String string)
Alias for calling minValue with
MinValue.ofString(string).
-
minValue
final CustomMetadataField.Schema.Builder minValue(Double number)
Alias for calling minValue with
MinValue.ofNumber(number).
-
selectOptions
final CustomMetadataField.Schema.Builder selectOptions(List<CustomMetadataField.Schema.SelectOption> selectOptions)
An array of allowed values when field type is
SingleSelectorMultiSelect.
-
selectOptions
final CustomMetadataField.Schema.Builder selectOptions(JsonField<List<CustomMetadataField.Schema.SelectOption>> selectOptions)
Sets Builder.selectOptions to an arbitrary JSON value.
You should usually call Builder.selectOptions with a well-typed
List<SelectOption>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSelectOption
final CustomMetadataField.Schema.Builder addSelectOption(CustomMetadataField.Schema.SelectOption selectOption)
Adds a single SelectOption to selectOptions.
-
addSelectOption
final CustomMetadataField.Schema.Builder addSelectOption(String string)
Alias for calling addSelectOption with
SelectOption.ofString(string).
-
addSelectOption
final CustomMetadataField.Schema.Builder addSelectOption(Double number)
Alias for calling addSelectOption with
SelectOption.ofNumber(number).
-
addSelectOption
final CustomMetadataField.Schema.Builder addSelectOption(Boolean bool)
Alias for calling addSelectOption with
SelectOption.ofBool(bool).
-
additionalProperties
final CustomMetadataField.Schema.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomMetadataField.Schema.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomMetadataField.Schema.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomMetadataField.Schema.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomMetadataField.Schema.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomMetadataField.Schema build()
Returns an immutable instance of Schema.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-