Class CustomMetadataField.Schema.MaxValue

  • All Implemented Interfaces:

    
    public final class CustomMetadataField.Schema.MaxValue
    
                        

    Maximum value of the field. Only set if field type is Date or Number. For Date type field, the value will be in ISO8601 string format. For Number type field, it will be a numeric value.