Class CustomMetadataField.Schema.SelectOption
-
- All Implemented Interfaces:
public final class CustomMetadataField.Schema.SelectOption
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataField.Schema.SelectOption.VisitorAn interface that defines how to map each variant of SelectOption to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<Double>number()final Optional<Boolean>bool()final BooleanisString()final BooleanisNumber()final BooleanisBool()final StringasString()final DoubleasNumber()final BooleanasBool()final Optional<JsonValue>_json()final <T extends Any> Taccept(CustomMetadataField.Schema.SelectOption.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final CustomMetadataField.Schema.SelectOptionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataField.Schema.SelectOptionofString(String string)final static CustomMetadataField.Schema.SelectOptionofNumber(Double number)final static CustomMetadataField.Schema.SelectOptionofBool(Boolean bool)-
-
Method Detail
-
accept
final <T extends Any> T accept(CustomMetadataField.Schema.SelectOption.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = selectOption.accept(new SelectOption.Visitor<Optional<String>>() { @Override public Optional<String> visitString(String string) { return Optional.of(string.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final CustomMetadataField.Schema.SelectOption validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofString
final static CustomMetadataField.Schema.SelectOption ofString(String string)
-
ofNumber
final static CustomMetadataField.Schema.SelectOption ofNumber(Double number)
-
ofBool
final static CustomMetadataField.Schema.SelectOption ofBool(Boolean bool)
-
-
-
-