Interface CustomMetadataField.Schema.SelectOption.Visitor
-
- All Implemented Interfaces:
public interface CustomMetadataField.Schema.SelectOption.Visitor<T extends Object>An interface that defines how to map each variant of SelectOption to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitString(String string)abstract TvisitNumber(Double number)abstract TvisitBool(Boolean bool)Tunknown(JsonValue json)Maps an unknown variant of SelectOption to a value of type T. -
-
Method Detail
-
visitString
abstract T visitString(String string)
-
visitNumber
abstract T visitNumber(Double number)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of SelectOption to a value of type T.
An instance of SelectOption can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-