Class CustomMetadataFieldCreateParams.Body
-
- All Implemented Interfaces:
public final class CustomMetadataFieldCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringlabel()Human readable name of the custom metadata field. final Stringname()API name of the custom metadata field. final CustomMetadataFieldCreateParams.Schemaschema()final JsonField<String>_label()Returns the raw JSON value of label. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<CustomMetadataFieldCreateParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalProperties()final CustomMetadataFieldCreateParams.Body.BuildertoBuilder()final CustomMetadataFieldCreateParams.Bodyvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
label
final String label()
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI.
-
name
final String name()
API name of the custom metadata field. This should be unique across all (including deleted) custom metadata fields.
-
schema
final CustomMetadataFieldCreateParams.Schema schema()
-
_label
final JsonField<String> _label()
Returns the raw JSON value of label.
Unlike label, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<CustomMetadataFieldCreateParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomMetadataFieldCreateParams.Body.Builder toBuilder()
-
validate
final CustomMetadataFieldCreateParams.Body validate()
-
builder
final static CustomMetadataFieldCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.label() .name() .schema()
-
-
-
-