Class CustomMetadataFieldCreateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CustomMetadataFieldCreateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
label
final CustomMetadataFieldCreateParams.Body.Builder label(String label)
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI.
-
label
final CustomMetadataFieldCreateParams.Body.Builder label(JsonField<String> label)
Sets Builder.label to an arbitrary JSON value.
You should usually call Builder.label with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final CustomMetadataFieldCreateParams.Body.Builder name(String name)
API name of the custom metadata field. This should be unique across all (including deleted) custom metadata fields.
-
name
final CustomMetadataFieldCreateParams.Body.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schema
final CustomMetadataFieldCreateParams.Body.Builder schema(CustomMetadataFieldCreateParams.Schema schema)
-
schema
final CustomMetadataFieldCreateParams.Body.Builder schema(JsonField<CustomMetadataFieldCreateParams.Schema> schema)
Sets Builder.schema to an arbitrary JSON value.
You should usually call Builder.schema with a well-typed Schema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CustomMetadataFieldCreateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomMetadataFieldCreateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomMetadataFieldCreateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomMetadataFieldCreateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomMetadataFieldCreateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomMetadataFieldCreateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.label() .name() .schema()
-
-
-
-