Class CustomMetadataFieldCreateParams.Schema
-
- All Implemented Interfaces:
public final class CustomMetadataFieldCreateParams.Schema
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldCreateParams.Schema.BuilderA builder for Schema.
public final classCustomMetadataFieldCreateParams.Schema.TypeType of the custom metadata field.
public final classCustomMetadataFieldCreateParams.Schema.DefaultValueThe default value for this custom metadata field. This property is only required if
isValueRequiredproperty is set totrue. The value should match thetypeof custom metadata field.public final classCustomMetadataFieldCreateParams.Schema.MaxValueMaximum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.public final classCustomMetadataFieldCreateParams.Schema.MinValueMinimum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.public final classCustomMetadataFieldCreateParams.Schema.SelectOption
-
Method Summary
-
-
Method Detail
-
type
final CustomMetadataFieldCreateParams.Schema.Type type()
Type of the custom metadata field.
-
defaultValue
final Optional<CustomMetadataFieldCreateParams.Schema.DefaultValue> defaultValue()
The default value for this custom metadata field. This property is only required if
isValueRequiredproperty is set totrue. The value should match thetypeof custom metadata field.
-
isValueRequired
final Optional<Boolean> isValueRequired()
Sets this custom metadata field as required. Setting custom metadata fields on an asset will throw error if the value for all required fields are not present in upload or update asset API request body.
-
maxLength
final Optional<Double> maxLength()
Maximum length of string. Only set this property if
typeis set toTextorTextarea.
-
maxValue
final Optional<CustomMetadataFieldCreateParams.Schema.MaxValue> maxValue()
Maximum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
minLength
final Optional<Double> minLength()
Minimum length of string. Only set this property if
typeis set toTextorTextarea.
-
minValue
final Optional<CustomMetadataFieldCreateParams.Schema.MinValue> minValue()
Minimum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
selectOptions
final Optional<List<CustomMetadataFieldCreateParams.Schema.SelectOption>> selectOptions()
An array of allowed values. This property is only required if
typeproperty is set toSingleSelectorMultiSelect.
-
_type
final JsonField<CustomMetadataFieldCreateParams.Schema.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_defaultValue
final JsonField<CustomMetadataFieldCreateParams.Schema.DefaultValue> _defaultValue()
Returns the raw JSON value of defaultValue.
Unlike defaultValue, this method doesn't throw if the JSON field has an unexpected type.
-
_isValueRequired
final JsonField<Boolean> _isValueRequired()
Returns the raw JSON value of isValueRequired.
Unlike isValueRequired, this method doesn't throw if the JSON field has an unexpected type.
-
_maxLength
final JsonField<Double> _maxLength()
Returns the raw JSON value of maxLength.
Unlike maxLength, this method doesn't throw if the JSON field has an unexpected type.
-
_maxValue
final JsonField<CustomMetadataFieldCreateParams.Schema.MaxValue> _maxValue()
Returns the raw JSON value of maxValue.
Unlike maxValue, this method doesn't throw if the JSON field has an unexpected type.
-
_minLength
final JsonField<Double> _minLength()
Returns the raw JSON value of minLength.
Unlike minLength, this method doesn't throw if the JSON field has an unexpected type.
-
_minValue
final JsonField<CustomMetadataFieldCreateParams.Schema.MinValue> _minValue()
Returns the raw JSON value of minValue.
Unlike minValue, this method doesn't throw if the JSON field has an unexpected type.
-
_selectOptions
final JsonField<List<CustomMetadataFieldCreateParams.Schema.SelectOption>> _selectOptions()
Returns the raw JSON value of selectOptions.
Unlike selectOptions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomMetadataFieldCreateParams.Schema.Builder toBuilder()
-
validate
final CustomMetadataFieldCreateParams.Schema validate()
-
builder
final static CustomMetadataFieldCreateParams.Schema.Builder builder()
Returns a mutable builder for constructing an instance of Schema.
The following fields are required:
.type()
-
-
-
-