Class CustomMetadataFieldCreateParams.Schema.MaxValue
-
- All Implemented Interfaces:
public final class CustomMetadataFieldCreateParams.Schema.MaxValueMaximum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataFieldCreateParams.Schema.MaxValue.VisitorAn interface that defines how to map each variant of MaxValue to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<Double>number()final BooleanisString()final BooleanisNumber()final StringasString()final DoubleasNumber()final Optional<JsonValue>_json()final <T extends Any> Taccept(CustomMetadataFieldCreateParams.Schema.MaxValue.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final CustomMetadataFieldCreateParams.Schema.MaxValuevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldCreateParams.Schema.MaxValueofString(String string)final static CustomMetadataFieldCreateParams.Schema.MaxValueofNumber(Double number)-
-
Method Detail
-
accept
final <T extends Any> T accept(CustomMetadataFieldCreateParams.Schema.MaxValue.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = maxValue.accept(new MaxValue.Visitor<Optional<String>>() { @Override public Optional<String> visitString(String string) { return Optional.of(string.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final CustomMetadataFieldCreateParams.Schema.MaxValue validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofString
final static CustomMetadataFieldCreateParams.Schema.MaxValue ofString(String string)
-
ofNumber
final static CustomMetadataFieldCreateParams.Schema.MaxValue ofNumber(Double number)
-
-
-
-