Class CustomMetadataFieldDeleteResponse
-
- All Implemented Interfaces:
public final class CustomMetadataFieldDeleteResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldDeleteResponse.BuilderA builder for CustomMetadataFieldDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final CustomMetadataFieldDeleteResponse.BuildertoBuilder()final CustomMetadataFieldDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadataFieldDeleteResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomMetadataFieldDeleteResponse.Builder toBuilder()
-
validate
final CustomMetadataFieldDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CustomMetadataFieldDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadataFieldDeleteResponse.
-
-
-
-