Class CustomMetadataFieldUpdateParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class CustomMetadataFieldUpdateParams implements Params
This API updates the label or schema of an existing custom metadata field.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldUpdateParams.BuilderA builder for CustomMetadataFieldUpdateParams.
public final classCustomMetadataFieldUpdateParams.Bodypublic final classCustomMetadataFieldUpdateParams.SchemaAn object that describes the rules for the custom metadata key. This parameter is required if
labelis not provided. Note:typecannot be updated and will be ignored if sent with theschema. The schema will be validated as per the existingtype.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()final Optional<String>label()Human readable name of the custom metadata field. final Optional<CustomMetadataFieldUpdateParams.Schema>schema()An object that describes the rules for the custom metadata key. final JsonField<String>_label()Returns the raw JSON value of label. final JsonField<CustomMetadataFieldUpdateParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CustomMetadataFieldUpdateParams.BuildertoBuilder()final CustomMetadataFieldUpdateParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldUpdateParamsnone()final static CustomMetadataFieldUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadataFieldUpdateParams. -
-
Method Detail
-
label
final Optional<String> label()
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI. This parameter is required if
schemais not provided.
-
schema
final Optional<CustomMetadataFieldUpdateParams.Schema> schema()
An object that describes the rules for the custom metadata key. This parameter is required if
labelis not provided. Note:typecannot be updated and will be ignored if sent with theschema. The schema will be validated as per the existingtype.
-
_label
final JsonField<String> _label()
Returns the raw JSON value of label.
Unlike label, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<CustomMetadataFieldUpdateParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CustomMetadataFieldUpdateParams.Builder toBuilder()
-
_body
final CustomMetadataFieldUpdateParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CustomMetadataFieldUpdateParams none()
-
builder
final static CustomMetadataFieldUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadataFieldUpdateParams.
-
-
-
-