Class CustomMetadataFieldUpdateParams.Body
-
- All Implemented Interfaces:
public final class CustomMetadataFieldUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>label()Human readable name of the custom metadata field. final Optional<CustomMetadataFieldUpdateParams.Schema>schema()An object that describes the rules for the custom metadata key. final JsonField<String>_label()Returns the raw JSON value of label. final JsonField<CustomMetadataFieldUpdateParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalProperties()final CustomMetadataFieldUpdateParams.Body.BuildertoBuilder()final CustomMetadataFieldUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
label
final Optional<String> label()
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI. This parameter is required if
schemais not provided.
-
schema
final Optional<CustomMetadataFieldUpdateParams.Schema> schema()
An object that describes the rules for the custom metadata key. This parameter is required if
labelis not provided. Note:typecannot be updated and will be ignored if sent with theschema. The schema will be validated as per the existingtype.
-
_label
final JsonField<String> _label()
Returns the raw JSON value of label.
Unlike label, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<CustomMetadataFieldUpdateParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CustomMetadataFieldUpdateParams.Body.Builder toBuilder()
-
validate
final CustomMetadataFieldUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CustomMetadataFieldUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-