Class CustomMetadataFieldUpdateParams.Body.Builder
-
- All Implemented Interfaces:
public final class CustomMetadataFieldUpdateParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
label
final CustomMetadataFieldUpdateParams.Body.Builder label(String label)
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI. This parameter is required if
schemais not provided.
-
label
final CustomMetadataFieldUpdateParams.Body.Builder label(JsonField<String> label)
Sets Builder.label to an arbitrary JSON value.
You should usually call Builder.label with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
schema
final CustomMetadataFieldUpdateParams.Body.Builder schema(CustomMetadataFieldUpdateParams.Schema schema)
An object that describes the rules for the custom metadata key. This parameter is required if
labelis not provided. Note:typecannot be updated and will be ignored if sent with theschema. The schema will be validated as per the existingtype.
-
schema
final CustomMetadataFieldUpdateParams.Body.Builder schema(JsonField<CustomMetadataFieldUpdateParams.Schema> schema)
Sets Builder.schema to an arbitrary JSON value.
You should usually call Builder.schema with a well-typed Schema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final CustomMetadataFieldUpdateParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomMetadataFieldUpdateParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomMetadataFieldUpdateParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomMetadataFieldUpdateParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomMetadataFieldUpdateParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomMetadataFieldUpdateParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-