Class CustomMetadataFieldUpdateParams.Schema

  • All Implemented Interfaces:

    
    public final class CustomMetadataFieldUpdateParams.Schema
    
                        

    An object that describes the rules for the custom metadata key. This parameter is required if label is not provided. Note: type cannot be updated and will be ignored if sent with the schema. The schema will be validated as per the existing type.