Class CustomMetadataFieldUpdateParams.Schema.Builder
-
- All Implemented Interfaces:
public final class CustomMetadataFieldUpdateParams.Schema.BuilderA builder for Schema.
-
-
Method Summary
-
-
Method Detail
-
defaultValue
final CustomMetadataFieldUpdateParams.Schema.Builder defaultValue(CustomMetadataFieldUpdateParams.Schema.DefaultValue defaultValue)
The default value for this custom metadata field. This property is only required if
isValueRequiredproperty is set totrue. The value should match thetypeof custom metadata field.
-
defaultValue
final CustomMetadataFieldUpdateParams.Schema.Builder defaultValue(JsonField<CustomMetadataFieldUpdateParams.Schema.DefaultValue> defaultValue)
Sets Builder.defaultValue to an arbitrary JSON value.
You should usually call Builder.defaultValue with a well-typed DefaultValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
defaultValue
final CustomMetadataFieldUpdateParams.Schema.Builder defaultValue(String string)
Alias for calling defaultValue with
DefaultValue.ofString(string).
-
defaultValue
final CustomMetadataFieldUpdateParams.Schema.Builder defaultValue(Double number)
Alias for calling defaultValue with
DefaultValue.ofNumber(number).
-
defaultValue
final CustomMetadataFieldUpdateParams.Schema.Builder defaultValue(Boolean bool)
Alias for calling defaultValue with
DefaultValue.ofBool(bool).
-
defaultValueOfMixed
final CustomMetadataFieldUpdateParams.Schema.Builder defaultValueOfMixed(List<CustomMetadataFieldUpdateParams.Schema.DefaultValue.DefaultValueItem> mixed)
Alias for calling defaultValue with
DefaultValue.ofMixed(mixed).
-
isValueRequired
final CustomMetadataFieldUpdateParams.Schema.Builder isValueRequired(Boolean isValueRequired)
Sets this custom metadata field as required. Setting custom metadata fields on an asset will throw error if the value for all required fields are not present in upload or update asset API request body.
-
isValueRequired
final CustomMetadataFieldUpdateParams.Schema.Builder isValueRequired(JsonField<Boolean> isValueRequired)
Sets Builder.isValueRequired to an arbitrary JSON value.
You should usually call Builder.isValueRequired with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxLength
final CustomMetadataFieldUpdateParams.Schema.Builder maxLength(Double maxLength)
Maximum length of string. Only set this property if
typeis set toTextorTextarea.
-
maxLength
final CustomMetadataFieldUpdateParams.Schema.Builder maxLength(JsonField<Double> maxLength)
Sets Builder.maxLength to an arbitrary JSON value.
You should usually call Builder.maxLength with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxValue
final CustomMetadataFieldUpdateParams.Schema.Builder maxValue(CustomMetadataFieldUpdateParams.Schema.MaxValue maxValue)
Maximum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
maxValue
final CustomMetadataFieldUpdateParams.Schema.Builder maxValue(JsonField<CustomMetadataFieldUpdateParams.Schema.MaxValue> maxValue)
Sets Builder.maxValue to an arbitrary JSON value.
You should usually call Builder.maxValue with a well-typed MaxValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
maxValue
final CustomMetadataFieldUpdateParams.Schema.Builder maxValue(String string)
Alias for calling maxValue with
MaxValue.ofString(string).
-
maxValue
final CustomMetadataFieldUpdateParams.Schema.Builder maxValue(Double number)
Alias for calling maxValue with
MaxValue.ofNumber(number).
-
minLength
final CustomMetadataFieldUpdateParams.Schema.Builder minLength(Double minLength)
Minimum length of string. Only set this property if
typeis set toTextorTextarea.
-
minLength
final CustomMetadataFieldUpdateParams.Schema.Builder minLength(JsonField<Double> minLength)
Sets Builder.minLength to an arbitrary JSON value.
You should usually call Builder.minLength with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minValue
final CustomMetadataFieldUpdateParams.Schema.Builder minValue(CustomMetadataFieldUpdateParams.Schema.MinValue minValue)
Minimum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
minValue
final CustomMetadataFieldUpdateParams.Schema.Builder minValue(JsonField<CustomMetadataFieldUpdateParams.Schema.MinValue> minValue)
Sets Builder.minValue to an arbitrary JSON value.
You should usually call Builder.minValue with a well-typed MinValue value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
minValue
final CustomMetadataFieldUpdateParams.Schema.Builder minValue(String string)
Alias for calling minValue with
MinValue.ofString(string).
-
minValue
final CustomMetadataFieldUpdateParams.Schema.Builder minValue(Double number)
Alias for calling minValue with
MinValue.ofNumber(number).
-
selectOptions
final CustomMetadataFieldUpdateParams.Schema.Builder selectOptions(List<CustomMetadataFieldUpdateParams.Schema.SelectOption> selectOptions)
An array of allowed values. This property is only required if
typeproperty is set toSingleSelectorMultiSelect.
-
selectOptions
final CustomMetadataFieldUpdateParams.Schema.Builder selectOptions(JsonField<List<CustomMetadataFieldUpdateParams.Schema.SelectOption>> selectOptions)
Sets Builder.selectOptions to an arbitrary JSON value.
You should usually call Builder.selectOptions with a well-typed
List<SelectOption>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addSelectOption
final CustomMetadataFieldUpdateParams.Schema.Builder addSelectOption(CustomMetadataFieldUpdateParams.Schema.SelectOption selectOption)
Adds a single SelectOption to selectOptions.
-
addSelectOption
final CustomMetadataFieldUpdateParams.Schema.Builder addSelectOption(String string)
Alias for calling addSelectOption with
SelectOption.ofString(string).
-
addSelectOption
final CustomMetadataFieldUpdateParams.Schema.Builder addSelectOption(Double number)
Alias for calling addSelectOption with
SelectOption.ofNumber(number).
-
addSelectOption
final CustomMetadataFieldUpdateParams.Schema.Builder addSelectOption(Boolean bool)
Alias for calling addSelectOption with
SelectOption.ofBool(bool).
-
additionalProperties
final CustomMetadataFieldUpdateParams.Schema.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final CustomMetadataFieldUpdateParams.Schema.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final CustomMetadataFieldUpdateParams.Schema.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final CustomMetadataFieldUpdateParams.Schema.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final CustomMetadataFieldUpdateParams.Schema.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final CustomMetadataFieldUpdateParams.Schema build()
Returns an immutable instance of Schema.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-