Class CustomMetadataFieldUpdateParams.Schema.MaxValue
-
- All Implemented Interfaces:
public final class CustomMetadataFieldUpdateParams.Schema.MaxValueMaximum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataFieldUpdateParams.Schema.MaxValue.VisitorAn interface that defines how to map each variant of MaxValue to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<Double>number()final BooleanisString()final BooleanisNumber()final StringasString()final DoubleasNumber()final Optional<JsonValue>_json()final <T extends Any> Taccept(CustomMetadataFieldUpdateParams.Schema.MaxValue.Visitor<T> visitor)final CustomMetadataFieldUpdateParams.Schema.MaxValuevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldUpdateParams.Schema.MaxValueofString(String string)final static CustomMetadataFieldUpdateParams.Schema.MaxValueofNumber(Double number)-
-
Method Detail
-
accept
final <T extends Any> T accept(CustomMetadataFieldUpdateParams.Schema.MaxValue.Visitor<T> visitor)
-
validate
final CustomMetadataFieldUpdateParams.Schema.MaxValue validate()
-
ofString
final static CustomMetadataFieldUpdateParams.Schema.MaxValue ofString(String string)
-
ofNumber
final static CustomMetadataFieldUpdateParams.Schema.MaxValue ofNumber(Double number)
-
-
-
-