Interface CustomMetadataFieldUpdateParams.Schema.MaxValue.Visitor
-
- All Implemented Interfaces:
public interface CustomMetadataFieldUpdateParams.Schema.MaxValue.Visitor<T extends Object>
-
-
Method Summary
-
-
Method Detail
-
visitString
abstract T visitString(String string)
-
visitNumber
abstract T visitNumber(Double number)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of MaxValue to a value of type T.
An instance of MaxValue can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-