Class CustomMetadataFieldUpdateParams.Schema.MinValue

  • All Implemented Interfaces:

    
    public final class CustomMetadataFieldUpdateParams.Schema.MinValue
    
                        

    Minimum value of the field. Only set this property if field type is Date or Number. For Date type field, set the minimum date in ISO8601 string format. For Number type field, set the minimum numeric value.