Package io.imagekit.models.custommetadatafields
See: Description
-
Class Summary Class Description Builder A builder for CustomMetadataField. Builder A builder for Schema. Type Type of the custom metadata field. DefaultValueItem DefaultValue The default value for this custom metadata field. MaxValue Maximum value of the field. MinValue Minimum value of the field. SelectOption Schema An object that describes the rules for the custom metadata field value. CustomMetadataField Object containing details of a custom metadata field. Builder A builder for CustomMetadataFieldCreateParams. Builder A builder for Body. Body Builder A builder for Schema. Type Type of the custom metadata field. DefaultValueItem DefaultValue The default value for this custom metadata field. MaxValue Maximum value of the field. MinValue Minimum value of the field. SelectOption Schema CustomMetadataFieldCreateParams This API creates a new custom metadata field. Builder A builder for CustomMetadataFieldDeleteParams. CustomMetadataFieldDeleteParams This API deletes a custom metadata field. Builder A builder for CustomMetadataFieldDeleteResponse. CustomMetadataFieldDeleteResponse Builder A builder for CustomMetadataFieldListParams. CustomMetadataFieldListParams This API returns the array of created custom metadata field objects. Builder A builder for CustomMetadataFieldUpdateParams. Builder A builder for Body. Body Builder A builder for Schema. DefaultValueItem DefaultValue The default value for this custom metadata field. MaxValue Maximum value of the field. MinValue Minimum value of the field. SelectOption Schema An object that describes the rules for the custom metadata key. CustomMetadataFieldUpdateParams This API updates the label or schema of an existing custom metadata field. -
Interface Summary Interface Description Visitor An interface that defines how to map each variant of DefaultValue to a value of type T. Visitor An interface that defines how to map each variant of DefaultValueItem to a value of type T. Visitor An interface that defines how to map each variant of MaxValue to a value of type T. Visitor An interface that defines how to map each variant of MinValue to a value of type T. Visitor An interface that defines how to map each variant of SelectOption to a value of type T. Visitor An interface that defines how to map each variant of DefaultValue to a value of type T. Visitor An interface that defines how to map each variant of DefaultValueItem to a value of type T. Visitor An interface that defines how to map each variant of MaxValue to a value of type T. Visitor An interface that defines how to map each variant of MinValue to a value of type T. Visitor An interface that defines how to map each variant of SelectOption to a value of type T. Visitor An interface that defines how to map each variant of DefaultValue to a value of type T. Visitor An interface that defines how to map each variant of DefaultValueItem to a value of type T. Visitor An interface that defines how to map each variant of MaxValue to a value of type T. Visitor An interface that defines how to map each variant of MinValue to a value of type T. Visitor An interface that defines how to map each variant of SelectOption to a value of type T.