Class File.Builder
-
- All Implemented Interfaces:
public final class File.BuilderA builder for File.
-
-
Method Summary
Modifier and Type Method Description final File.BuilderaiTags(List<AiTag> aiTags)Array of AI-generated tags associated with the image. final File.BuilderaiTags(Optional<List<AiTag>> aiTags)Alias for calling Builder.aiTags with aiTags.orElse(null).final File.BuilderaiTags(JsonField<List<AiTag>> aiTags)Sets Builder.aiTags to an arbitrary JSON value. final File.BuilderaddAiTag(AiTag aiTag)Adds a single AiTag to aiTags. final File.BuilderaudioCodec(String audioCodec)The audio codec used in the video (only for video/audio). final File.BuilderaudioCodec(JsonField<String> audioCodec)Sets Builder.audioCodec to an arbitrary JSON value. final File.BuilderbitRate(Long bitRate)The bit rate of the video in kbps (only for video). final File.BuilderbitRate(JsonField<Long> bitRate)Sets Builder.bitRate to an arbitrary JSON value. final File.BuildercreatedAt(OffsetDateTime createdAt)Date and time when the file was uploaded. final File.BuildercreatedAt(JsonField<OffsetDateTime> createdAt)Sets Builder.createdAt to an arbitrary JSON value. final File.BuildercustomCoordinates(String customCoordinates)An string with custom coordinates of the file. final File.BuildercustomCoordinates(Optional<String> customCoordinates)Alias for calling Builder.customCoordinates with customCoordinates.orElse(null).final File.BuildercustomCoordinates(JsonField<String> customCoordinates)Sets Builder.customCoordinates to an arbitrary JSON value. final File.BuildercustomMetadata(CustomMetadata customMetadata)An object with custom metadata for the file. final File.BuildercustomMetadata(JsonField<CustomMetadata> customMetadata)Sets Builder.customMetadata to an arbitrary JSON value. final File.Builderdescription(String description)Optional text to describe the contents of the file. final File.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final File.Builderduration(Long duration)The duration of the video in seconds (only for video). final File.Builderduration(JsonField<Long> duration)Sets Builder.duration to an arbitrary JSON value. final File.BuilderembeddedMetadata(EmbeddedMetadata embeddedMetadata)Consolidated embedded metadata associated with the file. final File.BuilderembeddedMetadata(JsonField<EmbeddedMetadata> embeddedMetadata)Sets Builder.embeddedMetadata to an arbitrary JSON value. final File.BuilderfileId(String fileId)Unique identifier of the asset. final File.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final File.BuilderfilePath(String filePath)Path of the file. final File.BuilderfilePath(JsonField<String> filePath)Sets Builder.filePath to an arbitrary JSON value. final File.BuilderfileType(String fileType)Type of the file. final File.BuilderfileType(JsonField<String> fileType)Sets Builder.fileType to an arbitrary JSON value. final File.BuilderhasAlpha(Boolean hasAlpha)Specifies if the image has an alpha channel. final File.BuilderhasAlpha(JsonField<Boolean> hasAlpha)Sets Builder.hasAlpha to an arbitrary JSON value. final File.Builderheight(Double height)Height of the file. final File.Builderheight(JsonField<Double> height)Sets Builder.height to an arbitrary JSON value. final File.BuilderisPrivateFile(Boolean isPrivateFile)Specifies if the file is private or not. final File.BuilderisPrivateFile(JsonField<Boolean> isPrivateFile)Sets Builder.isPrivateFile to an arbitrary JSON value. final File.BuilderisPublished(Boolean isPublished)Specifies if the file is published or not. final File.BuilderisPublished(JsonField<Boolean> isPublished)Sets Builder.isPublished to an arbitrary JSON value. final File.Buildermime(String mime)MIME type of the file. final File.Buildermime(JsonField<String> mime)Sets Builder.mime to an arbitrary JSON value. final File.Buildername(String name)Name of the asset. final File.Buildername(JsonField<String> name)Sets Builder.name to an arbitrary JSON value. final File.BuilderselectedFieldsSchema(SelectedFieldsSchema selectedFieldsSchema)This field is included in the response only if the Path policy feature is available in the plan. final File.BuilderselectedFieldsSchema(JsonField<SelectedFieldsSchema> selectedFieldsSchema)Sets Builder.selectedFieldsSchema to an arbitrary JSON value. final File.Buildersize(Double size)Size of the file in bytes. final File.Buildersize(JsonField<Double> size)Sets Builder.size to an arbitrary JSON value. final File.Buildertags(List<String> tags)An array of tags assigned to the file. final File.Buildertags(Optional<List<String>> tags)Alias for calling Builder.tags with tags.orElse(null).final File.Buildertags(JsonField<List<String>> tags)Sets Builder.tags to an arbitrary JSON value. final File.BuilderaddTag(String tag)Adds a single String to tags. final File.Builderthumbnail(String thumbnail)URL of the thumbnail image. final File.Builderthumbnail(JsonField<String> thumbnail)Sets Builder.thumbnail to an arbitrary JSON value. final File.Buildertype(File.Type type)Type of the asset. final File.Buildertype(JsonField<File.Type> type)Sets Builder.type to an arbitrary JSON value. final File.BuilderupdatedAt(OffsetDateTime updatedAt)Date and time when the file was last updated. final File.BuilderupdatedAt(JsonField<OffsetDateTime> updatedAt)Sets Builder.updatedAt to an arbitrary JSON value. final File.Builderurl(String url)URL of the file. final File.Builderurl(JsonField<String> url)Sets Builder.url to an arbitrary JSON value. final File.BuilderversionInfo(VersionInfo versionInfo)An object with details of the file version. final File.BuilderversionInfo(JsonField<VersionInfo> versionInfo)Sets Builder.versionInfo to an arbitrary JSON value. final File.BuildervideoCodec(String videoCodec)The video codec used in the video (only for video). final File.BuildervideoCodec(JsonField<String> videoCodec)Sets Builder.videoCodec to an arbitrary JSON value. final File.Builderwidth(Double width)Width of the file. final File.Builderwidth(JsonField<Double> width)Sets Builder.width to an arbitrary JSON value. final File.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final File.BuilderputAdditionalProperty(String key, JsonValue value)final File.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final File.BuilderremoveAdditionalProperty(String key)final File.BuilderremoveAllAdditionalProperties(Set<String> keys)final Filebuild()Returns an immutable instance of File. -
-
Method Detail
-
aiTags
final File.Builder aiTags(List<AiTag> aiTags)
Array of AI-generated tags associated with the image. If no AITags are set, it will be null.
-
aiTags
final File.Builder aiTags(Optional<List<AiTag>> aiTags)
Alias for calling Builder.aiTags with
aiTags.orElse(null).
-
aiTags
final File.Builder aiTags(JsonField<List<AiTag>> aiTags)
Sets Builder.aiTags to an arbitrary JSON value.
You should usually call Builder.aiTags with a well-typed
List<AiTag>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAiTag
final File.Builder addAiTag(AiTag aiTag)
-
audioCodec
final File.Builder audioCodec(String audioCodec)
The audio codec used in the video (only for video/audio).
-
audioCodec
final File.Builder audioCodec(JsonField<String> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bitRate
final File.Builder bitRate(Long bitRate)
The bit rate of the video in kbps (only for video).
-
bitRate
final File.Builder bitRate(JsonField<Long> bitRate)
Sets Builder.bitRate to an arbitrary JSON value.
You should usually call Builder.bitRate with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final File.Builder createdAt(OffsetDateTime createdAt)
Date and time when the file was uploaded. The date and time is in ISO8601 format.
-
createdAt
final File.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customCoordinates
final File.Builder customCoordinates(String customCoordinates)
An string with custom coordinates of the file.
-
customCoordinates
final File.Builder customCoordinates(Optional<String> customCoordinates)
Alias for calling Builder.customCoordinates with
customCoordinates.orElse(null).
-
customCoordinates
final File.Builder customCoordinates(JsonField<String> customCoordinates)
Sets Builder.customCoordinates to an arbitrary JSON value.
You should usually call Builder.customCoordinates with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customMetadata
final File.Builder customMetadata(CustomMetadata customMetadata)
An object with custom metadata for the file.
-
customMetadata
final File.Builder customMetadata(JsonField<CustomMetadata> customMetadata)
Sets Builder.customMetadata to an arbitrary JSON value.
You should usually call Builder.customMetadata with a well-typed CustomMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final File.Builder description(String description)
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
-
description
final File.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final File.Builder duration(Long duration)
The duration of the video in seconds (only for video).
-
duration
final File.Builder duration(JsonField<Long> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
embeddedMetadata
final File.Builder embeddedMetadata(EmbeddedMetadata embeddedMetadata)
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.
-
embeddedMetadata
final File.Builder embeddedMetadata(JsonField<EmbeddedMetadata> embeddedMetadata)
Sets Builder.embeddedMetadata to an arbitrary JSON value.
You should usually call Builder.embeddedMetadata with a well-typed EmbeddedMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final File.Builder fileId(String fileId)
Unique identifier of the asset.
-
fileId
final File.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filePath
final File.Builder filePath(String filePath)
Path of the file. This is the path you would use in the URL to access the file. For example, if the file is at the root of the media library, the path will be
/file.jpg. If the file is inside a folder namedimages, the path will be/images/file.jpg.
-
filePath
final File.Builder filePath(JsonField<String> filePath)
Sets Builder.filePath to an arbitrary JSON value.
You should usually call Builder.filePath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileType
final File.Builder fileType(String fileType)
Type of the file. Possible values are
image,non-image.
-
fileType
final File.Builder fileType(JsonField<String> fileType)
Sets Builder.fileType to an arbitrary JSON value.
You should usually call Builder.fileType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hasAlpha
final File.Builder hasAlpha(Boolean hasAlpha)
Specifies if the image has an alpha channel.
-
hasAlpha
final File.Builder hasAlpha(JsonField<Boolean> hasAlpha)
Sets Builder.hasAlpha to an arbitrary JSON value.
You should usually call Builder.hasAlpha with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final File.Builder height(Double height)
Height of the file.
-
height
final File.Builder height(JsonField<Double> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPrivateFile
final File.Builder isPrivateFile(Boolean isPrivateFile)
Specifies if the file is private or not.
-
isPrivateFile
final File.Builder isPrivateFile(JsonField<Boolean> isPrivateFile)
Sets Builder.isPrivateFile to an arbitrary JSON value.
You should usually call Builder.isPrivateFile with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPublished
final File.Builder isPublished(Boolean isPublished)
Specifies if the file is published or not.
-
isPublished
final File.Builder isPublished(JsonField<Boolean> isPublished)
Sets Builder.isPublished to an arbitrary JSON value.
You should usually call Builder.isPublished with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mime
final File.Builder mime(String mime)
MIME type of the file.
-
mime
final File.Builder mime(JsonField<String> mime)
Sets Builder.mime to an arbitrary JSON value.
You should usually call Builder.mime with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final File.Builder name(String name)
Name of the asset.
-
name
final File.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
selectedFieldsSchema
final File.Builder selectedFieldsSchema(SelectedFieldsSchema selectedFieldsSchema)
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
selectedFieldsSchema
final File.Builder selectedFieldsSchema(JsonField<SelectedFieldsSchema> selectedFieldsSchema)
Sets Builder.selectedFieldsSchema to an arbitrary JSON value.
You should usually call Builder.selectedFieldsSchema with a well-typed SelectedFieldsSchema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
size
final File.Builder size(Double size)
Size of the file in bytes.
-
size
final File.Builder size(JsonField<Double> size)
Sets Builder.size to an arbitrary JSON value.
You should usually call Builder.size with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final File.Builder tags(List<String> tags)
An array of tags assigned to the file. Tags are used to search files in the media library.
-
tags
final File.Builder tags(Optional<List<String>> tags)
Alias for calling Builder.tags with
tags.orElse(null).
-
tags
final File.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final File.Builder addTag(String tag)
-
thumbnail
final File.Builder thumbnail(String thumbnail)
URL of the thumbnail image. This URL is used to access the thumbnail image of the file in the media library.
-
thumbnail
final File.Builder thumbnail(JsonField<String> thumbnail)
Sets Builder.thumbnail to an arbitrary JSON value.
You should usually call Builder.thumbnail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final File.Builder type(File.Type type)
Type of the asset.
-
type
final File.Builder type(JsonField<File.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final File.Builder updatedAt(OffsetDateTime updatedAt)
Date and time when the file was last updated. The date and time is in ISO8601 format.
-
updatedAt
final File.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final File.Builder url(String url)
URL of the file.
-
url
final File.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
versionInfo
final File.Builder versionInfo(VersionInfo versionInfo)
An object with details of the file version.
-
versionInfo
final File.Builder versionInfo(JsonField<VersionInfo> versionInfo)
Sets Builder.versionInfo to an arbitrary JSON value.
You should usually call Builder.versionInfo with a well-typed VersionInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
videoCodec
final File.Builder videoCodec(String videoCodec)
The video codec used in the video (only for video).
-
videoCodec
final File.Builder videoCodec(JsonField<String> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final File.Builder width(Double width)
Width of the file.
-
width
final File.Builder width(JsonField<Double> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final File.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final File.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final File.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final File.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final File.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-