Class FileCopyParams

  • All Implemented Interfaces:
    io.imagekit.core.Params

    
    public final class FileCopyParams
     implements Params
                        

    This will copy a file from one folder to another.

    Note: If any file at the destination has the same name as the source file, then the source file and its versions (if includeFileVersions is set to true) will be appended to the destination file version history.