Class FileCopyParams.Body
-
- All Implemented Interfaces:
public final class FileCopyParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileCopyParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringdestinationPath()Full path to the folder you want to copy the above file into. final StringsourceFilePath()The full path of the file you want to copy. final Optional<Boolean>includeFileVersions()Option to copy all versions of a file. final JsonField<String>_destinationPath()Returns the raw JSON value of destinationPath. final JsonField<String>_sourceFilePath()Returns the raw JSON value of sourceFilePath. final JsonField<Boolean>_includeFileVersions()Returns the raw JSON value of includeFileVersions. final Map<String, JsonValue>_additionalProperties()final FileCopyParams.Body.BuildertoBuilder()final FileCopyParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileCopyParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
destinationPath
final String destinationPath()
Full path to the folder you want to copy the above file into.
-
sourceFilePath
final String sourceFilePath()
The full path of the file you want to copy.
-
includeFileVersions
final Optional<Boolean> includeFileVersions()
Option to copy all versions of a file. By default, only the current version of the file is copied. When set to true, all versions of the file will be copied. Default value -
false.
-
_destinationPath
final JsonField<String> _destinationPath()
Returns the raw JSON value of destinationPath.
Unlike destinationPath, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceFilePath
final JsonField<String> _sourceFilePath()
Returns the raw JSON value of sourceFilePath.
Unlike sourceFilePath, this method doesn't throw if the JSON field has an unexpected type.
-
_includeFileVersions
final JsonField<Boolean> _includeFileVersions()
Returns the raw JSON value of includeFileVersions.
Unlike includeFileVersions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileCopyParams.Body.Builder toBuilder()
-
validate
final FileCopyParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileCopyParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.destinationPath() .sourceFilePath()
-
-
-
-