Class FileCopyParams.Body.Builder
-
- All Implemented Interfaces:
public final class FileCopyParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
destinationPath
final FileCopyParams.Body.Builder destinationPath(String destinationPath)
Full path to the folder you want to copy the above file into.
-
destinationPath
final FileCopyParams.Body.Builder destinationPath(JsonField<String> destinationPath)
Sets Builder.destinationPath to an arbitrary JSON value.
You should usually call Builder.destinationPath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceFilePath
final FileCopyParams.Body.Builder sourceFilePath(String sourceFilePath)
The full path of the file you want to copy.
-
sourceFilePath
final FileCopyParams.Body.Builder sourceFilePath(JsonField<String> sourceFilePath)
Sets Builder.sourceFilePath to an arbitrary JSON value.
You should usually call Builder.sourceFilePath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
includeFileVersions
final FileCopyParams.Body.Builder includeFileVersions(Boolean includeFileVersions)
Option to copy all versions of a file. By default, only the current version of the file is copied. When set to true, all versions of the file will be copied. Default value -
false.
-
includeFileVersions
final FileCopyParams.Body.Builder includeFileVersions(JsonField<Boolean> includeFileVersions)
Sets Builder.includeFileVersions to an arbitrary JSON value.
You should usually call Builder.includeFileVersions with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileCopyParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileCopyParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileCopyParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileCopyParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileCopyParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileCopyParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.destinationPath() .sourceFilePath()
-
-
-
-