Package io.imagekit.models.files
Class FileCopyResponse
-
- All Implemented Interfaces:
public final class FileCopyResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileCopyResponse.BuilderA builder for FileCopyResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final FileCopyResponse.BuildertoBuilder()final FileCopyResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileCopyResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FileCopyResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileCopyResponse.Builder toBuilder()
-
validate
final FileCopyResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileCopyResponse.Builder builder()
Returns a mutable builder for constructing an instance of FileCopyResponse.
-
-
-
-