Class FileDeleteParams

  • All Implemented Interfaces:
    io.imagekit.core.Params

    
    public final class FileDeleteParams
     implements Params
                        

    This API deletes the file and all its file versions permanently.

    Note: If a file or specific transformation has been requested in the past, then the response is cached. Deleting a file does not purge the cache. You can purge the cache using purge cache API.