Class FileMoveParams

  • All Implemented Interfaces:
    io.imagekit.core.Params

    
    public final class FileMoveParams
     implements Params
                        

    This will move a file and all its versions from one folder to another.

    Note: If any file at the destination has the same name as the source file, then the source file and its versions will be appended to the destination file.