Package io.imagekit.models.files
Class FileMoveParams.Body
-
- All Implemented Interfaces:
public final class FileMoveParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileMoveParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringdestinationPath()Full path to the folder you want to move the above file into. final StringsourceFilePath()The full path of the file you want to move. final JsonField<String>_destinationPath()Returns the raw JSON value of destinationPath. final JsonField<String>_sourceFilePath()Returns the raw JSON value of sourceFilePath. final Map<String, JsonValue>_additionalProperties()final FileMoveParams.Body.BuildertoBuilder()final FileMoveParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileMoveParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
destinationPath
final String destinationPath()
Full path to the folder you want to move the above file into.
-
sourceFilePath
final String sourceFilePath()
The full path of the file you want to move.
-
_destinationPath
final JsonField<String> _destinationPath()
Returns the raw JSON value of destinationPath.
Unlike destinationPath, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceFilePath
final JsonField<String> _sourceFilePath()
Returns the raw JSON value of sourceFilePath.
Unlike sourceFilePath, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileMoveParams.Body.Builder toBuilder()
-
validate
final FileMoveParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileMoveParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.destinationPath() .sourceFilePath()
-
-
-
-