Package io.imagekit.models.files
Class FileMoveParams.Body.Builder
-
- All Implemented Interfaces:
public final class FileMoveParams.Body.BuilderA builder for Body.
-
-
Method Summary
-
-
Method Detail
-
destinationPath
final FileMoveParams.Body.Builder destinationPath(String destinationPath)
Full path to the folder you want to move the above file into.
-
destinationPath
final FileMoveParams.Body.Builder destinationPath(JsonField<String> destinationPath)
Sets Builder.destinationPath to an arbitrary JSON value.
You should usually call Builder.destinationPath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sourceFilePath
final FileMoveParams.Body.Builder sourceFilePath(String sourceFilePath)
The full path of the file you want to move.
-
sourceFilePath
final FileMoveParams.Body.Builder sourceFilePath(JsonField<String> sourceFilePath)
Sets Builder.sourceFilePath to an arbitrary JSON value.
You should usually call Builder.sourceFilePath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileMoveParams.Body.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileMoveParams.Body.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileMoveParams.Body.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileMoveParams.Body.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileMoveParams.Body.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileMoveParams.Body build()
Returns an immutable instance of Body.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.destinationPath() .sourceFilePath()
-
-
-
-