Package io.imagekit.models.files
Class FileMoveResponse
-
- All Implemented Interfaces:
public final class FileMoveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileMoveResponse.BuilderA builder for FileMoveResponse.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final FileMoveResponse.BuildertoBuilder()final FileMoveResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileMoveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FileMoveResponse. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileMoveResponse.Builder toBuilder()
-
validate
final FileMoveResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileMoveResponse.Builder builder()
Returns a mutable builder for constructing an instance of FileMoveResponse.
-
-
-
-