Package io.imagekit.models.files
Class FileRenameResponse
-
- All Implemented Interfaces:
public final class FileRenameResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileRenameResponse.BuilderA builder for FileRenameResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>purgeRequestId()Unique identifier of the purge request. final JsonField<String>_purgeRequestId()Returns the raw JSON value of purgeRequestId. final Map<String, JsonValue>_additionalProperties()final FileRenameResponse.BuildertoBuilder()final FileRenameResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileRenameResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FileRenameResponse. -
-
Method Detail
-
purgeRequestId
final Optional<String> purgeRequestId()
Unique identifier of the purge request. This can be used to check the status of the purge request.
-
_purgeRequestId
final JsonField<String> _purgeRequestId()
Returns the raw JSON value of purgeRequestId.
Unlike purgeRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileRenameResponse.Builder toBuilder()
-
validate
final FileRenameResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileRenameResponse.Builder builder()
Returns a mutable builder for constructing an instance of FileRenameResponse.
-
-
-
-