Package io.imagekit.models.files
Class FileUpdateParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class FileUpdateParams implements Params
This API updates the details or attributes of the current version of the file. You can update
tags,customCoordinates,customMetadata, publication status, remove existingAITagsand apply extensions using this API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileUpdateParams.BuilderA builder for FileUpdateParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>fileId()final UpdateFileRequestupdateFileRequest()Schema for update file update request. final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FileUpdateParams.BuildertoBuilder()final UpdateFileRequest_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileUpdateParams.Builderbuilder()Returns a mutable builder for constructing an instance of FileUpdateParams. -
-
Method Detail
-
updateFileRequest
final UpdateFileRequest updateFileRequest()
Schema for update file update request.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FileUpdateParams.Builder toBuilder()
-
_body
final UpdateFileRequest _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static FileUpdateParams.Builder builder()
Returns a mutable builder for constructing an instance of FileUpdateParams.
The following fields are required:
.updateFileRequest()
-
-
-
-