Class FileUpdateResponse
-
- All Implemented Interfaces:
public final class FileUpdateResponseObject containing details of a file or file version.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileUpdateResponse.BuilderA builder for FileUpdateResponse.
public final classFileUpdateResponse.ExtensionStatus
-
Method Summary
Modifier and Type Method Description final FiletoFile()final Optional<List<AiTag>>aiTags()Array of AI-generated tags associated with the image. final Optional<String>audioCodec()The audio codec used in the video (only for video/audio). final Optional<Long>bitRate()The bit rate of the video in kbps (only for video). final Optional<OffsetDateTime>createdAt()Date and time when the file was uploaded. final Optional<String>customCoordinates()An string with custom coordinates of the file. final Optional<CustomMetadata>customMetadata()An object with custom metadata for the file. final Optional<String>description()Optional text to describe the contents of the file. final Optional<Long>duration()The duration of the video in seconds (only for video). final Optional<EmbeddedMetadata>embeddedMetadata()Consolidated embedded metadata associated with the file. final Optional<String>fileId()Unique identifier of the asset. final Optional<String>filePath()Path of the file. final Optional<String>fileType()Type of the file. final Optional<Boolean>hasAlpha()Specifies if the image has an alpha channel. final Optional<Double>height()Height of the file. final Optional<Boolean>isPrivateFile()Specifies if the file is private or not. final Optional<Boolean>isPublished()Specifies if the file is published or not. final Optional<String>mime()MIME type of the file. final Optional<String>name()Name of the asset. final Optional<SelectedFieldsSchema>selectedFieldsSchema()This field is included in the response only if the Path policy feature is available in the plan. final Optional<Double>size()Size of the file in bytes. final Optional<List<String>>tags()An array of tags assigned to the file. final Optional<String>thumbnail()URL of the thumbnail image. final Optional<File.Type>type()Type of the asset. final Optional<OffsetDateTime>updatedAt()Date and time when the file was last updated. final Optional<String>url()URL of the file. final Optional<VersionInfo>versionInfo()An object with details of the file version. final Optional<String>videoCodec()The video codec used in the video (only for video). final Optional<Double>width()Width of the file. final Optional<FileUpdateResponse.ExtensionStatus>extensionStatus()final JsonField<List<AiTag>>_aiTags()Returns the raw JSON value of aiTags. final JsonField<String>_audioCodec()Returns the raw JSON value of audioCodec. final JsonField<Long>_bitRate()Returns the raw JSON value of bitRate. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_customCoordinates()Returns the raw JSON value of customCoordinates. final JsonField<CustomMetadata>_customMetadata()Returns the raw JSON value of customMetadata. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Long>_duration()Returns the raw JSON value of duration. final JsonField<EmbeddedMetadata>_embeddedMetadata()Returns the raw JSON value of embeddedMetadata. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_filePath()Returns the raw JSON value of filePath. final JsonField<String>_fileType()Returns the raw JSON value of fileType. final JsonField<Boolean>_hasAlpha()Returns the raw JSON value of hasAlpha. final JsonField<Double>_height()Returns the raw JSON value of height. final JsonField<Boolean>_isPrivateFile()Returns the raw JSON value of isPrivateFile. final JsonField<Boolean>_isPublished()Returns the raw JSON value of isPublished. final JsonField<String>_mime()Returns the raw JSON value of mime. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<SelectedFieldsSchema>_selectedFieldsSchema()Returns the raw JSON value of selectedFieldsSchema. final JsonField<Double>_size()Returns the raw JSON value of size. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<String>_thumbnail()Returns the raw JSON value of thumbnail. final JsonField<File.Type>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<VersionInfo>_versionInfo()Returns the raw JSON value of versionInfo. final JsonField<String>_videoCodec()Returns the raw JSON value of videoCodec. final JsonField<Double>_width()Returns the raw JSON value of width. final JsonField<FileUpdateResponse.ExtensionStatus>_extensionStatus()Returns the raw JSON value of extensionStatus. final Map<String, JsonValue>_additionalProperties()final FileUpdateResponse.BuildertoBuilder()final FileUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FileUpdateResponse. -
-
Method Detail
-
aiTags
final Optional<List<AiTag>> aiTags()
Array of AI-generated tags associated with the image. If no AITags are set, it will be null.
-
audioCodec
final Optional<String> audioCodec()
The audio codec used in the video (only for video/audio).
-
createdAt
final Optional<OffsetDateTime> createdAt()
Date and time when the file was uploaded. The date and time is in ISO8601 format.
-
customCoordinates
final Optional<String> customCoordinates()
An string with custom coordinates of the file.
-
customMetadata
final Optional<CustomMetadata> customMetadata()
An object with custom metadata for the file.
-
description
final Optional<String> description()
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
-
embeddedMetadata
final Optional<EmbeddedMetadata> embeddedMetadata()
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.
-
filePath
final Optional<String> filePath()
Path of the file. This is the path you would use in the URL to access the file. For example, if the file is at the root of the media library, the path will be
/file.jpg. If the file is inside a folder namedimages, the path will be/images/file.jpg.
-
isPrivateFile
final Optional<Boolean> isPrivateFile()
Specifies if the file is private or not.
-
isPublished
final Optional<Boolean> isPublished()
Specifies if the file is published or not.
-
selectedFieldsSchema
final Optional<SelectedFieldsSchema> selectedFieldsSchema()
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
tags
final Optional<List<String>> tags()
An array of tags assigned to the file. Tags are used to search files in the media library.
-
thumbnail
final Optional<String> thumbnail()
URL of the thumbnail image. This URL is used to access the thumbnail image of the file in the media library.
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Date and time when the file was last updated. The date and time is in ISO8601 format.
-
versionInfo
final Optional<VersionInfo> versionInfo()
An object with details of the file version.
-
videoCodec
final Optional<String> videoCodec()
The video codec used in the video (only for video).
-
extensionStatus
final Optional<FileUpdateResponse.ExtensionStatus> extensionStatus()
-
_aiTags
final JsonField<List<AiTag>> _aiTags()
Returns the raw JSON value of aiTags.
Unlike aiTags, this method doesn't throw if the JSON field has an unexpected type.
-
_audioCodec
final JsonField<String> _audioCodec()
Returns the raw JSON value of audioCodec.
Unlike audioCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_bitRate
final JsonField<Long> _bitRate()
Returns the raw JSON value of bitRate.
Unlike bitRate, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_customCoordinates
final JsonField<String> _customCoordinates()
Returns the raw JSON value of customCoordinates.
Unlike customCoordinates, this method doesn't throw if the JSON field has an unexpected type.
-
_customMetadata
final JsonField<CustomMetadata> _customMetadata()
Returns the raw JSON value of customMetadata.
Unlike customMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_duration
final JsonField<Long> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_embeddedMetadata
final JsonField<EmbeddedMetadata> _embeddedMetadata()
Returns the raw JSON value of embeddedMetadata.
Unlike embeddedMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_filePath
final JsonField<String> _filePath()
Returns the raw JSON value of filePath.
Unlike filePath, this method doesn't throw if the JSON field has an unexpected type.
-
_fileType
final JsonField<String> _fileType()
Returns the raw JSON value of fileType.
Unlike fileType, this method doesn't throw if the JSON field has an unexpected type.
-
_hasAlpha
final JsonField<Boolean> _hasAlpha()
Returns the raw JSON value of hasAlpha.
Unlike hasAlpha, this method doesn't throw if the JSON field has an unexpected type.
-
_height
final JsonField<Double> _height()
Returns the raw JSON value of height.
Unlike height, this method doesn't throw if the JSON field has an unexpected type.
-
_isPrivateFile
final JsonField<Boolean> _isPrivateFile()
Returns the raw JSON value of isPrivateFile.
Unlike isPrivateFile, this method doesn't throw if the JSON field has an unexpected type.
-
_isPublished
final JsonField<Boolean> _isPublished()
Returns the raw JSON value of isPublished.
Unlike isPublished, this method doesn't throw if the JSON field has an unexpected type.
-
_mime
final JsonField<String> _mime()
Returns the raw JSON value of mime.
Unlike mime, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_selectedFieldsSchema
final JsonField<SelectedFieldsSchema> _selectedFieldsSchema()
Returns the raw JSON value of selectedFieldsSchema.
Unlike selectedFieldsSchema, this method doesn't throw if the JSON field has an unexpected type.
-
_size
final JsonField<Double> _size()
Returns the raw JSON value of size.
Unlike size, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_thumbnail
final JsonField<String> _thumbnail()
Returns the raw JSON value of thumbnail.
Unlike thumbnail, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<File.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_versionInfo
final JsonField<VersionInfo> _versionInfo()
Returns the raw JSON value of versionInfo.
Unlike versionInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_videoCodec
final JsonField<String> _videoCodec()
Returns the raw JSON value of videoCodec.
Unlike videoCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<Double> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_extensionStatus
final JsonField<FileUpdateResponse.ExtensionStatus> _extensionStatus()
Returns the raw JSON value of extensionStatus.
Unlike extensionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileUpdateResponse.Builder toBuilder()
-
validate
final FileUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of FileUpdateResponse.
-
-
-
-