Class FileUpdateResponse.Builder
-
- All Implemented Interfaces:
public final class FileUpdateResponse.BuilderA builder for FileUpdateResponse.
-
-
Method Summary
-
-
Method Detail
-
aiTags
final FileUpdateResponse.Builder aiTags(List<AiTag> aiTags)
Array of AI-generated tags associated with the image. If no AITags are set, it will be null.
-
aiTags
final FileUpdateResponse.Builder aiTags(Optional<List<AiTag>> aiTags)
Alias for calling Builder.aiTags with
aiTags.orElse(null).
-
aiTags
final FileUpdateResponse.Builder aiTags(JsonField<List<AiTag>> aiTags)
Sets Builder.aiTags to an arbitrary JSON value.
You should usually call Builder.aiTags with a well-typed
List<AiTag>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAiTag
final FileUpdateResponse.Builder addAiTag(AiTag aiTag)
-
audioCodec
final FileUpdateResponse.Builder audioCodec(String audioCodec)
The audio codec used in the video (only for video/audio).
-
audioCodec
final FileUpdateResponse.Builder audioCodec(JsonField<String> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bitRate
final FileUpdateResponse.Builder bitRate(Long bitRate)
The bit rate of the video in kbps (only for video).
-
bitRate
final FileUpdateResponse.Builder bitRate(JsonField<Long> bitRate)
Sets Builder.bitRate to an arbitrary JSON value.
You should usually call Builder.bitRate with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final FileUpdateResponse.Builder createdAt(OffsetDateTime createdAt)
Date and time when the file was uploaded. The date and time is in ISO8601 format.
-
createdAt
final FileUpdateResponse.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customCoordinates
final FileUpdateResponse.Builder customCoordinates(String customCoordinates)
An string with custom coordinates of the file.
-
customCoordinates
final FileUpdateResponse.Builder customCoordinates(Optional<String> customCoordinates)
Alias for calling Builder.customCoordinates with
customCoordinates.orElse(null).
-
customCoordinates
final FileUpdateResponse.Builder customCoordinates(JsonField<String> customCoordinates)
Sets Builder.customCoordinates to an arbitrary JSON value.
You should usually call Builder.customCoordinates with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customMetadata
final FileUpdateResponse.Builder customMetadata(CustomMetadata customMetadata)
An object with custom metadata for the file.
-
customMetadata
final FileUpdateResponse.Builder customMetadata(JsonField<CustomMetadata> customMetadata)
Sets Builder.customMetadata to an arbitrary JSON value.
You should usually call Builder.customMetadata with a well-typed CustomMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final FileUpdateResponse.Builder description(String description)
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
-
description
final FileUpdateResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final FileUpdateResponse.Builder duration(Long duration)
The duration of the video in seconds (only for video).
-
duration
final FileUpdateResponse.Builder duration(JsonField<Long> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
embeddedMetadata
final FileUpdateResponse.Builder embeddedMetadata(EmbeddedMetadata embeddedMetadata)
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data.
-
embeddedMetadata
final FileUpdateResponse.Builder embeddedMetadata(JsonField<EmbeddedMetadata> embeddedMetadata)
Sets Builder.embeddedMetadata to an arbitrary JSON value.
You should usually call Builder.embeddedMetadata with a well-typed EmbeddedMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final FileUpdateResponse.Builder fileId(String fileId)
Unique identifier of the asset.
-
fileId
final FileUpdateResponse.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filePath
final FileUpdateResponse.Builder filePath(String filePath)
Path of the file. This is the path you would use in the URL to access the file. For example, if the file is at the root of the media library, the path will be
/file.jpg. If the file is inside a folder namedimages, the path will be/images/file.jpg.
-
filePath
final FileUpdateResponse.Builder filePath(JsonField<String> filePath)
Sets Builder.filePath to an arbitrary JSON value.
You should usually call Builder.filePath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileType
final FileUpdateResponse.Builder fileType(String fileType)
Type of the file. Possible values are
image,non-image.
-
fileType
final FileUpdateResponse.Builder fileType(JsonField<String> fileType)
Sets Builder.fileType to an arbitrary JSON value.
You should usually call Builder.fileType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hasAlpha
final FileUpdateResponse.Builder hasAlpha(Boolean hasAlpha)
Specifies if the image has an alpha channel.
-
hasAlpha
final FileUpdateResponse.Builder hasAlpha(JsonField<Boolean> hasAlpha)
Sets Builder.hasAlpha to an arbitrary JSON value.
You should usually call Builder.hasAlpha with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final FileUpdateResponse.Builder height(Double height)
Height of the file.
-
height
final FileUpdateResponse.Builder height(JsonField<Double> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPrivateFile
final FileUpdateResponse.Builder isPrivateFile(Boolean isPrivateFile)
Specifies if the file is private or not.
-
isPrivateFile
final FileUpdateResponse.Builder isPrivateFile(JsonField<Boolean> isPrivateFile)
Sets Builder.isPrivateFile to an arbitrary JSON value.
You should usually call Builder.isPrivateFile with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPublished
final FileUpdateResponse.Builder isPublished(Boolean isPublished)
Specifies if the file is published or not.
-
isPublished
final FileUpdateResponse.Builder isPublished(JsonField<Boolean> isPublished)
Sets Builder.isPublished to an arbitrary JSON value.
You should usually call Builder.isPublished with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
mime
final FileUpdateResponse.Builder mime(String mime)
MIME type of the file.
-
mime
final FileUpdateResponse.Builder mime(JsonField<String> mime)
Sets Builder.mime to an arbitrary JSON value.
You should usually call Builder.mime with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final FileUpdateResponse.Builder name(String name)
Name of the asset.
-
name
final FileUpdateResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
selectedFieldsSchema
final FileUpdateResponse.Builder selectedFieldsSchema(SelectedFieldsSchema selectedFieldsSchema)
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
selectedFieldsSchema
final FileUpdateResponse.Builder selectedFieldsSchema(JsonField<SelectedFieldsSchema> selectedFieldsSchema)
Sets Builder.selectedFieldsSchema to an arbitrary JSON value.
You should usually call Builder.selectedFieldsSchema with a well-typed SelectedFieldsSchema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
size
final FileUpdateResponse.Builder size(Double size)
Size of the file in bytes.
-
size
final FileUpdateResponse.Builder size(JsonField<Double> size)
Sets Builder.size to an arbitrary JSON value.
You should usually call Builder.size with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final FileUpdateResponse.Builder tags(List<String> tags)
An array of tags assigned to the file. Tags are used to search files in the media library.
-
tags
final FileUpdateResponse.Builder tags(Optional<List<String>> tags)
Alias for calling Builder.tags with
tags.orElse(null).
-
tags
final FileUpdateResponse.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final FileUpdateResponse.Builder addTag(String tag)
-
thumbnail
final FileUpdateResponse.Builder thumbnail(String thumbnail)
URL of the thumbnail image. This URL is used to access the thumbnail image of the file in the media library.
-
thumbnail
final FileUpdateResponse.Builder thumbnail(JsonField<String> thumbnail)
Sets Builder.thumbnail to an arbitrary JSON value.
You should usually call Builder.thumbnail with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final FileUpdateResponse.Builder type(File.Type type)
Type of the asset.
-
type
final FileUpdateResponse.Builder type(JsonField<File.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed File.Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
updatedAt
final FileUpdateResponse.Builder updatedAt(OffsetDateTime updatedAt)
Date and time when the file was last updated. The date and time is in ISO8601 format.
-
updatedAt
final FileUpdateResponse.Builder updatedAt(JsonField<OffsetDateTime> updatedAt)
Sets Builder.updatedAt to an arbitrary JSON value.
You should usually call Builder.updatedAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final FileUpdateResponse.Builder url(String url)
URL of the file.
-
url
final FileUpdateResponse.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
versionInfo
final FileUpdateResponse.Builder versionInfo(VersionInfo versionInfo)
An object with details of the file version.
-
versionInfo
final FileUpdateResponse.Builder versionInfo(JsonField<VersionInfo> versionInfo)
Sets Builder.versionInfo to an arbitrary JSON value.
You should usually call Builder.versionInfo with a well-typed VersionInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
videoCodec
final FileUpdateResponse.Builder videoCodec(String videoCodec)
The video codec used in the video (only for video).
-
videoCodec
final FileUpdateResponse.Builder videoCodec(JsonField<String> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final FileUpdateResponse.Builder width(Double width)
Width of the file.
-
width
final FileUpdateResponse.Builder width(JsonField<Double> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extensionStatus
final FileUpdateResponse.Builder extensionStatus(FileUpdateResponse.ExtensionStatus extensionStatus)
-
extensionStatus
final FileUpdateResponse.Builder extensionStatus(JsonField<FileUpdateResponse.ExtensionStatus> extensionStatus)
Sets Builder.extensionStatus to an arbitrary JSON value.
You should usually call Builder.extensionStatus with a well-typed ExtensionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileUpdateResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileUpdateResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileUpdateResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileUpdateResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileUpdateResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileUpdateResponse build()
Returns an immutable instance of FileUpdateResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-