Package io.imagekit.models.files
Class FileUploadParams.CustomMetadata
-
- All Implemented Interfaces:
public final class FileUploadParams.CustomMetadataJSON key-value pairs to associate with the asset. Create the custom metadata fields before setting these values.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileUploadParams.CustomMetadata.BuilderA builder for CustomMetadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final FileUploadParams.CustomMetadata.BuildertoBuilder()final FileUploadParams.CustomMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileUploadParams.CustomMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileUploadParams.CustomMetadata.Builder toBuilder()
-
validate
final FileUploadParams.CustomMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileUploadParams.CustomMetadata.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadata.
-
-
-
-