Class FileUploadParams.UploadTransformation.Post.Abs
-
- All Implemented Interfaces:
public final class FileUploadParams.UploadTransformation.Post.Abs
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileUploadParams.UploadTransformation.Post.Abs.BuilderA builder for Abs.
public final classFileUploadParams.UploadTransformation.Post.Abs.ProtocolStreaming protocol to use (
hlsordash).
-
Method Summary
Modifier and Type Method Description final FileUploadParams.UploadTransformation.Post.Abs.Protocolprotocol()Streaming protocol to use ( hlsordash).final JsonValue_type()Adaptive Bitrate Streaming (ABS) setup. final Stringvalue()List of different representations you want to create separated by an underscore. final MultipartField<FileUploadParams.UploadTransformation.Post.Abs.Protocol>_protocol()Returns the raw multipart value of protocol. final MultipartField<String>_value()Returns the raw multipart value of value. final Map<String, JsonValue>_additionalProperties()final FileUploadParams.UploadTransformation.Post.Abs.BuildertoBuilder()final FileUploadParams.UploadTransformation.Post.Absvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileUploadParams.UploadTransformation.Post.Abs.Builderbuilder()Returns a mutable builder for constructing an instance of Abs. -
-
Method Detail
-
protocol
final FileUploadParams.UploadTransformation.Post.Abs.Protocol protocol()
Streaming protocol to use (
hlsordash).
-
_type
final JsonValue _type()
Adaptive Bitrate Streaming (ABS) setup.
Expected to always return the following:
JsonValue.from("abs")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
value
final String value()
List of different representations you want to create separated by an underscore.
-
_protocol
final MultipartField<FileUploadParams.UploadTransformation.Post.Abs.Protocol> _protocol()
Returns the raw multipart value of protocol.
Unlike protocol, this method doesn't throw if the multipart field has an unexpected type.
-
_value
final MultipartField<String> _value()
Returns the raw multipart value of value.
Unlike value, this method doesn't throw if the multipart field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileUploadParams.UploadTransformation.Post.Abs.Builder toBuilder()
-
validate
final FileUploadParams.UploadTransformation.Post.Abs validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileUploadParams.UploadTransformation.Post.Abs.Builder builder()
Returns a mutable builder for constructing an instance of Abs.
The following fields are required:
.protocol() .value()
-
-
-
-