Class FileUploadResponse.Builder
-
- All Implemented Interfaces:
public final class FileUploadResponse.BuilderA builder for FileUploadResponse.
-
-
Method Summary
Modifier and Type Method Description final FileUploadResponse.BuilderaiTags(List<AiTag> aiTags)An array of tags assigned to the uploaded file by auto tagging. final FileUploadResponse.BuilderaiTags(Optional<List<AiTag>> aiTags)Alias for calling Builder.aiTags with aiTags.orElse(null).final FileUploadResponse.BuilderaiTags(JsonField<List<AiTag>> aiTags)Sets Builder.aiTags to an arbitrary JSON value. final FileUploadResponse.BuilderaddAiTag(AiTag aiTag)Adds a single AiTag to aiTags. final FileUploadResponse.BuilderaudioCodec(String audioCodec)The audio codec used in the video (only for video). final FileUploadResponse.BuilderaudioCodec(JsonField<String> audioCodec)Sets Builder.audioCodec to an arbitrary JSON value. final FileUploadResponse.BuilderbitRate(Long bitRate)The bit rate of the video in kbps (only for video). final FileUploadResponse.BuilderbitRate(JsonField<Long> bitRate)Sets Builder.bitRate to an arbitrary JSON value. final FileUploadResponse.BuildercustomCoordinates(String customCoordinates)Value of custom coordinates associated with the image in the format x,y,width,height.final FileUploadResponse.BuildercustomCoordinates(Optional<String> customCoordinates)Alias for calling Builder.customCoordinates with customCoordinates.orElse(null).final FileUploadResponse.BuildercustomCoordinates(JsonField<String> customCoordinates)Sets Builder.customCoordinates to an arbitrary JSON value. final FileUploadResponse.BuildercustomMetadata(CustomMetadata customMetadata)A key-value data associated with the asset. final FileUploadResponse.BuildercustomMetadata(JsonField<CustomMetadata> customMetadata)Sets Builder.customMetadata to an arbitrary JSON value. final FileUploadResponse.Builderdescription(String description)Optional text to describe the contents of the file. final FileUploadResponse.Builderdescription(JsonField<String> description)Sets Builder.description to an arbitrary JSON value. final FileUploadResponse.Builderduration(Long duration)The duration of the video in seconds (only for video). final FileUploadResponse.Builderduration(JsonField<Long> duration)Sets Builder.duration to an arbitrary JSON value. final FileUploadResponse.BuilderembeddedMetadata(EmbeddedMetadata embeddedMetadata)Consolidated embedded metadata associated with the file. final FileUploadResponse.BuilderembeddedMetadata(JsonField<EmbeddedMetadata> embeddedMetadata)Sets Builder.embeddedMetadata to an arbitrary JSON value. final FileUploadResponse.BuilderextensionStatus(FileUploadResponse.ExtensionStatus extensionStatus)Extension names with their processing status at the time of completion of the request. final FileUploadResponse.BuilderextensionStatus(JsonField<FileUploadResponse.ExtensionStatus> extensionStatus)Sets Builder.extensionStatus to an arbitrary JSON value. final FileUploadResponse.BuilderfileId(String fileId)Unique fileId. final FileUploadResponse.BuilderfileId(JsonField<String> fileId)Sets Builder.fileId to an arbitrary JSON value. final FileUploadResponse.BuilderfilePath(String filePath)The relative path of the file in the media library e.g. final FileUploadResponse.BuilderfilePath(JsonField<String> filePath)Sets Builder.filePath to an arbitrary JSON value. final FileUploadResponse.BuilderfileType(String fileType)Type of the uploaded file. final FileUploadResponse.BuilderfileType(JsonField<String> fileType)Sets Builder.fileType to an arbitrary JSON value. final FileUploadResponse.Builderheight(Double height)Height of the image in pixels (Only for images) final FileUploadResponse.Builderheight(JsonField<Double> height)Sets Builder.height to an arbitrary JSON value. final FileUploadResponse.BuilderisPrivateFile(Boolean isPrivateFile)Is the file marked as private. final FileUploadResponse.BuilderisPrivateFile(JsonField<Boolean> isPrivateFile)Sets Builder.isPrivateFile to an arbitrary JSON value. final FileUploadResponse.BuilderisPublished(Boolean isPublished)Is the file published or in draft state. final FileUploadResponse.BuilderisPublished(JsonField<Boolean> isPublished)Sets Builder.isPublished to an arbitrary JSON value. final FileUploadResponse.Buildermetadata(Metadata metadata)Legacy metadata. final FileUploadResponse.Buildermetadata(JsonField<Metadata> metadata)Sets Builder.metadata to an arbitrary JSON value. final FileUploadResponse.Buildername(String name)Name of the asset. final FileUploadResponse.Buildername(JsonField<String> name)Sets Builder.name to an arbitrary JSON value. final FileUploadResponse.BuilderselectedFieldsSchema(SelectedFieldsSchema selectedFieldsSchema)This field is included in the response only if the Path policy feature is available in the plan. final FileUploadResponse.BuilderselectedFieldsSchema(JsonField<SelectedFieldsSchema> selectedFieldsSchema)Sets Builder.selectedFieldsSchema to an arbitrary JSON value. final FileUploadResponse.Buildersize(Double size)Size of the image file in Bytes. final FileUploadResponse.Buildersize(JsonField<Double> size)Sets Builder.size to an arbitrary JSON value. final FileUploadResponse.Buildertags(List<String> tags)The array of tags associated with the asset. final FileUploadResponse.Buildertags(Optional<List<String>> tags)Alias for calling Builder.tags with tags.orElse(null).final FileUploadResponse.Buildertags(JsonField<List<String>> tags)Sets Builder.tags to an arbitrary JSON value. final FileUploadResponse.BuilderaddTag(String tag)Adds a single String to tags. final FileUploadResponse.BuilderthumbnailUrl(String thumbnailUrl)In the case of an image, a small thumbnail URL. final FileUploadResponse.BuilderthumbnailUrl(JsonField<String> thumbnailUrl)Sets Builder.thumbnailUrl to an arbitrary JSON value. final FileUploadResponse.Builderurl(String url)A publicly accessible URL of the file. final FileUploadResponse.Builderurl(JsonField<String> url)Sets Builder.url to an arbitrary JSON value. final FileUploadResponse.BuilderversionInfo(VersionInfo versionInfo)An object containing the file or file version's id(versionId) andname.final FileUploadResponse.BuilderversionInfo(JsonField<VersionInfo> versionInfo)Sets Builder.versionInfo to an arbitrary JSON value. final FileUploadResponse.BuildervideoCodec(String videoCodec)The video codec used in the video (only for video). final FileUploadResponse.BuildervideoCodec(JsonField<String> videoCodec)Sets Builder.videoCodec to an arbitrary JSON value. final FileUploadResponse.Builderwidth(Double width)Width of the image in pixels (Only for Images) final FileUploadResponse.Builderwidth(JsonField<Double> width)Sets Builder.width to an arbitrary JSON value. final FileUploadResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final FileUploadResponse.BuilderputAdditionalProperty(String key, JsonValue value)final FileUploadResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final FileUploadResponse.BuilderremoveAdditionalProperty(String key)final FileUploadResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final FileUploadResponsebuild()Returns an immutable instance of FileUploadResponse. -
-
Method Detail
-
aiTags
final FileUploadResponse.Builder aiTags(List<AiTag> aiTags)
An array of tags assigned to the uploaded file by auto tagging.
-
aiTags
final FileUploadResponse.Builder aiTags(Optional<List<AiTag>> aiTags)
Alias for calling Builder.aiTags with
aiTags.orElse(null).
-
aiTags
final FileUploadResponse.Builder aiTags(JsonField<List<AiTag>> aiTags)
Sets Builder.aiTags to an arbitrary JSON value.
You should usually call Builder.aiTags with a well-typed
List<AiTag>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAiTag
final FileUploadResponse.Builder addAiTag(AiTag aiTag)
-
audioCodec
final FileUploadResponse.Builder audioCodec(String audioCodec)
The audio codec used in the video (only for video).
-
audioCodec
final FileUploadResponse.Builder audioCodec(JsonField<String> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bitRate
final FileUploadResponse.Builder bitRate(Long bitRate)
The bit rate of the video in kbps (only for video).
-
bitRate
final FileUploadResponse.Builder bitRate(JsonField<Long> bitRate)
Sets Builder.bitRate to an arbitrary JSON value.
You should usually call Builder.bitRate with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customCoordinates
final FileUploadResponse.Builder customCoordinates(String customCoordinates)
Value of custom coordinates associated with the image in the format
x,y,width,height. IfcustomCoordinatesare not defined, then it isnull. SendcustomCoordinatesinresponseFieldsin API request to get the value of this field.
-
customCoordinates
final FileUploadResponse.Builder customCoordinates(Optional<String> customCoordinates)
Alias for calling Builder.customCoordinates with
customCoordinates.orElse(null).
-
customCoordinates
final FileUploadResponse.Builder customCoordinates(JsonField<String> customCoordinates)
Sets Builder.customCoordinates to an arbitrary JSON value.
You should usually call Builder.customCoordinates with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customMetadata
final FileUploadResponse.Builder customMetadata(CustomMetadata customMetadata)
A key-value data associated with the asset. Use
responseFieldin API request to getcustomMetadatain the upload API response. Before setting any custom metadata on an asset, you have to create the field using custom metadata fields API. SendcustomMetadatainresponseFieldsin API request to get the value of this field.
-
customMetadata
final FileUploadResponse.Builder customMetadata(JsonField<CustomMetadata> customMetadata)
Sets Builder.customMetadata to an arbitrary JSON value.
You should usually call Builder.customMetadata with a well-typed CustomMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final FileUploadResponse.Builder description(String description)
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
-
description
final FileUploadResponse.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final FileUploadResponse.Builder duration(Long duration)
The duration of the video in seconds (only for video).
-
duration
final FileUploadResponse.Builder duration(JsonField<Long> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
embeddedMetadata
final FileUploadResponse.Builder embeddedMetadata(EmbeddedMetadata embeddedMetadata)
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data. Send
embeddedMetadatainresponseFieldsin API request to get embeddedMetadata in the upload API response.
-
embeddedMetadata
final FileUploadResponse.Builder embeddedMetadata(JsonField<EmbeddedMetadata> embeddedMetadata)
Sets Builder.embeddedMetadata to an arbitrary JSON value.
You should usually call Builder.embeddedMetadata with a well-typed EmbeddedMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extensionStatus
final FileUploadResponse.Builder extensionStatus(FileUploadResponse.ExtensionStatus extensionStatus)
Extension names with their processing status at the time of completion of the request. It could have one of the following status values:
success: The extension has been successfully applied.failed: The extension has failed and will not be retried.pending: The extension will finish processing in some time. On completion, the final status (success / failed) will be sent to thewebhookUrlprovided.If no extension was requested, then this parameter is not returned.
-
extensionStatus
final FileUploadResponse.Builder extensionStatus(JsonField<FileUploadResponse.ExtensionStatus> extensionStatus)
Sets Builder.extensionStatus to an arbitrary JSON value.
You should usually call Builder.extensionStatus with a well-typed ExtensionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final FileUploadResponse.Builder fileId(String fileId)
Unique fileId. Store this fileld in your database, as this will be used to perform update action on this file.
-
fileId
final FileUploadResponse.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filePath
final FileUploadResponse.Builder filePath(String filePath)
The relative path of the file in the media library e.g.
/marketing-assets/new-banner.jpg.
-
filePath
final FileUploadResponse.Builder filePath(JsonField<String> filePath)
Sets Builder.filePath to an arbitrary JSON value.
You should usually call Builder.filePath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileType
final FileUploadResponse.Builder fileType(String fileType)
Type of the uploaded file. Possible values are
image,non-image.
-
fileType
final FileUploadResponse.Builder fileType(JsonField<String> fileType)
Sets Builder.fileType to an arbitrary JSON value.
You should usually call Builder.fileType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final FileUploadResponse.Builder height(Double height)
Height of the image in pixels (Only for images)
-
height
final FileUploadResponse.Builder height(JsonField<Double> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPrivateFile
final FileUploadResponse.Builder isPrivateFile(Boolean isPrivateFile)
Is the file marked as private. It can be either
trueorfalse. SendisPrivateFileinresponseFieldsin API request to get the value of this field.
-
isPrivateFile
final FileUploadResponse.Builder isPrivateFile(JsonField<Boolean> isPrivateFile)
Sets Builder.isPrivateFile to an arbitrary JSON value.
You should usually call Builder.isPrivateFile with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPublished
final FileUploadResponse.Builder isPublished(Boolean isPublished)
Is the file published or in draft state. It can be either
trueorfalse. SendisPublishedinresponseFieldsin API request to get the value of this field.
-
isPublished
final FileUploadResponse.Builder isPublished(JsonField<Boolean> isPublished)
Sets Builder.isPublished to an arbitrary JSON value.
You should usually call Builder.isPublished with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final FileUploadResponse.Builder metadata(Metadata metadata)
Legacy metadata. Send
metadatainresponseFieldsin API request to get metadata in the upload API response.
-
metadata
final FileUploadResponse.Builder metadata(JsonField<Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final FileUploadResponse.Builder name(String name)
Name of the asset.
-
name
final FileUploadResponse.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
selectedFieldsSchema
final FileUploadResponse.Builder selectedFieldsSchema(SelectedFieldsSchema selectedFieldsSchema)
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
selectedFieldsSchema
final FileUploadResponse.Builder selectedFieldsSchema(JsonField<SelectedFieldsSchema> selectedFieldsSchema)
Sets Builder.selectedFieldsSchema to an arbitrary JSON value.
You should usually call Builder.selectedFieldsSchema with a well-typed SelectedFieldsSchema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
size
final FileUploadResponse.Builder size(Double size)
Size of the image file in Bytes.
-
size
final FileUploadResponse.Builder size(JsonField<Double> size)
Sets Builder.size to an arbitrary JSON value.
You should usually call Builder.size with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final FileUploadResponse.Builder tags(List<String> tags)
The array of tags associated with the asset. If no tags are set, it will be
null. SendtagsinresponseFieldsin API request to get the value of this field.
-
tags
final FileUploadResponse.Builder tags(Optional<List<String>> tags)
Alias for calling Builder.tags with
tags.orElse(null).
-
tags
final FileUploadResponse.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final FileUploadResponse.Builder addTag(String tag)
-
thumbnailUrl
final FileUploadResponse.Builder thumbnailUrl(String thumbnailUrl)
In the case of an image, a small thumbnail URL.
-
thumbnailUrl
final FileUploadResponse.Builder thumbnailUrl(JsonField<String> thumbnailUrl)
Sets Builder.thumbnailUrl to an arbitrary JSON value.
You should usually call Builder.thumbnailUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final FileUploadResponse.Builder url(String url)
A publicly accessible URL of the file.
-
url
final FileUploadResponse.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
versionInfo
final FileUploadResponse.Builder versionInfo(VersionInfo versionInfo)
An object containing the file or file version's
id(versionId) andname.
-
versionInfo
final FileUploadResponse.Builder versionInfo(JsonField<VersionInfo> versionInfo)
Sets Builder.versionInfo to an arbitrary JSON value.
You should usually call Builder.versionInfo with a well-typed VersionInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
videoCodec
final FileUploadResponse.Builder videoCodec(String videoCodec)
The video codec used in the video (only for video).
-
videoCodec
final FileUploadResponse.Builder videoCodec(JsonField<String> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final FileUploadResponse.Builder width(Double width)
Width of the image in pixels (Only for Images)
-
width
final FileUploadResponse.Builder width(JsonField<Double> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileUploadResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileUploadResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileUploadResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileUploadResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileUploadResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileUploadResponse build()
Returns an immutable instance of FileUploadResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-