Class Folder
-
- All Implemented Interfaces:
public final class Folder
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFolder.BuilderA builder for Folder.
public final classFolder.CustomMetadataAn object with custom metadata for the folder. Returns empty object if no custom metadata is set.
public final classFolder.TypeType of the asset.
-
Method Summary
Modifier and Type Method Description final Optional<OffsetDateTime>createdAt()Date and time when the folder was created. final Optional<Folder.CustomMetadata>customMetadata()An object with custom metadata for the folder. final Optional<String>folderId()Unique identifier of the asset. final Optional<String>folderPath()Path of the folder. final Optional<String>name()Name of the asset. final Optional<Folder.Type>type()Type of the asset. final Optional<OffsetDateTime>updatedAt()Date and time when the folder was last updated. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<Folder.CustomMetadata>_customMetadata()Returns the raw JSON value of customMetadata. final JsonField<String>_folderId()Returns the raw JSON value of folderId. final JsonField<String>_folderPath()Returns the raw JSON value of folderPath. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Folder.Type>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_updatedAt()Returns the raw JSON value of updatedAt. final Map<String, JsonValue>_additionalProperties()final Folder.BuildertoBuilder()final Foldervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Folder.Builderbuilder()Returns a mutable builder for constructing an instance of Folder. -
-
Method Detail
-
createdAt
final Optional<OffsetDateTime> createdAt()
Date and time when the folder was created. The date and time is in ISO8601 format.
-
customMetadata
final Optional<Folder.CustomMetadata> customMetadata()
An object with custom metadata for the folder. Returns empty object if no custom metadata is set.
-
folderPath
final Optional<String> folderPath()
Path of the folder. This is the path you would use in the URL to access the folder. For example, if the folder is at the root of the media library, the path will be /folder. If the folder is inside another folder named images, the path will be /images/folder.
-
type
final Optional<Folder.Type> type()
Type of the asset.
-
updatedAt
final Optional<OffsetDateTime> updatedAt()
Date and time when the folder was last updated. The date and time is in ISO8601 format.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_customMetadata
final JsonField<Folder.CustomMetadata> _customMetadata()
Returns the raw JSON value of customMetadata.
Unlike customMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_folderId
final JsonField<String> _folderId()
Returns the raw JSON value of folderId.
Unlike folderId, this method doesn't throw if the JSON field has an unexpected type.
-
_folderPath
final JsonField<String> _folderPath()
Returns the raw JSON value of folderPath.
Unlike folderPath, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<Folder.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_updatedAt
final JsonField<OffsetDateTime> _updatedAt()
Returns the raw JSON value of updatedAt.
Unlike updatedAt, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Folder.Builder toBuilder()
-
validate
final Folder validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Folder.Builder builder()
Returns a mutable builder for constructing an instance of Folder.
-
-
-
-