Package io.imagekit.models.files
Class Folder.CustomMetadata
-
- All Implemented Interfaces:
public final class Folder.CustomMetadataAn object with custom metadata for the folder. Returns empty object if no custom metadata is set.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFolder.CustomMetadata.BuilderA builder for CustomMetadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final Folder.CustomMetadata.BuildertoBuilder()final Folder.CustomMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Folder.CustomMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Folder.CustomMetadata.Builder toBuilder()
-
validate
final Folder.CustomMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Folder.CustomMetadata.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadata.
-
-
-
-