Class Metadata
-
- All Implemented Interfaces:
public final class MetadataJSON object containing metadata.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadata.BuilderA builder for Metadata.
public final classMetadata.Exif
-
Method Summary
Modifier and Type Method Description final Optional<String>audioCodec()The audio codec used in the video (only for video). final Optional<Long>bitRate()The bit rate of the video in kbps (only for video). final Optional<Long>density()The density of the image in DPI. final Optional<Long>duration()The duration of the video in seconds (only for video). final Optional<Metadata.Exif>exif()final Optional<String>format()The format of the file (e.g., 'jpg', 'mp4'). final Optional<Boolean>hasColorProfile()Indicates if the image has a color profile. final Optional<Boolean>hasTransparency()Indicates if the image contains transparent areas. final Optional<Long>height()The height of the image or video in pixels. final Optional<String>pHash()Perceptual hash of the image. final Optional<Long>quality()The quality indicator of the image. final Optional<Long>size()The file size in bytes. final Optional<String>videoCodec()The video codec used in the video (only for video). final Optional<Long>width()The width of the image or video in pixels. final JsonField<String>_audioCodec()Returns the raw JSON value of audioCodec. final JsonField<Long>_bitRate()Returns the raw JSON value of bitRate. final JsonField<Long>_density()Returns the raw JSON value of density. final JsonField<Long>_duration()Returns the raw JSON value of duration. final JsonField<Metadata.Exif>_exif()Returns the raw JSON value of exif. final JsonField<String>_format()Returns the raw JSON value of format. final JsonField<Boolean>_hasColorProfile()Returns the raw JSON value of hasColorProfile. final JsonField<Boolean>_hasTransparency()Returns the raw JSON value of hasTransparency. final JsonField<Long>_height()Returns the raw JSON value of height. final JsonField<String>_pHash()Returns the raw JSON value of pHash. final JsonField<Long>_quality()Returns the raw JSON value of quality. final JsonField<Long>_size()Returns the raw JSON value of size. final JsonField<String>_videoCodec()Returns the raw JSON value of videoCodec. final JsonField<Long>_width()Returns the raw JSON value of width. final Map<String, JsonValue>_additionalProperties()final Metadata.BuildertoBuilder()final Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
audioCodec
final Optional<String> audioCodec()
The audio codec used in the video (only for video).
-
exif
final Optional<Metadata.Exif> exif()
-
hasColorProfile
final Optional<Boolean> hasColorProfile()
Indicates if the image has a color profile.
-
hasTransparency
final Optional<Boolean> hasTransparency()
Indicates if the image contains transparent areas.
-
videoCodec
final Optional<String> videoCodec()
The video codec used in the video (only for video).
-
_audioCodec
final JsonField<String> _audioCodec()
Returns the raw JSON value of audioCodec.
Unlike audioCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_bitRate
final JsonField<Long> _bitRate()
Returns the raw JSON value of bitRate.
Unlike bitRate, this method doesn't throw if the JSON field has an unexpected type.
-
_density
final JsonField<Long> _density()
Returns the raw JSON value of density.
Unlike density, this method doesn't throw if the JSON field has an unexpected type.
-
_duration
final JsonField<Long> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_exif
final JsonField<Metadata.Exif> _exif()
Returns the raw JSON value of exif.
Unlike exif, this method doesn't throw if the JSON field has an unexpected type.
-
_format
final JsonField<String> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_hasColorProfile
final JsonField<Boolean> _hasColorProfile()
Returns the raw JSON value of hasColorProfile.
Unlike hasColorProfile, this method doesn't throw if the JSON field has an unexpected type.
-
_hasTransparency
final JsonField<Boolean> _hasTransparency()
Returns the raw JSON value of hasTransparency.
Unlike hasTransparency, this method doesn't throw if the JSON field has an unexpected type.
-
_height
final JsonField<Long> _height()
Returns the raw JSON value of height.
Unlike height, this method doesn't throw if the JSON field has an unexpected type.
-
_pHash
final JsonField<String> _pHash()
Returns the raw JSON value of pHash.
Unlike pHash, this method doesn't throw if the JSON field has an unexpected type.
-
_quality
final JsonField<Long> _quality()
Returns the raw JSON value of quality.
Unlike quality, this method doesn't throw if the JSON field has an unexpected type.
-
_size
final JsonField<Long> _size()
Returns the raw JSON value of size.
Unlike size, this method doesn't throw if the JSON field has an unexpected type.
-
_videoCodec
final JsonField<String> _videoCodec()
Returns the raw JSON value of videoCodec.
Unlike videoCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<Long> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Metadata.Builder toBuilder()
-
validate
final Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-