Class Metadata.Builder
-
- All Implemented Interfaces:
public final class Metadata.BuilderA builder for Metadata.
-
-
Method Summary
Modifier and Type Method Description final Metadata.BuilderaudioCodec(String audioCodec)The audio codec used in the video (only for video). final Metadata.BuilderaudioCodec(JsonField<String> audioCodec)Sets Builder.audioCodec to an arbitrary JSON value. final Metadata.BuilderbitRate(Long bitRate)The bit rate of the video in kbps (only for video). final Metadata.BuilderbitRate(JsonField<Long> bitRate)Sets Builder.bitRate to an arbitrary JSON value. final Metadata.Builderdensity(Long density)The density of the image in DPI. final Metadata.Builderdensity(JsonField<Long> density)Sets Builder.density to an arbitrary JSON value. final Metadata.Builderduration(Long duration)The duration of the video in seconds (only for video). final Metadata.Builderduration(JsonField<Long> duration)Sets Builder.duration to an arbitrary JSON value. final Metadata.Builderexif(Metadata.Exif exif)final Metadata.Builderexif(JsonField<Metadata.Exif> exif)Sets Builder.exif to an arbitrary JSON value. final Metadata.Builderformat(String format)The format of the file (e.g., 'jpg', 'mp4'). final Metadata.Builderformat(JsonField<String> format)Sets Builder.format to an arbitrary JSON value. final Metadata.BuilderhasColorProfile(Boolean hasColorProfile)Indicates if the image has a color profile. final Metadata.BuilderhasColorProfile(JsonField<Boolean> hasColorProfile)Sets Builder.hasColorProfile to an arbitrary JSON value. final Metadata.BuilderhasTransparency(Boolean hasTransparency)Indicates if the image contains transparent areas. final Metadata.BuilderhasTransparency(JsonField<Boolean> hasTransparency)Sets Builder.hasTransparency to an arbitrary JSON value. final Metadata.Builderheight(Long height)The height of the image or video in pixels. final Metadata.Builderheight(JsonField<Long> height)Sets Builder.height to an arbitrary JSON value. final Metadata.BuilderpHash(String pHash)Perceptual hash of the image. final Metadata.BuilderpHash(JsonField<String> pHash)Sets Builder.pHash to an arbitrary JSON value. final Metadata.Builderquality(Long quality)The quality indicator of the image. final Metadata.Builderquality(JsonField<Long> quality)Sets Builder.quality to an arbitrary JSON value. final Metadata.Buildersize(Long size)The file size in bytes. final Metadata.Buildersize(JsonField<Long> size)Sets Builder.size to an arbitrary JSON value. final Metadata.BuildervideoCodec(String videoCodec)The video codec used in the video (only for video). final Metadata.BuildervideoCodec(JsonField<String> videoCodec)Sets Builder.videoCodec to an arbitrary JSON value. final Metadata.Builderwidth(Long width)The width of the image or video in pixels. final Metadata.Builderwidth(JsonField<Long> width)Sets Builder.width to an arbitrary JSON value. final Metadata.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final Metadata.BuilderputAdditionalProperty(String key, JsonValue value)final Metadata.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final Metadata.BuilderremoveAdditionalProperty(String key)final Metadata.BuilderremoveAllAdditionalProperties(Set<String> keys)final Metadatabuild()Returns an immutable instance of Metadata. -
-
Method Detail
-
audioCodec
final Metadata.Builder audioCodec(String audioCodec)
The audio codec used in the video (only for video).
-
audioCodec
final Metadata.Builder audioCodec(JsonField<String> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bitRate
final Metadata.Builder bitRate(Long bitRate)
The bit rate of the video in kbps (only for video).
-
bitRate
final Metadata.Builder bitRate(JsonField<Long> bitRate)
Sets Builder.bitRate to an arbitrary JSON value.
You should usually call Builder.bitRate with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
density
final Metadata.Builder density(Long density)
The density of the image in DPI.
-
density
final Metadata.Builder density(JsonField<Long> density)
Sets Builder.density to an arbitrary JSON value.
You should usually call Builder.density with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final Metadata.Builder duration(Long duration)
The duration of the video in seconds (only for video).
-
duration
final Metadata.Builder duration(JsonField<Long> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
exif
final Metadata.Builder exif(Metadata.Exif exif)
-
exif
final Metadata.Builder exif(JsonField<Metadata.Exif> exif)
Sets Builder.exif to an arbitrary JSON value.
You should usually call Builder.exif with a well-typed Exif value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
format
final Metadata.Builder format(String format)
The format of the file (e.g., 'jpg', 'mp4').
-
format
final Metadata.Builder format(JsonField<String> format)
Sets Builder.format to an arbitrary JSON value.
You should usually call Builder.format with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hasColorProfile
final Metadata.Builder hasColorProfile(Boolean hasColorProfile)
Indicates if the image has a color profile.
-
hasColorProfile
final Metadata.Builder hasColorProfile(JsonField<Boolean> hasColorProfile)
Sets Builder.hasColorProfile to an arbitrary JSON value.
You should usually call Builder.hasColorProfile with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
hasTransparency
final Metadata.Builder hasTransparency(Boolean hasTransparency)
Indicates if the image contains transparent areas.
-
hasTransparency
final Metadata.Builder hasTransparency(JsonField<Boolean> hasTransparency)
Sets Builder.hasTransparency to an arbitrary JSON value.
You should usually call Builder.hasTransparency with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final Metadata.Builder height(Long height)
The height of the image or video in pixels.
-
height
final Metadata.Builder height(JsonField<Long> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
pHash
final Metadata.Builder pHash(String pHash)
Perceptual hash of the image.
-
pHash
final Metadata.Builder pHash(JsonField<String> pHash)
Sets Builder.pHash to an arbitrary JSON value.
You should usually call Builder.pHash with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
quality
final Metadata.Builder quality(Long quality)
The quality indicator of the image.
-
quality
final Metadata.Builder quality(JsonField<Long> quality)
Sets Builder.quality to an arbitrary JSON value.
You should usually call Builder.quality with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
size
final Metadata.Builder size(Long size)
The file size in bytes.
-
size
final Metadata.Builder size(JsonField<Long> size)
Sets Builder.size to an arbitrary JSON value.
You should usually call Builder.size with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
videoCodec
final Metadata.Builder videoCodec(String videoCodec)
The video codec used in the video (only for video).
-
videoCodec
final Metadata.Builder videoCodec(JsonField<String> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final Metadata.Builder width(Long width)
The width of the image or video in pixels.
-
width
final Metadata.Builder width(JsonField<Long> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Metadata.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Metadata.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Metadata.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Metadata.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Metadata.Builder removeAllAdditionalProperties(Set<String> keys)
-
-
-
-