Class Metadata.Exif.Image
-
- All Implemented Interfaces:
public final class Metadata.Exif.ImageObject containing EXIF image information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadata.Exif.Image.BuilderA builder for Image.
-
Method Summary
Modifier and Type Method Description final Optional<String>artist()final Optional<String>copyright()final Optional<Long>exifOffset()final Optional<Long>gpsInfo()final Optional<String>imageDescription()final Optional<String>make()final Optional<String>model()final Optional<String>modifyDate()final Optional<Long>orientation()final Optional<Long>resolutionUnit()final Optional<String>software()final Optional<Double>xResolution()final Optional<Long>yCbCrPositioning()final Optional<Double>yResolution()final JsonField<String>_artist()Returns the raw JSON value of artist. final JsonField<String>_copyright()Returns the raw JSON value of copyright. final JsonField<Long>_exifOffset()Returns the raw JSON value of exifOffset. final JsonField<Long>_gpsInfo()Returns the raw JSON value of gpsInfo. final JsonField<String>_imageDescription()Returns the raw JSON value of imageDescription. final JsonField<String>_make()Returns the raw JSON value of make. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<String>_modifyDate()Returns the raw JSON value of modifyDate. final JsonField<Long>_orientation()Returns the raw JSON value of orientation. final JsonField<Long>_resolutionUnit()Returns the raw JSON value of resolutionUnit. final JsonField<String>_software()Returns the raw JSON value of software. final JsonField<Double>_xResolution()Returns the raw JSON value of xResolution. final JsonField<Long>_yCbCrPositioning()Returns the raw JSON value of yCbCrPositioning. final JsonField<Double>_yResolution()Returns the raw JSON value of yResolution. final Map<String, JsonValue>_additionalProperties()final Metadata.Exif.Image.BuildertoBuilder()final Metadata.Exif.Imagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Metadata.Exif.Image.Builderbuilder()Returns a mutable builder for constructing an instance of Image. -
-
Method Detail
-
exifOffset
final Optional<Long> exifOffset()
-
imageDescription
final Optional<String> imageDescription()
-
modifyDate
final Optional<String> modifyDate()
-
orientation
final Optional<Long> orientation()
-
resolutionUnit
final Optional<Long> resolutionUnit()
-
xResolution
final Optional<Double> xResolution()
-
yCbCrPositioning
final Optional<Long> yCbCrPositioning()
-
yResolution
final Optional<Double> yResolution()
-
_artist
final JsonField<String> _artist()
Returns the raw JSON value of artist.
Unlike artist, this method doesn't throw if the JSON field has an unexpected type.
-
_copyright
final JsonField<String> _copyright()
Returns the raw JSON value of copyright.
Unlike copyright, this method doesn't throw if the JSON field has an unexpected type.
-
_exifOffset
final JsonField<Long> _exifOffset()
Returns the raw JSON value of exifOffset.
Unlike exifOffset, this method doesn't throw if the JSON field has an unexpected type.
-
_gpsInfo
final JsonField<Long> _gpsInfo()
Returns the raw JSON value of gpsInfo.
Unlike gpsInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_imageDescription
final JsonField<String> _imageDescription()
Returns the raw JSON value of imageDescription.
Unlike imageDescription, this method doesn't throw if the JSON field has an unexpected type.
-
_make
final JsonField<String> _make()
Returns the raw JSON value of make.
Unlike make, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_modifyDate
final JsonField<String> _modifyDate()
Returns the raw JSON value of modifyDate.
Unlike modifyDate, this method doesn't throw if the JSON field has an unexpected type.
-
_orientation
final JsonField<Long> _orientation()
Returns the raw JSON value of orientation.
Unlike orientation, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionUnit
final JsonField<Long> _resolutionUnit()
Returns the raw JSON value of resolutionUnit.
Unlike resolutionUnit, this method doesn't throw if the JSON field has an unexpected type.
-
_software
final JsonField<String> _software()
Returns the raw JSON value of software.
Unlike software, this method doesn't throw if the JSON field has an unexpected type.
-
_xResolution
final JsonField<Double> _xResolution()
Returns the raw JSON value of xResolution.
Unlike xResolution, this method doesn't throw if the JSON field has an unexpected type.
-
_yCbCrPositioning
final JsonField<Long> _yCbCrPositioning()
Returns the raw JSON value of yCbCrPositioning.
Unlike yCbCrPositioning, this method doesn't throw if the JSON field has an unexpected type.
-
_yResolution
final JsonField<Double> _yResolution()
Returns the raw JSON value of yResolution.
Unlike yResolution, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Metadata.Exif.Image.Builder toBuilder()
-
validate
final Metadata.Exif.Image validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Metadata.Exif.Image.Builder builder()
Returns a mutable builder for constructing an instance of Image.
-
-
-
-