Class Metadata.Exif.Image.Builder
-
- All Implemented Interfaces:
public final class Metadata.Exif.Image.BuilderA builder for Image.
-
-
Method Summary
-
-
Method Detail
-
exifOffset
final Metadata.Exif.Image.Builder exifOffset(Long exifOffset)
-
exifOffset
final Metadata.Exif.Image.Builder exifOffset(JsonField<Long> exifOffset)
Sets Builder.exifOffset to an arbitrary JSON value.
You should usually call Builder.exifOffset with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
gpsInfo
final Metadata.Exif.Image.Builder gpsInfo(Long gpsInfo)
-
gpsInfo
final Metadata.Exif.Image.Builder gpsInfo(JsonField<Long> gpsInfo)
Sets Builder.gpsInfo to an arbitrary JSON value.
You should usually call Builder.gpsInfo with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
make
final Metadata.Exif.Image.Builder make(String make)
-
make
final Metadata.Exif.Image.Builder make(JsonField<String> make)
Sets Builder.make to an arbitrary JSON value.
You should usually call Builder.make with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
model
final Metadata.Exif.Image.Builder model(String model)
-
model
final Metadata.Exif.Image.Builder model(JsonField<String> model)
Sets Builder.model to an arbitrary JSON value.
You should usually call Builder.model with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
modifyDate
final Metadata.Exif.Image.Builder modifyDate(String modifyDate)
-
modifyDate
final Metadata.Exif.Image.Builder modifyDate(JsonField<String> modifyDate)
Sets Builder.modifyDate to an arbitrary JSON value.
You should usually call Builder.modifyDate with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
orientation
final Metadata.Exif.Image.Builder orientation(Long orientation)
-
orientation
final Metadata.Exif.Image.Builder orientation(JsonField<Long> orientation)
Sets Builder.orientation to an arbitrary JSON value.
You should usually call Builder.orientation with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
resolutionUnit
final Metadata.Exif.Image.Builder resolutionUnit(Long resolutionUnit)
-
resolutionUnit
final Metadata.Exif.Image.Builder resolutionUnit(JsonField<Long> resolutionUnit)
Sets Builder.resolutionUnit to an arbitrary JSON value.
You should usually call Builder.resolutionUnit with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
software
final Metadata.Exif.Image.Builder software(String software)
-
software
final Metadata.Exif.Image.Builder software(JsonField<String> software)
Sets Builder.software to an arbitrary JSON value.
You should usually call Builder.software with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
xResolution
final Metadata.Exif.Image.Builder xResolution(Long xResolution)
-
xResolution
final Metadata.Exif.Image.Builder xResolution(JsonField<Long> xResolution)
Sets Builder.xResolution to an arbitrary JSON value.
You should usually call Builder.xResolution with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
yCbCrPositioning
final Metadata.Exif.Image.Builder yCbCrPositioning(Long yCbCrPositioning)
-
yCbCrPositioning
final Metadata.Exif.Image.Builder yCbCrPositioning(JsonField<Long> yCbCrPositioning)
Sets Builder.yCbCrPositioning to an arbitrary JSON value.
You should usually call Builder.yCbCrPositioning with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
yResolution
final Metadata.Exif.Image.Builder yResolution(Long yResolution)
-
yResolution
final Metadata.Exif.Image.Builder yResolution(JsonField<Long> yResolution)
Sets Builder.yResolution to an arbitrary JSON value.
You should usually call Builder.yResolution with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final Metadata.Exif.Image.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final Metadata.Exif.Image.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final Metadata.Exif.Image.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final Metadata.Exif.Image.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final Metadata.Exif.Image.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final Metadata.Exif.Image build()
Returns an immutable instance of Image.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-