Package io.imagekit.models.files
Class Metadata.Exif.Interoperability
-
- All Implemented Interfaces:
public final class Metadata.Exif.InteroperabilityJSON object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadata.Exif.Interoperability.BuilderA builder for Interoperability.
-
Method Summary
Modifier and Type Method Description final Optional<String>interopIndex()final Optional<String>interopVersion()final JsonField<String>_interopIndex()Returns the raw JSON value of interopIndex. final JsonField<String>_interopVersion()Returns the raw JSON value of interopVersion. final Map<String, JsonValue>_additionalProperties()final Metadata.Exif.Interoperability.BuildertoBuilder()final Metadata.Exif.Interoperabilityvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Metadata.Exif.Interoperability.Builderbuilder()Returns a mutable builder for constructing an instance of Interoperability. -
-
Method Detail
-
interopIndex
final Optional<String> interopIndex()
-
interopVersion
final Optional<String> interopVersion()
-
_interopIndex
final JsonField<String> _interopIndex()
Returns the raw JSON value of interopIndex.
Unlike interopIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_interopVersion
final JsonField<String> _interopVersion()
Returns the raw JSON value of interopVersion.
Unlike interopVersion, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Metadata.Exif.Interoperability.Builder toBuilder()
-
validate
final Metadata.Exif.Interoperability validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static Metadata.Exif.Interoperability.Builder builder()
Returns a mutable builder for constructing an instance of Interoperability.
-
-
-
-