Package io.imagekit.models.files
Class UpdateFileRequest.ChangePublicationStatus
-
- All Implemented Interfaces:
public final class UpdateFileRequest.ChangePublicationStatus
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUpdateFileRequest.ChangePublicationStatus.BuilderA builder for ChangePublicationStatus.
public final classUpdateFileRequest.ChangePublicationStatus.PublishConfigure the publication status of a file and its versions.
-
Method Summary
Modifier and Type Method Description final Optional<UpdateFileRequest.ChangePublicationStatus.Publish>publish()Configure the publication status of a file and its versions. final JsonField<UpdateFileRequest.ChangePublicationStatus.Publish>_publish()Returns the raw JSON value of publish. final Map<String, JsonValue>_additionalProperties()final UpdateFileRequest.ChangePublicationStatus.BuildertoBuilder()final UpdateFileRequest.ChangePublicationStatusvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UpdateFileRequest.ChangePublicationStatus.Builderbuilder()Returns a mutable builder for constructing an instance of ChangePublicationStatus. -
-
Method Detail
-
publish
final Optional<UpdateFileRequest.ChangePublicationStatus.Publish> publish()
Configure the publication status of a file and its versions.
-
_publish
final JsonField<UpdateFileRequest.ChangePublicationStatus.Publish> _publish()
Returns the raw JSON value of publish.
Unlike publish, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UpdateFileRequest.ChangePublicationStatus.Builder toBuilder()
-
validate
final UpdateFileRequest.ChangePublicationStatus validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UpdateFileRequest.ChangePublicationStatus.Builder builder()
Returns a mutable builder for constructing an instance of ChangePublicationStatus.
-
-
-
-