Class UpdateFileRequest.UpdateFileDetails.Builder
-
- All Implemented Interfaces:
public final class UpdateFileRequest.UpdateFileDetails.BuilderA builder for UpdateFileDetails.
-
-
Method Summary
-
-
Method Detail
-
customCoordinates
final UpdateFileRequest.UpdateFileDetails.Builder customCoordinates(String customCoordinates)
Define an important area in the image in the format
x,y,width,heighte.g.10,10,100,100. Sendnullto unset this value.
-
customCoordinates
final UpdateFileRequest.UpdateFileDetails.Builder customCoordinates(Optional<String> customCoordinates)
Alias for calling Builder.customCoordinates with
customCoordinates.orElse(null).
-
customCoordinates
final UpdateFileRequest.UpdateFileDetails.Builder customCoordinates(JsonField<String> customCoordinates)
Sets Builder.customCoordinates to an arbitrary JSON value.
You should usually call Builder.customCoordinates with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customMetadata
final UpdateFileRequest.UpdateFileDetails.Builder customMetadata(UpdateFileRequest.UpdateFileDetails.CustomMetadata customMetadata)
A key-value data to be associated with the asset. To unset a key, send
nullvalue for that key. Before setting any custom metadata on an asset you have to create the field using custom metadata fields API.
-
customMetadata
final UpdateFileRequest.UpdateFileDetails.Builder customMetadata(JsonField<UpdateFileRequest.UpdateFileDetails.CustomMetadata> customMetadata)
Sets Builder.customMetadata to an arbitrary JSON value.
You should usually call Builder.customMetadata with a well-typed CustomMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final UpdateFileRequest.UpdateFileDetails.Builder description(String description)
Optional text to describe the contents of the file.
-
description
final UpdateFileRequest.UpdateFileDetails.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extensions
final UpdateFileRequest.UpdateFileDetails.Builder extensions(List<ExtensionItem> extensions)
Array of extensions to be applied to the asset. Each extension can be configured with specific parameters based on the extension type.
-
extensions
final UpdateFileRequest.UpdateFileDetails.Builder extensions(JsonField<List<ExtensionItem>> extensions)
Sets Builder.extensions to an arbitrary JSON value.
You should usually call Builder.extensions with a well-typed
List<ExtensionItem>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addExtension
final UpdateFileRequest.UpdateFileDetails.Builder addExtension(ExtensionItem extension)
Adds a single ExtensionItem to extensions.
-
addExtension
final UpdateFileRequest.UpdateFileDetails.Builder addExtension(ExtensionItem.RemoveBg removeBg)
Alias for calling addExtension with
ExtensionItem.ofRemoveBg(removeBg).
-
addExtension
final UpdateFileRequest.UpdateFileDetails.Builder addExtension(ExtensionItem.AutoTaggingExtension autoTaggingExtension)
Alias for calling addExtension with
ExtensionItem.ofAutoTaggingExtension(autoTaggingExtension).
-
addExtension
final UpdateFileRequest.UpdateFileDetails.Builder addExtension(ExtensionItem.AiTasks aiTasks)
Alias for calling addExtension with
ExtensionItem.ofAiTasks(aiTasks).
-
addExtension
final UpdateFileRequest.UpdateFileDetails.Builder addExtension(ExtensionItem.SavedExtension savedExtension)
Alias for calling addExtension with
ExtensionItem.ofSavedExtension(savedExtension).
-
addExtensionAiAutoDescription
final UpdateFileRequest.UpdateFileDetails.Builder addExtensionAiAutoDescription()
Alias for calling addExtension with
ExtensionItem.ofAiAutoDescription().
-
addAiTasksExtension
final UpdateFileRequest.UpdateFileDetails.Builder addAiTasksExtension(List<ExtensionItem.AiTasks.Task> tasks)
Alias for calling addExtension with the following:
ExtensionItem.AiTasks.builder() .tasks(tasks) .build()
-
addSavedExtensionExtension
final UpdateFileRequest.UpdateFileDetails.Builder addSavedExtensionExtension(String id)
Alias for calling addExtension with the following:
ExtensionItem.SavedExtension.builder() .id(id) .build()
-
removeAiTags
final UpdateFileRequest.UpdateFileDetails.Builder removeAiTags(UpdateFileRequest.UpdateFileDetails.RemoveAiTags removeAiTags)
An array of AITags associated with the file that you want to remove, e.g.
["car", "vehicle", "motorsports"].If you want to remove all AITags associated with the file, send a string - "all".
Note: The remove operation for
AITagsexecutes before any of theextensionsare processed.
-
removeAiTags
final UpdateFileRequest.UpdateFileDetails.Builder removeAiTags(JsonField<UpdateFileRequest.UpdateFileDetails.RemoveAiTags> removeAiTags)
Sets Builder.removeAiTags to an arbitrary JSON value.
You should usually call Builder.removeAiTags with a well-typed RemoveAiTags value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
removeAiTagsOfStrings
final UpdateFileRequest.UpdateFileDetails.Builder removeAiTagsOfStrings(List<String> strings)
Alias for calling removeAiTags with
RemoveAiTags.ofStrings(strings).
-
removeAiTagsAll
final UpdateFileRequest.UpdateFileDetails.Builder removeAiTagsAll()
Alias for calling removeAiTags with
RemoveAiTags.ofAll().
-
tags
final UpdateFileRequest.UpdateFileDetails.Builder tags(List<String> tags)
An array of tags associated with the file, such as
["tag1", "tag2"]. Sendnullto unset all tags associated with the file.
-
tags
final UpdateFileRequest.UpdateFileDetails.Builder tags(Optional<List<String>> tags)
Alias for calling Builder.tags with
tags.orElse(null).
-
tags
final UpdateFileRequest.UpdateFileDetails.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final UpdateFileRequest.UpdateFileDetails.Builder addTag(String tag)
-
webhookUrl
final UpdateFileRequest.UpdateFileDetails.Builder webhookUrl(String webhookUrl)
The final status of extensions after they have completed execution will be delivered to this endpoint as a POST request. /docs/api-reference/digital-asset-management-dam/managing-assets/update-file-details#webhook-payload-structure about the webhook payload structure.
-
webhookUrl
final UpdateFileRequest.UpdateFileDetails.Builder webhookUrl(JsonField<String> webhookUrl)
Sets Builder.webhookUrl to an arbitrary JSON value.
You should usually call Builder.webhookUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UpdateFileRequest.UpdateFileDetails.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UpdateFileRequest.UpdateFileDetails.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UpdateFileRequest.UpdateFileDetails.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UpdateFileRequest.UpdateFileDetails.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UpdateFileRequest.UpdateFileDetails.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UpdateFileRequest.UpdateFileDetails build()
Returns an immutable instance of UpdateFileDetails.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-