Class UpdateFileRequest.UpdateFileDetails.CustomMetadata

  • All Implemented Interfaces:

    
    public final class UpdateFileRequest.UpdateFileDetails.CustomMetadata
    
                        

    A key-value data to be associated with the asset. To unset a key, send null value for that key. Before setting any custom metadata on an asset you have to create the field using custom metadata fields API.