Package io.imagekit.models.folders
Class FolderCopyResponse
-
- All Implemented Interfaces:
public final class FolderCopyResponseJob submitted successfully. A
jobIdwill be returned.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFolderCopyResponse.BuilderA builder for FolderCopyResponse.
-
Method Summary
Modifier and Type Method Description final StringjobId()Unique identifier of the bulk job. final JsonField<String>_jobId()Returns the raw JSON value of jobId. final Map<String, JsonValue>_additionalProperties()final FolderCopyResponse.BuildertoBuilder()final FolderCopyResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FolderCopyResponse.Builderbuilder()Returns a mutable builder for constructing an instance of FolderCopyResponse. -
-
Method Detail
-
jobId
final String jobId()
Unique identifier of the bulk job. This can be used to check the status of the bulk job.
-
_jobId
final JsonField<String> _jobId()
Returns the raw JSON value of jobId.
Unlike jobId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FolderCopyResponse.Builder toBuilder()
-
validate
final FolderCopyResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FolderCopyResponse.Builder builder()
Returns a mutable builder for constructing an instance of FolderCopyResponse.
The following fields are required:
.jobId()
-
-
-
-