Class FolderCreateParams

  • All Implemented Interfaces:
    io.imagekit.core.Params

    
    public final class FolderCreateParams
     implements Params
                        

    This will create a new folder. You can specify the folder name and location of the parent folder where this new folder should be created.