Class FolderCreateParams.Body
-
- All Implemented Interfaces:
public final class FolderCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFolderCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringfolderName()The folder will be created with this name. final StringparentFolderPath()The folder where the new folder should be created, for root use /else the path e.g.final JsonField<String>_folderName()Returns the raw JSON value of folderName. final JsonField<String>_parentFolderPath()Returns the raw JSON value of parentFolderPath. final Map<String, JsonValue>_additionalProperties()final FolderCreateParams.Body.BuildertoBuilder()final FolderCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FolderCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
folderName
final String folderName()
The folder will be created with this name.
All characters except alphabets and numbers (inclusive of unicode letters, marks, and numerals in other languages) will be replaced by an underscore i.e.
_.
-
parentFolderPath
final String parentFolderPath()
The folder where the new folder should be created, for root use
/else the path e.g.containing/folder/.Note: If any folder(s) is not present in the parentFolderPath parameter, it will be automatically created. For example, if you pass
/product/images/summer, thenproduct,images, andsummerfolders will be created if they don't already exist.
-
_folderName
final JsonField<String> _folderName()
Returns the raw JSON value of folderName.
Unlike folderName, this method doesn't throw if the JSON field has an unexpected type.
-
_parentFolderPath
final JsonField<String> _parentFolderPath()
Returns the raw JSON value of parentFolderPath.
Unlike parentFolderPath, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FolderCreateParams.Body.Builder toBuilder()
-
validate
final FolderCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FolderCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.folderName() .parentFolderPath()
-
-
-
-