Package io.imagekit.models
See: Description
-
Class Summary Class Description Builder A builder for AiTag. AiTag AI-generated tag associated with an image. Builder A builder for BaseOverlay. LayerMode Controls how the layer blends with the base image or underlying content. BaseOverlay Builder A builder for CustomMetadata. CustomMetadata A key-value data associated with the asset. Builder A builder for EmbeddedMetadata. EmbeddedMetadata Consolidated embedded metadata associated with the file. Builder A builder for RemoveBg. Builder A builder for Options. Options RemoveBg Builder A builder for AutoTaggingExtension. Name Specifies the auto-tagging extension used. AutoTaggingExtension Builder A builder for AiTasks. Builder A builder for SelectTags. SelectTags Builder A builder for SelectMetadata. Vocabulary SelectMetadata Builder A builder for YesNo. Builder A builder for OnNo. Builder A builder for SetMetadata. MetadataValueItem Value Value to set for the custom metadata field. SetMetadata Builder A builder for UnsetMetadata. UnsetMetadata OnNo Actions to execute if the AI answers no. Builder A builder for OnUnknown. Builder A builder for SetMetadata. MetadataValueItem Value Value to set for the custom metadata field. SetMetadata Builder A builder for UnsetMetadata. UnsetMetadata OnUnknown Actions to execute if the AI cannot determine the answer. Builder A builder for OnYes. Builder A builder for SetMetadata. MetadataValueItem Value Value to set for the custom metadata field. SetMetadata Builder A builder for UnsetMetadata. UnsetMetadata OnYes Actions to execute if the AI answers yes. YesNo Task AiTasks ExtensionConfig Configuration object for an extension (base extensions only, not saved extension references). Builder A builder for RemoveBg. Builder A builder for Options. Options RemoveBg Builder A builder for AutoTaggingExtension. Name Specifies the auto-tagging extension used. AutoTaggingExtension Builder A builder for AiTasks. Builder A builder for SelectTags. SelectTags Builder A builder for SelectMetadata. Vocabulary SelectMetadata Builder A builder for YesNo. Builder A builder for OnNo. Builder A builder for SetMetadata. MetadataValueItem Value Value to set for the custom metadata field. SetMetadata Builder A builder for UnsetMetadata. UnsetMetadata OnNo Actions to execute if the AI answers no. Builder A builder for OnUnknown. Builder A builder for SetMetadata. MetadataValueItem Value Value to set for the custom metadata field. SetMetadata Builder A builder for UnsetMetadata. UnsetMetadata OnUnknown Actions to execute if the AI cannot determine the answer. Builder A builder for OnYes. Builder A builder for SetMetadata. MetadataValueItem Value Value to set for the custom metadata field. SetMetadata Builder A builder for UnsetMetadata. UnsetMetadata OnYes Actions to execute if the AI answers yes. YesNo Task AiTasks Builder A builder for SavedExtension. SavedExtension ExtensionItem Builder A builder for GetImageAttributesOptions. GetImageAttributesOptions Options for generating responsive image attributes including src,srcSet, andsizesfor HTML<img>elements.Builder A builder for ImageOverlay. Encoding The input path can be included in the layer as either i-{input}orie-{base64_encoded_input}.ImageOverlay Overlay Specifies an overlay to be applied on the parent image or video. Builder A builder for OverlayPosition. AnchorPoint Sets the anchor point on the base asset from which the overlay offset is calculated. Focus Specifies the position of the overlay relative to the parent image or video. X Specifies the x-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. XCenter Specifies the x-coordinate on the base asset where the overlay's center will be positioned. Y Specifies the y-coordinate of the top-left corner of the base asset where the overlay's top-left corner will be positioned. YCenter Specifies the y-coordinate on the base asset where the overlay's center will be positioned. OverlayPosition Builder A builder for OverlayTiming. Duration Specifies the duration (in seconds) during which the overlay should appear on the base video. End Specifies the end time (in seconds) for when the overlay should disappear from the base video. Start Specifies the start time (in seconds) for when the overlay should appear on the base video. OverlayTiming Builder A builder for ResponsiveImageAttributes. ResponsiveImageAttributes Resulting set of attributes suitable for an HTML <img>element.Builder A builder for SavedExtension. SavedExtension Saved extension object containing extension configuration. Builder A builder for SelectedFieldsSchema. SelectedFieldsSchema This field is included in the response only if the Path policy feature is available in the plan. Builder A builder for SolidColorOverlay. SolidColorOverlay Builder A builder for SolidColorOverlayTransformation. Gradient Creates a linear gradient with two colors. Height Controls the height of the solid color overlay. Radius Specifies the corner radius of the solid color overlay. Width Controls the width of the solid color overlay. SolidColorOverlayTransformation Builder A builder for SrcOptions. Builder A builder for QueryParameters. QueryParameters These are additional query parameters that you want to add to the final URL. SrcOptions Options for generating ImageKit URLs with transformations. StreamingResolution Available streaming resolutions for adaptive bitrate streaming Builder A builder for SubtitleOverlay. Encoding The input path can be included in the layer as either i-{input}orie-{base64_encoded_input}.SubtitleOverlay Builder A builder for SubtitleOverlayTransformation. Typography Sets the typography style of the subtitle text. SubtitleOverlayTransformation Subtitle styling options. Builder A builder for TextOverlay. Encoding Text can be included in the layer as either i-{input}(plain text) orie-{base64_encoded_input}(base64).TextOverlay Builder A builder for TextOverlayTransformation. Flip Flip/mirror the text horizontally, vertically, or in both directions. FontSize Specifies the font size of the overlaid text. InnerAlignment Specifies the inner alignment of the text when width is more than the text length. LineHeight Specifies the line height for multi-line text overlays. Padding Specifies the padding around the overlaid text. Radius Specifies the corner radius: Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
Rotation Specifies the rotation angle of the text overlay. Width Specifies the maximum width (in pixels) of the overlaid text. TextOverlayTransformation Builder A builder for Transformation. AiDropShadow Adds an AI-based drop shadow around a foreground object on a transparent or removed background. AiRemoveBackground Applies ImageKit's in-house background removal. AiRemoveBackgroundExternal Uses third-party background removal. AiRetouch Performs AI-based retouching to improve faces or product shots. AiUpscale Upscales images beyond their original dimensions using AI. AiVariation Generates a variation of an image using AI. AspectRatio Specifies the aspect ratio for the output, e.g., "ar-4-3". AudioCodec Specifies the audio codec, e.g. ContrastStretch Automatically enhances the contrast of an image (contrast stretch). Crop Crop modes for image resizing. CropMode Additional crop modes for image resizing. Duration Specifies the duration (in seconds) for trimming videos, e.g. EndOffset Specifies the end offset (in seconds) for trimming videos, e.g. Flip Flips or mirrors an image either horizontally, vertically, or both. Format Specifies the output format for images or videos, e.g. Gradient Creates a linear gradient with two colors. Grayscale Enables a grayscale effect for images. Height Specifies the height of the output. Page Extracts a specific page or frame from multi-page or layered files (PDF, PSD, AI). Radius Specifies the corner radius for rounded corners. Rotation Specifies the rotation angle in degrees. Shadow Adds a shadow beneath solid objects in an image with a transparent background. Sharpen Sharpens the input image, highlighting edges and finer details. StartOffset Specifies the start offset (in seconds) for trimming videos, e.g. Trim Useful for images with a solid or nearly solid background and a central object. UnsharpMask Applies Unsharp Masking (USM), an image sharpening technique. VideoCodec Specifies the video codec, e.g. Width Specifies the width of the output. X Focus using cropped image coordinates - X coordinate. XCenter Focus using cropped image coordinates - X center coordinate. Y Focus using cropped image coordinates - Y coordinate. YCenter Focus using cropped image coordinates - Y center coordinate. Transformation The SDK provides easy-to-use names for transformations. TransformationPosition By default, the transformation string is added as a query parameter in the URL, e.g. Builder A builder for VersionInfo. VersionInfo An object containing the file or file version's id(versionId) andname.Builder A builder for VideoOverlay. Encoding The input path can be included in the layer as either i-{input}orie-{base64_encoded_input}.VideoOverlay -
Enum Summary Enum Description Known An enum containing LayerMode's known values. Value An enum containing LayerMode's known values, as well as an _UNKNOWN member. Known An enum containing Name's known values. Value An enum containing Name's known values, as well as an _UNKNOWN member. Known An enum containing Name's known values. Value An enum containing Name's known values, as well as an _UNKNOWN member. Known An enum containing Encoding's known values. Value An enum containing Encoding's known values, as well as an _UNKNOWN member. Known An enum containing AnchorPoint's known values. Value An enum containing AnchorPoint's known values, as well as an _UNKNOWN member. Known An enum containing Focus's known values. Value An enum containing Focus's known values, as well as an _UNKNOWN member. Known An enum containing StreamingResolution's known values. Value An enum containing StreamingResolution's known values, as well as an _UNKNOWN member. Known An enum containing Encoding's known values. Value An enum containing Encoding's known values, as well as an _UNKNOWN member. Known An enum containing Typography's known values. Value An enum containing Typography's known values, as well as an _UNKNOWN member. Known An enum containing Encoding's known values. Value An enum containing Encoding's known values, as well as an _UNKNOWN member. Known An enum containing Flip's known values. Value An enum containing Flip's known values, as well as an _UNKNOWN member. Known An enum containing InnerAlignment's known values. Value An enum containing InnerAlignment's known values, as well as an _UNKNOWN member. Known An enum containing AiRemoveBackground's known values. Value An enum containing AiRemoveBackground's known values, as well as an _UNKNOWN member. Known An enum containing AiRemoveBackgroundExternal's known values. Value An enum containing AiRemoveBackgroundExternal's known values, as well as an _UNKNOWN member. Known An enum containing AiRetouch's known values. Value An enum containing AiRetouch's known values, as well as an _UNKNOWN member. Known An enum containing AiUpscale's known values. Value An enum containing AiUpscale's known values, as well as an _UNKNOWN member. Known An enum containing AiVariation's known values. Value An enum containing AiVariation's known values, as well as an _UNKNOWN member. Known An enum containing AudioCodec's known values. Value An enum containing AudioCodec's known values, as well as an _UNKNOWN member. Known An enum containing ContrastStretch's known values. Value An enum containing ContrastStretch's known values, as well as an _UNKNOWN member. Known An enum containing Crop's known values. Value An enum containing Crop's known values, as well as an _UNKNOWN member. Known An enum containing CropMode's known values. Value An enum containing CropMode's known values, as well as an _UNKNOWN member. Known An enum containing Flip's known values. Value An enum containing Flip's known values, as well as an _UNKNOWN member. Known An enum containing Format's known values. Value An enum containing Format's known values, as well as an _UNKNOWN member. Known An enum containing Grayscale's known values. Value An enum containing Grayscale's known values, as well as an _UNKNOWN member. Known An enum containing VideoCodec's known values. Value An enum containing VideoCodec's known values, as well as an _UNKNOWN member. Known An enum containing TransformationPosition's known values. Value An enum containing TransformationPosition's known values, as well as an _UNKNOWN member. Known An enum containing Encoding's known values. Value An enum containing Encoding's known values, as well as an _UNKNOWN member. -
Interface Summary Interface Description Visitor An interface that defines how to map each variant of ExtensionConfig to a value of type T. Visitor An interface that defines how to map each variant of Task to a value of type T. Visitor An interface that defines how to map each variant of Vocabulary to a value of type T. Visitor An interface that defines how to map each variant of Value to a value of type T. Visitor An interface that defines how to map each variant of MetadataValueItem to a value of type T. Visitor An interface that defines how to map each variant of Value to a value of type T. Visitor An interface that defines how to map each variant of MetadataValueItem to a value of type T. Visitor An interface that defines how to map each variant of Value to a value of type T. Visitor An interface that defines how to map each variant of MetadataValueItem to a value of type T. Visitor An interface that defines how to map each variant of ExtensionItem to a value of type T. Visitor An interface that defines how to map each variant of Task to a value of type T. Visitor An interface that defines how to map each variant of Vocabulary to a value of type T. Visitor An interface that defines how to map each variant of Value to a value of type T. Visitor An interface that defines how to map each variant of MetadataValueItem to a value of type T. Visitor An interface that defines how to map each variant of Value to a value of type T. Visitor An interface that defines how to map each variant of MetadataValueItem to a value of type T. Visitor An interface that defines how to map each variant of Value to a value of type T. Visitor An interface that defines how to map each variant of MetadataValueItem to a value of type T. Visitor An interface that defines how to map each variant of Overlay to a value of type T. Visitor An interface that defines how to map each variant of X to a value of type T. Visitor An interface that defines how to map each variant of XCenter to a value of type T. Visitor An interface that defines how to map each variant of Y to a value of type T. Visitor An interface that defines how to map each variant of YCenter to a value of type T. Visitor An interface that defines how to map each variant of Duration to a value of type T. Visitor An interface that defines how to map each variant of End to a value of type T. Visitor An interface that defines how to map each variant of Start to a value of type T. Visitor An interface that defines how to map each variant of Gradient to a value of type T. Visitor An interface that defines how to map each variant of Height to a value of type T. Visitor An interface that defines how to map each variant of Radius to a value of type T. Visitor An interface that defines how to map each variant of Width to a value of type T. Visitor An interface that defines how to map each variant of FontSize to a value of type T. Visitor An interface that defines how to map each variant of LineHeight to a value of type T. Visitor An interface that defines how to map each variant of Padding to a value of type T. Visitor An interface that defines how to map each variant of Radius to a value of type T. Visitor An interface that defines how to map each variant of Rotation to a value of type T. Visitor An interface that defines how to map each variant of Width to a value of type T. Visitor An interface that defines how to map each variant of AiDropShadow to a value of type T. Visitor An interface that defines how to map each variant of AspectRatio to a value of type T. Visitor An interface that defines how to map each variant of Duration to a value of type T. Visitor An interface that defines how to map each variant of EndOffset to a value of type T. Visitor An interface that defines how to map each variant of Gradient to a value of type T. Visitor An interface that defines how to map each variant of Height to a value of type T. Visitor An interface that defines how to map each variant of Page to a value of type T. Visitor An interface that defines how to map each variant of Radius to a value of type T. Visitor An interface that defines how to map each variant of Rotation to a value of type T. Visitor An interface that defines how to map each variant of Shadow to a value of type T. Visitor An interface that defines how to map each variant of Sharpen to a value of type T. Visitor An interface that defines how to map each variant of StartOffset to a value of type T. Visitor An interface that defines how to map each variant of Trim to a value of type T. Visitor An interface that defines how to map each variant of UnsharpMask to a value of type T. Visitor An interface that defines how to map each variant of Width to a value of type T. Visitor An interface that defines how to map each variant of X to a value of type T. Visitor An interface that defines how to map each variant of XCenter to a value of type T. Visitor An interface that defines how to map each variant of Y to a value of type T. Visitor An interface that defines how to map each variant of YCenter to a value of type T.