Package io.imagekit.models.webhooks
Class BaseWebhookEvent
-
- All Implemented Interfaces:
public final class BaseWebhookEvent
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBaseWebhookEvent.BuilderA builder for BaseWebhookEvent.
-
Method Summary
Modifier and Type Method Description final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final BaseWebhookEvent.BuildertoBuilder()final BaseWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BaseWebhookEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BaseWebhookEvent. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BaseWebhookEvent.Builder toBuilder()
-
validate
final BaseWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BaseWebhookEvent.Builder builder()
Returns a mutable builder for constructing an instance of BaseWebhookEvent.
The following fields are required:
.id() .type()
-
-
-
-