Package io.imagekit.models.webhooks
Class BaseWebhookEvent.Builder
-
- All Implemented Interfaces:
public final class BaseWebhookEvent.BuilderA builder for BaseWebhookEvent.
-
-
Method Summary
Modifier and Type Method Description final BaseWebhookEvent.Builderid(String id)Unique identifier for the event. final BaseWebhookEvent.Builderid(JsonField<String> id)Sets Builder.id to an arbitrary JSON value. final BaseWebhookEvent.Buildertype(String type)The type of webhook event. final BaseWebhookEvent.Buildertype(JsonField<String> type)Sets Builder.type to an arbitrary JSON value. final BaseWebhookEvent.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final BaseWebhookEvent.BuilderputAdditionalProperty(String key, JsonValue value)final BaseWebhookEvent.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final BaseWebhookEvent.BuilderremoveAdditionalProperty(String key)final BaseWebhookEvent.BuilderremoveAllAdditionalProperties(Set<String> keys)final BaseWebhookEventbuild()Returns an immutable instance of BaseWebhookEvent. -
-
Method Detail
-
id
final BaseWebhookEvent.Builder id(String id)
Unique identifier for the event.
-
id
final BaseWebhookEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BaseWebhookEvent.Builder type(String type)
The type of webhook event.
-
type
final BaseWebhookEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BaseWebhookEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BaseWebhookEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BaseWebhookEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BaseWebhookEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BaseWebhookEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BaseWebhookEvent build()
Returns an immutable instance of BaseWebhookEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type()
-
-
-
-