Class FileCreateEvent
-
- All Implemented Interfaces:
public final class FileCreateEventTriggered when a file is created.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileCreateEvent.BuilderA builder for FileCreateEvent.
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp of when the event occurred in ISO8601 format. final Filedata()Object containing details of a file or file version. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<File>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final FileCreateEvent.BuildertoBuilder()final FileCreateEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileCreateEvent.Builderbuilder()Returns a mutable builder for constructing an instance of FileCreateEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp of when the event occurred in ISO8601 format.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<File> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileCreateEvent.Builder toBuilder()
-
validate
final FileCreateEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileCreateEvent.Builder builder()
Returns a mutable builder for constructing an instance of FileCreateEvent.
The following fields are required:
.id() .type() .createdAt() .data()
-
-
-
-