Class FileCreateEvent.Builder
-
- All Implemented Interfaces:
public final class FileCreateEvent.BuilderA builder for FileCreateEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final FileCreateEvent.Builder id(String id)
Unique identifier for the event.
-
id
final FileCreateEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final FileCreateEvent.Builder type(String type)
The type of webhook event.
-
type
final FileCreateEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final FileCreateEvent.Builder createdAt(OffsetDateTime createdAt)
Timestamp of when the event occurred in ISO8601 format.
-
createdAt
final FileCreateEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final FileCreateEvent.Builder data(File data)
Object containing details of a file or file version.
-
data
final FileCreateEvent.Builder data(JsonField<File> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed File value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileCreateEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileCreateEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileCreateEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileCreateEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileCreateEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileCreateEvent build()
Returns an immutable instance of FileCreateEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type() .createdAt() .data()
-
-
-
-