Class FileDeleteEvent
-
- All Implemented Interfaces:
public final class FileDeleteEventTriggered when a file is deleted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileDeleteEvent.BuilderA builder for FileDeleteEvent.
public final classFileDeleteEvent.Data
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp of when the event occurred in ISO8601 format. final FileDeleteEvent.Datadata()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<FileDeleteEvent.Data>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final FileDeleteEvent.BuildertoBuilder()final FileDeleteEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileDeleteEvent.Builderbuilder()Returns a mutable builder for constructing an instance of FileDeleteEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp of when the event occurred in ISO8601 format.
-
data
final FileDeleteEvent.Data data()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<FileDeleteEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileDeleteEvent.Builder toBuilder()
-
validate
final FileDeleteEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileDeleteEvent.Builder builder()
Returns a mutable builder for constructing an instance of FileDeleteEvent.
The following fields are required:
.id() .type() .createdAt() .data()
-
-
-
-