Package io.imagekit.models.webhooks
Class FileVersionDeleteEvent
-
- All Implemented Interfaces:
public final class FileVersionDeleteEventTriggered when a file version is deleted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileVersionDeleteEvent.BuilderA builder for FileVersionDeleteEvent.
public final classFileVersionDeleteEvent.Data
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp of when the event occurred in ISO8601 format. final FileVersionDeleteEvent.Datadata()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<FileVersionDeleteEvent.Data>_data()Returns the raw JSON value of data. final Map<String, JsonValue>_additionalProperties()final FileVersionDeleteEvent.BuildertoBuilder()final FileVersionDeleteEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileVersionDeleteEvent.Builderbuilder()Returns a mutable builder for constructing an instance of FileVersionDeleteEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp of when the event occurred in ISO8601 format.
-
data
final FileVersionDeleteEvent.Data data()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<FileVersionDeleteEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileVersionDeleteEvent.Builder toBuilder()
-
validate
final FileVersionDeleteEvent validate()
-
builder
final static FileVersionDeleteEvent.Builder builder()
Returns a mutable builder for constructing an instance of FileVersionDeleteEvent.
The following fields are required:
.id() .type() .createdAt() .data()
-
-
-
-