Package io.imagekit.models.webhooks
Class FileVersionDeleteEvent.Data
-
- All Implemented Interfaces:
public final class FileVersionDeleteEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileVersionDeleteEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final StringfileId()The unique fileIdof the deleted file.final StringversionId()The unique versionIdof the deleted file version.final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_versionId()Returns the raw JSON value of versionId. final Map<String, JsonValue>_additionalProperties()final FileVersionDeleteEvent.Data.BuildertoBuilder()final FileVersionDeleteEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileVersionDeleteEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_versionId
final JsonField<String> _versionId()
Returns the raw JSON value of versionId.
Unlike versionId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileVersionDeleteEvent.Data.Builder toBuilder()
-
validate
final FileVersionDeleteEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileVersionDeleteEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.fileId() .versionId()
-
-
-
-