Package io.imagekit.models.webhooks
Class FileVersionDeleteEvent.Data.Builder
-
- All Implemented Interfaces:
public final class FileVersionDeleteEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
fileId
final FileVersionDeleteEvent.Data.Builder fileId(String fileId)
The unique
fileIdof the deleted file.
-
fileId
final FileVersionDeleteEvent.Data.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
versionId
final FileVersionDeleteEvent.Data.Builder versionId(String versionId)
The unique
versionIdof the deleted file version.
-
versionId
final FileVersionDeleteEvent.Data.Builder versionId(JsonField<String> versionId)
Sets Builder.versionId to an arbitrary JSON value.
You should usually call Builder.versionId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final FileVersionDeleteEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FileVersionDeleteEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FileVersionDeleteEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FileVersionDeleteEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FileVersionDeleteEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FileVersionDeleteEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.fileId() .versionId()
-
-
-
-