Class UnwrapWebhookEvent
-
- All Implemented Interfaces:
public final class UnwrapWebhookEventTriggered when a new video transformation request is accepted for processing. This event confirms that ImageKit has received and queued your transformation request. Use this for debugging and tracking transformation lifecycle.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceUnwrapWebhookEvent.VisitorAn interface that defines how to map each variant of UnwrapWebhookEvent to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<VideoTransformationAcceptedEvent>videoTransformationAccepted()Triggered when a new video transformation request is accepted for processing. final Optional<VideoTransformationReadyEvent>videoTransformationReady()Triggered when video encoding is finished and the transformed resource is ready to be served. final Optional<VideoTransformationErrorEvent>videoTransformationError()Triggered when an error occurs during video encoding. final Optional<UploadPreTransformSuccessEvent>uploadPreTransformSuccess()Triggered when a pre-transformation completes successfully. final Optional<UploadPreTransformErrorEvent>uploadPreTransformError()Triggered when a pre-transformation fails. final Optional<UploadPostTransformSuccessEvent>uploadPostTransformSuccess()Triggered when a post-transformation completes successfully. final Optional<UploadPostTransformErrorEvent>uploadPostTransformError()Triggered when a post-transformation fails. final Optional<FileCreateEvent>fileCreate()Triggered when a file is created. final Optional<FileUpdateEvent>fileUpdate()Triggered when a file is updated. final Optional<FileDeleteEvent>fileDelete()Triggered when a file is deleted. final Optional<FileVersionCreateEvent>fileVersionCreate()Triggered when a file version is created. final Optional<FileVersionDeleteEvent>fileVersionDelete()Triggered when a file version is deleted. final BooleanisVideoTransformationAccepted()final BooleanisVideoTransformationReady()final BooleanisVideoTransformationError()final BooleanisUploadPreTransformSuccess()final BooleanisUploadPreTransformError()final BooleanisUploadPostTransformSuccess()final BooleanisUploadPostTransformError()final BooleanisFileCreate()final BooleanisFileUpdate()final BooleanisFileDelete()final BooleanisFileVersionCreate()final BooleanisFileVersionDelete()final VideoTransformationAcceptedEventasVideoTransformationAccepted()Triggered when a new video transformation request is accepted for processing. final VideoTransformationReadyEventasVideoTransformationReady()Triggered when video encoding is finished and the transformed resource is ready to be served. final VideoTransformationErrorEventasVideoTransformationError()Triggered when an error occurs during video encoding. final UploadPreTransformSuccessEventasUploadPreTransformSuccess()Triggered when a pre-transformation completes successfully. final UploadPreTransformErrorEventasUploadPreTransformError()Triggered when a pre-transformation fails. final UploadPostTransformSuccessEventasUploadPostTransformSuccess()Triggered when a post-transformation completes successfully. final UploadPostTransformErrorEventasUploadPostTransformError()Triggered when a post-transformation fails. final FileCreateEventasFileCreate()Triggered when a file is created. final FileUpdateEventasFileUpdate()Triggered when a file is updated. final FileDeleteEventasFileDelete()Triggered when a file is deleted. final FileVersionCreateEventasFileVersionCreate()Triggered when a file version is created. final FileVersionDeleteEventasFileVersionDelete()Triggered when a file version is deleted. final Optional<JsonValue>_json()final <T extends Any> Taccept(UnwrapWebhookEvent.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final UnwrapWebhookEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UnwrapWebhookEventofVideoTransformationAccepted(VideoTransformationAcceptedEvent videoTransformationAccepted)Triggered when a new video transformation request is accepted for processing. final static UnwrapWebhookEventofVideoTransformationReady(VideoTransformationReadyEvent videoTransformationReady)Triggered when video encoding is finished and the transformed resource is ready to be served. final static UnwrapWebhookEventofVideoTransformationError(VideoTransformationErrorEvent videoTransformationError)Triggered when an error occurs during video encoding. final static UnwrapWebhookEventofUploadPreTransformSuccess(UploadPreTransformSuccessEvent uploadPreTransformSuccess)Triggered when a pre-transformation completes successfully. final static UnwrapWebhookEventofUploadPreTransformError(UploadPreTransformErrorEvent uploadPreTransformError)Triggered when a pre-transformation fails. final static UnwrapWebhookEventofUploadPostTransformSuccess(UploadPostTransformSuccessEvent uploadPostTransformSuccess)Triggered when a post-transformation completes successfully. final static UnwrapWebhookEventofUploadPostTransformError(UploadPostTransformErrorEvent uploadPostTransformError)Triggered when a post-transformation fails. final static UnwrapWebhookEventofFileCreate(FileCreateEvent fileCreate)Triggered when a file is created. final static UnwrapWebhookEventofFileUpdate(FileUpdateEvent fileUpdate)Triggered when a file is updated. final static UnwrapWebhookEventofFileDelete(FileDeleteEvent fileDelete)Triggered when a file is deleted. final static UnwrapWebhookEventofFileVersionCreate(FileVersionCreateEvent fileVersionCreate)Triggered when a file version is created. final static UnwrapWebhookEventofFileVersionDelete(FileVersionDeleteEvent fileVersionDelete)Triggered when a file version is deleted. -
-
Method Detail
-
videoTransformationAccepted
final Optional<VideoTransformationAcceptedEvent> videoTransformationAccepted()
Triggered when a new video transformation request is accepted for processing. This event confirms that ImageKit has received and queued your transformation request. Use this for debugging and tracking transformation lifecycle.
-
videoTransformationReady
final Optional<VideoTransformationReadyEvent> videoTransformationReady()
Triggered when video encoding is finished and the transformed resource is ready to be served. This is the key event to listen for - update your database or CMS flags when you receive this so your application can start showing the transformed video to users.
-
videoTransformationError
final Optional<VideoTransformationErrorEvent> videoTransformationError()
Triggered when an error occurs during video encoding. Listen to this webhook to log error reasons and debug issues. Check your origin and URL endpoint settings if the reason is related to download failure. For other errors, contact ImageKit support.
-
uploadPreTransformSuccess
final Optional<UploadPreTransformSuccessEvent> uploadPreTransformSuccess()
Triggered when a pre-transformation completes successfully. The file has been processed with the requested transformation and is now available in the Media Library.
-
uploadPreTransformError
final Optional<UploadPreTransformErrorEvent> uploadPreTransformError()
Triggered when a pre-transformation fails. The file upload may have been accepted, but the requested transformation could not be applied.
-
uploadPostTransformSuccess
final Optional<UploadPostTransformSuccessEvent> uploadPostTransformSuccess()
Triggered when a post-transformation completes successfully. The transformed version of the file is now ready and can be accessed via the provided URL. Note that each post-transformation generates a separate webhook event.
-
uploadPostTransformError
final Optional<UploadPostTransformErrorEvent> uploadPostTransformError()
Triggered when a post-transformation fails. The original file remains available, but the requested transformation could not be generated.
-
fileCreate
final Optional<FileCreateEvent> fileCreate()
Triggered when a file is created.
-
fileUpdate
final Optional<FileUpdateEvent> fileUpdate()
Triggered when a file is updated.
-
fileDelete
final Optional<FileDeleteEvent> fileDelete()
Triggered when a file is deleted.
-
fileVersionCreate
final Optional<FileVersionCreateEvent> fileVersionCreate()
Triggered when a file version is created.
-
fileVersionDelete
final Optional<FileVersionDeleteEvent> fileVersionDelete()
Triggered when a file version is deleted.
-
isVideoTransformationAccepted
final Boolean isVideoTransformationAccepted()
-
isVideoTransformationReady
final Boolean isVideoTransformationReady()
-
isVideoTransformationError
final Boolean isVideoTransformationError()
-
isUploadPreTransformSuccess
final Boolean isUploadPreTransformSuccess()
-
isUploadPreTransformError
final Boolean isUploadPreTransformError()
-
isUploadPostTransformSuccess
final Boolean isUploadPostTransformSuccess()
-
isUploadPostTransformError
final Boolean isUploadPostTransformError()
-
isFileCreate
final Boolean isFileCreate()
-
isFileUpdate
final Boolean isFileUpdate()
-
isFileDelete
final Boolean isFileDelete()
-
isFileVersionCreate
final Boolean isFileVersionCreate()
-
isFileVersionDelete
final Boolean isFileVersionDelete()
-
asVideoTransformationAccepted
final VideoTransformationAcceptedEvent asVideoTransformationAccepted()
Triggered when a new video transformation request is accepted for processing. This event confirms that ImageKit has received and queued your transformation request. Use this for debugging and tracking transformation lifecycle.
-
asVideoTransformationReady
final VideoTransformationReadyEvent asVideoTransformationReady()
Triggered when video encoding is finished and the transformed resource is ready to be served. This is the key event to listen for - update your database or CMS flags when you receive this so your application can start showing the transformed video to users.
-
asVideoTransformationError
final VideoTransformationErrorEvent asVideoTransformationError()
Triggered when an error occurs during video encoding. Listen to this webhook to log error reasons and debug issues. Check your origin and URL endpoint settings if the reason is related to download failure. For other errors, contact ImageKit support.
-
asUploadPreTransformSuccess
final UploadPreTransformSuccessEvent asUploadPreTransformSuccess()
Triggered when a pre-transformation completes successfully. The file has been processed with the requested transformation and is now available in the Media Library.
-
asUploadPreTransformError
final UploadPreTransformErrorEvent asUploadPreTransformError()
Triggered when a pre-transformation fails. The file upload may have been accepted, but the requested transformation could not be applied.
-
asUploadPostTransformSuccess
final UploadPostTransformSuccessEvent asUploadPostTransformSuccess()
Triggered when a post-transformation completes successfully. The transformed version of the file is now ready and can be accessed via the provided URL. Note that each post-transformation generates a separate webhook event.
-
asUploadPostTransformError
final UploadPostTransformErrorEvent asUploadPostTransformError()
Triggered when a post-transformation fails. The original file remains available, but the requested transformation could not be generated.
-
asFileCreate
final FileCreateEvent asFileCreate()
Triggered when a file is created.
-
asFileUpdate
final FileUpdateEvent asFileUpdate()
Triggered when a file is updated.
-
asFileDelete
final FileDeleteEvent asFileDelete()
Triggered when a file is deleted.
-
asFileVersionCreate
final FileVersionCreateEvent asFileVersionCreate()
Triggered when a file version is created.
-
asFileVersionDelete
final FileVersionDeleteEvent asFileVersionDelete()
Triggered when a file version is deleted.
-
accept
final <T extends Any> T accept(UnwrapWebhookEvent.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import io.imagekit.core.JsonValue; import java.util.Optional; Optional<String> result = unwrapWebhookEvent.accept(new UnwrapWebhookEvent.Visitor<Optional<String>>() { @Override public Optional<String> visitVideoTransformationAccepted(VideoTransformationAcceptedEvent videoTransformationAccepted) { return Optional.of(videoTransformationAccepted.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final UnwrapWebhookEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofVideoTransformationAccepted
final static UnwrapWebhookEvent ofVideoTransformationAccepted(VideoTransformationAcceptedEvent videoTransformationAccepted)
Triggered when a new video transformation request is accepted for processing. This event confirms that ImageKit has received and queued your transformation request. Use this for debugging and tracking transformation lifecycle.
-
ofVideoTransformationReady
final static UnwrapWebhookEvent ofVideoTransformationReady(VideoTransformationReadyEvent videoTransformationReady)
Triggered when video encoding is finished and the transformed resource is ready to be served. This is the key event to listen for - update your database or CMS flags when you receive this so your application can start showing the transformed video to users.
-
ofVideoTransformationError
final static UnwrapWebhookEvent ofVideoTransformationError(VideoTransformationErrorEvent videoTransformationError)
Triggered when an error occurs during video encoding. Listen to this webhook to log error reasons and debug issues. Check your origin and URL endpoint settings if the reason is related to download failure. For other errors, contact ImageKit support.
-
ofUploadPreTransformSuccess
final static UnwrapWebhookEvent ofUploadPreTransformSuccess(UploadPreTransformSuccessEvent uploadPreTransformSuccess)
Triggered when a pre-transformation completes successfully. The file has been processed with the requested transformation and is now available in the Media Library.
-
ofUploadPreTransformError
final static UnwrapWebhookEvent ofUploadPreTransformError(UploadPreTransformErrorEvent uploadPreTransformError)
Triggered when a pre-transformation fails. The file upload may have been accepted, but the requested transformation could not be applied.
-
ofUploadPostTransformSuccess
final static UnwrapWebhookEvent ofUploadPostTransformSuccess(UploadPostTransformSuccessEvent uploadPostTransformSuccess)
Triggered when a post-transformation completes successfully. The transformed version of the file is now ready and can be accessed via the provided URL. Note that each post-transformation generates a separate webhook event.
-
ofUploadPostTransformError
final static UnwrapWebhookEvent ofUploadPostTransformError(UploadPostTransformErrorEvent uploadPostTransformError)
Triggered when a post-transformation fails. The original file remains available, but the requested transformation could not be generated.
-
ofFileCreate
final static UnwrapWebhookEvent ofFileCreate(FileCreateEvent fileCreate)
Triggered when a file is created.
-
ofFileUpdate
final static UnwrapWebhookEvent ofFileUpdate(FileUpdateEvent fileUpdate)
Triggered when a file is updated.
-
ofFileDelete
final static UnwrapWebhookEvent ofFileDelete(FileDeleteEvent fileDelete)
Triggered when a file is deleted.
-
ofFileVersionCreate
final static UnwrapWebhookEvent ofFileVersionCreate(FileVersionCreateEvent fileVersionCreate)
Triggered when a file version is created.
-
ofFileVersionDelete
final static UnwrapWebhookEvent ofFileVersionDelete(FileVersionDeleteEvent fileVersionDelete)
Triggered when a file version is deleted.
-
-
-
-