Class UploadPostTransformErrorEvent
-
- All Implemented Interfaces:
public final class UploadPostTransformErrorEventTriggered when a post-transformation fails. The original file remains available, but the requested transformation could not be generated.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformErrorEvent.BuilderA builder for UploadPostTransformErrorEvent.
public final classUploadPostTransformErrorEvent.Datapublic final classUploadPostTransformErrorEvent.Request
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp of when the event occurred in ISO8601 format. final UploadPostTransformErrorEvent.Datadata()final UploadPostTransformErrorEvent.Requestrequest()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<UploadPostTransformErrorEvent.Data>_data()Returns the raw JSON value of data. final JsonField<UploadPostTransformErrorEvent.Request>_request()Returns the raw JSON value of request. final Map<String, JsonValue>_additionalProperties()final UploadPostTransformErrorEvent.BuildertoBuilder()final UploadPostTransformErrorEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPostTransformErrorEvent.Builderbuilder()Returns a mutable builder for constructing an instance of UploadPostTransformErrorEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp of when the event occurred in ISO8601 format.
-
data
final UploadPostTransformErrorEvent.Data data()
-
request
final UploadPostTransformErrorEvent.Request request()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<UploadPostTransformErrorEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_request
final JsonField<UploadPostTransformErrorEvent.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformErrorEvent.Builder toBuilder()
-
validate
final UploadPostTransformErrorEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPostTransformErrorEvent.Builder builder()
Returns a mutable builder for constructing an instance of UploadPostTransformErrorEvent.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-