Class UploadPostTransformErrorEvent.Builder
-
- All Implemented Interfaces:
public final class UploadPostTransformErrorEvent.BuilderA builder for UploadPostTransformErrorEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final UploadPostTransformErrorEvent.Builder id(String id)
Unique identifier for the event.
-
id
final UploadPostTransformErrorEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final UploadPostTransformErrorEvent.Builder type(String type)
The type of webhook event.
-
type
final UploadPostTransformErrorEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final UploadPostTransformErrorEvent.Builder createdAt(OffsetDateTime createdAt)
Timestamp of when the event occurred in ISO8601 format.
-
createdAt
final UploadPostTransformErrorEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final UploadPostTransformErrorEvent.Builder data(UploadPostTransformErrorEvent.Data data)
-
data
final UploadPostTransformErrorEvent.Builder data(JsonField<UploadPostTransformErrorEvent.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
request
final UploadPostTransformErrorEvent.Builder request(UploadPostTransformErrorEvent.Request request)
-
request
final UploadPostTransformErrorEvent.Builder request(JsonField<UploadPostTransformErrorEvent.Request> request)
Sets Builder.request to an arbitrary JSON value.
You should usually call Builder.request with a well-typed Request value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPostTransformErrorEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPostTransformErrorEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPostTransformErrorEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPostTransformErrorEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPostTransformErrorEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPostTransformErrorEvent build()
Returns an immutable instance of UploadPostTransformErrorEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-