Class UploadPostTransformErrorEvent.Data
-
- All Implemented Interfaces:
public final class UploadPostTransformErrorEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformErrorEvent.Data.BuilderA builder for Data.
public final classUploadPostTransformErrorEvent.Data.Transformation
-
Method Summary
Modifier and Type Method Description final StringfileId()Unique identifier of the originally uploaded file. final Stringname()Name of the file. final Stringpath()Path of the file. final UploadPostTransformErrorEvent.Data.Transformationtransformation()final Stringurl()URL of the attempted post-transformation. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<UploadPostTransformErrorEvent.Data.Transformation>_transformation()Returns the raw JSON value of transformation. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final UploadPostTransformErrorEvent.Data.BuildertoBuilder()final UploadPostTransformErrorEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPostTransformErrorEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
transformation
final UploadPostTransformErrorEvent.Data.Transformation transformation()
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_transformation
final JsonField<UploadPostTransformErrorEvent.Data.Transformation> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformErrorEvent.Data.Builder toBuilder()
-
validate
final UploadPostTransformErrorEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPostTransformErrorEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.fileId() .name() .path() .transformation() .url()
-
-
-
-