Class UploadPostTransformErrorEvent.Data.Builder
-
- All Implemented Interfaces:
public final class UploadPostTransformErrorEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
fileId
final UploadPostTransformErrorEvent.Data.Builder fileId(String fileId)
Unique identifier of the originally uploaded file.
-
fileId
final UploadPostTransformErrorEvent.Data.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final UploadPostTransformErrorEvent.Data.Builder name(String name)
Name of the file.
-
name
final UploadPostTransformErrorEvent.Data.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
path
final UploadPostTransformErrorEvent.Data.Builder path(String path)
Path of the file.
-
path
final UploadPostTransformErrorEvent.Data.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transformation
final UploadPostTransformErrorEvent.Data.Builder transformation(UploadPostTransformErrorEvent.Data.Transformation transformation)
-
transformation
final UploadPostTransformErrorEvent.Data.Builder transformation(JsonField<UploadPostTransformErrorEvent.Data.Transformation> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed Transformation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final UploadPostTransformErrorEvent.Data.Builder url(String url)
URL of the attempted post-transformation.
-
url
final UploadPostTransformErrorEvent.Data.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPostTransformErrorEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPostTransformErrorEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPostTransformErrorEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPostTransformErrorEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPostTransformErrorEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPostTransformErrorEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.fileId() .name() .path() .transformation() .url()
-
-
-
-