Package io.imagekit.models.webhooks
Class UploadPostTransformErrorEvent.Data.Transformation
-
- All Implemented Interfaces:
public final class UploadPostTransformErrorEvent.Data.Transformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformErrorEvent.Data.Transformation.BuilderA builder for Transformation.
public final classUploadPostTransformErrorEvent.Data.Transformation.Error
-
Method Summary
Modifier and Type Method Description final UploadPostTransformErrorEvent.Data.Transformation.Errorerror()final JsonField<UploadPostTransformErrorEvent.Data.Transformation.Error>_error()Returns the raw JSON value of error. final Map<String, JsonValue>_additionalProperties()final UploadPostTransformErrorEvent.Data.Transformation.BuildertoBuilder()final UploadPostTransformErrorEvent.Data.Transformationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPostTransformErrorEvent.Data.Transformation.Builderbuilder()Returns a mutable builder for constructing an instance of Transformation. -
-
Method Detail
-
error
final UploadPostTransformErrorEvent.Data.Transformation.Error error()
-
_error
final JsonField<UploadPostTransformErrorEvent.Data.Transformation.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformErrorEvent.Data.Transformation.Builder toBuilder()
-
validate
final UploadPostTransformErrorEvent.Data.Transformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPostTransformErrorEvent.Data.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.error()
-
-
-
-