Package io.imagekit.models.webhooks
Class UploadPostTransformErrorEvent.Request.Transformation
-
- All Implemented Interfaces:
public final class UploadPostTransformErrorEvent.Request.Transformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformErrorEvent.Request.Transformation.BuilderA builder for Transformation.
public final classUploadPostTransformErrorEvent.Request.Transformation.TypeType of the requested post-transformation.
public final classUploadPostTransformErrorEvent.Request.Transformation.ProtocolOnly applicable if transformation type is 'abs'. Streaming protocol used.
-
Method Summary
-
-
Method Detail
-
type
final UploadPostTransformErrorEvent.Request.Transformation.Type type()
Type of the requested post-transformation.
-
protocol
final Optional<UploadPostTransformErrorEvent.Request.Transformation.Protocol> protocol()
Only applicable if transformation type is 'abs'. Streaming protocol used.
-
_type
final JsonField<UploadPostTransformErrorEvent.Request.Transformation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_protocol
final JsonField<UploadPostTransformErrorEvent.Request.Transformation.Protocol> _protocol()
Returns the raw JSON value of protocol.
Unlike protocol, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformErrorEvent.Request.Transformation.Builder toBuilder()
-
validate
final UploadPostTransformErrorEvent.Request.Transformation validate()
-
builder
final static UploadPostTransformErrorEvent.Request.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.type()
-
-
-
-