Class UploadPostTransformSuccessEvent

  • All Implemented Interfaces:

    
    public final class UploadPostTransformSuccessEvent
    
                        

    Triggered when a post-transformation completes successfully. The transformed version of the file is now ready and can be accessed via the provided URL. Note that each post-transformation generates a separate webhook event.