Class UploadPostTransformSuccessEvent.Builder
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEvent.BuilderA builder for UploadPostTransformSuccessEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final UploadPostTransformSuccessEvent.Builder id(String id)
Unique identifier for the event.
-
id
final UploadPostTransformSuccessEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final UploadPostTransformSuccessEvent.Builder type(String type)
The type of webhook event.
-
type
final UploadPostTransformSuccessEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final UploadPostTransformSuccessEvent.Builder createdAt(OffsetDateTime createdAt)
Timestamp of when the event occurred in ISO8601 format.
-
createdAt
final UploadPostTransformSuccessEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final UploadPostTransformSuccessEvent.Builder data(JsonField<UploadPostTransformSuccessEvent.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
request
final UploadPostTransformSuccessEvent.Builder request(UploadPostTransformSuccessEvent.Request request)
-
request
final UploadPostTransformSuccessEvent.Builder request(JsonField<UploadPostTransformSuccessEvent.Request> request)
Sets Builder.request to an arbitrary JSON value.
You should usually call Builder.request with a well-typed Request value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPostTransformSuccessEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPostTransformSuccessEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPostTransformSuccessEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPostTransformSuccessEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPostTransformSuccessEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPostTransformSuccessEvent build()
Returns an immutable instance of UploadPostTransformSuccessEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-