Class UploadPostTransformSuccessEvent.Data.Builder
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
fileId
final UploadPostTransformSuccessEvent.Data.Builder fileId(String fileId)
Unique identifier of the originally uploaded file.
-
fileId
final UploadPostTransformSuccessEvent.Data.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final UploadPostTransformSuccessEvent.Data.Builder name(String name)
Name of the file.
-
name
final UploadPostTransformSuccessEvent.Data.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final UploadPostTransformSuccessEvent.Data.Builder url(String url)
URL of the generated post-transformation.
-
url
final UploadPostTransformSuccessEvent.Data.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPostTransformSuccessEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPostTransformSuccessEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPostTransformSuccessEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPostTransformSuccessEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPostTransformSuccessEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPostTransformSuccessEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.fileId() .name() .url()
-
-
-
-