Package io.imagekit.models.webhooks
Class UploadPostTransformSuccessEvent.Request
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEvent.Request
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformSuccessEvent.Request.BuilderA builder for Request.
public final classUploadPostTransformSuccessEvent.Request.Transformation
-
Method Summary
Modifier and Type Method Description final UploadPostTransformSuccessEvent.Request.Transformationtransformation()final StringxRequestId()Unique identifier for the originating request. final JsonField<UploadPostTransformSuccessEvent.Request.Transformation>_transformation()Returns the raw JSON value of transformation. final JsonField<String>_xRequestId()Returns the raw JSON value of xRequestId. final Map<String, JsonValue>_additionalProperties()final UploadPostTransformSuccessEvent.Request.BuildertoBuilder()final UploadPostTransformSuccessEvent.Requestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPostTransformSuccessEvent.Request.Builderbuilder()Returns a mutable builder for constructing an instance of Request. -
-
Method Detail
-
transformation
final UploadPostTransformSuccessEvent.Request.Transformation transformation()
-
xRequestId
final String xRequestId()
Unique identifier for the originating request.
-
_transformation
final JsonField<UploadPostTransformSuccessEvent.Request.Transformation> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_xRequestId
final JsonField<String> _xRequestId()
Returns the raw JSON value of xRequestId.
Unlike xRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformSuccessEvent.Request.Builder toBuilder()
-
validate
final UploadPostTransformSuccessEvent.Request validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPostTransformSuccessEvent.Request.Builder builder()
Returns a mutable builder for constructing an instance of Request.
The following fields are required:
.transformation() .xRequestId()
-
-
-
-