Class UploadPostTransformSuccessEvent.Request.Transformation
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEvent.Request.Transformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformSuccessEvent.Request.Transformation.BuilderA builder for Transformation.
public final classUploadPostTransformSuccessEvent.Request.Transformation.TypeType of the requested post-transformation.
public final classUploadPostTransformSuccessEvent.Request.Transformation.ProtocolOnly applicable if transformation type is 'abs'. Streaming protocol used.
-
Method Summary
-
-
Method Detail
-
type
final UploadPostTransformSuccessEvent.Request.Transformation.Type type()
Type of the requested post-transformation.
-
protocol
final Optional<UploadPostTransformSuccessEvent.Request.Transformation.Protocol> protocol()
Only applicable if transformation type is 'abs'. Streaming protocol used.
-
_type
final JsonField<UploadPostTransformSuccessEvent.Request.Transformation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_protocol
final JsonField<UploadPostTransformSuccessEvent.Request.Transformation.Protocol> _protocol()
Returns the raw JSON value of protocol.
Unlike protocol, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<String> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformSuccessEvent.Request.Transformation.Builder toBuilder()
-
validate
final UploadPostTransformSuccessEvent.Request.Transformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPostTransformSuccessEvent.Request.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.type()
-
-
-
-