Class UploadPostTransformSuccessEvent.Request.Transformation.Builder
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEvent.Request.Transformation.BuilderA builder for Transformation.
-
-
Method Summary
-
-
Method Detail
-
type
final UploadPostTransformSuccessEvent.Request.Transformation.Builder type(UploadPostTransformSuccessEvent.Request.Transformation.Type type)
Type of the requested post-transformation.
-
type
final UploadPostTransformSuccessEvent.Request.Transformation.Builder type(JsonField<UploadPostTransformSuccessEvent.Request.Transformation.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
protocol
final UploadPostTransformSuccessEvent.Request.Transformation.Builder protocol(UploadPostTransformSuccessEvent.Request.Transformation.Protocol protocol)
Only applicable if transformation type is 'abs'. Streaming protocol used.
-
protocol
final UploadPostTransformSuccessEvent.Request.Transformation.Builder protocol(JsonField<UploadPostTransformSuccessEvent.Request.Transformation.Protocol> protocol)
Sets Builder.protocol to an arbitrary JSON value.
You should usually call Builder.protocol with a well-typed Protocol value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
value
final UploadPostTransformSuccessEvent.Request.Transformation.Builder value(String value)
Value for the requested transformation type.
-
value
final UploadPostTransformSuccessEvent.Request.Transformation.Builder value(JsonField<String> value)
Sets Builder.value to an arbitrary JSON value.
You should usually call Builder.value with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPostTransformSuccessEvent.Request.Transformation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPostTransformSuccessEvent.Request.Transformation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPostTransformSuccessEvent.Request.Transformation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPostTransformSuccessEvent.Request.Transformation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPostTransformSuccessEvent.Request.Transformation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPostTransformSuccessEvent.Request.Transformation build()
Returns an immutable instance of Transformation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-