Class UploadPreTransformErrorEvent.Builder
-
- All Implemented Interfaces:
public final class UploadPreTransformErrorEvent.BuilderA builder for UploadPreTransformErrorEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final UploadPreTransformErrorEvent.Builder id(String id)
Unique identifier for the event.
-
id
final UploadPreTransformErrorEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final UploadPreTransformErrorEvent.Builder type(String type)
The type of webhook event.
-
type
final UploadPreTransformErrorEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final UploadPreTransformErrorEvent.Builder createdAt(OffsetDateTime createdAt)
Timestamp of when the event occurred in ISO8601 format.
-
createdAt
final UploadPreTransformErrorEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final UploadPreTransformErrorEvent.Builder data(UploadPreTransformErrorEvent.Data data)
-
data
final UploadPreTransformErrorEvent.Builder data(JsonField<UploadPreTransformErrorEvent.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
request
final UploadPreTransformErrorEvent.Builder request(UploadPreTransformErrorEvent.Request request)
-
request
final UploadPreTransformErrorEvent.Builder request(JsonField<UploadPreTransformErrorEvent.Request> request)
Sets Builder.request to an arbitrary JSON value.
You should usually call Builder.request with a well-typed Request value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPreTransformErrorEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPreTransformErrorEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPreTransformErrorEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPreTransformErrorEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPreTransformErrorEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPreTransformErrorEvent build()
Returns an immutable instance of UploadPreTransformErrorEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-