Class UploadPreTransformErrorEvent.Data.Builder
-
- All Implemented Interfaces:
public final class UploadPreTransformErrorEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
name
final UploadPreTransformErrorEvent.Data.Builder name(String name)
Name of the file.
-
name
final UploadPreTransformErrorEvent.Data.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
path
final UploadPreTransformErrorEvent.Data.Builder path(String path)
Path of the file.
-
path
final UploadPreTransformErrorEvent.Data.Builder path(JsonField<String> path)
Sets Builder.path to an arbitrary JSON value.
You should usually call Builder.path with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transformation
final UploadPreTransformErrorEvent.Data.Builder transformation(UploadPreTransformErrorEvent.Data.Transformation transformation)
-
transformation
final UploadPreTransformErrorEvent.Data.Builder transformation(JsonField<UploadPreTransformErrorEvent.Data.Transformation> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed Transformation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPreTransformErrorEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPreTransformErrorEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPreTransformErrorEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPreTransformErrorEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPreTransformErrorEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPreTransformErrorEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.name() .path() .transformation()
-
-
-
-