Package io.imagekit.models.webhooks
Class UploadPreTransformErrorEvent.Data.Transformation.Error
-
- All Implemented Interfaces:
public final class UploadPreTransformErrorEvent.Data.Transformation.Error
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPreTransformErrorEvent.Data.Transformation.Error.BuilderA builder for Error.
-
Method Summary
Modifier and Type Method Description final Stringreason()Reason for the pre-transformation failure. final JsonField<String>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final UploadPreTransformErrorEvent.Data.Transformation.Error.BuildertoBuilder()final UploadPreTransformErrorEvent.Data.Transformation.Errorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPreTransformErrorEvent.Data.Transformation.Error.Builderbuilder()Returns a mutable builder for constructing an instance of Error. -
-
Method Detail
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPreTransformErrorEvent.Data.Transformation.Error.Builder toBuilder()
-
validate
final UploadPreTransformErrorEvent.Data.Transformation.Error validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPreTransformErrorEvent.Data.Transformation.Error.Builder builder()
Returns a mutable builder for constructing an instance of Error.
The following fields are required:
.reason()
-
-
-
-