Package io.imagekit.models.webhooks
Class UploadPreTransformErrorEvent.Request.Builder
-
- All Implemented Interfaces:
public final class UploadPreTransformErrorEvent.Request.BuilderA builder for Request.
-
-
Method Summary
-
-
Method Detail
-
transformation
final UploadPreTransformErrorEvent.Request.Builder transformation(String transformation)
The requested pre-transformation string.
-
transformation
final UploadPreTransformErrorEvent.Request.Builder transformation(JsonField<String> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
xRequestId
final UploadPreTransformErrorEvent.Request.Builder xRequestId(String xRequestId)
Unique identifier for the originating request.
-
xRequestId
final UploadPreTransformErrorEvent.Request.Builder xRequestId(JsonField<String> xRequestId)
Sets Builder.xRequestId to an arbitrary JSON value.
You should usually call Builder.xRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPreTransformErrorEvent.Request.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPreTransformErrorEvent.Request.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPreTransformErrorEvent.Request.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPreTransformErrorEvent.Request.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPreTransformErrorEvent.Request.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPreTransformErrorEvent.Request build()
Returns an immutable instance of Request.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.transformation() .xRequestId()
-
-
-
-