Class UploadPreTransformSuccessEvent
-
- All Implemented Interfaces:
public final class UploadPreTransformSuccessEventTriggered when a pre-transformation completes successfully. The file has been processed with the requested transformation and is now available in the Media Library.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPreTransformSuccessEvent.BuilderA builder for UploadPreTransformSuccessEvent.
public final classUploadPreTransformSuccessEvent.DataObject containing details of a successful upload.
public final classUploadPreTransformSuccessEvent.Request
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp of when the event occurred in ISO8601 format. final UploadPreTransformSuccessEvent.Datadata()Object containing details of a successful upload. final UploadPreTransformSuccessEvent.Requestrequest()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<UploadPreTransformSuccessEvent.Data>_data()Returns the raw JSON value of data. final JsonField<UploadPreTransformSuccessEvent.Request>_request()Returns the raw JSON value of request. final Map<String, JsonValue>_additionalProperties()final UploadPreTransformSuccessEvent.BuildertoBuilder()final UploadPreTransformSuccessEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPreTransformSuccessEvent.Builderbuilder()Returns a mutable builder for constructing an instance of UploadPreTransformSuccessEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp of when the event occurred in ISO8601 format.
-
data
final UploadPreTransformSuccessEvent.Data data()
Object containing details of a successful upload.
-
request
final UploadPreTransformSuccessEvent.Request request()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<UploadPreTransformSuccessEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_request
final JsonField<UploadPreTransformSuccessEvent.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPreTransformSuccessEvent.Builder toBuilder()
-
validate
final UploadPreTransformSuccessEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPreTransformSuccessEvent.Builder builder()
Returns a mutable builder for constructing an instance of UploadPreTransformSuccessEvent.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-