Class UploadPreTransformSuccessEvent.Builder
-
- All Implemented Interfaces:
public final class UploadPreTransformSuccessEvent.BuilderA builder for UploadPreTransformSuccessEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final UploadPreTransformSuccessEvent.Builder id(String id)
Unique identifier for the event.
-
id
final UploadPreTransformSuccessEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final UploadPreTransformSuccessEvent.Builder type(String type)
The type of webhook event.
-
type
final UploadPreTransformSuccessEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final UploadPreTransformSuccessEvent.Builder createdAt(OffsetDateTime createdAt)
Timestamp of when the event occurred in ISO8601 format.
-
createdAt
final UploadPreTransformSuccessEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final UploadPreTransformSuccessEvent.Builder data(UploadPreTransformSuccessEvent.Data data)
Object containing details of a successful upload.
-
data
final UploadPreTransformSuccessEvent.Builder data(JsonField<UploadPreTransformSuccessEvent.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
request
final UploadPreTransformSuccessEvent.Builder request(UploadPreTransformSuccessEvent.Request request)
-
request
final UploadPreTransformSuccessEvent.Builder request(JsonField<UploadPreTransformSuccessEvent.Request> request)
Sets Builder.request to an arbitrary JSON value.
You should usually call Builder.request with a well-typed Request value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPreTransformSuccessEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPreTransformSuccessEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPreTransformSuccessEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPreTransformSuccessEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPreTransformSuccessEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPreTransformSuccessEvent build()
Returns an immutable instance of UploadPreTransformSuccessEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-