Class UploadPreTransformSuccessEvent.Data
-
- All Implemented Interfaces:
public final class UploadPreTransformSuccessEvent.DataObject containing details of a successful upload.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPreTransformSuccessEvent.Data.BuilderA builder for Data.
public final classUploadPreTransformSuccessEvent.Data.ExtensionStatusExtension names with their processing status at the time of completion of the request. It could have one of the following status values:
success: The extension has been successfully applied.failed: The extension has failed and will not be retried.pending: The extension will finish processing in some time. On completion, the final status (success / failed) will be sent to thewebhookUrlprovided.If no extension was requested, then this parameter is not returned.
-
Method Summary
Modifier and Type Method Description final Optional<List<AiTag>>aiTags()An array of tags assigned to the uploaded file by auto tagging. final Optional<String>audioCodec()The audio codec used in the video (only for video). final Optional<Long>bitRate()The bit rate of the video in kbps (only for video). final Optional<String>customCoordinates()Value of custom coordinates associated with the image in the format x,y,width,height.final Optional<CustomMetadata>customMetadata()A key-value data associated with the asset. final Optional<String>description()Optional text to describe the contents of the file. final Optional<Long>duration()The duration of the video in seconds (only for video). final Optional<EmbeddedMetadata>embeddedMetadata()Consolidated embedded metadata associated with the file. final Optional<UploadPreTransformSuccessEvent.Data.ExtensionStatus>extensionStatus()Extension names with their processing status at the time of completion of the request. final Optional<String>fileId()Unique fileId. final Optional<String>filePath()The relative path of the file in the media library e.g. final Optional<String>fileType()Type of the uploaded file. final Optional<Double>height()Height of the image in pixels (Only for images) final Optional<Boolean>isPrivateFile()Is the file marked as private. final Optional<Boolean>isPublished()Is the file published or in draft state. final Optional<Metadata>metadata()Legacy metadata. final Optional<String>name()Name of the asset. final Optional<SelectedFieldsSchema>selectedFieldsSchema()This field is included in the response only if the Path policy feature is available in the plan. final Optional<Double>size()Size of the image file in Bytes. final Optional<List<String>>tags()The array of tags associated with the asset. final Optional<String>thumbnailUrl()In the case of an image, a small thumbnail URL. final Optional<String>url()A publicly accessible URL of the file. final Optional<VersionInfo>versionInfo()An object containing the file or file version's id(versionId) andname.final Optional<String>videoCodec()The video codec used in the video (only for video). final Optional<Double>width()Width of the image in pixels (Only for Images) final JsonField<List<AiTag>>_aiTags()Returns the raw JSON value of aiTags. final JsonField<String>_audioCodec()Returns the raw JSON value of audioCodec. final JsonField<Long>_bitRate()Returns the raw JSON value of bitRate. final JsonField<String>_customCoordinates()Returns the raw JSON value of customCoordinates. final JsonField<CustomMetadata>_customMetadata()Returns the raw JSON value of customMetadata. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<Long>_duration()Returns the raw JSON value of duration. final JsonField<EmbeddedMetadata>_embeddedMetadata()Returns the raw JSON value of embeddedMetadata. final JsonField<UploadPreTransformSuccessEvent.Data.ExtensionStatus>_extensionStatus()Returns the raw JSON value of extensionStatus. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_filePath()Returns the raw JSON value of filePath. final JsonField<String>_fileType()Returns the raw JSON value of fileType. final JsonField<Double>_height()Returns the raw JSON value of height. final JsonField<Boolean>_isPrivateFile()Returns the raw JSON value of isPrivateFile. final JsonField<Boolean>_isPublished()Returns the raw JSON value of isPublished. final JsonField<Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<SelectedFieldsSchema>_selectedFieldsSchema()Returns the raw JSON value of selectedFieldsSchema. final JsonField<Double>_size()Returns the raw JSON value of size. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<String>_thumbnailUrl()Returns the raw JSON value of thumbnailUrl. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<VersionInfo>_versionInfo()Returns the raw JSON value of versionInfo. final JsonField<String>_videoCodec()Returns the raw JSON value of videoCodec. final JsonField<Double>_width()Returns the raw JSON value of width. final Map<String, JsonValue>_additionalProperties()final UploadPreTransformSuccessEvent.Data.BuildertoBuilder()final UploadPreTransformSuccessEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPreTransformSuccessEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
aiTags
final Optional<List<AiTag>> aiTags()
An array of tags assigned to the uploaded file by auto tagging.
-
audioCodec
final Optional<String> audioCodec()
The audio codec used in the video (only for video).
-
customCoordinates
final Optional<String> customCoordinates()
Value of custom coordinates associated with the image in the format
x,y,width,height. IfcustomCoordinatesare not defined, then it isnull. SendcustomCoordinatesinresponseFieldsin API request to get the value of this field.
-
customMetadata
final Optional<CustomMetadata> customMetadata()
A key-value data associated with the asset. Use
responseFieldin API request to getcustomMetadatain the upload API response. Before setting any custom metadata on an asset, you have to create the field using custom metadata fields API. SendcustomMetadatainresponseFieldsin API request to get the value of this field.
-
description
final Optional<String> description()
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
-
embeddedMetadata
final Optional<EmbeddedMetadata> embeddedMetadata()
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data. Send
embeddedMetadatainresponseFieldsin API request to get embeddedMetadata in the upload API response.
-
extensionStatus
final Optional<UploadPreTransformSuccessEvent.Data.ExtensionStatus> extensionStatus()
Extension names with their processing status at the time of completion of the request. It could have one of the following status values:
success: The extension has been successfully applied.failed: The extension has failed and will not be retried.pending: The extension will finish processing in some time. On completion, the final status (success / failed) will be sent to thewebhookUrlprovided.If no extension was requested, then this parameter is not returned.
-
fileId
final Optional<String> fileId()
Unique fileId. Store this fileld in your database, as this will be used to perform update action on this file.
-
filePath
final Optional<String> filePath()
The relative path of the file in the media library e.g.
/marketing-assets/new-banner.jpg.
-
fileType
final Optional<String> fileType()
Type of the uploaded file. Possible values are
image,non-image.
-
isPrivateFile
final Optional<Boolean> isPrivateFile()
Is the file marked as private. It can be either
trueorfalse. SendisPrivateFileinresponseFieldsin API request to get the value of this field.
-
isPublished
final Optional<Boolean> isPublished()
Is the file published or in draft state. It can be either
trueorfalse. SendisPublishedinresponseFieldsin API request to get the value of this field.
-
metadata
final Optional<Metadata> metadata()
Legacy metadata. Send
metadatainresponseFieldsin API request to get metadata in the upload API response.
-
selectedFieldsSchema
final Optional<SelectedFieldsSchema> selectedFieldsSchema()
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
tags
final Optional<List<String>> tags()
The array of tags associated with the asset. If no tags are set, it will be
null. SendtagsinresponseFieldsin API request to get the value of this field.
-
thumbnailUrl
final Optional<String> thumbnailUrl()
In the case of an image, a small thumbnail URL.
-
versionInfo
final Optional<VersionInfo> versionInfo()
An object containing the file or file version's
id(versionId) andname.
-
videoCodec
final Optional<String> videoCodec()
The video codec used in the video (only for video).
-
_aiTags
final JsonField<List<AiTag>> _aiTags()
Returns the raw JSON value of aiTags.
Unlike aiTags, this method doesn't throw if the JSON field has an unexpected type.
-
_audioCodec
final JsonField<String> _audioCodec()
Returns the raw JSON value of audioCodec.
Unlike audioCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_bitRate
final JsonField<Long> _bitRate()
Returns the raw JSON value of bitRate.
Unlike bitRate, this method doesn't throw if the JSON field has an unexpected type.
-
_customCoordinates
final JsonField<String> _customCoordinates()
Returns the raw JSON value of customCoordinates.
Unlike customCoordinates, this method doesn't throw if the JSON field has an unexpected type.
-
_customMetadata
final JsonField<CustomMetadata> _customMetadata()
Returns the raw JSON value of customMetadata.
Unlike customMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_duration
final JsonField<Long> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_embeddedMetadata
final JsonField<EmbeddedMetadata> _embeddedMetadata()
Returns the raw JSON value of embeddedMetadata.
Unlike embeddedMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_extensionStatus
final JsonField<UploadPreTransformSuccessEvent.Data.ExtensionStatus> _extensionStatus()
Returns the raw JSON value of extensionStatus.
Unlike extensionStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_filePath
final JsonField<String> _filePath()
Returns the raw JSON value of filePath.
Unlike filePath, this method doesn't throw if the JSON field has an unexpected type.
-
_fileType
final JsonField<String> _fileType()
Returns the raw JSON value of fileType.
Unlike fileType, this method doesn't throw if the JSON field has an unexpected type.
-
_height
final JsonField<Double> _height()
Returns the raw JSON value of height.
Unlike height, this method doesn't throw if the JSON field has an unexpected type.
-
_isPrivateFile
final JsonField<Boolean> _isPrivateFile()
Returns the raw JSON value of isPrivateFile.
Unlike isPrivateFile, this method doesn't throw if the JSON field has an unexpected type.
-
_isPublished
final JsonField<Boolean> _isPublished()
Returns the raw JSON value of isPublished.
Unlike isPublished, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_selectedFieldsSchema
final JsonField<SelectedFieldsSchema> _selectedFieldsSchema()
Returns the raw JSON value of selectedFieldsSchema.
Unlike selectedFieldsSchema, this method doesn't throw if the JSON field has an unexpected type.
-
_size
final JsonField<Double> _size()
Returns the raw JSON value of size.
Unlike size, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_thumbnailUrl
final JsonField<String> _thumbnailUrl()
Returns the raw JSON value of thumbnailUrl.
Unlike thumbnailUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_versionInfo
final JsonField<VersionInfo> _versionInfo()
Returns the raw JSON value of versionInfo.
Unlike versionInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_videoCodec
final JsonField<String> _videoCodec()
Returns the raw JSON value of videoCodec.
Unlike videoCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<Double> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPreTransformSuccessEvent.Data.Builder toBuilder()
-
validate
final UploadPreTransformSuccessEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPreTransformSuccessEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
-
-
-
-