Class UploadPreTransformSuccessEvent.Data.Builder
-
- All Implemented Interfaces:
public final class UploadPreTransformSuccessEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
aiTags
final UploadPreTransformSuccessEvent.Data.Builder aiTags(List<AiTag> aiTags)
An array of tags assigned to the uploaded file by auto tagging.
-
aiTags
final UploadPreTransformSuccessEvent.Data.Builder aiTags(Optional<List<AiTag>> aiTags)
Alias for calling Builder.aiTags with
aiTags.orElse(null).
-
aiTags
final UploadPreTransformSuccessEvent.Data.Builder aiTags(JsonField<List<AiTag>> aiTags)
Sets Builder.aiTags to an arbitrary JSON value.
You should usually call Builder.aiTags with a well-typed
List<AiTag>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAiTag
final UploadPreTransformSuccessEvent.Data.Builder addAiTag(AiTag aiTag)
-
audioCodec
final UploadPreTransformSuccessEvent.Data.Builder audioCodec(String audioCodec)
The audio codec used in the video (only for video).
-
audioCodec
final UploadPreTransformSuccessEvent.Data.Builder audioCodec(JsonField<String> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
bitRate
final UploadPreTransformSuccessEvent.Data.Builder bitRate(Long bitRate)
The bit rate of the video in kbps (only for video).
-
bitRate
final UploadPreTransformSuccessEvent.Data.Builder bitRate(JsonField<Long> bitRate)
Sets Builder.bitRate to an arbitrary JSON value.
You should usually call Builder.bitRate with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customCoordinates
final UploadPreTransformSuccessEvent.Data.Builder customCoordinates(String customCoordinates)
Value of custom coordinates associated with the image in the format
x,y,width,height. IfcustomCoordinatesare not defined, then it isnull. SendcustomCoordinatesinresponseFieldsin API request to get the value of this field.
-
customCoordinates
final UploadPreTransformSuccessEvent.Data.Builder customCoordinates(Optional<String> customCoordinates)
Alias for calling Builder.customCoordinates with
customCoordinates.orElse(null).
-
customCoordinates
final UploadPreTransformSuccessEvent.Data.Builder customCoordinates(JsonField<String> customCoordinates)
Sets Builder.customCoordinates to an arbitrary JSON value.
You should usually call Builder.customCoordinates with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
customMetadata
final UploadPreTransformSuccessEvent.Data.Builder customMetadata(CustomMetadata customMetadata)
A key-value data associated with the asset. Use
responseFieldin API request to getcustomMetadatain the upload API response. Before setting any custom metadata on an asset, you have to create the field using custom metadata fields API. SendcustomMetadatainresponseFieldsin API request to get the value of this field.
-
customMetadata
final UploadPreTransformSuccessEvent.Data.Builder customMetadata(JsonField<CustomMetadata> customMetadata)
Sets Builder.customMetadata to an arbitrary JSON value.
You should usually call Builder.customMetadata with a well-typed CustomMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
description
final UploadPreTransformSuccessEvent.Data.Builder description(String description)
Optional text to describe the contents of the file. Can be set by the user or the ai-auto-description extension.
-
description
final UploadPreTransformSuccessEvent.Data.Builder description(JsonField<String> description)
Sets Builder.description to an arbitrary JSON value.
You should usually call Builder.description with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
duration
final UploadPreTransformSuccessEvent.Data.Builder duration(Long duration)
The duration of the video in seconds (only for video).
-
duration
final UploadPreTransformSuccessEvent.Data.Builder duration(JsonField<Long> duration)
Sets Builder.duration to an arbitrary JSON value.
You should usually call Builder.duration with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
embeddedMetadata
final UploadPreTransformSuccessEvent.Data.Builder embeddedMetadata(EmbeddedMetadata embeddedMetadata)
Consolidated embedded metadata associated with the file. It includes exif, iptc, and xmp data. Send
embeddedMetadatainresponseFieldsin API request to get embeddedMetadata in the upload API response.
-
embeddedMetadata
final UploadPreTransformSuccessEvent.Data.Builder embeddedMetadata(JsonField<EmbeddedMetadata> embeddedMetadata)
Sets Builder.embeddedMetadata to an arbitrary JSON value.
You should usually call Builder.embeddedMetadata with a well-typed EmbeddedMetadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
extensionStatus
final UploadPreTransformSuccessEvent.Data.Builder extensionStatus(UploadPreTransformSuccessEvent.Data.ExtensionStatus extensionStatus)
Extension names with their processing status at the time of completion of the request. It could have one of the following status values:
success: The extension has been successfully applied.failed: The extension has failed and will not be retried.pending: The extension will finish processing in some time. On completion, the final status (success / failed) will be sent to thewebhookUrlprovided.If no extension was requested, then this parameter is not returned.
-
extensionStatus
final UploadPreTransformSuccessEvent.Data.Builder extensionStatus(JsonField<UploadPreTransformSuccessEvent.Data.ExtensionStatus> extensionStatus)
Sets Builder.extensionStatus to an arbitrary JSON value.
You should usually call Builder.extensionStatus with a well-typed ExtensionStatus value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileId
final UploadPreTransformSuccessEvent.Data.Builder fileId(String fileId)
Unique fileId. Store this fileld in your database, as this will be used to perform update action on this file.
-
fileId
final UploadPreTransformSuccessEvent.Data.Builder fileId(JsonField<String> fileId)
Sets Builder.fileId to an arbitrary JSON value.
You should usually call Builder.fileId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
filePath
final UploadPreTransformSuccessEvent.Data.Builder filePath(String filePath)
The relative path of the file in the media library e.g.
/marketing-assets/new-banner.jpg.
-
filePath
final UploadPreTransformSuccessEvent.Data.Builder filePath(JsonField<String> filePath)
Sets Builder.filePath to an arbitrary JSON value.
You should usually call Builder.filePath with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
fileType
final UploadPreTransformSuccessEvent.Data.Builder fileType(String fileType)
Type of the uploaded file. Possible values are
image,non-image.
-
fileType
final UploadPreTransformSuccessEvent.Data.Builder fileType(JsonField<String> fileType)
Sets Builder.fileType to an arbitrary JSON value.
You should usually call Builder.fileType with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
height
final UploadPreTransformSuccessEvent.Data.Builder height(Double height)
Height of the image in pixels (Only for images)
-
height
final UploadPreTransformSuccessEvent.Data.Builder height(JsonField<Double> height)
Sets Builder.height to an arbitrary JSON value.
You should usually call Builder.height with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPrivateFile
final UploadPreTransformSuccessEvent.Data.Builder isPrivateFile(Boolean isPrivateFile)
Is the file marked as private. It can be either
trueorfalse. SendisPrivateFileinresponseFieldsin API request to get the value of this field.
-
isPrivateFile
final UploadPreTransformSuccessEvent.Data.Builder isPrivateFile(JsonField<Boolean> isPrivateFile)
Sets Builder.isPrivateFile to an arbitrary JSON value.
You should usually call Builder.isPrivateFile with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
isPublished
final UploadPreTransformSuccessEvent.Data.Builder isPublished(Boolean isPublished)
Is the file published or in draft state. It can be either
trueorfalse. SendisPublishedinresponseFieldsin API request to get the value of this field.
-
isPublished
final UploadPreTransformSuccessEvent.Data.Builder isPublished(JsonField<Boolean> isPublished)
Sets Builder.isPublished to an arbitrary JSON value.
You should usually call Builder.isPublished with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
metadata
final UploadPreTransformSuccessEvent.Data.Builder metadata(Metadata metadata)
Legacy metadata. Send
metadatainresponseFieldsin API request to get metadata in the upload API response.
-
metadata
final UploadPreTransformSuccessEvent.Data.Builder metadata(JsonField<Metadata> metadata)
Sets Builder.metadata to an arbitrary JSON value.
You should usually call Builder.metadata with a well-typed Metadata value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
name
final UploadPreTransformSuccessEvent.Data.Builder name(String name)
Name of the asset.
-
name
final UploadPreTransformSuccessEvent.Data.Builder name(JsonField<String> name)
Sets Builder.name to an arbitrary JSON value.
You should usually call Builder.name with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
selectedFieldsSchema
final UploadPreTransformSuccessEvent.Data.Builder selectedFieldsSchema(SelectedFieldsSchema selectedFieldsSchema)
This field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
selectedFieldsSchema
final UploadPreTransformSuccessEvent.Data.Builder selectedFieldsSchema(JsonField<SelectedFieldsSchema> selectedFieldsSchema)
Sets Builder.selectedFieldsSchema to an arbitrary JSON value.
You should usually call Builder.selectedFieldsSchema with a well-typed SelectedFieldsSchema value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
size
final UploadPreTransformSuccessEvent.Data.Builder size(Double size)
Size of the image file in Bytes.
-
size
final UploadPreTransformSuccessEvent.Data.Builder size(JsonField<Double> size)
Sets Builder.size to an arbitrary JSON value.
You should usually call Builder.size with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
tags
final UploadPreTransformSuccessEvent.Data.Builder tags(List<String> tags)
The array of tags associated with the asset. If no tags are set, it will be
null. SendtagsinresponseFieldsin API request to get the value of this field.
-
tags
final UploadPreTransformSuccessEvent.Data.Builder tags(Optional<List<String>> tags)
Alias for calling Builder.tags with
tags.orElse(null).
-
tags
final UploadPreTransformSuccessEvent.Data.Builder tags(JsonField<List<String>> tags)
Sets Builder.tags to an arbitrary JSON value.
You should usually call Builder.tags with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addTag
final UploadPreTransformSuccessEvent.Data.Builder addTag(String tag)
-
thumbnailUrl
final UploadPreTransformSuccessEvent.Data.Builder thumbnailUrl(String thumbnailUrl)
In the case of an image, a small thumbnail URL.
-
thumbnailUrl
final UploadPreTransformSuccessEvent.Data.Builder thumbnailUrl(JsonField<String> thumbnailUrl)
Sets Builder.thumbnailUrl to an arbitrary JSON value.
You should usually call Builder.thumbnailUrl with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
url
final UploadPreTransformSuccessEvent.Data.Builder url(String url)
A publicly accessible URL of the file.
-
url
final UploadPreTransformSuccessEvent.Data.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
versionInfo
final UploadPreTransformSuccessEvent.Data.Builder versionInfo(VersionInfo versionInfo)
An object containing the file or file version's
id(versionId) andname.
-
versionInfo
final UploadPreTransformSuccessEvent.Data.Builder versionInfo(JsonField<VersionInfo> versionInfo)
Sets Builder.versionInfo to an arbitrary JSON value.
You should usually call Builder.versionInfo with a well-typed VersionInfo value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
videoCodec
final UploadPreTransformSuccessEvent.Data.Builder videoCodec(String videoCodec)
The video codec used in the video (only for video).
-
videoCodec
final UploadPreTransformSuccessEvent.Data.Builder videoCodec(JsonField<String> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
width
final UploadPreTransformSuccessEvent.Data.Builder width(Double width)
Width of the image in pixels (Only for Images)
-
width
final UploadPreTransformSuccessEvent.Data.Builder width(JsonField<Double> width)
Sets Builder.width to an arbitrary JSON value.
You should usually call Builder.width with a well-typed Double value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final UploadPreTransformSuccessEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final UploadPreTransformSuccessEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final UploadPreTransformSuccessEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final UploadPreTransformSuccessEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final UploadPreTransformSuccessEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final UploadPreTransformSuccessEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-