Package io.imagekit.models.webhooks
Class UploadPreTransformSuccessEvent.Request
-
- All Implemented Interfaces:
public final class UploadPreTransformSuccessEvent.Request
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPreTransformSuccessEvent.Request.BuilderA builder for Request.
-
Method Summary
Modifier and Type Method Description final Stringtransformation()The requested pre-transformation string. final StringxRequestId()Unique identifier for the originating request. final JsonField<String>_transformation()Returns the raw JSON value of transformation. final JsonField<String>_xRequestId()Returns the raw JSON value of xRequestId. final Map<String, JsonValue>_additionalProperties()final UploadPreTransformSuccessEvent.Request.BuildertoBuilder()final UploadPreTransformSuccessEvent.Requestvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPreTransformSuccessEvent.Request.Builderbuilder()Returns a mutable builder for constructing an instance of Request. -
-
Method Detail
-
transformation
final String transformation()
The requested pre-transformation string.
-
xRequestId
final String xRequestId()
Unique identifier for the originating request.
-
_transformation
final JsonField<String> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_xRequestId
final JsonField<String> _xRequestId()
Returns the raw JSON value of xRequestId.
Unlike xRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPreTransformSuccessEvent.Request.Builder toBuilder()
-
validate
final UploadPreTransformSuccessEvent.Request validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UploadPreTransformSuccessEvent.Request.Builder builder()
Returns a mutable builder for constructing an instance of Request.
The following fields are required:
.transformation() .xRequestId()
-
-
-
-