Class VideoTransformationAcceptedEvent
-
- All Implemented Interfaces:
public final class VideoTransformationAcceptedEventTriggered when a new video transformation request is accepted for processing. This event confirms that ImageKit has received and queued your transformation request. Use this for debugging and tracking transformation lifecycle.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationAcceptedEvent.BuilderA builder for VideoTransformationAcceptedEvent.
public final classVideoTransformationAcceptedEvent.Datapublic final classVideoTransformationAcceptedEvent.RequestInformation about the original request that triggered the video transformation.
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp when the event was created in ISO8601 format. final VideoTransformationAcceptedEvent.Datadata()final VideoTransformationAcceptedEvent.Requestrequest()Information about the original request that triggered the video transformation. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<VideoTransformationAcceptedEvent.Data>_data()Returns the raw JSON value of data. final JsonField<VideoTransformationAcceptedEvent.Request>_request()Returns the raw JSON value of request. final Map<String, JsonValue>_additionalProperties()final VideoTransformationAcceptedEvent.BuildertoBuilder()final VideoTransformationAcceptedEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationAcceptedEvent.Builderbuilder()Returns a mutable builder for constructing an instance of VideoTransformationAcceptedEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp when the event was created in ISO8601 format.
-
data
final VideoTransformationAcceptedEvent.Data data()
-
request
final VideoTransformationAcceptedEvent.Request request()
Information about the original request that triggered the video transformation.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<VideoTransformationAcceptedEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_request
final JsonField<VideoTransformationAcceptedEvent.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationAcceptedEvent.Builder toBuilder()
-
validate
final VideoTransformationAcceptedEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationAcceptedEvent.Builder builder()
Returns a mutable builder for constructing an instance of VideoTransformationAcceptedEvent.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-