Class VideoTransformationAcceptedEvent.Data
-
- All Implemented Interfaces:
public final class VideoTransformationAcceptedEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationAcceptedEvent.Data.BuilderA builder for Data.
public final classVideoTransformationAcceptedEvent.Data.AssetInformation about the source video asset being transformed.
public final classVideoTransformationAcceptedEvent.Data.TransformationBase information about a video transformation request.
-
Method Summary
-
-
Method Detail
-
asset
final VideoTransformationAcceptedEvent.Data.Asset asset()
Information about the source video asset being transformed.
-
transformation
final VideoTransformationAcceptedEvent.Data.Transformation transformation()
Base information about a video transformation request.
-
_asset
final JsonField<VideoTransformationAcceptedEvent.Data.Asset> _asset()
Returns the raw JSON value of asset.
Unlike asset, this method doesn't throw if the JSON field has an unexpected type.
-
_transformation
final JsonField<VideoTransformationAcceptedEvent.Data.Transformation> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationAcceptedEvent.Data.Builder toBuilder()
-
validate
final VideoTransformationAcceptedEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationAcceptedEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.asset() .transformation()
-
-
-
-