Class VideoTransformationAcceptedEvent.Data.Transformation
-
- All Implemented Interfaces:
public final class VideoTransformationAcceptedEvent.Data.TransformationBase information about a video transformation request.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationAcceptedEvent.Data.Transformation.BuilderA builder for Transformation.
public final classVideoTransformationAcceptedEvent.Data.Transformation.TypeType of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
public final classVideoTransformationAcceptedEvent.Data.Transformation.OptionsConfiguration options for video transformations.
-
Method Summary
Modifier and Type Method Description final VideoTransformationAcceptedEvent.Data.Transformation.Typetype()Type of video transformation: video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
final Optional<VideoTransformationAcceptedEvent.Data.Transformation.Options>options()Configuration options for video transformations. final JsonField<VideoTransformationAcceptedEvent.Data.Transformation.Type>_type()Returns the raw JSON value of type. final JsonField<VideoTransformationAcceptedEvent.Data.Transformation.Options>_options()Returns the raw JSON value of options. final Map<String, JsonValue>_additionalProperties()final VideoTransformationAcceptedEvent.Data.Transformation.BuildertoBuilder()final VideoTransformationAcceptedEvent.Data.Transformationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationAcceptedEvent.Data.Transformation.Builderbuilder()Returns a mutable builder for constructing an instance of Transformation. -
-
Method Detail
-
type
final VideoTransformationAcceptedEvent.Data.Transformation.Type type()
Type of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
-
options
final Optional<VideoTransformationAcceptedEvent.Data.Transformation.Options> options()
Configuration options for video transformations.
-
_type
final JsonField<VideoTransformationAcceptedEvent.Data.Transformation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<VideoTransformationAcceptedEvent.Data.Transformation.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationAcceptedEvent.Data.Transformation.Builder toBuilder()
-
validate
final VideoTransformationAcceptedEvent.Data.Transformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationAcceptedEvent.Data.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.type()
-
-
-