Class VideoTransformationErrorEvent

  • All Implemented Interfaces:

    
    public final class VideoTransformationErrorEvent
    
                        

    Triggered when an error occurs during video encoding. Listen to this webhook to log error reasons and debug issues. Check your origin and URL endpoint settings if the reason is related to download failure. For other errors, contact ImageKit support.