Package io.imagekit.models.webhooks
Class VideoTransformationErrorEvent.Data
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.Data.BuilderA builder for Data.
public final classVideoTransformationErrorEvent.Data.AssetInformation about the source video asset being transformed.
public final classVideoTransformationErrorEvent.Data.Transformation
-
Method Summary
Modifier and Type Method Description final VideoTransformationErrorEvent.Data.Assetasset()Information about the source video asset being transformed. final VideoTransformationErrorEvent.Data.Transformationtransformation()final JsonField<VideoTransformationErrorEvent.Data.Asset>_asset()Returns the raw JSON value of asset. final JsonField<VideoTransformationErrorEvent.Data.Transformation>_transformation()Returns the raw JSON value of transformation. final Map<String, JsonValue>_additionalProperties()final VideoTransformationErrorEvent.Data.BuildertoBuilder()final VideoTransformationErrorEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationErrorEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
asset
final VideoTransformationErrorEvent.Data.Asset asset()
Information about the source video asset being transformed.
-
transformation
final VideoTransformationErrorEvent.Data.Transformation transformation()
-
_asset
final JsonField<VideoTransformationErrorEvent.Data.Asset> _asset()
Returns the raw JSON value of asset.
Unlike asset, this method doesn't throw if the JSON field has an unexpected type.
-
_transformation
final JsonField<VideoTransformationErrorEvent.Data.Transformation> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Data.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationErrorEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.asset() .transformation()
-
-
-
-