Package io.imagekit.models.webhooks
Class VideoTransformationErrorEvent.Data.Asset
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.AssetInformation about the source video asset being transformed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.Data.Asset.BuilderA builder for Asset.
-
Method Summary
Modifier and Type Method Description final Stringurl()URL to download or access the source video file. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final VideoTransformationErrorEvent.Data.Asset.BuildertoBuilder()final VideoTransformationErrorEvent.Data.Assetvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationErrorEvent.Data.Asset.Builderbuilder()Returns a mutable builder for constructing an instance of Asset. -
-
Method Detail
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Data.Asset.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent.Data.Asset validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationErrorEvent.Data.Asset.Builder builder()
Returns a mutable builder for constructing an instance of Asset.
The following fields are required:
.url()
-
-
-
-