Package io.imagekit.models.webhooks
Class VideoTransformationErrorEvent.Data.Builder
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.BuilderA builder for Data.
-
-
Method Summary
-
-
Method Detail
-
asset
final VideoTransformationErrorEvent.Data.Builder asset(VideoTransformationErrorEvent.Data.Asset asset)
Information about the source video asset being transformed.
-
asset
final VideoTransformationErrorEvent.Data.Builder asset(JsonField<VideoTransformationErrorEvent.Data.Asset> asset)
Sets Builder.asset to an arbitrary JSON value.
You should usually call Builder.asset with a well-typed Asset value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
transformation
final VideoTransformationErrorEvent.Data.Builder transformation(VideoTransformationErrorEvent.Data.Transformation transformation)
-
transformation
final VideoTransformationErrorEvent.Data.Builder transformation(JsonField<VideoTransformationErrorEvent.Data.Transformation> transformation)
Sets Builder.transformation to an arbitrary JSON value.
You should usually call Builder.transformation with a well-typed Transformation value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VideoTransformationErrorEvent.Data.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VideoTransformationErrorEvent.Data.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VideoTransformationErrorEvent.Data.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VideoTransformationErrorEvent.Data.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VideoTransformationErrorEvent.Data.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VideoTransformationErrorEvent.Data build()
Returns an immutable instance of Data.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.asset() .transformation()
-
-
-
-