Class VideoTransformationErrorEvent.Data.Transformation
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.Transformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.Data.Transformation.BuilderA builder for Transformation.
public final classVideoTransformationErrorEvent.Data.Transformation.TypeType of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
public final classVideoTransformationErrorEvent.Data.Transformation.ErrorDetails about the transformation error.
public final classVideoTransformationErrorEvent.Data.Transformation.OptionsConfiguration options for video transformations.
-
Method Summary
Modifier and Type Method Description final VideoTransformationErrorEvent.Data.Transformation.Typetype()Type of video transformation: video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
final Optional<VideoTransformationErrorEvent.Data.Transformation.Error>error()Details about the transformation error. final Optional<VideoTransformationErrorEvent.Data.Transformation.Options>options()Configuration options for video transformations. final JsonField<VideoTransformationErrorEvent.Data.Transformation.Type>_type()Returns the raw JSON value of type. final JsonField<VideoTransformationErrorEvent.Data.Transformation.Error>_error()Returns the raw JSON value of error. final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options>_options()Returns the raw JSON value of options. final Map<String, JsonValue>_additionalProperties()final VideoTransformationErrorEvent.Data.Transformation.BuildertoBuilder()final VideoTransformationErrorEvent.Data.Transformationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationErrorEvent.Data.Transformation.Builderbuilder()Returns a mutable builder for constructing an instance of Transformation. -
-
Method Detail
-
type
final VideoTransformationErrorEvent.Data.Transformation.Type type()
Type of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
-
error
final Optional<VideoTransformationErrorEvent.Data.Transformation.Error> error()
Details about the transformation error.
-
options
final Optional<VideoTransformationErrorEvent.Data.Transformation.Options> options()
Configuration options for video transformations.
-
_type
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Data.Transformation.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent.Data.Transformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationErrorEvent.Data.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.type()
-
-
-