Class VideoTransformationErrorEvent.Data.Transformation.Builder
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.Transformation.BuilderA builder for Transformation.
-
-
Method Summary
-
-
Method Detail
-
type
final VideoTransformationErrorEvent.Data.Transformation.Builder type(VideoTransformationErrorEvent.Data.Transformation.Type type)
Type of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
-
type
final VideoTransformationErrorEvent.Data.Transformation.Builder type(JsonField<VideoTransformationErrorEvent.Data.Transformation.Type> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed Type value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
error
final VideoTransformationErrorEvent.Data.Transformation.Builder error(VideoTransformationErrorEvent.Data.Transformation.Error error)
Details about the transformation error.
-
error
final VideoTransformationErrorEvent.Data.Transformation.Builder error(JsonField<VideoTransformationErrorEvent.Data.Transformation.Error> error)
Sets Builder.error to an arbitrary JSON value.
You should usually call Builder.error with a well-typed Error value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
options
final VideoTransformationErrorEvent.Data.Transformation.Builder options(VideoTransformationErrorEvent.Data.Transformation.Options options)
Configuration options for video transformations.
-
options
final VideoTransformationErrorEvent.Data.Transformation.Builder options(JsonField<VideoTransformationErrorEvent.Data.Transformation.Options> options)
Sets Builder.options to an arbitrary JSON value.
You should usually call Builder.options with a well-typed Options value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VideoTransformationErrorEvent.Data.Transformation.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VideoTransformationErrorEvent.Data.Transformation.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VideoTransformationErrorEvent.Data.Transformation.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VideoTransformationErrorEvent.Data.Transformation.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VideoTransformationErrorEvent.Data.Transformation.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VideoTransformationErrorEvent.Data.Transformation build()
Returns an immutable instance of Transformation.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.type()
-
-
-
-