Class VideoTransformationErrorEvent.Data.Transformation.Options
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.Transformation.OptionsConfiguration options for video transformations.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.Data.Transformation.Options.BuilderA builder for Options.
public final classVideoTransformationErrorEvent.Data.Transformation.Options.AudioCodecAudio codec used for encoding (aac or opus).
public final classVideoTransformationErrorEvent.Data.Transformation.Options.FormatOutput format for the transformed video or thumbnail.
public final classVideoTransformationErrorEvent.Data.Transformation.Options.StreamProtocolStreaming protocol for adaptive bitrate streaming.
public final classVideoTransformationErrorEvent.Data.Transformation.Options.VideoCodecVideo codec used for encoding (h264, vp9, or av1).
-
Method Summary
-
-
Method Detail
-
audioCodec
final Optional<VideoTransformationErrorEvent.Data.Transformation.Options.AudioCodec> audioCodec()
Audio codec used for encoding (aac or opus).
-
autoRotate
final Optional<Boolean> autoRotate()
Whether to automatically rotate the video based on metadata.
-
format
final Optional<VideoTransformationErrorEvent.Data.Transformation.Options.Format> format()
Output format for the transformed video or thumbnail.
-
streamProtocol
final Optional<VideoTransformationErrorEvent.Data.Transformation.Options.StreamProtocol> streamProtocol()
Streaming protocol for adaptive bitrate streaming.
-
variants
final Optional<List<String>> variants()
Array of quality representations for adaptive bitrate streaming.
-
videoCodec
final Optional<VideoTransformationErrorEvent.Data.Transformation.Options.VideoCodec> videoCodec()
Video codec used for encoding (h264, vp9, or av1).
-
_audioCodec
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.AudioCodec> _audioCodec()
Returns the raw JSON value of audioCodec.
Unlike audioCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_autoRotate
final JsonField<Boolean> _autoRotate()
Returns the raw JSON value of autoRotate.
Unlike autoRotate, this method doesn't throw if the JSON field has an unexpected type.
-
_format
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.Format> _format()
Returns the raw JSON value of format.
Unlike format, this method doesn't throw if the JSON field has an unexpected type.
-
_quality
final JsonField<Long> _quality()
Returns the raw JSON value of quality.
Unlike quality, this method doesn't throw if the JSON field has an unexpected type.
-
_streamProtocol
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.StreamProtocol> _streamProtocol()
Returns the raw JSON value of streamProtocol.
Unlike streamProtocol, this method doesn't throw if the JSON field has an unexpected type.
-
_variants
final JsonField<List<String>> _variants()
Returns the raw JSON value of variants.
Unlike variants, this method doesn't throw if the JSON field has an unexpected type.
-
_videoCodec
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.VideoCodec> _videoCodec()
Returns the raw JSON value of videoCodec.
Unlike videoCodec, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent.Data.Transformation.Options validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationErrorEvent.Data.Transformation.Options.Builder builder()
Returns a mutable builder for constructing an instance of Options.
-
-
-
-