Class VideoTransformationErrorEvent.Data.Transformation.Options.Builder
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.Transformation.Options.BuilderA builder for Options.
-
-
Method Summary
-
-
Method Detail
-
audioCodec
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder audioCodec(VideoTransformationErrorEvent.Data.Transformation.Options.AudioCodec audioCodec)
Audio codec used for encoding (aac or opus).
-
audioCodec
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder audioCodec(JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.AudioCodec> audioCodec)
Sets Builder.audioCodec to an arbitrary JSON value.
You should usually call Builder.audioCodec with a well-typed AudioCodec value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
autoRotate
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder autoRotate(Boolean autoRotate)
Whether to automatically rotate the video based on metadata.
-
autoRotate
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder autoRotate(JsonField<Boolean> autoRotate)
Sets Builder.autoRotate to an arbitrary JSON value.
You should usually call Builder.autoRotate with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
format
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder format(VideoTransformationErrorEvent.Data.Transformation.Options.Format format)
Output format for the transformed video or thumbnail.
-
format
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder format(JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.Format> format)
Sets Builder.format to an arbitrary JSON value.
You should usually call Builder.format with a well-typed Format value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
quality
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder quality(Long quality)
Quality setting for the output video.
-
quality
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder quality(JsonField<Long> quality)
Sets Builder.quality to an arbitrary JSON value.
You should usually call Builder.quality with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
streamProtocol
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder streamProtocol(VideoTransformationErrorEvent.Data.Transformation.Options.StreamProtocol streamProtocol)
Streaming protocol for adaptive bitrate streaming.
-
streamProtocol
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder streamProtocol(JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.StreamProtocol> streamProtocol)
Sets Builder.streamProtocol to an arbitrary JSON value.
You should usually call Builder.streamProtocol with a well-typed StreamProtocol value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
variants
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder variants(List<String> variants)
Array of quality representations for adaptive bitrate streaming.
-
variants
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder variants(JsonField<List<String>> variants)
Sets Builder.variants to an arbitrary JSON value.
You should usually call Builder.variants with a well-typed
List<String>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addVariant
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder addVariant(String variant)
-
videoCodec
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder videoCodec(VideoTransformationErrorEvent.Data.Transformation.Options.VideoCodec videoCodec)
Video codec used for encoding (h264, vp9, or av1).
-
videoCodec
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder videoCodec(JsonField<VideoTransformationErrorEvent.Data.Transformation.Options.VideoCodec> videoCodec)
Sets Builder.videoCodec to an arbitrary JSON value.
You should usually call Builder.videoCodec with a well-typed VideoCodec value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VideoTransformationErrorEvent.Data.Transformation.Options.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VideoTransformationErrorEvent.Data.Transformation.Options build()
Returns an immutable instance of Options.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-