Class VideoTransformationErrorEvent.Request.Builder
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Request.BuilderA builder for Request.
-
-
Method Summary
-
-
Method Detail
-
url
final VideoTransformationErrorEvent.Request.Builder url(String url)
Full URL of the transformation request that was submitted.
-
url
final VideoTransformationErrorEvent.Request.Builder url(JsonField<String> url)
Sets Builder.url to an arbitrary JSON value.
You should usually call Builder.url with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
xRequestId
final VideoTransformationErrorEvent.Request.Builder xRequestId(String xRequestId)
Unique identifier for the originating transformation request.
-
xRequestId
final VideoTransformationErrorEvent.Request.Builder xRequestId(JsonField<String> xRequestId)
Sets Builder.xRequestId to an arbitrary JSON value.
You should usually call Builder.xRequestId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
userAgent
final VideoTransformationErrorEvent.Request.Builder userAgent(String userAgent)
User-Agent header from the original request that triggered the transformation.
-
userAgent
final VideoTransformationErrorEvent.Request.Builder userAgent(JsonField<String> userAgent)
Sets Builder.userAgent to an arbitrary JSON value.
You should usually call Builder.userAgent with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VideoTransformationErrorEvent.Request.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VideoTransformationErrorEvent.Request.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VideoTransformationErrorEvent.Request.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VideoTransformationErrorEvent.Request.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VideoTransformationErrorEvent.Request.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VideoTransformationErrorEvent.Request build()
Returns an immutable instance of Request.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.url() .xRequestId()
-
-
-
-