Class VideoTransformationReadyEvent

  • All Implemented Interfaces:

    
    public final class VideoTransformationReadyEvent
    
                        

    Triggered when video encoding is finished and the transformed resource is ready to be served. This is the key event to listen for - update your database or CMS flags when you receive this so your application can start showing the transformed video to users.