Class VideoTransformationReadyEvent.Builder
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEvent.BuilderA builder for VideoTransformationReadyEvent.
-
-
Method Summary
-
-
Method Detail
-
id
final VideoTransformationReadyEvent.Builder id(String id)
Unique identifier for the event.
-
id
final VideoTransformationReadyEvent.Builder id(JsonField<String> id)
Sets Builder.id to an arbitrary JSON value.
You should usually call Builder.id with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final VideoTransformationReadyEvent.Builder type(String type)
The type of webhook event.
-
type
final VideoTransformationReadyEvent.Builder type(JsonField<String> type)
Sets Builder.type to an arbitrary JSON value.
You should usually call Builder.type with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
createdAt
final VideoTransformationReadyEvent.Builder createdAt(OffsetDateTime createdAt)
Timestamp when the event was created in ISO8601 format.
-
createdAt
final VideoTransformationReadyEvent.Builder createdAt(JsonField<OffsetDateTime> createdAt)
Sets Builder.createdAt to an arbitrary JSON value.
You should usually call Builder.createdAt with a well-typed OffsetDateTime value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
data
final VideoTransformationReadyEvent.Builder data(VideoTransformationReadyEvent.Data data)
-
data
final VideoTransformationReadyEvent.Builder data(JsonField<VideoTransformationReadyEvent.Data> data)
Sets Builder.data to an arbitrary JSON value.
You should usually call Builder.data with a well-typed Data value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
request
final VideoTransformationReadyEvent.Builder request(VideoTransformationReadyEvent.Request request)
Information about the original request that triggered the video transformation.
-
request
final VideoTransformationReadyEvent.Builder request(JsonField<VideoTransformationReadyEvent.Request> request)
Sets Builder.request to an arbitrary JSON value.
You should usually call Builder.request with a well-typed Request value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
timings
final VideoTransformationReadyEvent.Builder timings(VideoTransformationReadyEvent.Timings timings)
Performance metrics for the transformation process.
-
timings
final VideoTransformationReadyEvent.Builder timings(JsonField<VideoTransformationReadyEvent.Timings> timings)
Sets Builder.timings to an arbitrary JSON value.
You should usually call Builder.timings with a well-typed Timings value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final VideoTransformationReadyEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final VideoTransformationReadyEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final VideoTransformationReadyEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final VideoTransformationReadyEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final VideoTransformationReadyEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final VideoTransformationReadyEvent build()
Returns an immutable instance of VideoTransformationReadyEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-