Package io.imagekit.models.webhooks
Class VideoTransformationReadyEvent.Data.Transformation.Output
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEvent.Data.Transformation.OutputInformation about the transformed output video.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationReadyEvent.Data.Transformation.Output.BuilderA builder for Output.
public final classVideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadataMetadata of the output video file.
-
Method Summary
Modifier and Type Method Description final Stringurl()URL to access the transformed video. final Optional<VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata>videoMetadata()Metadata of the output video file. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata>_videoMetadata()Returns the raw JSON value of videoMetadata. final Map<String, JsonValue>_additionalProperties()final VideoTransformationReadyEvent.Data.Transformation.Output.BuildertoBuilder()final VideoTransformationReadyEvent.Data.Transformation.Outputvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationReadyEvent.Data.Transformation.Output.Builderbuilder()Returns a mutable builder for constructing an instance of Output. -
-
Method Detail
-
videoMetadata
final Optional<VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata> videoMetadata()
Metadata of the output video file.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_videoMetadata
final JsonField<VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata> _videoMetadata()
Returns the raw JSON value of videoMetadata.
Unlike videoMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationReadyEvent.Data.Transformation.Output.Builder toBuilder()
-
validate
final VideoTransformationReadyEvent.Data.Transformation.Output validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationReadyEvent.Data.Transformation.Output.Builder builder()
Returns a mutable builder for constructing an instance of Output.
The following fields are required:
.url()
-
-
-
-