Class VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadataMetadata of the output video file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata.BuilderA builder for VideoMetadata.
-
Method Summary
Modifier and Type Method Description final Longbitrate()Bitrate of the output video in bits per second. final Doubleduration()Duration of the output video in seconds. final Longheight()Height of the output video in pixels. final Longwidth()Width of the output video in pixels. final JsonField<Long>_bitrate()Returns the raw JSON value of bitrate. final JsonField<Double>_duration()Returns the raw JSON value of duration. final JsonField<Long>_height()Returns the raw JSON value of height. final JsonField<Long>_width()Returns the raw JSON value of width. final Map<String, JsonValue>_additionalProperties()final VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata.BuildertoBuilder()final VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of VideoMetadata. -
-
Method Detail
-
_bitrate
final JsonField<Long> _bitrate()
Returns the raw JSON value of bitrate.
Unlike bitrate, this method doesn't throw if the JSON field has an unexpected type.
-
_duration
final JsonField<Double> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_height
final JsonField<Long> _height()
Returns the raw JSON value of height.
Unlike height, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<Long> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata.Builder toBuilder()
-
validate
final VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationReadyEvent.Data.Transformation.Output.VideoMetadata.Builder builder()
Returns a mutable builder for constructing an instance of VideoMetadata.
The following fields are required:
.bitrate() .duration() .height() .width()
-
-
-
-