Package io.imagekit.models.webhooks
Class VideoTransformationReadyEvent.Timings
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEvent.TimingsPerformance metrics for the transformation process.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationReadyEvent.Timings.BuilderA builder for Timings.
-
Method Summary
Modifier and Type Method Description final Optional<Long>downloadDuration()Time spent downloading the source video from your origin or media library, in milliseconds. final Optional<Long>encodingDuration()Time spent encoding the video, in milliseconds. final JsonField<Long>_downloadDuration()Returns the raw JSON value of downloadDuration. final JsonField<Long>_encodingDuration()Returns the raw JSON value of encodingDuration. final Map<String, JsonValue>_additionalProperties()final VideoTransformationReadyEvent.Timings.BuildertoBuilder()final VideoTransformationReadyEvent.Timingsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationReadyEvent.Timings.Builderbuilder()Returns a mutable builder for constructing an instance of Timings. -
-
Method Detail
-
downloadDuration
final Optional<Long> downloadDuration()
Time spent downloading the source video from your origin or media library, in milliseconds.
-
encodingDuration
final Optional<Long> encodingDuration()
Time spent encoding the video, in milliseconds.
-
_downloadDuration
final JsonField<Long> _downloadDuration()
Returns the raw JSON value of downloadDuration.
Unlike downloadDuration, this method doesn't throw if the JSON field has an unexpected type.
-
_encodingDuration
final JsonField<Long> _encodingDuration()
Returns the raw JSON value of encodingDuration.
Unlike encodingDuration, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationReadyEvent.Timings.Builder toBuilder()
-
validate
final VideoTransformationReadyEvent.Timings validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationReadyEvent.Timings.Builder builder()
Returns a mutable builder for constructing an instance of Timings.
-
-
-
-