Package io.imagekit.services.async
Interface AccountServiceAsync
-
- All Implemented Interfaces:
public interface AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountServiceAsync.WithRawResponseA view of AccountServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AccountServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract UsageServiceAsyncusage()abstract OriginServiceAsyncorigins()abstract UrlEndpointServiceAsyncurlEndpoints()-
-
Method Detail
-
withRawResponse
abstract AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
abstract UsageServiceAsync usage()
-
origins
abstract OriginServiceAsync origins()
-
urlEndpoints
abstract UrlEndpointServiceAsync urlEndpoints()
-
-
-
-