Package io.imagekit.services.async
Interface AccountServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface AccountServiceAsync.WithRawResponseA view of AccountServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AccountServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract UsageServiceAsync.WithRawResponseusage()abstract OriginServiceAsync.WithRawResponseorigins()abstract UrlEndpointServiceAsync.WithRawResponseurlEndpoints()-
-
Method Detail
-
withOptions
abstract AccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
abstract UsageServiceAsync.WithRawResponse usage()
-
origins
abstract OriginServiceAsync.WithRawResponse origins()
-
urlEndpoints
abstract UrlEndpointServiceAsync.WithRawResponse urlEndpoints()
-
-
-
-