Package io.imagekit.services.async
Class AccountServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.AccountServiceAsync
public final class AccountServiceAsyncImpl implements AccountServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UsageServiceAsyncusage()OriginServiceAsyncorigins()UrlEndpointServiceAsyncurlEndpoints()-
-
Method Detail
-
withRawResponse
AccountServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
UsageServiceAsync usage()
-
origins
OriginServiceAsync origins()
-
urlEndpoints
UrlEndpointServiceAsync urlEndpoints()
-
-
-
-