Package io.imagekit.services.async
Class AccountServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.AccountServiceAsync.WithRawResponse
public final class AccountServiceAsyncImpl.WithRawResponseImpl implements AccountServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UsageServiceAsync.WithRawResponseusage()OriginServiceAsync.WithRawResponseorigins()UrlEndpointServiceAsync.WithRawResponseurlEndpoints()-
-
Method Detail
-
withOptions
AccountServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
origins
OriginServiceAsync.WithRawResponse origins()
-
urlEndpoints
UrlEndpointServiceAsync.WithRawResponse urlEndpoints()
-
-
-
-