Package io.imagekit.services.async
Interface AssetServiceAsync
-
- All Implemented Interfaces:
public interface AssetServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAssetServiceAsync.WithRawResponseA view of AssetServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AssetServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AssetServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<List<AssetListResponse>>list()This API can list all the uploaded files and folders in your ImageKit.io media library. abstract CompletableFuture<List<AssetListResponse>>list(AssetListParams params, RequestOptions requestOptions)CompletableFuture<List<AssetListResponse>>list(AssetListParams params)CompletableFuture<List<AssetListResponse>>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AssetServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AssetServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<List<AssetListResponse>> list()
This API can list all the uploaded files and folders in your ImageKit.io media library. In addition, you can fine-tune your query by specifying various filters by generating a query string in a Lucene-like syntax and provide this generated string as the value of the
searchQuery.
-
list
abstract CompletableFuture<List<AssetListResponse>> list(AssetListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<List<AssetListResponse>> list(AssetListParams params)
-
list
CompletableFuture<List<AssetListResponse>> list(RequestOptions requestOptions)
-
-
-
-