Package io.imagekit.services.async
Interface AssetServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface AssetServiceAsync.WithRawResponseA view of AssetServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AssetServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<List<AssetListResponse>>>list()Returns a raw HTTP response for get /v1/files, but is otherwise the same as AssetServiceAsync.list.abstract CompletableFuture<HttpResponseFor<List<AssetListResponse>>>list(AssetListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<List<AssetListResponse>>>list(AssetListParams params)CompletableFuture<HttpResponseFor<List<AssetListResponse>>>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract AssetServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<List<AssetListResponse>>> list()
Returns a raw HTTP response for
get /v1/files, but is otherwise the same as AssetServiceAsync.list.
-
list
abstract CompletableFuture<HttpResponseFor<List<AssetListResponse>>> list(AssetListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<List<AssetListResponse>>> list(AssetListParams params)
-
list
CompletableFuture<HttpResponseFor<List<AssetListResponse>>> list(RequestOptions requestOptions)
-
-
-
-