Package io.imagekit.services.async
Class AssetServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.AssetServiceAsync
public final class AssetServiceAsyncImpl implements AssetServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAssetServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AssetServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AssetServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<List<AssetListResponse>>list(AssetListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AssetServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AssetServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<List<AssetListResponse>> list(AssetListParams params, RequestOptions requestOptions)
-
-
-
-