Package io.imagekit.services.async
Class AssetServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.AssetServiceAsync.WithRawResponse
public final class AssetServiceAsyncImpl.WithRawResponseImpl implements AssetServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AssetServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<List<AssetListResponse>>>list(AssetListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
AssetServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<HttpResponseFor<List<AssetListResponse>>> list(AssetListParams params, RequestOptions requestOptions)
-
-
-
-