Package io.imagekit.services.async
Interface CacheServiceAsync
-
- All Implemented Interfaces:
public interface CacheServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCacheServiceAsync.WithRawResponseA view of CacheServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CacheServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CacheServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract InvalidationServiceAsyncinvalidation()-
-
Method Detail
-
withRawResponse
abstract CacheServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CacheServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
abstract InvalidationServiceAsync invalidation()
-
-
-
-