Package io.imagekit.services.async
Interface CacheServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface CacheServiceAsync.WithRawResponseA view of CacheServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CacheServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract InvalidationServiceAsync.WithRawResponseinvalidation()-
-
Method Detail
-
withOptions
abstract CacheServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
abstract InvalidationServiceAsync.WithRawResponse invalidation()
-
-
-
-