Package io.imagekit.services.async
Class CacheServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.CacheServiceAsync
public final class CacheServiceAsyncImpl implements CacheServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCacheServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CacheServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CacheServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InvalidationServiceAsyncinvalidation()-
-
Method Detail
-
withRawResponse
CacheServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CacheServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
InvalidationServiceAsync invalidation()
-
-
-
-