Package io.imagekit.services.async
Class CacheServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.CacheServiceAsync.WithRawResponse
public final class CacheServiceAsyncImpl.WithRawResponseImpl implements CacheServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CacheServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InvalidationServiceAsync.WithRawResponseinvalidation()-
-
Method Detail
-
withOptions
CacheServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
InvalidationServiceAsync.WithRawResponse invalidation()
-
-
-
-