Package io.imagekit.services.async
Class CustomMetadataFieldServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.CustomMetadataFieldServiceAsync
public final class CustomMetadataFieldServiceAsyncImpl implements CustomMetadataFieldServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CustomMetadataFieldServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CustomMetadataFieldServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<CustomMetadataField>create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)CompletableFuture<CustomMetadataField>update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)CompletableFuture<List<CustomMetadataField>>list(CustomMetadataFieldListParams params, RequestOptions requestOptions)CompletableFuture<CustomMetadataFieldDeleteResponse>delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.async.CustomMetadataFieldServiceAsync
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CustomMetadataFieldServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CustomMetadataFieldServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<CustomMetadataField> create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<CustomMetadataField> update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<List<CustomMetadataField>> list(CustomMetadataFieldListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<CustomMetadataFieldDeleteResponse> delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)
-
-
-
-