Package io.imagekit.services.async
Class CustomMetadataFieldServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.CustomMetadataFieldServiceAsync.WithRawResponse
public final class CustomMetadataFieldServiceAsyncImpl.WithRawResponseImpl implements CustomMetadataFieldServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CustomMetadataFieldServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<CustomMetadataField>>create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CustomMetadataField>>update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<List<CustomMetadataField>>>list(CustomMetadataFieldListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<CustomMetadataFieldDeleteResponse>>delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.async.CustomMetadataFieldServiceAsync.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CustomMetadataFieldServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<CustomMetadataField>> create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<CustomMetadataField>> update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<List<CustomMetadataField>>> list(CustomMetadataFieldListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponseFor<CustomMetadataFieldDeleteResponse>> delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)
-
-
-
-