Package io.imagekit.services.async
Class FileServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.FileServiceAsync
public final class FileServiceAsyncImpl implements FileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class io.imagekit.services.async.FileServiceAsync
copy, delete, delete, delete, delete, delete, get, get, get, get, get, move, rename, update, update, update, upload -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
bulk
BulkServiceAsync bulk()
-
versions
VersionServiceAsync versions()
-
metadata
MetadataServiceAsync metadata()
-
update
CompletableFuture<FileUpdateResponse> update(FileUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(FileDeleteParams params, RequestOptions requestOptions)
-
copy
CompletableFuture<FileCopyResponse> copy(FileCopyParams params, RequestOptions requestOptions)
-
get
CompletableFuture<File> get(FileGetParams params, RequestOptions requestOptions)
-
move
CompletableFuture<FileMoveResponse> move(FileMoveParams params, RequestOptions requestOptions)
-
rename
CompletableFuture<FileRenameResponse> rename(FileRenameParams params, RequestOptions requestOptions)
-
upload
CompletableFuture<FileUploadResponse> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-