Package io.imagekit.services.async
Class FileServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.FileServiceAsync.WithRawResponse
public final class FileServiceAsyncImpl.WithRawResponseImpl implements FileServiceAsync.WithRawResponse
-
-
Method Summary
-
Methods inherited from class io.imagekit.services.async.FileServiceAsync.WithRawResponse
copy, delete, delete, delete, delete, delete, get, get, get, get, get, move, rename, update, update, update, upload -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
FileServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
versions
VersionServiceAsync.WithRawResponse versions()
-
metadata
MetadataServiceAsync.WithRawResponse metadata()
-
update
CompletableFuture<HttpResponseFor<FileUpdateResponse>> update(FileUpdateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(FileDeleteParams params, RequestOptions requestOptions)
-
copy
CompletableFuture<HttpResponseFor<FileCopyResponse>> copy(FileCopyParams params, RequestOptions requestOptions)
-
get
CompletableFuture<HttpResponseFor<File>> get(FileGetParams params, RequestOptions requestOptions)
-
move
CompletableFuture<HttpResponseFor<FileMoveResponse>> move(FileMoveParams params, RequestOptions requestOptions)
-
rename
CompletableFuture<HttpResponseFor<FileRenameResponse>> rename(FileRenameParams params, RequestOptions requestOptions)
-
upload
CompletableFuture<HttpResponseFor<FileUploadResponse>> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-