Interface FolderServiceAsync
-
- All Implemented Interfaces:
public interface FolderServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFolderServiceAsync.WithRawResponseA view of FolderServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract FolderServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FolderServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
job
abstract JobServiceAsync job()
-
create
CompletableFuture<FolderCreateResponse> create(FolderCreateParams params)
This will create a new folder. You can specify the folder name and location of the parent folder where this new folder should be created.
-
create
abstract CompletableFuture<FolderCreateResponse> create(FolderCreateParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<FolderDeleteResponse> delete(FolderDeleteParams params)
This will delete a folder and all its contents permanently. The API returns an empty response.
-
delete
abstract CompletableFuture<FolderDeleteResponse> delete(FolderDeleteParams params, RequestOptions requestOptions)
-
copy
CompletableFuture<FolderCopyResponse> copy(FolderCopyParams params)
This will copy one folder into another. The selected folder, its nested folders, files, and their versions (in
includeVersionsis set to true) are copied in this operation. Note: If any file at the destination has the same name as the source file, then the source file and its versions will be appended to the destination file version history.
-
copy
abstract CompletableFuture<FolderCopyResponse> copy(FolderCopyParams params, RequestOptions requestOptions)
-
move
CompletableFuture<FolderMoveResponse> move(FolderMoveParams params)
This will move one folder into another. The selected folder, its nested folders, files, and their versions are moved in this operation. Note: If any file at the destination has the same name as the source file, then the source file and its versions will be appended to the destination file version history.
-
move
abstract CompletableFuture<FolderMoveResponse> move(FolderMoveParams params, RequestOptions requestOptions)
-
rename
CompletableFuture<FolderRenameResponse> rename(FolderRenameParams params)
This API allows you to rename an existing folder. The folder and all its nested assets and sub-folders will remain unchanged, but their paths will be updated to reflect the new folder name.
-
rename
abstract CompletableFuture<FolderRenameResponse> rename(FolderRenameParams params, RequestOptions requestOptions)
-
-
-
-