Interface SavedExtensionServiceAsync
-
- All Implemented Interfaces:
public interface SavedExtensionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSavedExtensionServiceAsync.WithRawResponseA view of SavedExtensionServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SavedExtensionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SavedExtensionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<SavedExtension> create(SavedExtensionCreateParams params)
This API creates a new saved extension. Saved extensions allow you to save complex extension configurations (like AI tasks) and reuse them by referencing the ID in upload or update file APIs.
Saved extension limit \ You can create a maximum of 100 saved extensions per account.
-
create
abstract CompletableFuture<SavedExtension> create(SavedExtensionCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<SavedExtension> update(String id)
This API updates an existing saved extension. You can update the name, description, or config.
-
update
CompletableFuture<SavedExtension> update(String id, SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<SavedExtension> update(String id, SavedExtensionUpdateParams params)
-
update
abstract CompletableFuture<SavedExtension> update(SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<SavedExtension> update(SavedExtensionUpdateParams params)
-
update
CompletableFuture<SavedExtension> update(String id, RequestOptions requestOptions)
-
list
CompletableFuture<List<SavedExtension>> list()
This API returns an array of all saved extensions for your account. Saved extensions allow you to save complex extension configurations and reuse them by referencing them by ID in upload or update file APIs.
-
list
abstract CompletableFuture<List<SavedExtension>> list(SavedExtensionListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<List<SavedExtension>> list(SavedExtensionListParams params)
-
list
CompletableFuture<List<SavedExtension>> list(RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id)
This API deletes a saved extension permanently.
-
delete
CompletableFuture<Void> delete(String id, SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(String id, SavedExtensionDeleteParams params)
-
delete
abstract CompletableFuture<Void> delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(SavedExtensionDeleteParams params)
-
delete
CompletableFuture<Void> delete(String id, RequestOptions requestOptions)
-
get
CompletableFuture<SavedExtension> get(String id)
This API returns details of a specific saved extension by ID.
-
get
CompletableFuture<SavedExtension> get(String id, SavedExtensionGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<SavedExtension> get(String id, SavedExtensionGetParams params)
-
get
abstract CompletableFuture<SavedExtension> get(SavedExtensionGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<SavedExtension> get(SavedExtensionGetParams params)
-
get
CompletableFuture<SavedExtension> get(String id, RequestOptions requestOptions)
-
-
-
-