Package io.imagekit.services.async
Class SavedExtensionServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.SavedExtensionServiceAsync
public final class SavedExtensionServiceAsyncImpl implements SavedExtensionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSavedExtensionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SavedExtensionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SavedExtensionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<SavedExtension>create(SavedExtensionCreateParams params, RequestOptions requestOptions)CompletableFuture<SavedExtension>update(SavedExtensionUpdateParams params, RequestOptions requestOptions)CompletableFuture<List<SavedExtension>>list(SavedExtensionListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)CompletableFuture<SavedExtension>get(SavedExtensionGetParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.async.SavedExtensionServiceAsync
create, delete, delete, delete, delete, delete, get, get, get, get, get, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SavedExtensionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SavedExtensionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<SavedExtension> create(SavedExtensionCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<SavedExtension> update(SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<List<SavedExtension>> list(SavedExtensionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
get
CompletableFuture<SavedExtension> get(SavedExtensionGetParams params, RequestOptions requestOptions)
-
-
-
-