Package io.imagekit.services.async
Class SavedExtensionServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.SavedExtensionServiceAsync.WithRawResponse
public final class SavedExtensionServiceAsyncImpl.WithRawResponseImpl implements SavedExtensionServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description SavedExtensionServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<SavedExtension>>create(SavedExtensionCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<SavedExtension>>update(SavedExtensionUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<List<SavedExtension>>>list(SavedExtensionListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<SavedExtension>>get(SavedExtensionGetParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.async.SavedExtensionServiceAsync.WithRawResponse
create, delete, delete, delete, delete, delete, get, get, get, get, get, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
SavedExtensionServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<SavedExtension>> create(SavedExtensionCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<SavedExtension>> update(SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<List<SavedExtension>>> list(SavedExtensionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
get
CompletableFuture<HttpResponseFor<SavedExtension>> get(SavedExtensionGetParams params, RequestOptions requestOptions)
-
-
-
-