Package io.imagekit.services.async
Class WebhookServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.WebhookServiceAsync
public final class WebhookServiceAsyncImpl implements WebhookServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WebhookServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WebhookServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnsafeUnwrapWebhookEventunsafeUnwrap(String body)Unwraps a webhook event from its JSON representation. UnwrapWebhookEventunwrap(String body)Unwraps a webhook event from its JSON representation. UnwrapWebhookEventunwrap(UnwrapWebhookParams unwrapParams)Unwraps a webhook event from its JSON representation. -
-
Method Detail
-
withRawResponse
WebhookServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhookServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
unsafeUnwrap
UnsafeUnwrapWebhookEvent unsafeUnwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
UnwrapWebhookEvent unwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
UnwrapWebhookEvent unwrap(UnwrapWebhookParams unwrapParams)
Unwraps a webhook event from its JSON representation.
-
-
-
-