Class OriginServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.accounts.OriginServiceAsync
public final class OriginServiceAsyncImpl implements OriginServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOriginServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description OriginServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. OriginServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<OriginResponse>create(OriginCreateParams params, RequestOptions requestOptions)CompletableFuture<OriginResponse>update(OriginUpdateParams params, RequestOptions requestOptions)CompletableFuture<List<OriginResponse>>list(OriginListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(OriginDeleteParams params, RequestOptions requestOptions)CompletableFuture<OriginResponse>get(OriginGetParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.async.accounts.OriginServiceAsync
create, create, create, create, create, create, create, create, create, create, create, create, create, create, create, create, create, create, create, delete, delete, delete, delete, delete, get, get, get, get, get, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
OriginServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
OriginServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<OriginResponse> create(OriginCreateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<OriginResponse> update(OriginUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<List<OriginResponse>> list(OriginListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(OriginDeleteParams params, RequestOptions requestOptions)
-
get
CompletableFuture<OriginResponse> get(OriginGetParams params, RequestOptions requestOptions)
-
-
-
-