Interface UsageAnalyticsServiceAsync
-
- All Implemented Interfaces:
public interface UsageAnalyticsServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceUsageAnalyticsServiceAsync.WithRawResponseA view of UsageAnalyticsServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract UsageAnalyticsServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract UsageAnalyticsServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<UsageAnalyticsResponse>get(UsageAnalyticsGetParams params)Note: This API is currently in beta. abstract CompletableFuture<UsageAnalyticsResponse>get(UsageAnalyticsGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract UsageAnalyticsServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract UsageAnalyticsServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
CompletableFuture<UsageAnalyticsResponse> get(UsageAnalyticsGetParams params)
Note: This API is currently in beta.
Get the account analytics data between two dates. The response covers the period from the start date to the end date, both dates inclusive. Both dates are interpreted as UTC calendar days.
The returned data is scoped to the requesting account only. Unlike
/v1/accounts/usage, an agency account's analytics are not aggregated across its child accounts.The response is cached for 5 minutes per account and date range. Use
generatedAtto check how fresh the returned data is.
-
get
abstract CompletableFuture<UsageAnalyticsResponse> get(UsageAnalyticsGetParams params, RequestOptions requestOptions)
-
-
-
-