Interface UsageServiceAsync
-
- All Implemented Interfaces:
public interface UsageServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceUsageServiceAsync.WithRawResponseA view of UsageServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract UsageServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract UsageServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<UsageGetResponse>get(UsageGetParams params)Get the account usage information between two dates. abstract CompletableFuture<UsageGetResponse>get(UsageGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract UsageServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract UsageServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
CompletableFuture<UsageGetResponse> get(UsageGetParams params)
Get the account usage information between two dates. Note that the API response includes data from the start date while excluding data from the end date. In other words, the data covers the period starting from the specified start date up to, but not including, the end date.
For an agency account, the returned usage is aggregated across the agency and all of its child accounts that are billed to it.
The response is cached for 6 hours per account, date range and requested metrics.
-
get
abstract CompletableFuture<UsageGetResponse> get(UsageGetParams params, RequestOptions requestOptions)
-
-
-
-