Package io.imagekit.services.async.beta
Interface V2ServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface V2ServiceAsync.WithRawResponseA view of V2ServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V2ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract FileServiceAsync.WithRawResponsefiles()-
-
Method Detail
-
withOptions
abstract V2ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
abstract FileServiceAsync.WithRawResponse files()
-
-
-
-