Package io.imagekit.services.async.beta
Class V2ServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.beta.V2ServiceAsync
public final class V2ServiceAsyncImpl implements V2ServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classV2ServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description V2ServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. V2ServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileServiceAsyncfiles()-
-
Method Detail
-
withRawResponse
V2ServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
V2ServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
FileServiceAsync files()
-
-
-
-