Package io.imagekit.services.async.beta
Class V2ServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.beta.V2ServiceAsync.WithRawResponse
public final class V2ServiceAsyncImpl.WithRawResponseImpl implements V2ServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V2ServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileServiceAsync.WithRawResponsefiles()-
-
Method Detail
-
withOptions
V2ServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
-
-
-