Interface FileServiceAsync.WithRawResponse
-
- All Implemented Interfaces:
public interface FileServiceAsync.WithRawResponseA view of FileServiceAsync that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract FileServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<FileUploadResponse>>upload(FileUploadParams params)Returns a raw HTTP response for post /api/v2/files/upload, but is otherwise the same as FileServiceAsync.upload.abstract CompletableFuture<HttpResponseFor<FileUploadResponse>>upload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract FileServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
CompletableFuture<HttpResponseFor<FileUploadResponse>> upload(FileUploadParams params)
Returns a raw HTTP response for
post /api/v2/files/upload, but is otherwise the same as FileServiceAsync.upload.
-
upload
abstract CompletableFuture<HttpResponseFor<FileUploadResponse>> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-