Class FileServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.beta.v2.FileServiceAsync
public final class FileServiceAsyncImpl implements FileServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<FileUploadResponse>upload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
CompletableFuture<FileUploadResponse> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-