Class FileServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.beta.v2.FileServiceAsync.WithRawResponse
public final class FileServiceAsyncImpl.WithRawResponseImpl implements FileServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FileServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<FileUploadResponse>>upload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
FileServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
CompletableFuture<HttpResponseFor<FileUploadResponse>> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-