Package io.imagekit.services.async.cache
Interface InvalidationServiceAsync
-
- All Implemented Interfaces:
public interface InvalidationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInvalidationServiceAsync.WithRawResponseA view of InvalidationServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract InvalidationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InvalidationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InvalidationCreateResponse> create(InvalidationCreateParams params)
This API will purge CDN cache and ImageKit.io's internal cache for a file. Note: Purge cache is an asynchronous process and it may take some time to reflect the changes.
-
create
abstract CompletableFuture<InvalidationCreateResponse> create(InvalidationCreateParams params, RequestOptions requestOptions)
-
get
CompletableFuture<InvalidationGetResponse> get(String requestId)
This API returns the status of a purge cache request.
-
get
CompletableFuture<InvalidationGetResponse> get(String requestId, InvalidationGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<InvalidationGetResponse> get(String requestId, InvalidationGetParams params)
-
get
abstract CompletableFuture<InvalidationGetResponse> get(InvalidationGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<InvalidationGetResponse> get(InvalidationGetParams params)
-
get
CompletableFuture<InvalidationGetResponse> get(String requestId, RequestOptions requestOptions)
-
-
-
-