Package io.imagekit.services.async.cache
Class InvalidationServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.cache.InvalidationServiceAsync
public final class InvalidationServiceAsyncImpl implements InvalidationServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInvalidationServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InvalidationServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InvalidationServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<InvalidationCreateResponse>create(InvalidationCreateParams params, RequestOptions requestOptions)CompletableFuture<InvalidationGetResponse>get(InvalidationGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InvalidationServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InvalidationServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<InvalidationCreateResponse> create(InvalidationCreateParams params, RequestOptions requestOptions)
-
get
CompletableFuture<InvalidationGetResponse> get(InvalidationGetParams params, RequestOptions requestOptions)
-
-
-
-