Package io.imagekit.services.async.cache
Class InvalidationServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.cache.InvalidationServiceAsync.WithRawResponse
public final class InvalidationServiceAsyncImpl.WithRawResponseImpl implements InvalidationServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description InvalidationServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<InvalidationCreateResponse>>create(InvalidationCreateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<InvalidationGetResponse>>get(InvalidationGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
InvalidationServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<HttpResponseFor<InvalidationCreateResponse>> create(InvalidationCreateParams params, RequestOptions requestOptions)
-
get
CompletableFuture<HttpResponseFor<InvalidationGetResponse>> get(InvalidationGetParams params, RequestOptions requestOptions)
-
-
-
-