Interface BulkServiceAsync
-
- All Implemented Interfaces:
public interface BulkServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBulkServiceAsync.WithRawResponseA view of BulkServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract BulkServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BulkServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
delete
CompletableFuture<BulkDeleteResponse> delete(BulkDeleteParams params)
This API deletes multiple files and all their file versions permanently.
Note: If a file or specific transformation has been requested in the past, then the response is cached. Deleting a file does not purge the cache. You can purge the cache using purge cache API.
A maximum of 100 files can be deleted at a time.
-
delete
abstract CompletableFuture<BulkDeleteResponse> delete(BulkDeleteParams params, RequestOptions requestOptions)
-
addTags
CompletableFuture<BulkAddTagsResponse> addTags(BulkAddTagsParams params)
This API adds tags to multiple files in bulk. A maximum of 50 files can be specified at a time.
-
addTags
abstract CompletableFuture<BulkAddTagsResponse> addTags(BulkAddTagsParams params, RequestOptions requestOptions)
-
removeAiTags
CompletableFuture<BulkRemoveAiTagsResponse> removeAiTags(BulkRemoveAiTagsParams params)
This API removes AITags from multiple files in bulk. A maximum of 50 files can be specified at a time.
-
removeAiTags
abstract CompletableFuture<BulkRemoveAiTagsResponse> removeAiTags(BulkRemoveAiTagsParams params, RequestOptions requestOptions)
-
removeTags
CompletableFuture<BulkRemoveTagsResponse> removeTags(BulkRemoveTagsParams params)
This API removes tags from multiple files in bulk. A maximum of 50 files can be specified at a time.
-
removeTags
abstract CompletableFuture<BulkRemoveTagsResponse> removeTags(BulkRemoveTagsParams params, RequestOptions requestOptions)
-
-
-
-