Package io.imagekit.services.async.files
Class BulkServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.files.BulkServiceAsync
public final class BulkServiceAsyncImpl implements BulkServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBulkServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description BulkServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. BulkServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<BulkDeleteResponse>delete(BulkDeleteParams params, RequestOptions requestOptions)CompletableFuture<BulkAddTagsResponse>addTags(BulkAddTagsParams params, RequestOptions requestOptions)CompletableFuture<BulkRemoveAiTagsResponse>removeAiTags(BulkRemoveAiTagsParams params, RequestOptions requestOptions)CompletableFuture<BulkRemoveTagsResponse>removeTags(BulkRemoveTagsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
BulkServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
BulkServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
delete
CompletableFuture<BulkDeleteResponse> delete(BulkDeleteParams params, RequestOptions requestOptions)
-
addTags
CompletableFuture<BulkAddTagsResponse> addTags(BulkAddTagsParams params, RequestOptions requestOptions)
-
removeAiTags
CompletableFuture<BulkRemoveAiTagsResponse> removeAiTags(BulkRemoveAiTagsParams params, RequestOptions requestOptions)
-
removeTags
CompletableFuture<BulkRemoveTagsResponse> removeTags(BulkRemoveTagsParams params, RequestOptions requestOptions)
-
-
-
-