Package io.imagekit.services.async.files
Interface MetadataServiceAsync
-
- All Implemented Interfaces:
public interface MetadataServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMetadataServiceAsync.WithRawResponseA view of MetadataServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MetadataServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MetadataServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Metadata>get(String fileId)You can programmatically get image EXIF, pHash, and other metadata for uploaded files in the ImageKit.io media library using this API. CompletableFuture<Metadata>get(String fileId, MetadataGetParams params, RequestOptions requestOptions)CompletableFuture<Metadata>get(String fileId, MetadataGetParams params)abstract CompletableFuture<Metadata>get(MetadataGetParams params, RequestOptions requestOptions)CompletableFuture<Metadata>get(MetadataGetParams params)CompletableFuture<Metadata>get(String fileId, RequestOptions requestOptions)CompletableFuture<Metadata>getFromUrl(MetadataGetFromUrlParams params)Get image EXIF, pHash, and other metadata from ImageKit.io powered remote URL using this API. abstract CompletableFuture<Metadata>getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MetadataServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MetadataServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
CompletableFuture<Metadata> get(String fileId)
You can programmatically get image EXIF, pHash, and other metadata for uploaded files in the ImageKit.io media library using this API.
You can also get the metadata in upload API response by passing
metadatainresponseFieldsparameter.
-
get
CompletableFuture<Metadata> get(String fileId, MetadataGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<Metadata> get(String fileId, MetadataGetParams params)
-
get
abstract CompletableFuture<Metadata> get(MetadataGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<Metadata> get(MetadataGetParams params)
-
get
CompletableFuture<Metadata> get(String fileId, RequestOptions requestOptions)
-
getFromUrl
CompletableFuture<Metadata> getFromUrl(MetadataGetFromUrlParams params)
Get image EXIF, pHash, and other metadata from ImageKit.io powered remote URL using this API.
-
getFromUrl
abstract CompletableFuture<Metadata> getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)
-
-
-
-