Package io.imagekit.services.async.files
Class MetadataServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.files.MetadataServiceAsync
public final class MetadataServiceAsyncImpl implements MetadataServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadataServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MetadataServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MetadataServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<Metadata>get(MetadataGetParams params, RequestOptions requestOptions)CompletableFuture<Metadata>getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MetadataServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MetadataServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
CompletableFuture<Metadata> get(MetadataGetParams params, RequestOptions requestOptions)
-
getFromUrl
CompletableFuture<Metadata> getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)
-
-
-
-