Package io.imagekit.services.async.files
Class MetadataServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.files.MetadataServiceAsync.WithRawResponse
public final class MetadataServiceAsyncImpl.WithRawResponseImpl implements MetadataServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description MetadataServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<Metadata>>get(MetadataGetParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<Metadata>>getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
MetadataServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
CompletableFuture<HttpResponseFor<Metadata>> get(MetadataGetParams params, RequestOptions requestOptions)
-
getFromUrl
CompletableFuture<HttpResponseFor<Metadata>> getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)
-
-
-
-