Package io.imagekit.services.async.files
Class VersionServiceAsyncImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.async.files.VersionServiceAsync
public final class VersionServiceAsyncImpl implements VersionServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVersionServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description VersionServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. VersionServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<List<File>>list(VersionListParams params, RequestOptions requestOptions)CompletableFuture<VersionDeleteResponse>delete(VersionDeleteParams params, RequestOptions requestOptions)CompletableFuture<File>get(VersionGetParams params, RequestOptions requestOptions)CompletableFuture<File>restore(VersionRestoreParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.async.files.VersionServiceAsync
delete, delete, delete, get, get, get, list, list, list, list, list, restore, restore, restore -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
VersionServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VersionServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
CompletableFuture<List<File>> list(VersionListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<VersionDeleteResponse> delete(VersionDeleteParams params, RequestOptions requestOptions)
-
get
CompletableFuture<File> get(VersionGetParams params, RequestOptions requestOptions)
-
restore
CompletableFuture<File> restore(VersionRestoreParams params, RequestOptions requestOptions)
-
-
-
-