Interface JobServiceAsync
-
- All Implemented Interfaces:
public interface JobServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceJobServiceAsync.WithRawResponseA view of JobServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract JobServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract JobServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<JobGetResponse>get(String jobId)This API returns the status of a bulk job like copy and move folder operations. CompletableFuture<JobGetResponse>get(String jobId, JobGetParams params, RequestOptions requestOptions)CompletableFuture<JobGetResponse>get(String jobId, JobGetParams params)abstract CompletableFuture<JobGetResponse>get(JobGetParams params, RequestOptions requestOptions)CompletableFuture<JobGetResponse>get(JobGetParams params)CompletableFuture<JobGetResponse>get(String jobId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract JobServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract JobServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
CompletableFuture<JobGetResponse> get(String jobId)
This API returns the status of a bulk job like copy and move folder operations.
-
get
CompletableFuture<JobGetResponse> get(String jobId, JobGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<JobGetResponse> get(String jobId, JobGetParams params)
-
get
abstract CompletableFuture<JobGetResponse> get(JobGetParams params, RequestOptions requestOptions)
-
get
CompletableFuture<JobGetResponse> get(JobGetParams params)
-
get
CompletableFuture<JobGetResponse> get(String jobId, RequestOptions requestOptions)
-
-
-
-