Package io.imagekit.services.blocking
Interface AccountService
-
- All Implemented Interfaces:
public interface AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAccountService.WithRawResponseA view of AccountService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AccountServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract UsageServiceusage()abstract OriginServiceorigins()abstract UrlEndpointServiceurlEndpoints()-
-
Method Detail
-
withRawResponse
abstract AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
abstract UsageService usage()
-
origins
abstract OriginService origins()
-
urlEndpoints
abstract UrlEndpointService urlEndpoints()
-
-
-
-