Package io.imagekit.services.blocking
Interface AccountService.WithRawResponse
-
- All Implemented Interfaces:
public interface AccountService.WithRawResponseA view of AccountService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AccountService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract UsageService.WithRawResponseusage()abstract OriginService.WithRawResponseorigins()abstract UrlEndpointService.WithRawResponseurlEndpoints()-
-
Method Detail
-
withOptions
abstract AccountService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
abstract UsageService.WithRawResponse usage()
-
origins
abstract OriginService.WithRawResponse origins()
-
urlEndpoints
abstract UrlEndpointService.WithRawResponse urlEndpoints()
-
-
-
-