Package io.imagekit.services.blocking
Class AccountServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.AccountService
public final class AccountServiceImpl implements AccountService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAccountServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AccountServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UsageServiceusage()OriginServiceorigins()UrlEndpointServiceurlEndpoints()-
-
Method Detail
-
withRawResponse
AccountService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AccountService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
UsageService usage()
-
origins
OriginService origins()
-
urlEndpoints
UrlEndpointService urlEndpoints()
-
-
-
-