Package io.imagekit.services.blocking
Class AccountServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.AccountService.WithRawResponse
public final class AccountServiceImpl.WithRawResponseImpl implements AccountService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AccountService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UsageService.WithRawResponseusage()OriginService.WithRawResponseorigins()UrlEndpointService.WithRawResponseurlEndpoints()-
-
Method Detail
-
withOptions
AccountService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
usage
UsageService.WithRawResponse usage()
-
origins
OriginService.WithRawResponse origins()
-
urlEndpoints
UrlEndpointService.WithRawResponse urlEndpoints()
-
-
-
-