Package io.imagekit.services.blocking
Interface AssetService
-
- All Implemented Interfaces:
public interface AssetService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAssetService.WithRawResponseA view of AssetService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AssetService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AssetServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. List<AssetListResponse>list()This API can list all the uploaded files and folders in your ImageKit.io media library. abstract List<AssetListResponse>list(AssetListParams params, RequestOptions requestOptions)List<AssetListResponse>list(AssetListParams params)List<AssetListResponse>list(RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract AssetService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AssetService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
List<AssetListResponse> list()
This API can list all the uploaded files and folders in your ImageKit.io media library. In addition, you can fine-tune your query by specifying various filters by generating a query string in a Lucene-like syntax and provide this generated string as the value of the
searchQuery.
-
list
abstract List<AssetListResponse> list(AssetListParams params, RequestOptions requestOptions)
-
list
List<AssetListResponse> list(AssetListParams params)
-
list
List<AssetListResponse> list(RequestOptions requestOptions)
-
-
-
-