Package io.imagekit.services.blocking
Interface AssetService.WithRawResponse
-
- All Implemented Interfaces:
public interface AssetService.WithRawResponseA view of AssetService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract AssetService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<List<AssetListResponse>>list()Returns a raw HTTP response for get /v1/files, but is otherwise the same as AssetService.list.abstract HttpResponseFor<List<AssetListResponse>>list(AssetListParams params, RequestOptions requestOptions)HttpResponseFor<List<AssetListResponse>>list(AssetListParams params)HttpResponseFor<List<AssetListResponse>>list(RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract AssetService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
@MustBeClosed() HttpResponseFor<List<AssetListResponse>> list()
Returns a raw HTTP response for
get /v1/files, but is otherwise the same as AssetService.list.
-
list
@MustBeClosed() abstract HttpResponseFor<List<AssetListResponse>> list(AssetListParams params, RequestOptions requestOptions)
-
list
@MustBeClosed() HttpResponseFor<List<AssetListResponse>> list(AssetListParams params)
-
list
@MustBeClosed() HttpResponseFor<List<AssetListResponse>> list(RequestOptions requestOptions)
-
-
-
-