Package io.imagekit.services.blocking
Class AssetServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.AssetService
public final class AssetServiceImpl implements AssetService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAssetServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AssetService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AssetServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. List<AssetListResponse>list(AssetListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
AssetService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AssetService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
List<AssetListResponse> list(AssetListParams params, RequestOptions requestOptions)
-
-
-
-