Package io.imagekit.services.blocking
Class AssetServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.AssetService.WithRawResponse
public final class AssetServiceImpl.WithRawResponseImpl implements AssetService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description AssetService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<List<AssetListResponse>>list(AssetListParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
AssetService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
HttpResponseFor<List<AssetListResponse>> list(AssetListParams params, RequestOptions requestOptions)
-
-
-
-