Package io.imagekit.services.blocking
Interface CacheService
-
- All Implemented Interfaces:
public interface CacheService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCacheService.WithRawResponseA view of CacheService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract CacheService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract CacheServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract InvalidationServiceinvalidation()-
-
Method Detail
-
withRawResponse
abstract CacheService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CacheService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
abstract InvalidationService invalidation()
-
-
-
-