Package io.imagekit.services.blocking
Interface CacheService.WithRawResponse
-
- All Implemented Interfaces:
public interface CacheService.WithRawResponseA view of CacheService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract CacheService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract InvalidationService.WithRawResponseinvalidation()-
-
Method Detail
-
withOptions
abstract CacheService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
abstract InvalidationService.WithRawResponse invalidation()
-
-
-
-