Package io.imagekit.services.blocking
Class CacheServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.CacheService
public final class CacheServiceImpl implements CacheService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCacheServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CacheService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CacheServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InvalidationServiceinvalidation()-
-
Method Detail
-
withRawResponse
CacheService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CacheService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
InvalidationService invalidation()
-
-
-
-