Package io.imagekit.services.blocking
Class CacheServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.CacheService.WithRawResponse
public final class CacheServiceImpl.WithRawResponseImpl implements CacheService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CacheService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InvalidationService.WithRawResponseinvalidation()-
-
Method Detail
-
withOptions
CacheService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
invalidation
InvalidationService.WithRawResponse invalidation()
-
-
-
-