Interface CustomMetadataFieldService
-
- All Implemented Interfaces:
public interface CustomMetadataFieldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataFieldService.WithRawResponseA view of CustomMetadataFieldService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract CustomMetadataFieldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract CustomMetadataFieldService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CustomMetadataField create(CustomMetadataFieldCreateParams params)
This API creates a new custom metadata field. Once a custom metadata field is created either through this API or using the dashboard UI, its value can be set on the assets. The value of a field for an asset can be set using the media library UI or programmatically through upload or update assets API.
-
create
abstract CustomMetadataField create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)
-
update
CustomMetadataField update(String id)
This API updates the label or schema of an existing custom metadata field.
-
update
CustomMetadataField update(String id, CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)
-
update
CustomMetadataField update(String id, CustomMetadataFieldUpdateParams params)
-
update
abstract CustomMetadataField update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)
-
update
CustomMetadataField update(CustomMetadataFieldUpdateParams params)
-
update
CustomMetadataField update(String id, RequestOptions requestOptions)
-
list
List<CustomMetadataField> list()
This API returns the array of created custom metadata field objects. By default the API returns only non deleted field objects, but you can include deleted fields in the API response.
You can also filter results by a specific folder path to retrieve custom metadata fields applicable at that location. This path-specific filtering is useful when using the Path policy feature to determine which custom metadata fields are selected for a given path.
-
list
abstract List<CustomMetadataField> list(CustomMetadataFieldListParams params, RequestOptions requestOptions)
-
list
List<CustomMetadataField> list(CustomMetadataFieldListParams params)
-
list
List<CustomMetadataField> list(RequestOptions requestOptions)
-
delete
CustomMetadataFieldDeleteResponse delete(String id)
This API deletes a custom metadata field. Even after deleting a custom metadata field, you cannot create any new custom metadata field with the same name.
-
delete
CustomMetadataFieldDeleteResponse delete(String id, CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)
-
delete
CustomMetadataFieldDeleteResponse delete(String id, CustomMetadataFieldDeleteParams params)
-
delete
abstract CustomMetadataFieldDeleteResponse delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)
-
delete
CustomMetadataFieldDeleteResponse delete(String id, RequestOptions requestOptions)
-
-
-
-