Package io.imagekit.services.blocking
Class CustomMetadataFieldServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.CustomMetadataFieldService
public final class CustomMetadataFieldServiceImpl implements CustomMetadataFieldService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description CustomMetadataFieldService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. CustomMetadataFieldServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CustomMetadataFieldcreate(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)CustomMetadataFieldupdate(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)List<CustomMetadataField>list(CustomMetadataFieldListParams params, RequestOptions requestOptions)CustomMetadataFieldDeleteResponsedelete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.blocking.CustomMetadataFieldService
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
CustomMetadataFieldService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
CustomMetadataFieldService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CustomMetadataField create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)
-
update
CustomMetadataField update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)
-
list
List<CustomMetadataField> list(CustomMetadataFieldListParams params, RequestOptions requestOptions)
-
delete
CustomMetadataFieldDeleteResponse delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)
-
-
-
-