Package io.imagekit.services.blocking
Class CustomMetadataFieldServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.CustomMetadataFieldService.WithRawResponse
public final class CustomMetadataFieldServiceImpl.WithRawResponseImpl implements CustomMetadataFieldService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description CustomMetadataFieldService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<CustomMetadataField>create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)HttpResponseFor<CustomMetadataField>update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)HttpResponseFor<List<CustomMetadataField>>list(CustomMetadataFieldListParams params, RequestOptions requestOptions)HttpResponseFor<CustomMetadataFieldDeleteResponse>delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.blocking.CustomMetadataFieldService.WithRawResponse
create, delete, delete, delete, delete, delete, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
CustomMetadataFieldService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
HttpResponseFor<CustomMetadataField> create(CustomMetadataFieldCreateParams params, RequestOptions requestOptions)
-
update
HttpResponseFor<CustomMetadataField> update(CustomMetadataFieldUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<List<CustomMetadataField>> list(CustomMetadataFieldListParams params, RequestOptions requestOptions)
-
delete
HttpResponseFor<CustomMetadataFieldDeleteResponse> delete(CustomMetadataFieldDeleteParams params, RequestOptions requestOptions)
-
-
-
-