Interface FolderService
-
- All Implemented Interfaces:
public interface FolderService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFolderService.WithRawResponseA view of FolderService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FolderService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FolderServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract JobServicejob()FolderCreateResponsecreate(FolderCreateParams params)This will create a new folder. abstract FolderCreateResponsecreate(FolderCreateParams params, RequestOptions requestOptions)FolderDeleteResponsedelete(FolderDeleteParams params)This will delete a folder and all its contents permanently. abstract FolderDeleteResponsedelete(FolderDeleteParams params, RequestOptions requestOptions)FolderCopyResponsecopy(FolderCopyParams params)This will copy one folder into another. abstract FolderCopyResponsecopy(FolderCopyParams params, RequestOptions requestOptions)FolderMoveResponsemove(FolderMoveParams params)This will move one folder into another. abstract FolderMoveResponsemove(FolderMoveParams params, RequestOptions requestOptions)FolderRenameResponserename(FolderRenameParams params)This API allows you to rename an existing folder. abstract FolderRenameResponserename(FolderRenameParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FolderService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FolderService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
job
abstract JobService job()
-
create
FolderCreateResponse create(FolderCreateParams params)
This will create a new folder. You can specify the folder name and location of the parent folder where this new folder should be created.
-
create
abstract FolderCreateResponse create(FolderCreateParams params, RequestOptions requestOptions)
-
delete
FolderDeleteResponse delete(FolderDeleteParams params)
This will delete a folder and all its contents permanently. The API returns an empty response.
-
delete
abstract FolderDeleteResponse delete(FolderDeleteParams params, RequestOptions requestOptions)
-
copy
FolderCopyResponse copy(FolderCopyParams params)
This will copy one folder into another. The selected folder, its nested folders, files, and their versions (in
includeVersionsis set to true) are copied in this operation. Note: If any file at the destination has the same name as the source file, then the source file and its versions will be appended to the destination file version history.
-
copy
abstract FolderCopyResponse copy(FolderCopyParams params, RequestOptions requestOptions)
-
move
FolderMoveResponse move(FolderMoveParams params)
This will move one folder into another. The selected folder, its nested folders, files, and their versions are moved in this operation. Note: If any file at the destination has the same name as the source file, then the source file and its versions will be appended to the destination file version history.
-
move
abstract FolderMoveResponse move(FolderMoveParams params, RequestOptions requestOptions)
-
rename
FolderRenameResponse rename(FolderRenameParams params)
This API allows you to rename an existing folder. The folder and all its nested assets and sub-folders will remain unchanged, but their paths will be updated to reflect the new folder name.
-
rename
abstract FolderRenameResponse rename(FolderRenameParams params, RequestOptions requestOptions)
-
-
-
-