Interface SavedExtensionService
-
- All Implemented Interfaces:
public interface SavedExtensionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSavedExtensionService.WithRawResponseA view of SavedExtensionService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract SavedExtensionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SavedExtensionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
SavedExtension create(SavedExtensionCreateParams params)
This API creates a new saved extension. Saved extensions allow you to save complex extension configurations (like AI tasks) and reuse them by referencing the ID in upload or update file APIs.
Saved extension limit \ You can create a maximum of 100 saved extensions per account.
-
create
abstract SavedExtension create(SavedExtensionCreateParams params, RequestOptions requestOptions)
-
update
SavedExtension update(String id)
This API updates an existing saved extension. You can update the name, description, or config.
-
update
SavedExtension update(String id, SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
update
SavedExtension update(String id, SavedExtensionUpdateParams params)
-
update
abstract SavedExtension update(SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
update
SavedExtension update(SavedExtensionUpdateParams params)
-
update
SavedExtension update(String id, RequestOptions requestOptions)
-
list
List<SavedExtension> list()
This API returns an array of all saved extensions for your account. Saved extensions allow you to save complex extension configurations and reuse them by referencing them by ID in upload or update file APIs.
-
list
abstract List<SavedExtension> list(SavedExtensionListParams params, RequestOptions requestOptions)
-
list
List<SavedExtension> list(SavedExtensionListParams params)
-
list
List<SavedExtension> list(RequestOptions requestOptions)
-
delete
Unit delete(String id, SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String id, SavedExtensionDeleteParams params)
-
delete
abstract Unit delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(SavedExtensionDeleteParams params)
-
delete
Unit delete(String id, RequestOptions requestOptions)
-
get
SavedExtension get(String id)
This API returns details of a specific saved extension by ID.
-
get
SavedExtension get(String id, SavedExtensionGetParams params, RequestOptions requestOptions)
-
get
SavedExtension get(String id, SavedExtensionGetParams params)
-
get
abstract SavedExtension get(SavedExtensionGetParams params, RequestOptions requestOptions)
-
get
SavedExtension get(SavedExtensionGetParams params)
-
get
SavedExtension get(String id, RequestOptions requestOptions)
-
-
-
-