Package io.imagekit.services.blocking
Class SavedExtensionServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.SavedExtensionService
public final class SavedExtensionServiceImpl implements SavedExtensionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSavedExtensionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description SavedExtensionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. SavedExtensionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. SavedExtensioncreate(SavedExtensionCreateParams params, RequestOptions requestOptions)SavedExtensionupdate(SavedExtensionUpdateParams params, RequestOptions requestOptions)List<SavedExtension>list(SavedExtensionListParams params, RequestOptions requestOptions)Unitdelete(SavedExtensionDeleteParams params, RequestOptions requestOptions)SavedExtensionget(SavedExtensionGetParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.blocking.SavedExtensionService
create, delete, delete, delete, delete, delete, get, get, get, get, get, list, list, list, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
SavedExtensionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
SavedExtensionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
SavedExtension create(SavedExtensionCreateParams params, RequestOptions requestOptions)
-
update
SavedExtension update(SavedExtensionUpdateParams params, RequestOptions requestOptions)
-
list
List<SavedExtension> list(SavedExtensionListParams params, RequestOptions requestOptions)
-
delete
Unit delete(SavedExtensionDeleteParams params, RequestOptions requestOptions)
-
get
SavedExtension get(SavedExtensionGetParams params, RequestOptions requestOptions)
-
-
-
-