Package io.imagekit.services.blocking
Class WebhookServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.WebhookService
public final class WebhookServiceImpl implements WebhookService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWebhookServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description WebhookService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. WebhookServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UnsafeUnwrapWebhookEventunsafeUnwrap(String body)Unwraps a webhook event from its JSON representation. UnwrapWebhookEventunwrap(String body)Unwraps a webhook event from its JSON representation. UnwrapWebhookEventunwrap(UnwrapWebhookParams unwrapParams)Unwraps a webhook event from its JSON representation. -
-
Method Detail
-
withRawResponse
WebhookService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
WebhookService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
unsafeUnwrap
UnsafeUnwrapWebhookEvent unsafeUnwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
UnwrapWebhookEvent unwrap(String body)
Unwraps a webhook event from its JSON representation.
-
unwrap
UnwrapWebhookEvent unwrap(UnwrapWebhookParams unwrapParams)
Unwraps a webhook event from its JSON representation.
-
-
-
-