Interface OriginService
-
- All Implemented Interfaces:
public interface OriginService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOriginService.WithRawResponseA view of OriginService that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract OriginService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract OriginService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
OriginResponse create(OriginCreateParams params)
Note: This API is currently in beta. Creates a new origin and returns the origin object.
-
create
abstract OriginResponse create(OriginCreateParams params, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest originRequest, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest originRequest)
-
create
OriginResponse create(OriginRequest.S3 s3, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.S3 s3)
-
create
OriginResponse create(OriginRequest.S3Compatible s3Compatible, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.S3Compatible s3Compatible)
-
create
OriginResponse create(OriginRequest.CloudinaryBackup cloudinaryBackup, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.CloudinaryBackup cloudinaryBackup)
-
create
OriginResponse create(OriginRequest.WebFolder webFolder, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.WebFolder webFolder)
-
create
OriginResponse create(OriginRequest.WebProxy webProxy, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.WebProxy webProxy)
-
create
OriginResponse create(OriginRequest.Gcs gcs, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.Gcs gcs)
-
create
OriginResponse create(OriginRequest.AzureBlob azureBlob, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.AzureBlob azureBlob)
-
create
OriginResponse create(OriginRequest.AkeneoPim akeneoPim, RequestOptions requestOptions)
-
create
OriginResponse create(OriginRequest.AkeneoPim akeneoPim)
-
update
OriginResponse update(String id, OriginUpdateParams params)
Note: This API is currently in beta. Updates the origin identified by
idand returns the updated origin object.
-
update
OriginResponse update(String id, OriginUpdateParams params, RequestOptions requestOptions)
-
update
OriginResponse update(OriginUpdateParams params)
-
update
abstract OriginResponse update(OriginUpdateParams params, RequestOptions requestOptions)
-
list
List<OriginResponse> list()
Note: This API is currently in beta. Returns an array of all configured origins for the current account.
-
list
abstract List<OriginResponse> list(OriginListParams params, RequestOptions requestOptions)
-
list
List<OriginResponse> list(OriginListParams params)
-
list
List<OriginResponse> list(RequestOptions requestOptions)
-
delete
Unit delete(String id)
Note: This API is currently in beta. Permanently removes the origin identified by
id. If the origin is in use by any URL‑endpoints, the API will return an error.
-
delete
Unit delete(String id, OriginDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(String id, OriginDeleteParams params)
-
delete
abstract Unit delete(OriginDeleteParams params, RequestOptions requestOptions)
-
delete
Unit delete(OriginDeleteParams params)
-
delete
Unit delete(String id, RequestOptions requestOptions)
-
get
OriginResponse get(String id)
Note: This API is currently in beta. Retrieves the origin identified by
id.
-
get
OriginResponse get(String id, OriginGetParams params, RequestOptions requestOptions)
-
get
OriginResponse get(String id, OriginGetParams params)
-
get
abstract OriginResponse get(OriginGetParams params, RequestOptions requestOptions)
-
get
OriginResponse get(OriginGetParams params)
-
get
OriginResponse get(String id, RequestOptions requestOptions)
-
-
-
-