Interface UsageAnalyticsService.WithRawResponse
-
- All Implemented Interfaces:
public interface UsageAnalyticsService.WithRawResponseA view of UsageAnalyticsService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract UsageAnalyticsService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<UsageAnalyticsResponse>get(UsageAnalyticsGetParams params)Returns a raw HTTP response for get /v1/accounts/usage-analytics, but is otherwise the same as UsageAnalyticsService.get.abstract HttpResponseFor<UsageAnalyticsResponse>get(UsageAnalyticsGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract UsageAnalyticsService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
@MustBeClosed() HttpResponseFor<UsageAnalyticsResponse> get(UsageAnalyticsGetParams params)
Returns a raw HTTP response for
get /v1/accounts/usage-analytics, but is otherwise the same as UsageAnalyticsService.get.
-
get
@MustBeClosed() abstract HttpResponseFor<UsageAnalyticsResponse> get(UsageAnalyticsGetParams params, RequestOptions requestOptions)
-
-
-
-