Class UsageServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.accounts.UsageService
public final class UsageServiceImpl implements UsageService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUsageServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description UsageService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. UsageServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UsageGetResponseget(UsageGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
UsageService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
UsageService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
UsageGetResponse get(UsageGetParams params, RequestOptions requestOptions)
-
-
-
-