Interface V2Service
-
- All Implemented Interfaces:
public interface V2Service
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceV2Service.WithRawResponseA view of V2Service that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract V2Service.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract V2ServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract FileServicefiles()-
-
Method Detail
-
withRawResponse
abstract V2Service.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract V2Service withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
abstract FileService files()
-
-
-
-