Interface V2Service.WithRawResponse
-
- All Implemented Interfaces:
public interface V2Service.WithRawResponseA view of V2Service that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract V2Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract FileService.WithRawResponsefiles()-
-
Method Detail
-
withOptions
abstract V2Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
abstract FileService.WithRawResponse files()
-
-
-
-