Class V2ServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.beta.V2Service.WithRawResponse
public final class V2ServiceImpl.WithRawResponseImpl implements V2Service.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description V2Service.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileService.WithRawResponsefiles()-
-
Method Detail
-
withOptions
V2Service.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
files
FileService.WithRawResponse files()
-
-
-
-