Interface FileService
-
- All Implemented Interfaces:
public interface FileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceFileService.WithRawResponseA view of FileService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract FileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract FileServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileUploadResponseupload(FileUploadParams params)The V2 API enhances security by verifying the entire payload using JWT. abstract FileUploadResponseupload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract FileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract FileService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
FileUploadResponse upload(FileUploadParams params)
The V2 API enhances security by verifying the entire payload using JWT. This API is in beta.
ImageKit.io allows you to upload files directly from both the server and client sides. For server-side uploads, private API key authentication is used. For client-side uploads, generate a one-time
tokenfrom your secure backend using private API. /docs/api-reference/upload-file/upload-file-v2#how-to-implement-secure-client-side-file-upload about how to implement secure client-side file upload.File size limit \ On the free plan, the maximum upload file sizes are 25MB for images, audio, and raw files, and 100MB for videos. On the Lite paid plan, these limits increase to 40MB for images, audio, and raw files and 300MB for videos, whereas on the Pro paid plan, these limits increase to 50MB for images, audio, and raw files and 2GB for videos. These limits can be further increased with enterprise plans.
Version limit \ A file can have a maximum of 100 versions.
Demo applications
A full-fledged upload widget using Uppy, supporting file selections from local storage, URL, Dropbox, Google Drive, Instagram, and more.
/docs/quick-start-guides for various frameworks and technologies.
-
upload
abstract FileUploadResponse upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-