Interface FileService.WithRawResponse
-
- All Implemented Interfaces:
public interface FileService.WithRawResponseA view of FileService that provides access to raw HTTP responses for each method.
-
-
Method Summary
Modifier and Type Method Description abstract FileService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<FileUploadResponse>upload(FileUploadParams params)Returns a raw HTTP response for post /api/v2/files/upload, but is otherwise the same as FileService.upload.abstract HttpResponseFor<FileUploadResponse>upload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
abstract FileService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
@MustBeClosed() HttpResponseFor<FileUploadResponse> upload(FileUploadParams params)
Returns a raw HTTP response for
post /api/v2/files/upload, but is otherwise the same as FileService.upload.
-
upload
@MustBeClosed() abstract HttpResponseFor<FileUploadResponse> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-