Class FileServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.beta.v2.FileService
public final class FileServiceImpl implements FileService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description FileService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. FileServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. FileUploadResponseupload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
FileService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
FileService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
FileUploadResponse upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-