Class FileServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.beta.v2.FileService.WithRawResponse
public final class FileServiceImpl.WithRawResponseImpl implements FileService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description FileService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<FileUploadResponse>upload(FileUploadParams params, RequestOptions requestOptions)-
-
Method Detail
-
withOptions
FileService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
upload
HttpResponseFor<FileUploadResponse> upload(FileUploadParams params, RequestOptions requestOptions)
-
-
-
-