Interface InvalidationService
-
- All Implemented Interfaces:
public interface InvalidationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceInvalidationService.WithRawResponseA view of InvalidationService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract InvalidationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract InvalidationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InvalidationCreateResponsecreate(InvalidationCreateParams params)This API will purge CDN cache and ImageKit.io's internal cache for a file. abstract InvalidationCreateResponsecreate(InvalidationCreateParams params, RequestOptions requestOptions)InvalidationGetResponseget(String requestId)This API returns the status of a purge cache request. InvalidationGetResponseget(String requestId, InvalidationGetParams params, RequestOptions requestOptions)InvalidationGetResponseget(String requestId, InvalidationGetParams params)abstract InvalidationGetResponseget(InvalidationGetParams params, RequestOptions requestOptions)InvalidationGetResponseget(InvalidationGetParams params)InvalidationGetResponseget(String requestId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract InvalidationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract InvalidationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InvalidationCreateResponse create(InvalidationCreateParams params)
This API will purge CDN cache and ImageKit.io's internal cache for a file. Note: Purge cache is an asynchronous process and it may take some time to reflect the changes.
-
create
abstract InvalidationCreateResponse create(InvalidationCreateParams params, RequestOptions requestOptions)
-
get
InvalidationGetResponse get(String requestId)
This API returns the status of a purge cache request.
-
get
InvalidationGetResponse get(String requestId, InvalidationGetParams params, RequestOptions requestOptions)
-
get
InvalidationGetResponse get(String requestId, InvalidationGetParams params)
-
get
abstract InvalidationGetResponse get(InvalidationGetParams params, RequestOptions requestOptions)
-
get
InvalidationGetResponse get(InvalidationGetParams params)
-
get
InvalidationGetResponse get(String requestId, RequestOptions requestOptions)
-
-
-
-