Class InvalidationServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.cache.InvalidationService
public final class InvalidationServiceImpl implements InvalidationService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInvalidationServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description InvalidationService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. InvalidationServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. InvalidationCreateResponsecreate(InvalidationCreateParams params, RequestOptions requestOptions)InvalidationGetResponseget(InvalidationGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
InvalidationService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
InvalidationService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
InvalidationCreateResponse create(InvalidationCreateParams params, RequestOptions requestOptions)
-
get
InvalidationGetResponse get(InvalidationGetParams params, RequestOptions requestOptions)
-
-
-
-