Interface BulkService
-
- All Implemented Interfaces:
public interface BulkService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceBulkService.WithRawResponseA view of BulkService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract BulkService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract BulkServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. BulkDeleteResponsedelete(BulkDeleteParams params)This API deletes multiple files and all their file versions permanently. abstract BulkDeleteResponsedelete(BulkDeleteParams params, RequestOptions requestOptions)BulkAddTagsResponseaddTags(BulkAddTagsParams params)This API adds tags to multiple files in bulk. abstract BulkAddTagsResponseaddTags(BulkAddTagsParams params, RequestOptions requestOptions)BulkRemoveAiTagsResponseremoveAiTags(BulkRemoveAiTagsParams params)This API removes AITags from multiple files in bulk. abstract BulkRemoveAiTagsResponseremoveAiTags(BulkRemoveAiTagsParams params, RequestOptions requestOptions)BulkRemoveTagsResponseremoveTags(BulkRemoveTagsParams params)This API removes tags from multiple files in bulk. abstract BulkRemoveTagsResponseremoveTags(BulkRemoveTagsParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract BulkService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract BulkService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
delete
BulkDeleteResponse delete(BulkDeleteParams params)
This API deletes multiple files and all their file versions permanently.
Note: If a file or specific transformation has been requested in the past, then the response is cached. Deleting a file does not purge the cache. You can purge the cache using purge cache API.
A maximum of 100 files can be deleted at a time.
-
delete
abstract BulkDeleteResponse delete(BulkDeleteParams params, RequestOptions requestOptions)
-
addTags
BulkAddTagsResponse addTags(BulkAddTagsParams params)
This API adds tags to multiple files in bulk. A maximum of 50 files can be specified at a time.
-
addTags
abstract BulkAddTagsResponse addTags(BulkAddTagsParams params, RequestOptions requestOptions)
-
removeAiTags
BulkRemoveAiTagsResponse removeAiTags(BulkRemoveAiTagsParams params)
This API removes AITags from multiple files in bulk. A maximum of 50 files can be specified at a time.
-
removeAiTags
abstract BulkRemoveAiTagsResponse removeAiTags(BulkRemoveAiTagsParams params, RequestOptions requestOptions)
-
removeTags
BulkRemoveTagsResponse removeTags(BulkRemoveTagsParams params)
This API removes tags from multiple files in bulk. A maximum of 50 files can be specified at a time.
-
removeTags
abstract BulkRemoveTagsResponse removeTags(BulkRemoveTagsParams params, RequestOptions requestOptions)
-
-
-
-