Interface MetadataService
-
- All Implemented Interfaces:
public interface MetadataService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceMetadataService.WithRawResponseA view of MetadataService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract MetadataService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract MetadataServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Metadataget(String fileId)You can programmatically get image EXIF, pHash, and other metadata for uploaded files in the ImageKit.io media library using this API. Metadataget(String fileId, MetadataGetParams params, RequestOptions requestOptions)Metadataget(String fileId, MetadataGetParams params)abstract Metadataget(MetadataGetParams params, RequestOptions requestOptions)Metadataget(MetadataGetParams params)Metadataget(String fileId, RequestOptions requestOptions)MetadatagetFromUrl(MetadataGetFromUrlParams params)Get image EXIF, pHash, and other metadata from ImageKit.io powered remote URL using this API. abstract MetadatagetFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract MetadataService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract MetadataService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
Metadata get(String fileId)
You can programmatically get image EXIF, pHash, and other metadata for uploaded files in the ImageKit.io media library using this API.
You can also get the metadata in upload API response by passing
metadatainresponseFieldsparameter.
-
get
Metadata get(String fileId, MetadataGetParams params, RequestOptions requestOptions)
-
get
Metadata get(String fileId, MetadataGetParams params)
-
get
abstract Metadata get(MetadataGetParams params, RequestOptions requestOptions)
-
get
Metadata get(MetadataGetParams params)
-
get
Metadata get(String fileId, RequestOptions requestOptions)
-
getFromUrl
Metadata getFromUrl(MetadataGetFromUrlParams params)
Get image EXIF, pHash, and other metadata from ImageKit.io powered remote URL using this API.
-
getFromUrl
abstract Metadata getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)
-
-
-
-