Class MetadataServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.files.MetadataService
public final class MetadataServiceImpl implements MetadataService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadataServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description MetadataService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. MetadataServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. Metadataget(MetadataGetParams params, RequestOptions requestOptions)MetadatagetFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
MetadataService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
MetadataService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
Metadata get(MetadataGetParams params, RequestOptions requestOptions)
-
getFromUrl
Metadata getFromUrl(MetadataGetFromUrlParams params, RequestOptions requestOptions)
-
-
-
-