Class VersionServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.files.VersionService
public final class VersionServiceImpl implements VersionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVersionServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description VersionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. VersionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. List<File>list(VersionListParams params, RequestOptions requestOptions)VersionDeleteResponsedelete(VersionDeleteParams params, RequestOptions requestOptions)Fileget(VersionGetParams params, RequestOptions requestOptions)Filerestore(VersionRestoreParams params, RequestOptions requestOptions)-
Methods inherited from class io.imagekit.services.blocking.files.VersionService
delete, delete, delete, get, get, get, list, list, list, list, list, restore, restore, restore -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
VersionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VersionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
list
List<File> list(VersionListParams params, RequestOptions requestOptions)
-
delete
VersionDeleteResponse delete(VersionDeleteParams params, RequestOptions requestOptions)
-
get
File get(VersionGetParams params, RequestOptions requestOptions)
-
restore
File restore(VersionRestoreParams params, RequestOptions requestOptions)
-
-
-
-