Interface JobService
-
- All Implemented Interfaces:
public interface JobService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceJobService.WithRawResponseA view of JobService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract JobService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract JobServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. JobGetResponseget(String jobId)This API returns the status of a bulk job like copy and move folder operations. JobGetResponseget(String jobId, JobGetParams params, RequestOptions requestOptions)JobGetResponseget(String jobId, JobGetParams params)abstract JobGetResponseget(JobGetParams params, RequestOptions requestOptions)JobGetResponseget(JobGetParams params)JobGetResponseget(String jobId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract JobService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract JobService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
JobGetResponse get(String jobId)
This API returns the status of a bulk job like copy and move folder operations.
-
get
JobGetResponse get(String jobId, JobGetParams params, RequestOptions requestOptions)
-
get
JobGetResponse get(String jobId, JobGetParams params)
-
get
abstract JobGetResponse get(JobGetParams params, RequestOptions requestOptions)
-
get
JobGetResponse get(JobGetParams params)
-
get
JobGetResponse get(String jobId, RequestOptions requestOptions)
-
-
-
-