Class JobServiceImpl
-
- All Implemented Interfaces:
-
io.imagekit.services.blocking.folders.JobService
public final class JobServiceImpl implements JobService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classJobServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description JobService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. JobServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. JobGetResponseget(JobGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
JobService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
JobService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
JobGetResponse get(JobGetParams params, RequestOptions requestOptions)
-
-
-
-