Package io.imagekit.core
Enum LogLevel
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classLogLevel.Companion
-
Enum Constant Summary
Enum Constants Enum Constant Description OFFNo logging.
INFOMinimal request and response summary logs. No headers or bodies are logged.
ERRORINFO logs plus details about request failures.
DEBUGFull request and response logs. Sensitive headers are redacted, but sensitive data in request and response bodies may still be visible.
-
Method Summary
Modifier and Type Method Description final BooleanshouldLog(LogLevel level)Returns whether this level is at or higher than the given level. final LogLevelvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<LogLevel>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<LogLevel>getEntries()The level at which to log request and response information. -
-
Method Detail
-
shouldLog
final Boolean shouldLog(LogLevel level)
Returns whether this level is at or higher than the given level.
-
valueOf
final LogLevel valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<LogLevel> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<LogLevel> getEntries()
The level at which to log request and response information.
-
-
-
-