Package io.imagekit.lib
Interface HelperService
-
- All Implemented Interfaces:
public interface HelperServiceHelper service interface for ImageKit SDK operations like URL building, transformation string generation, and authentication parameter generation.
You should not instantiate this service directly, and instead use it via the client:
ImageKitClient client = ImageKitOkHttpClient.builder() .privateKey("private_key_xxx") .build(); String url = client.helper().buildUrl(srcOptions);
-
-
Method Summary
Modifier and Type Method Description abstract StringbuildUrl(SrcOptions options)abstract StringbuildTransformationString(List<Transformation> transformations)abstract Map<String, Object>getAuthenticationParameters(String token, Long expire)-
-
Method Detail
-
buildUrl
abstract String buildUrl(SrcOptions options)
-
buildTransformationString
abstract String buildTransformationString(List<Transformation> transformations)
-
-
-
-