Package io.imagekit.models
Class AiTag
-
- All Implemented Interfaces:
public final class AiTagAI-generated tag associated with an image. These tags can be added using the
google-auto-taggingoraws-auto-taggingextensions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAiTag.BuilderA builder for AiTag.
-
Method Summary
Modifier and Type Method Description final Optional<Double>confidence()Confidence score of the tag. final Optional<String>name()Name of the tag. final Optional<String>source()Source of the tag. final JsonField<Double>_confidence()Returns the raw JSON value of confidence. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_source()Returns the raw JSON value of source. final Map<String, JsonValue>_additionalProperties()final AiTag.BuildertoBuilder()final AiTagvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AiTag.Builderbuilder()Returns a mutable builder for constructing an instance of AiTag. -
-
Method Detail
-
confidence
final Optional<Double> confidence()
Confidence score of the tag.
-
source
final Optional<String> source()
Source of the tag. Possible values are
google-auto-taggingandaws-auto-tagging.
-
_confidence
final JsonField<Double> _confidence()
Returns the raw JSON value of confidence.
Unlike confidence, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_source
final JsonField<String> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AiTag.Builder toBuilder()
-
builder
final static AiTag.Builder builder()
Returns a mutable builder for constructing an instance of AiTag.
-
-
-
-