Class BaseOverlay
-
- All Implemented Interfaces:
public final class BaseOverlay
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBaseOverlay.BuilderA builder for BaseOverlay.
public final classBaseOverlay.LayerModeControls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
Method Summary
Modifier and Type Method Description final Optional<BaseOverlay.LayerMode>layerMode()Controls how the layer blends with the base image or underlying content. final Optional<OverlayPosition>position()Specifies the overlay's position relative to the parent asset. final Optional<OverlayTiming>timing()Specifies timing information for the overlay (only applicable if the base asset is a video). final JsonField<BaseOverlay.LayerMode>_layerMode()Returns the raw JSON value of layerMode. final JsonField<OverlayPosition>_position()Returns the raw JSON value of position. final JsonField<OverlayTiming>_timing()Returns the raw JSON value of timing. final Map<String, JsonValue>_additionalProperties()final BaseOverlay.BuildertoBuilder()final BaseOverlayvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BaseOverlay.Builderbuilder()Returns a mutable builder for constructing an instance of BaseOverlay. -
-
Method Detail
-
layerMode
final Optional<BaseOverlay.LayerMode> layerMode()
Controls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
position
final Optional<OverlayPosition> position()
Specifies the overlay's position relative to the parent asset. See Position of Layer.
-
timing
final Optional<OverlayTiming> timing()
Specifies timing information for the overlay (only applicable if the base asset is a video). See Position of Layer.
-
_layerMode
final JsonField<BaseOverlay.LayerMode> _layerMode()
Returns the raw JSON value of layerMode.
Unlike layerMode, this method doesn't throw if the JSON field has an unexpected type.
-
_position
final JsonField<OverlayPosition> _position()
Returns the raw JSON value of position.
Unlike position, this method doesn't throw if the JSON field has an unexpected type.
-
_timing
final JsonField<OverlayTiming> _timing()
Returns the raw JSON value of timing.
Unlike timing, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BaseOverlay.Builder toBuilder()
-
validate
final BaseOverlay validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BaseOverlay.Builder builder()
Returns a mutable builder for constructing an instance of BaseOverlay.
-
-
-
-