Class BaseOverlay.LayerMode
-
- All Implemented Interfaces:
-
io.imagekit.core.Enum
public final class BaseOverlay.LayerMode implements EnumControls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public enumBaseOverlay.LayerMode.KnownAn enum containing LayerMode's known values.
public enumBaseOverlay.LayerMode.ValueAn enum containing LayerMode's known values, as well as an _UNKNOWN member.
An instance of LayerMode can contain an unknown value in a couple of cases:
It was deserialized from data that doesn't match any known member. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
It was constructed with an arbitrary value using the of method.
-
Field Summary
Fields Modifier and Type Field Description public final static BaseOverlay.LayerModeMULTIPLYpublic final static BaseOverlay.LayerModeCUTTERpublic final static BaseOverlay.LayerModeCUTOUTpublic final static BaseOverlay.LayerModeDISPLACE
-
Method Summary
Modifier and Type Method Description final JsonField<String>_value()Returns this class instance's raw value. final BaseOverlay.LayerMode.Valuevalue()Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value. final BaseOverlay.LayerMode.Knownknown()Returns an enum member corresponding to this class instance's value. final StringasString()Returns this class instance's primitive wire representation. final BaseOverlay.LayerModevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BaseOverlay.LayerModeof(String value)-
-
Method Detail
-
_value
final JsonField<String> _value()
Returns this class instance's raw value.
This is usually only useful if this instance was deserialized from data that doesn't match any known member, and you want to know that value. For example, if the SDK is on an older version than the API, then the API may respond with new members that the SDK is unaware of.
-
value
final BaseOverlay.LayerMode.Value value()
Returns an enum member corresponding to this class instance's value, or Value._UNKNOWN if the class was instantiated with an unknown value.
Use the known method instead if you're certain the value is always known or if you want to throw for the unknown case.
-
known
final BaseOverlay.LayerMode.Known known()
Returns an enum member corresponding to this class instance's value.
Use the value method instead if you're uncertain the value is always known and don't want to throw for the unknown case.
-
asString
final String asString()
Returns this class instance's primitive wire representation.
This differs from the toString method because that method is primarily for debugging and generally doesn't throw.
-
validate
final BaseOverlay.LayerMode validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
of
final static BaseOverlay.LayerMode of(String value)
-
-
-
-