Class ExtensionConfig.AiTasks.Task.YesNo
-
- All Implemented Interfaces:
public final class ExtensionConfig.AiTasks.Task.YesNo
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtensionConfig.AiTasks.Task.YesNo.BuilderA builder for YesNo.
public final classExtensionConfig.AiTasks.Task.YesNo.OnNoActions to execute if the AI answers no.
public final classExtensionConfig.AiTasks.Task.YesNo.OnUnknownActions to execute if the AI cannot determine the answer.
public final classExtensionConfig.AiTasks.Task.YesNo.OnYesActions to execute if the AI answers yes.
-
Method Summary
Modifier and Type Method Description final Stringinstruction()The yes/no question for the AI to answer about the image. final JsonValue_type()Task type that asks a yes/no question and executes actions based on the answer. final Optional<ExtensionConfig.AiTasks.Task.YesNo.OnNo>onNo()Actions to execute if the AI answers no. final Optional<ExtensionConfig.AiTasks.Task.YesNo.OnUnknown>onUnknown()Actions to execute if the AI cannot determine the answer. final Optional<ExtensionConfig.AiTasks.Task.YesNo.OnYes>onYes()Actions to execute if the AI answers yes. final JsonField<String>_instruction()Returns the raw JSON value of instruction. final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnNo>_onNo()Returns the raw JSON value of onNo. final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnUnknown>_onUnknown()Returns the raw JSON value of onUnknown. final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnYes>_onYes()Returns the raw JSON value of onYes. final Map<String, JsonValue>_additionalProperties()final ExtensionConfig.AiTasks.Task.YesNo.BuildertoBuilder()final ExtensionConfig.AiTasks.Task.YesNovalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtensionConfig.AiTasks.Task.YesNo.Builderbuilder()Returns a mutable builder for constructing an instance of YesNo. -
-
Method Detail
-
instruction
final String instruction()
The yes/no question for the AI to answer about the image.
-
_type
final JsonValue _type()
Task type that asks a yes/no question and executes actions based on the answer.
Expected to always return the following:
JsonValue.from("yes_no")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
onNo
final Optional<ExtensionConfig.AiTasks.Task.YesNo.OnNo> onNo()
Actions to execute if the AI answers no.
-
onUnknown
final Optional<ExtensionConfig.AiTasks.Task.YesNo.OnUnknown> onUnknown()
Actions to execute if the AI cannot determine the answer.
-
onYes
final Optional<ExtensionConfig.AiTasks.Task.YesNo.OnYes> onYes()
Actions to execute if the AI answers yes.
-
_instruction
final JsonField<String> _instruction()
Returns the raw JSON value of instruction.
Unlike instruction, this method doesn't throw if the JSON field has an unexpected type.
-
_onNo
final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnNo> _onNo()
Returns the raw JSON value of onNo.
Unlike onNo, this method doesn't throw if the JSON field has an unexpected type.
-
_onUnknown
final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnUnknown> _onUnknown()
Returns the raw JSON value of onUnknown.
Unlike onUnknown, this method doesn't throw if the JSON field has an unexpected type.
-
_onYes
final JsonField<ExtensionConfig.AiTasks.Task.YesNo.OnYes> _onYes()
Returns the raw JSON value of onYes.
Unlike onYes, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtensionConfig.AiTasks.Task.YesNo.Builder toBuilder()
-
validate
final ExtensionConfig.AiTasks.Task.YesNo validate()
-
builder
final static ExtensionConfig.AiTasks.Task.YesNo.Builder builder()
Returns a mutable builder for constructing an instance of YesNo.
The following fields are required:
.instruction()
-
-
-
-