Package io.imagekit.models
Class ExtensionConfig.RemoveBg
-
- All Implemented Interfaces:
public final class ExtensionConfig.RemoveBg
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtensionConfig.RemoveBg.BuilderA builder for RemoveBg.
public final classExtensionConfig.RemoveBg.Options
-
Method Summary
Modifier and Type Method Description final JsonValue_name()Specifies the background removal extension. final Optional<ExtensionConfig.RemoveBg.Options>options()final JsonField<ExtensionConfig.RemoveBg.Options>_options()Returns the raw JSON value of options. final Map<String, JsonValue>_additionalProperties()final ExtensionConfig.RemoveBg.BuildertoBuilder()final ExtensionConfig.RemoveBgvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtensionConfig.RemoveBg.Builderbuilder()Returns a mutable builder for constructing an instance of RemoveBg. -
-
Method Detail
-
_name
final JsonValue _name()
Specifies the background removal extension.
Expected to always return the following:
JsonValue.from("remove-bg")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
options
final Optional<ExtensionConfig.RemoveBg.Options> options()
-
_options
final JsonField<ExtensionConfig.RemoveBg.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtensionConfig.RemoveBg.Builder toBuilder()
-
validate
final ExtensionConfig.RemoveBg validate()
-
builder
final static ExtensionConfig.RemoveBg.Builder builder()
Returns a mutable builder for constructing an instance of RemoveBg.
-
-
-
-