Class ExtensionConfig.RemoveBg.Options
-
- All Implemented Interfaces:
public final class ExtensionConfig.RemoveBg.Options
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classExtensionConfig.RemoveBg.Options.BuilderA builder for Options.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>addShadow()Whether to add an artificial shadow to the result. final Optional<String>bgColor()Specifies a solid color background using hex code (e.g., "81d4fa", "fff") or color name (e.g., "green"). final Optional<String>bgImageUrl()Sets a background image from a URL. final Optional<Boolean>semitransparency()Allows semi-transparent regions in the result. final JsonField<Boolean>_addShadow()Returns the raw JSON value of addShadow. final JsonField<String>_bgColor()Returns the raw JSON value of bgColor. final JsonField<String>_bgImageUrl()Returns the raw JSON value of bgImageUrl. final JsonField<Boolean>_semitransparency()Returns the raw JSON value of semitransparency. final Map<String, JsonValue>_additionalProperties()final ExtensionConfig.RemoveBg.Options.BuildertoBuilder()final ExtensionConfig.RemoveBg.Optionsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ExtensionConfig.RemoveBg.Options.Builderbuilder()Returns a mutable builder for constructing an instance of Options. -
-
Method Detail
-
addShadow
final Optional<Boolean> addShadow()
Whether to add an artificial shadow to the result. Default is false. Note: Adding shadows is currently only supported for car photos.
-
bgColor
final Optional<String> bgColor()
Specifies a solid color background using hex code (e.g., "81d4fa", "fff") or color name (e.g., "green"). If this parameter is set,
bg_image_urlmust be empty.
-
bgImageUrl
final Optional<String> bgImageUrl()
Sets a background image from a URL. If this parameter is set,
bg_colormust be empty.
-
semitransparency
final Optional<Boolean> semitransparency()
Allows semi-transparent regions in the result. Default is true. Note: Semitransparency is currently only supported for car windows.
-
_addShadow
final JsonField<Boolean> _addShadow()
Returns the raw JSON value of addShadow.
Unlike addShadow, this method doesn't throw if the JSON field has an unexpected type.
-
_bgColor
final JsonField<String> _bgColor()
Returns the raw JSON value of bgColor.
Unlike bgColor, this method doesn't throw if the JSON field has an unexpected type.
-
_bgImageUrl
final JsonField<String> _bgImageUrl()
Returns the raw JSON value of bgImageUrl.
Unlike bgImageUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_semitransparency
final JsonField<Boolean> _semitransparency()
Returns the raw JSON value of semitransparency.
Unlike semitransparency, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ExtensionConfig.RemoveBg.Options.Builder toBuilder()
-
validate
final ExtensionConfig.RemoveBg.Options validate()
-
builder
final static ExtensionConfig.RemoveBg.Options.Builder builder()
Returns a mutable builder for constructing an instance of Options.
-
-
-
-