Package io.imagekit.models
Class Overlay
-
- All Implemented Interfaces:
public final class OverlaySpecifies an overlay to be applied on the parent image or video. ImageKit supports overlays including images, text, videos, subtitles, and solid colors. See Overlay using layers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceOverlay.VisitorAn interface that defines how to map each variant of Overlay to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<TextOverlay>text()final Optional<ImageOverlay>image()final Optional<VideoOverlay>video()final Optional<SubtitleOverlay>subtitle()final Optional<SolidColorOverlay>solidColor()final BooleanisText()final BooleanisImage()final BooleanisVideo()final BooleanisSubtitle()final BooleanisSolidColor()final TextOverlayasText()final ImageOverlayasImage()final VideoOverlayasVideo()final SubtitleOverlayasSubtitle()final SolidColorOverlayasSolidColor()final Optional<JsonValue>_json()final <T extends Any> Taccept(Overlay.Visitor<T> visitor)final Overlayvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayofText(TextOverlay text)final static OverlayofImage(ImageOverlay image)final static OverlayofVideo(VideoOverlay video)final static OverlayofSubtitle(SubtitleOverlay subtitle)final static OverlayofSolidColor(SolidColorOverlay solidColor)-
-
Method Detail
-
text
final Optional<TextOverlay> text()
-
image
final Optional<ImageOverlay> image()
-
video
final Optional<VideoOverlay> video()
-
subtitle
final Optional<SubtitleOverlay> subtitle()
-
solidColor
final Optional<SolidColorOverlay> solidColor()
-
isSubtitle
final Boolean isSubtitle()
-
isSolidColor
final Boolean isSolidColor()
-
asText
final TextOverlay asText()
-
asImage
final ImageOverlay asImage()
-
asVideo
final VideoOverlay asVideo()
-
asSubtitle
final SubtitleOverlay asSubtitle()
-
asSolidColor
final SolidColorOverlay asSolidColor()
-
accept
final <T extends Any> T accept(Overlay.Visitor<T> visitor)
-
ofText
final static Overlay ofText(TextOverlay text)
-
ofImage
final static Overlay ofImage(ImageOverlay image)
-
ofVideo
final static Overlay ofVideo(VideoOverlay video)
-
ofSubtitle
final static Overlay ofSubtitle(SubtitleOverlay subtitle)
-
ofSolidColor
final static Overlay ofSolidColor(SolidColorOverlay solidColor)
-
-
-
-