Package io.imagekit.models
Interface Overlay.Visitor
-
- All Implemented Interfaces:
public interface Overlay.Visitor<T extends Object>
-
-
Method Summary
Modifier and Type Method Description abstract TvisitText(TextOverlay text)abstract TvisitImage(ImageOverlay image)abstract TvisitVideo(VideoOverlay video)abstract TvisitSubtitle(SubtitleOverlay subtitle)abstract TvisitSolidColor(SolidColorOverlay solidColor)Tunknown(JsonValue json)Maps an unknown variant of Overlay to a value of type T. -
-
Method Detail
-
visitText
abstract T visitText(TextOverlay text)
-
visitImage
abstract T visitImage(ImageOverlay image)
-
visitVideo
abstract T visitVideo(VideoOverlay video)
-
visitSubtitle
abstract T visitSubtitle(SubtitleOverlay subtitle)
-
visitSolidColor
abstract T visitSolidColor(SolidColorOverlay solidColor)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Overlay to a value of type T.
An instance of Overlay can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-