Class OverlayTiming
-
- All Implemented Interfaces:
public final class OverlayTiming
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOverlayTiming.BuilderA builder for OverlayTiming.
public final classOverlayTiming.DurationSpecifies the duration (in seconds) during which the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps tolduin the URL.public final classOverlayTiming.EndSpecifies the end time (in seconds) for when the overlay should disappear from the base video. If both end and duration are provided, duration is ignored. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps toleoin the URL.public final classOverlayTiming.StartSpecifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps tolsoin the URL.
-
Method Summary
Modifier and Type Method Description final Optional<OverlayTiming.Duration>duration()Specifies the duration (in seconds) during which the overlay should appear on the base video. final Optional<OverlayTiming.End>end()Specifies the end time (in seconds) for when the overlay should disappear from the base video. final Optional<OverlayTiming.Start>start()Specifies the start time (in seconds) for when the overlay should appear on the base video. final JsonField<OverlayTiming.Duration>_duration()Returns the raw JSON value of duration. final JsonField<OverlayTiming.End>_end()Returns the raw JSON value of end. final JsonField<OverlayTiming.Start>_start()Returns the raw JSON value of start. final Map<String, JsonValue>_additionalProperties()final OverlayTiming.BuildertoBuilder()final OverlayTimingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OverlayTiming.Builderbuilder()Returns a mutable builder for constructing an instance of OverlayTiming. -
-
Method Detail
-
duration
final Optional<OverlayTiming.Duration> duration()
Specifies the duration (in seconds) during which the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps tolduin the URL.
-
end
final Optional<OverlayTiming.End> end()
Specifies the end time (in seconds) for when the overlay should disappear from the base video. If both end and duration are provided, duration is ignored. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps toleoin the URL.
-
start
final Optional<OverlayTiming.Start> start()
Specifies the start time (in seconds) for when the overlay should appear on the base video. Accepts a positive number up to two decimal places (e.g.,
20or20.50) and arithmetic expressions such asbdu_mul_0.4orbdu_sub_idu. Applies only if the base asset is a video. Maps tolsoin the URL.
-
_duration
final JsonField<OverlayTiming.Duration> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_end
final JsonField<OverlayTiming.End> _end()
Returns the raw JSON value of end.
Unlike end, this method doesn't throw if the JSON field has an unexpected type.
-
_start
final JsonField<OverlayTiming.Start> _start()
Returns the raw JSON value of start.
Unlike start, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OverlayTiming.Builder toBuilder()
-
validate
final OverlayTiming validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OverlayTiming.Builder builder()
Returns a mutable builder for constructing an instance of OverlayTiming.
-
-
-
-