Package io.imagekit.models
Class SelectedFieldsSchema
-
- All Implemented Interfaces:
public final class SelectedFieldsSchemaThis field is included in the response only if the Path policy feature is available in the plan. It contains schema definitions for the custom metadata fields selected for the specified file path. Field selection can only be done when the Path policy feature is enabled.
Keys are the names of the custom metadata fields; the value object has details about the custom metadata schema.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSelectedFieldsSchema.BuilderA builder for SelectedFieldsSchema.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final SelectedFieldsSchema.BuildertoBuilder()final SelectedFieldsSchemavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SelectedFieldsSchema.Builderbuilder()Returns a mutable builder for constructing an instance of SelectedFieldsSchema. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SelectedFieldsSchema.Builder toBuilder()
-
validate
final SelectedFieldsSchema validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SelectedFieldsSchema.Builder builder()
Returns a mutable builder for constructing an instance of SelectedFieldsSchema.
-
-
-
-