Class SolidColorOverlay
-
- All Implemented Interfaces:
public final class SolidColorOverlay
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSolidColorOverlay.BuilderA builder for SolidColorOverlay.
-
Method Summary
Modifier and Type Method Description final BaseOverlaytoBaseOverlay()final Optional<BaseOverlay.LayerMode>layerMode()Controls how the layer blends with the base image or underlying content. final Optional<OverlayPosition>position()Specifies the overlay's position relative to the parent asset. final Optional<OverlayTiming>timing()Specifies timing information for the overlay (only applicable if the base asset is a video). final Stringcolor()Specifies the color of the block using an RGB hex code (e.g. final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("solidColor")final Optional<List<SolidColorOverlayTransformation>>transformation()Control width and height of the solid color overlay. final JsonField<BaseOverlay.LayerMode>_layerMode()Returns the raw JSON value of layerMode. final JsonField<OverlayPosition>_position()Returns the raw JSON value of position. final JsonField<OverlayTiming>_timing()Returns the raw JSON value of timing. final JsonField<String>_color()Returns the raw JSON value of color. final JsonField<List<SolidColorOverlayTransformation>>_transformation()Returns the raw JSON value of transformation. final Map<String, JsonValue>_additionalProperties()final SolidColorOverlay.BuildertoBuilder()final SolidColorOverlayvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SolidColorOverlay.Builderbuilder()Returns a mutable builder for constructing an instance of SolidColorOverlay. -
-
Method Detail
-
toBaseOverlay
final BaseOverlay toBaseOverlay()
-
layerMode
final Optional<BaseOverlay.LayerMode> layerMode()
Controls how the layer blends with the base image or underlying content. Maps to
lmin the URL. By default, layers completely cover the base image beneath them. Layer modes change this behavior:multiply: Multiplies the pixel values of the layer with the base image. The result is always darker than the original images. This is ideal for applying shadows or color tints.displace: Uses the layer as a displacement map to distort pixels in the base image. The red channel controls horizontal displacement, and the green channel controls vertical displacement. Requiresxoryparameter to control displacement magnitude.cutout: Acts as an inverse mask where opaque areas of the layer turn the base image transparent, while transparent areas leave the base image unchanged. This mode functions like a hole-punch, effectively cutting the shape of the layer out of the underlying image.cutter: Acts as a shape mask where only the parts of the base image that fall inside the opaque area of the layer are preserved. This mode functions like a cookie-cutter, trimming the base image to match the specific dimensions and shape of the layer. See Layer modes.
-
position
final Optional<OverlayPosition> position()
Specifies the overlay's position relative to the parent asset. See Position of Layer.
-
timing
final Optional<OverlayTiming> timing()
Specifies timing information for the overlay (only applicable if the base asset is a video). See Position of Layer.
-
color
final String color()
Specifies the color of the block using an RGB hex code (e.g.,
FF0000), an RGBA code (e.g.,FFAABB50), or a color name (e.g.,red). If an 8-character value is provided, the last two characters represent the opacity level (from00for 0.00 to99for 0.99).
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("solidColor")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
transformation
final Optional<List<SolidColorOverlayTransformation>> transformation()
Control width and height of the solid color overlay. Supported transformations depend on the base/parent asset. See overlays on Images and Videos.
-
_layerMode
final JsonField<BaseOverlay.LayerMode> _layerMode()
Returns the raw JSON value of layerMode.
Unlike layerMode, this method doesn't throw if the JSON field has an unexpected type.
-
_position
final JsonField<OverlayPosition> _position()
Returns the raw JSON value of position.
Unlike position, this method doesn't throw if the JSON field has an unexpected type.
-
_timing
final JsonField<OverlayTiming> _timing()
Returns the raw JSON value of timing.
Unlike timing, this method doesn't throw if the JSON field has an unexpected type.
-
_color
final JsonField<String> _color()
Returns the raw JSON value of color.
Unlike color, this method doesn't throw if the JSON field has an unexpected type.
-
_transformation
final JsonField<List<SolidColorOverlayTransformation>> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SolidColorOverlay.Builder toBuilder()
-
validate
final SolidColorOverlay validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SolidColorOverlay.Builder builder()
Returns a mutable builder for constructing an instance of SolidColorOverlay.
The following fields are required:
.color()
-
-
-
-