Class SolidColorOverlayTransformation
-
- All Implemented Interfaces:
public final class SolidColorOverlayTransformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSolidColorOverlayTransformation.BuilderA builder for SolidColorOverlayTransformation.
public final classSolidColorOverlayTransformation.GradientCreates a linear gradient with two colors. Pass
truefor a default gradient, or provide a string for a custom gradient. Only works if the base asset is an image. See gradient.public final classSolidColorOverlayTransformation.HeightControls the height of the solid color overlay. Accepts a numeric value or an arithmetic expression. Learn about arithmetic expressions.
public final classSolidColorOverlayTransformation.RadiusSpecifies the corner radius of the solid color overlay.
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
public final classSolidColorOverlayTransformation.WidthControls the width of the solid color overlay. Accepts a numeric value or an arithmetic expression (e.g.,
bw_mul_0.2orbh_div_2). Learn about arithmetic expressions.
-
Method Summary
Modifier and Type Method Description final Optional<Double>alpha()Specifies the transparency level of the overlaid solid color layer. final Optional<String>background()Specifies the background color of the solid color overlay. final Optional<SolidColorOverlayTransformation.Gradient>gradient()Creates a linear gradient with two colors. final Optional<SolidColorOverlayTransformation.Height>height()Controls the height of the solid color overlay. final Optional<SolidColorOverlayTransformation.Radius>radius()Specifies the corner radius of the solid color overlay. final Optional<SolidColorOverlayTransformation.Width>width()Controls the width of the solid color overlay. final JsonField<Double>_alpha()Returns the raw JSON value of alpha. final JsonField<String>_background()Returns the raw JSON value of background. final JsonField<SolidColorOverlayTransformation.Gradient>_gradient()Returns the raw JSON value of gradient. final JsonField<SolidColorOverlayTransformation.Height>_height()Returns the raw JSON value of height. final JsonField<SolidColorOverlayTransformation.Radius>_radius()Returns the raw JSON value of radius. final JsonField<SolidColorOverlayTransformation.Width>_width()Returns the raw JSON value of width. final Map<String, JsonValue>_additionalProperties()final SolidColorOverlayTransformation.BuildertoBuilder()final SolidColorOverlayTransformationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SolidColorOverlayTransformation.Builderbuilder()Returns a mutable builder for constructing an instance of SolidColorOverlayTransformation. -
-
Method Detail
-
alpha
final Optional<Double> alpha()
Specifies the transparency level of the overlaid solid color layer. Supports integers from
1to9.
-
background
final Optional<String> background()
Specifies the background color of the solid color overlay. Accepts an RGB hex code (e.g.,
FF0000), an RGBA code (e.g.,FFAABB50), or a color name.
-
gradient
final Optional<SolidColorOverlayTransformation.Gradient> gradient()
Creates a linear gradient with two colors. Pass
truefor a default gradient, or provide a string for a custom gradient. Only works if the base asset is an image. See gradient.
-
height
final Optional<SolidColorOverlayTransformation.Height> height()
Controls the height of the solid color overlay. Accepts a numeric value or an arithmetic expression. Learn about arithmetic expressions.
-
radius
final Optional<SolidColorOverlayTransformation.Radius> radius()
Specifies the corner radius of the solid color overlay.
Single value (positive integer): Applied to all corners (e.g.,
20).max: Creates a circular or oval shape.Per-corner array: Provide four underscore-separated values representing top-left, top-right, bottom-right, and bottom-left corners respectively (e.g.,
10_20_30_40). See Radius.
-
width
final Optional<SolidColorOverlayTransformation.Width> width()
Controls the width of the solid color overlay. Accepts a numeric value or an arithmetic expression (e.g.,
bw_mul_0.2orbh_div_2). Learn about arithmetic expressions.
-
_alpha
final JsonField<Double> _alpha()
Returns the raw JSON value of alpha.
Unlike alpha, this method doesn't throw if the JSON field has an unexpected type.
-
_background
final JsonField<String> _background()
Returns the raw JSON value of background.
Unlike background, this method doesn't throw if the JSON field has an unexpected type.
-
_gradient
final JsonField<SolidColorOverlayTransformation.Gradient> _gradient()
Returns the raw JSON value of gradient.
Unlike gradient, this method doesn't throw if the JSON field has an unexpected type.
-
_height
final JsonField<SolidColorOverlayTransformation.Height> _height()
Returns the raw JSON value of height.
Unlike height, this method doesn't throw if the JSON field has an unexpected type.
-
_radius
final JsonField<SolidColorOverlayTransformation.Radius> _radius()
Returns the raw JSON value of radius.
Unlike radius, this method doesn't throw if the JSON field has an unexpected type.
-
_width
final JsonField<SolidColorOverlayTransformation.Width> _width()
Returns the raw JSON value of width.
Unlike width, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SolidColorOverlayTransformation.Builder toBuilder()
-
validate
final SolidColorOverlayTransformation validate()
-
builder
final static SolidColorOverlayTransformation.Builder builder()
Returns a mutable builder for constructing an instance of SolidColorOverlayTransformation.
-
-
-
-