Package io.imagekit.models
Class SolidColorOverlayTransformation.Width
-
- All Implemented Interfaces:
public final class SolidColorOverlayTransformation.WidthControls the width of the solid color overlay. Accepts a numeric value or an arithmetic expression (e.g.,
bw_mul_0.2orbh_div_2). Learn about arithmetic expressions.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSolidColorOverlayTransformation.Width.VisitorAn interface that defines how to map each variant of Width to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(SolidColorOverlayTransformation.Width.Visitor<T> visitor)final SolidColorOverlayTransformation.Widthvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SolidColorOverlayTransformation.WidthofNumber(Double number)final static SolidColorOverlayTransformation.WidthofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(SolidColorOverlayTransformation.Width.Visitor<T> visitor)
-
validate
final SolidColorOverlayTransformation.Width validate()
-
ofNumber
final static SolidColorOverlayTransformation.Width ofNumber(Double number)
-
ofString
final static SolidColorOverlayTransformation.Width ofString(String string)
-
-
-
-