Package io.imagekit.models
Class SrcOptions.QueryParameters
-
- All Implemented Interfaces:
public final class SrcOptions.QueryParametersThese are additional query parameters that you want to add to the final URL. They can be any query parameters and not necessarily related to ImageKit. This is especially useful if you want to add a versioning parameter to your URLs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSrcOptions.QueryParameters.BuilderA builder for QueryParameters.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final SrcOptions.QueryParameters.BuildertoBuilder()final SrcOptions.QueryParametersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SrcOptions.QueryParameters.Builderbuilder()Returns a mutable builder for constructing an instance of QueryParameters. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SrcOptions.QueryParameters.Builder toBuilder()
-
validate
final SrcOptions.QueryParameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SrcOptions.QueryParameters.Builder builder()
Returns a mutable builder for constructing an instance of QueryParameters.
-
-
-
-