Package io.imagekit.models
Class Transformation.AiDropShadow
-
- All Implemented Interfaces:
public final class Transformation.AiDropShadowAdds an AI-based drop shadow around a foreground object on a transparent or removed background. Optionally, control the direction, elevation, and saturation of the light source (e.g.,
az-45to change light direction). Passtruefor the default drop shadow, or provide a string for a custom drop shadow. Supported inside overlay. See AI Drop Shadow.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.AiDropShadow.VisitorAn interface that defines how to map each variant of AiDropShadow to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<JsonValue>true_()final Optional<String>string()final BooleanisTrue()final BooleanisString()final JsonValueasTrue()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.AiDropShadow.Visitor<T> visitor)final Transformation.AiDropShadowvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.AiDropShadowofTrue()final static Transformation.AiDropShadowofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.AiDropShadow.Visitor<T> visitor)
-
validate
final Transformation.AiDropShadow validate()
-
ofTrue
final static Transformation.AiDropShadow ofTrue()
-
ofString
final static Transformation.AiDropShadow ofString(String string)
-
-
-
-