Package io.imagekit.models
Class Transformation.Rotation
-
- All Implemented Interfaces:
public final class Transformation.RotationSpecifies the rotation angle in degrees. Positive values rotate the image clockwise; you can also use, for example,
N40for counterclockwise rotation orautoto use the orientation specified in the image's EXIF data. For videos, only the following values are supported: 0, 90, 180, 270, or 360. See Rotate.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Rotation.VisitorAn interface that defines how to map each variant of Rotation to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Rotation.Visitor<T> visitor)final Transformation.Rotationvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.RotationofNumber(Double number)final static Transformation.RotationofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Rotation.Visitor<T> visitor)
-
validate
final Transformation.Rotation validate()
-
ofNumber
final static Transformation.Rotation ofNumber(Double number)
-
ofString
final static Transformation.Rotation ofString(String string)
-
-
-
-