Package io.imagekit.models
Class Transformation.Shadow
-
- All Implemented Interfaces:
public final class Transformation.ShadowAdds a shadow beneath solid objects in an image with a transparent background. For AI-based drop shadows, refer to aiDropShadow. Pass
truefor a default shadow, or provide a string for a custom shadow. See Shadow.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Shadow.VisitorAn interface that defines how to map each variant of Shadow to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<JsonValue>true_()final Optional<String>string()final BooleanisTrue()final BooleanisString()final JsonValueasTrue()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Shadow.Visitor<T> visitor)final Transformation.Shadowvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.ShadowofTrue()final static Transformation.ShadowofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Shadow.Visitor<T> visitor)
-
validate
final Transformation.Shadow validate()
-
ofTrue
final static Transformation.Shadow ofTrue()
-
ofString
final static Transformation.Shadow ofString(String string)
-
-
-
-