Package io.imagekit.models
Class Transformation.Trim
-
- All Implemented Interfaces:
public final class Transformation.TrimUseful for images with a solid or nearly solid background and a central object. This parameter trims the background, leaving only the central object in the output image. See Trim edges.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Trim.VisitorAn interface that defines how to map each variant of Trim to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<JsonValue>true_()final Optional<Double>number()final BooleanisTrue()final BooleanisNumber()final JsonValueasTrue()final DoubleasNumber()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Trim.Visitor<T> visitor)final Transformation.Trimvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.TrimofTrue()final static Transformation.TrimofNumber(Double number)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Trim.Visitor<T> visitor)
-
validate
final Transformation.Trim validate()
-
ofTrue
final static Transformation.Trim ofTrue()
-
ofNumber
final static Transformation.Trim ofNumber(Double number)
-
-
-
-