Package io.imagekit.models
Class Transformation.Y
-
- All Implemented Interfaces:
public final class Transformation.YFocus using cropped image coordinates - Y coordinate. See Focus using cropped coordinates.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTransformation.Y.VisitorAn interface that defines how to map each variant of Y to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<Double>number()final Optional<String>string()final BooleanisNumber()final BooleanisString()final DoubleasNumber()final StringasString()final Optional<JsonValue>_json()final <T extends Any> Taccept(Transformation.Y.Visitor<T> visitor)final Transformation.Yvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static Transformation.YofNumber(Double number)final static Transformation.YofString(String string)-
-
Method Detail
-
accept
final <T extends Any> T accept(Transformation.Y.Visitor<T> visitor)
-
validate
final Transformation.Y validate()
-
ofNumber
final static Transformation.Y ofNumber(Double number)
-
ofString
final static Transformation.Y ofString(String string)
-
-
-
-