Package io.imagekit.models
Class VersionInfo
-
- All Implemented Interfaces:
public final class VersionInfoAn object containing the file or file version's
id(versionId) andname.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVersionInfo.BuilderA builder for VersionInfo.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()Unique identifier of the file version. final Optional<String>name()Name of the file version. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final VersionInfo.BuildertoBuilder()final VersionInfovalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VersionInfo.Builderbuilder()Returns a mutable builder for constructing an instance of VersionInfo. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VersionInfo.Builder toBuilder()
-
validate
final VersionInfo validate()
-
builder
final static VersionInfo.Builder builder()
Returns a mutable builder for constructing an instance of VersionInfo.
-
-
-
-