Class CustomMetadataField.Schema.DefaultValue
-
- All Implemented Interfaces:
public final class CustomMetadataField.Schema.DefaultValueThe default value for this custom metadata field. Data type of default value depends on the field type.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataField.Schema.DefaultValue.VisitorAn interface that defines how to map each variant of DefaultValue to a value of type T.
public final classCustomMetadataField.Schema.DefaultValue.DefaultValueItem
-
Method Summary
-
-
Method Detail
-
mixed
final Optional<List<CustomMetadataField.Schema.DefaultValue.DefaultValueItem>> mixed()
Default value should be of type array when custom metadata field type is set to
MultiSelect.
-
asMixed
final List<CustomMetadataField.Schema.DefaultValue.DefaultValueItem> asMixed()
Default value should be of type array when custom metadata field type is set to
MultiSelect.
-
accept
final <T extends Any> T accept(CustomMetadataField.Schema.DefaultValue.Visitor<T> visitor)
-
validate
final CustomMetadataField.Schema.DefaultValue validate()
-
ofString
final static CustomMetadataField.Schema.DefaultValue ofString(String string)
-
ofNumber
final static CustomMetadataField.Schema.DefaultValue ofNumber(Double number)
-
ofBool
final static CustomMetadataField.Schema.DefaultValue ofBool(Boolean bool)
-
ofMixed
final static CustomMetadataField.Schema.DefaultValue ofMixed(List<CustomMetadataField.Schema.DefaultValue.DefaultValueItem> mixed)
Default value should be of type array when custom metadata field type is set to
MultiSelect.
-
-
-
-