Class CustomMetadataField.Schema.MaxValue
-
- All Implemented Interfaces:
public final class CustomMetadataField.Schema.MaxValueMaximum value of the field. Only set if field type is
DateorNumber. ForDatetype field, the value will be in ISO8601 string format. ForNumbertype field, it will be a numeric value.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataField.Schema.MaxValue.VisitorAn interface that defines how to map each variant of MaxValue to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<Double>number()final BooleanisString()final BooleanisNumber()final StringasString()final DoubleasNumber()final Optional<JsonValue>_json()final <T extends Any> Taccept(CustomMetadataField.Schema.MaxValue.Visitor<T> visitor)final CustomMetadataField.Schema.MaxValuevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataField.Schema.MaxValueofString(String string)final static CustomMetadataField.Schema.MaxValueofNumber(Double number)-
-
Method Detail
-
accept
final <T extends Any> T accept(CustomMetadataField.Schema.MaxValue.Visitor<T> visitor)
-
validate
final CustomMetadataField.Schema.MaxValue validate()
-
ofString
final static CustomMetadataField.Schema.MaxValue ofString(String string)
-
ofNumber
final static CustomMetadataField.Schema.MaxValue ofNumber(Double number)
-
-
-
-