Class CustomMetadataFieldCreateParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class CustomMetadataFieldCreateParams implements Params
This API creates a new custom metadata field. Once a custom metadata field is created either through this API or using the dashboard UI, its value can be set on the assets. The value of a field for an asset can be set using the media library UI or programmatically through upload or update assets API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldCreateParams.BuilderA builder for CustomMetadataFieldCreateParams.
public final classCustomMetadataFieldCreateParams.Bodypublic final classCustomMetadataFieldCreateParams.Schema
-
Method Summary
Modifier and Type Method Description final Stringlabel()Human readable name of the custom metadata field. final Stringname()API name of the custom metadata field. final CustomMetadataFieldCreateParams.Schemaschema()final JsonField<String>_label()Returns the raw JSON value of label. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<CustomMetadataFieldCreateParams.Schema>_schema()Returns the raw JSON value of schema. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CustomMetadataFieldCreateParams.BuildertoBuilder()final CustomMetadataFieldCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadataFieldCreateParams. -
-
Method Detail
-
label
final String label()
Human readable name of the custom metadata field. This should be unique across all non deleted custom metadata fields. This name is displayed as form field label to the users while setting field value on an asset in the media library UI.
-
name
final String name()
API name of the custom metadata field. This should be unique across all (including deleted) custom metadata fields.
-
schema
final CustomMetadataFieldCreateParams.Schema schema()
-
_label
final JsonField<String> _label()
Returns the raw JSON value of label.
Unlike label, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<CustomMetadataFieldCreateParams.Schema> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CustomMetadataFieldCreateParams.Builder toBuilder()
-
_body
final CustomMetadataFieldCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static CustomMetadataFieldCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadataFieldCreateParams.
The following fields are required:
.label() .name() .schema()
-
-
-
-