Class CustomMetadataFieldCreateParams.Schema.MaxValue

  • All Implemented Interfaces:

    
    public final class CustomMetadataFieldCreateParams.Schema.MaxValue
    
                        

    Maximum value of the field. Only set this property if field type is Date or Number. For Date type field, set the minimum date in ISO8601 string format. For Number type field, set the minimum numeric value.