Class CustomMetadataFieldCreateParams.Schema.MaxValue
-
- All Implemented Interfaces:
public final class CustomMetadataFieldCreateParams.Schema.MaxValueMaximum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataFieldCreateParams.Schema.MaxValue.VisitorAn interface that defines how to map each variant of MaxValue to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<Double>number()final BooleanisString()final BooleanisNumber()final StringasString()final DoubleasNumber()final Optional<JsonValue>_json()final <T extends Any> Taccept(CustomMetadataFieldCreateParams.Schema.MaxValue.Visitor<T> visitor)final CustomMetadataFieldCreateParams.Schema.MaxValuevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldCreateParams.Schema.MaxValueofString(String string)final static CustomMetadataFieldCreateParams.Schema.MaxValueofNumber(Double number)-
-
Method Detail
-
accept
final <T extends Any> T accept(CustomMetadataFieldCreateParams.Schema.MaxValue.Visitor<T> visitor)
-
validate
final CustomMetadataFieldCreateParams.Schema.MaxValue validate()
-
ofString
final static CustomMetadataFieldCreateParams.Schema.MaxValue ofString(String string)
-
ofNumber
final static CustomMetadataFieldCreateParams.Schema.MaxValue ofNumber(Double number)
-
-
-
-