Class CustomMetadataFieldListParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class CustomMetadataFieldListParams implements Params
This API returns the array of created custom metadata field objects. By default the API returns only non deleted field objects, but you can include deleted fields in the API response.
You can also filter results by a specific folder path to retrieve custom metadata fields applicable at that location. This path-specific filtering is useful when using the Path policy feature to determine which custom metadata fields are selected for a given path.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCustomMetadataFieldListParams.BuilderA builder for CustomMetadataFieldListParams.
-
Method Summary
Modifier and Type Method Description final Optional<String>folderPath()The folder path (e.g. final Optional<Boolean>includeDeleted()Set it to trueto include deleted field objects in the API response.final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final CustomMetadataFieldListParams.BuildertoBuilder()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldListParamsnone()final static CustomMetadataFieldListParams.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadataFieldListParams. -
-
Method Detail
-
folderPath
final Optional<String> folderPath()
The folder path (e.g.,
/path/to/folder) for which to retrieve applicable custom metadata fields. Useful for determining path-specific field selections when the Path policy feature is in use.
-
includeDeleted
final Optional<Boolean> includeDeleted()
Set it to
trueto include deleted field objects in the API response.
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final CustomMetadataFieldListParams.Builder toBuilder()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static CustomMetadataFieldListParams none()
-
builder
final static CustomMetadataFieldListParams.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadataFieldListParams.
-
-
-
-