Class CustomMetadataFieldUpdateParams.Schema.MinValue
-
- All Implemented Interfaces:
public final class CustomMetadataFieldUpdateParams.Schema.MinValueMinimum value of the field. Only set this property if field type is
DateorNumber. ForDatetype field, set the minimum date in ISO8601 string format. ForNumbertype field, set the minimum numeric value.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceCustomMetadataFieldUpdateParams.Schema.MinValue.VisitorAn interface that defines how to map each variant of MinValue to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<String>string()final Optional<Double>number()final BooleanisString()final BooleanisNumber()final StringasString()final DoubleasNumber()final Optional<JsonValue>_json()final <T extends Any> Taccept(CustomMetadataFieldUpdateParams.Schema.MinValue.Visitor<T> visitor)final CustomMetadataFieldUpdateParams.Schema.MinValuevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CustomMetadataFieldUpdateParams.Schema.MinValueofString(String string)final static CustomMetadataFieldUpdateParams.Schema.MinValueofNumber(Double number)-
-
Method Detail
-
accept
final <T extends Any> T accept(CustomMetadataFieldUpdateParams.Schema.MinValue.Visitor<T> visitor)
-
validate
final CustomMetadataFieldUpdateParams.Schema.MinValue validate()
-
ofString
final static CustomMetadataFieldUpdateParams.Schema.MinValue ofString(String string)
-
ofNumber
final static CustomMetadataFieldUpdateParams.Schema.MinValue ofNumber(Double number)
-
-
-
-