Class FileCopyParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class FileCopyParams implements Params
This will copy a file from one folder to another.
Note: If any file at the destination has the same name as the source file, then the source file and its versions (if
includeFileVersionsis set to true) will be appended to the destination file version history.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileCopyParams.BuilderA builder for FileCopyParams.
public final classFileCopyParams.Body
-
Method Summary
Modifier and Type Method Description final StringdestinationPath()Full path to the folder you want to copy the above file into. final StringsourceFilePath()The full path of the file you want to copy. final Optional<Boolean>includeFileVersions()Option to copy all versions of a file. final JsonField<String>_destinationPath()Returns the raw JSON value of destinationPath. final JsonField<String>_sourceFilePath()Returns the raw JSON value of sourceFilePath. final JsonField<Boolean>_includeFileVersions()Returns the raw JSON value of includeFileVersions. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FileCopyParams.BuildertoBuilder()final FileCopyParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileCopyParams.Builderbuilder()Returns a mutable builder for constructing an instance of FileCopyParams. -
-
Method Detail
-
destinationPath
final String destinationPath()
Full path to the folder you want to copy the above file into.
-
sourceFilePath
final String sourceFilePath()
The full path of the file you want to copy.
-
includeFileVersions
final Optional<Boolean> includeFileVersions()
Option to copy all versions of a file. By default, only the current version of the file is copied. When set to true, all versions of the file will be copied. Default value -
false.
-
_destinationPath
final JsonField<String> _destinationPath()
Returns the raw JSON value of destinationPath.
Unlike destinationPath, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceFilePath
final JsonField<String> _sourceFilePath()
Returns the raw JSON value of sourceFilePath.
Unlike sourceFilePath, this method doesn't throw if the JSON field has an unexpected type.
-
_includeFileVersions
final JsonField<Boolean> _includeFileVersions()
Returns the raw JSON value of includeFileVersions.
Unlike includeFileVersions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FileCopyParams.Builder toBuilder()
-
_body
final FileCopyParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static FileCopyParams.Builder builder()
Returns a mutable builder for constructing an instance of FileCopyParams.
The following fields are required:
.destinationPath() .sourceFilePath()
-
-
-
-