Class FileMoveParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class FileMoveParams implements Params
This will move a file and all its versions from one folder to another.
Note: If any file at the destination has the same name as the source file, then the source file and its versions will be appended to the destination file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileMoveParams.BuilderA builder for FileMoveParams.
public final classFileMoveParams.Body
-
Method Summary
Modifier and Type Method Description final StringdestinationPath()Full path to the folder you want to move the above file into. final StringsourceFilePath()The full path of the file you want to move. final JsonField<String>_destinationPath()Returns the raw JSON value of destinationPath. final JsonField<String>_sourceFilePath()Returns the raw JSON value of sourceFilePath. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FileMoveParams.BuildertoBuilder()final FileMoveParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileMoveParams.Builderbuilder()Returns a mutable builder for constructing an instance of FileMoveParams. -
-
Method Detail
-
destinationPath
final String destinationPath()
Full path to the folder you want to move the above file into.
-
sourceFilePath
final String sourceFilePath()
The full path of the file you want to move.
-
_destinationPath
final JsonField<String> _destinationPath()
Returns the raw JSON value of destinationPath.
Unlike destinationPath, this method doesn't throw if the JSON field has an unexpected type.
-
_sourceFilePath
final JsonField<String> _sourceFilePath()
Returns the raw JSON value of sourceFilePath.
Unlike sourceFilePath, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FileMoveParams.Builder toBuilder()
-
_body
final FileMoveParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static FileMoveParams.Builder builder()
Returns a mutable builder for constructing an instance of FileMoveParams.
The following fields are required:
.destinationPath() .sourceFilePath()
-
-
-
-