Class FileRenameParams.Body
-
- All Implemented Interfaces:
public final class FileRenameParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileRenameParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final StringfilePath()The full path of the file you want to rename. final StringnewFileName()The new name of the file. final Optional<Boolean>purgeCache()Option to purge cache for the old file and its versions' URLs. final JsonField<String>_filePath()Returns the raw JSON value of filePath. final JsonField<String>_newFileName()Returns the raw JSON value of newFileName. final JsonField<Boolean>_purgeCache()Returns the raw JSON value of purgeCache. final Map<String, JsonValue>_additionalProperties()final FileRenameParams.Body.BuildertoBuilder()final FileRenameParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileRenameParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
newFileName
final String newFileName()
The new name of the file. A filename can contain:
Alphanumeric Characters:
a-z,A-Z,0-9(including Unicode letters, marks, and numerals in other languages). Special Characters:.,_, and-.Any other character, including space, will be replaced by
_.
-
purgeCache
final Optional<Boolean> purgeCache()
Option to purge cache for the old file and its versions' URLs.
When set to true, it will internally issue a purge cache request on CDN to remove cached content of old file and its versions. This purge request is counted against your monthly purge quota.
Note: If the old file were accessible at
https://ik.imagekit.io/demo/old-filename.jpg, a purge cache request would be issued againsthttps://ik.imagekit.io/demo/old-filename.jpg*(with a wildcard at the end). It will remove the file and its versions' URLs and any transformations made using query parameters on this file or its versions. However, the cache for file transformations made using path parameters will persist. You can purge them using the purge API. For more details, refer to the purge API documentation.Default value -
false
-
_filePath
final JsonField<String> _filePath()
Returns the raw JSON value of filePath.
Unlike filePath, this method doesn't throw if the JSON field has an unexpected type.
-
_newFileName
final JsonField<String> _newFileName()
Returns the raw JSON value of newFileName.
Unlike newFileName, this method doesn't throw if the JSON field has an unexpected type.
-
_purgeCache
final JsonField<Boolean> _purgeCache()
Returns the raw JSON value of purgeCache.
Unlike purgeCache, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileRenameParams.Body.Builder toBuilder()
-
validate
final FileRenameParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileRenameParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.filePath() .newFileName()
-
-
-
-