Class FileUploadParams.UploadTransformation
-
- All Implemented Interfaces:
public final class FileUploadParams.UploadTransformationConfigure pre-processing (
pre) and post-processing (post) transformations.pre— applied before the file is uploaded to the Media Library. Useful for reducing file size or applying basic optimizations upfront (e.g., resize, compress).post— applied immediately after upload. Ideal for generating transformed versions (like video encodes or thumbnails) in advance, so they're ready for delivery without delay.
You can mix and match any combination of post-processing types.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFileUploadParams.UploadTransformation.BuilderA builder for UploadTransformation.
public final classFileUploadParams.UploadTransformation.Post
-
Method Summary
Modifier and Type Method Description final Optional<List<FileUploadParams.UploadTransformation.Post>>post()List of transformations to apply after the file is uploaded. final Optional<String>pre()Transformation string to apply before uploading the file to the Media Library. final MultipartField<List<FileUploadParams.UploadTransformation.Post>>_post()Returns the raw multipart value of post. final MultipartField<String>_pre()Returns the raw multipart value of pre. final Map<String, JsonValue>_additionalProperties()final FileUploadParams.UploadTransformation.BuildertoBuilder()final FileUploadParams.UploadTransformationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FileUploadParams.UploadTransformation.Builderbuilder()Returns a mutable builder for constructing an instance of UploadTransformation. -
-
Method Detail
-
post
final Optional<List<FileUploadParams.UploadTransformation.Post>> post()
List of transformations to apply after the file is uploaded. Each item must match one of the following types:
transformation,gif-to-video,thumbnail,abs.
-
pre
final Optional<String> pre()
Transformation string to apply before uploading the file to the Media Library. Useful for optimizing files at ingestion.
-
_post
final MultipartField<List<FileUploadParams.UploadTransformation.Post>> _post()
Returns the raw multipart value of post.
Unlike post, this method doesn't throw if the multipart field has an unexpected type.
-
_pre
final MultipartField<String> _pre()
Returns the raw multipart value of pre.
Unlike pre, this method doesn't throw if the multipart field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FileUploadParams.UploadTransformation.Builder toBuilder()
-
validate
final FileUploadParams.UploadTransformation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FileUploadParams.UploadTransformation.Builder builder()
Returns a mutable builder for constructing an instance of UploadTransformation.
-
-
-
-