Class Metadata.Exif.Image
-
- All Implemented Interfaces:
public final class Metadata.Exif.ImageObject containing EXIF image information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadata.Exif.Image.BuilderA builder for Image.
-
Method Summary
-
-
Method Detail
-
exifOffset
final Optional<Long> exifOffset()
-
modifyDate
final Optional<String> modifyDate()
-
orientation
final Optional<Long> orientation()
-
resolutionUnit
final Optional<Long> resolutionUnit()
-
xResolution
final Optional<Long> xResolution()
-
yCbCrPositioning
final Optional<Long> yCbCrPositioning()
-
yResolution
final Optional<Long> yResolution()
-
_exifOffset
final JsonField<Long> _exifOffset()
Returns the raw JSON value of exifOffset.
Unlike exifOffset, this method doesn't throw if the JSON field has an unexpected type.
-
_gpsInfo
final JsonField<Long> _gpsInfo()
Returns the raw JSON value of gpsInfo.
Unlike gpsInfo, this method doesn't throw if the JSON field has an unexpected type.
-
_make
final JsonField<String> _make()
Returns the raw JSON value of make.
Unlike make, this method doesn't throw if the JSON field has an unexpected type.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_modifyDate
final JsonField<String> _modifyDate()
Returns the raw JSON value of modifyDate.
Unlike modifyDate, this method doesn't throw if the JSON field has an unexpected type.
-
_orientation
final JsonField<Long> _orientation()
Returns the raw JSON value of orientation.
Unlike orientation, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionUnit
final JsonField<Long> _resolutionUnit()
Returns the raw JSON value of resolutionUnit.
Unlike resolutionUnit, this method doesn't throw if the JSON field has an unexpected type.
-
_software
final JsonField<String> _software()
Returns the raw JSON value of software.
Unlike software, this method doesn't throw if the JSON field has an unexpected type.
-
_xResolution
final JsonField<Long> _xResolution()
Returns the raw JSON value of xResolution.
Unlike xResolution, this method doesn't throw if the JSON field has an unexpected type.
-
_yCbCrPositioning
final JsonField<Long> _yCbCrPositioning()
Returns the raw JSON value of yCbCrPositioning.
Unlike yCbCrPositioning, this method doesn't throw if the JSON field has an unexpected type.
-
_yResolution
final JsonField<Long> _yResolution()
Returns the raw JSON value of yResolution.
Unlike yResolution, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Metadata.Exif.Image.Builder toBuilder()
-
validate
final Metadata.Exif.Image validate()
-
builder
final static Metadata.Exif.Image.Builder builder()
Returns a mutable builder for constructing an instance of Image.
-
-
-
-