Class Metadata.Exif.Thumbnail
-
- All Implemented Interfaces:
public final class Metadata.Exif.ThumbnailObject containing Thumbnail information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classMetadata.Exif.Thumbnail.BuilderA builder for Thumbnail.
-
Method Summary
-
-
Method Detail
-
compression
final Optional<Long> compression()
-
resolutionUnit
final Optional<Long> resolutionUnit()
-
thumbnailLength
final Optional<Long> thumbnailLength()
-
thumbnailOffset
final Optional<Long> thumbnailOffset()
-
xResolution
final Optional<Long> xResolution()
-
yResolution
final Optional<Long> yResolution()
-
_compression
final JsonField<Long> _compression()
Returns the raw JSON value of compression.
Unlike compression, this method doesn't throw if the JSON field has an unexpected type.
-
_resolutionUnit
final JsonField<Long> _resolutionUnit()
Returns the raw JSON value of resolutionUnit.
Unlike resolutionUnit, this method doesn't throw if the JSON field has an unexpected type.
-
_thumbnailLength
final JsonField<Long> _thumbnailLength()
Returns the raw JSON value of thumbnailLength.
Unlike thumbnailLength, this method doesn't throw if the JSON field has an unexpected type.
-
_thumbnailOffset
final JsonField<Long> _thumbnailOffset()
Returns the raw JSON value of thumbnailOffset.
Unlike thumbnailOffset, this method doesn't throw if the JSON field has an unexpected type.
-
_xResolution
final JsonField<Long> _xResolution()
Returns the raw JSON value of xResolution.
Unlike xResolution, this method doesn't throw if the JSON field has an unexpected type.
-
_yResolution
final JsonField<Long> _yResolution()
Returns the raw JSON value of yResolution.
Unlike yResolution, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final Metadata.Exif.Thumbnail.Builder toBuilder()
-
validate
final Metadata.Exif.Thumbnail validate()
-
builder
final static Metadata.Exif.Thumbnail.Builder builder()
Returns a mutable builder for constructing an instance of Thumbnail.
-
-
-
-