Class UpdateFileRequest.UpdateFileDetails
-
- All Implemented Interfaces:
public final class UpdateFileRequest.UpdateFileDetails
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUpdateFileRequest.UpdateFileDetails.BuilderA builder for UpdateFileDetails.
public final classUpdateFileRequest.UpdateFileDetails.CustomMetadataA key-value data to be associated with the asset. To unset a key, send
nullvalue for that key. Before setting any custom metadata on an asset you have to create the field using custom metadata fields API.public final classUpdateFileRequest.UpdateFileDetails.RemoveAiTagsAn array of AITags associated with the file that you want to remove, e.g.
["car", "vehicle", "motorsports"].If you want to remove all AITags associated with the file, send a string - "all".
Note: The remove operation for
AITagsexecutes before any of theextensionsare processed.
-
Method Summary
Modifier and Type Method Description final Optional<String>customCoordinates()Define an important area in the image in the format x,y,width,heighte.g.final Optional<UpdateFileRequest.UpdateFileDetails.CustomMetadata>customMetadata()A key-value data to be associated with the asset. final Optional<String>description()Optional text to describe the contents of the file. final Optional<List<ExtensionItem>>extensions()Array of extensions to be applied to the asset. final Optional<UpdateFileRequest.UpdateFileDetails.RemoveAiTags>removeAiTags()An array of AITags associated with the file that you want to remove, e.g. final Optional<List<String>>tags()An array of tags associated with the file, such as ["tag1", "tag2"].final Optional<String>webhookUrl()The final status of extensions after they have completed execution will be delivered to this endpoint as a POST request. final JsonField<String>_customCoordinates()Returns the raw JSON value of customCoordinates. final JsonField<UpdateFileRequest.UpdateFileDetails.CustomMetadata>_customMetadata()Returns the raw JSON value of customMetadata. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<List<ExtensionItem>>_extensions()Returns the raw JSON value of extensions. final JsonField<UpdateFileRequest.UpdateFileDetails.RemoveAiTags>_removeAiTags()Returns the raw JSON value of removeAiTags. final JsonField<List<String>>_tags()Returns the raw JSON value of tags. final JsonField<String>_webhookUrl()Returns the raw JSON value of webhookUrl. final Map<String, JsonValue>_additionalProperties()final UpdateFileRequest.UpdateFileDetails.BuildertoBuilder()final UpdateFileRequest.UpdateFileDetailsvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UpdateFileRequest.UpdateFileDetails.Builderbuilder()Returns a mutable builder for constructing an instance of UpdateFileDetails. -
-
Method Detail
-
customCoordinates
final Optional<String> customCoordinates()
Define an important area in the image in the format
x,y,width,heighte.g.10,10,100,100. Sendnullto unset this value.
-
customMetadata
final Optional<UpdateFileRequest.UpdateFileDetails.CustomMetadata> customMetadata()
A key-value data to be associated with the asset. To unset a key, send
nullvalue for that key. Before setting any custom metadata on an asset you have to create the field using custom metadata fields API.
-
description
final Optional<String> description()
Optional text to describe the contents of the file.
-
extensions
final Optional<List<ExtensionItem>> extensions()
Array of extensions to be applied to the asset. Each extension can be configured with specific parameters based on the extension type.
-
removeAiTags
final Optional<UpdateFileRequest.UpdateFileDetails.RemoveAiTags> removeAiTags()
An array of AITags associated with the file that you want to remove, e.g.
["car", "vehicle", "motorsports"].If you want to remove all AITags associated with the file, send a string - "all".
Note: The remove operation for
AITagsexecutes before any of theextensionsare processed.
-
tags
final Optional<List<String>> tags()
An array of tags associated with the file, such as
["tag1", "tag2"]. Sendnullto unset all tags associated with the file.
-
webhookUrl
final Optional<String> webhookUrl()
The final status of extensions after they have completed execution will be delivered to this endpoint as a POST request. /docs/api-reference/digital-asset-management-dam/managing-assets/update-file-details#webhook-payload-structure about the webhook payload structure.
-
_customCoordinates
final JsonField<String> _customCoordinates()
Returns the raw JSON value of customCoordinates.
Unlike customCoordinates, this method doesn't throw if the JSON field has an unexpected type.
-
_customMetadata
final JsonField<UpdateFileRequest.UpdateFileDetails.CustomMetadata> _customMetadata()
Returns the raw JSON value of customMetadata.
Unlike customMetadata, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_extensions
final JsonField<List<ExtensionItem>> _extensions()
Returns the raw JSON value of extensions.
Unlike extensions, this method doesn't throw if the JSON field has an unexpected type.
-
_removeAiTags
final JsonField<UpdateFileRequest.UpdateFileDetails.RemoveAiTags> _removeAiTags()
Returns the raw JSON value of removeAiTags.
Unlike removeAiTags, this method doesn't throw if the JSON field has an unexpected type.
-
_tags
final JsonField<List<String>> _tags()
Returns the raw JSON value of tags.
Unlike tags, this method doesn't throw if the JSON field has an unexpected type.
-
_webhookUrl
final JsonField<String> _webhookUrl()
Returns the raw JSON value of webhookUrl.
Unlike webhookUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UpdateFileRequest.UpdateFileDetails.Builder toBuilder()
-
validate
final UpdateFileRequest.UpdateFileDetails validate()
-
builder
final static UpdateFileRequest.UpdateFileDetails.Builder builder()
Returns a mutable builder for constructing an instance of UpdateFileDetails.
-
-
-
-