Package io.imagekit.models.files
Class UpdateFileRequest.UpdateFileDetails.CustomMetadata
-
- All Implemented Interfaces:
public final class UpdateFileRequest.UpdateFileDetails.CustomMetadataA key-value data to be associated with the asset. To unset a key, send
nullvalue for that key. Before setting any custom metadata on an asset you have to create the field using custom metadata fields API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUpdateFileRequest.UpdateFileDetails.CustomMetadata.BuilderA builder for CustomMetadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final UpdateFileRequest.UpdateFileDetails.CustomMetadata.BuildertoBuilder()final UpdateFileRequest.UpdateFileDetails.CustomMetadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UpdateFileRequest.UpdateFileDetails.CustomMetadata.Builderbuilder()Returns a mutable builder for constructing an instance of CustomMetadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UpdateFileRequest.UpdateFileDetails.CustomMetadata.Builder toBuilder()
-
validate
final UpdateFileRequest.UpdateFileDetails.CustomMetadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static UpdateFileRequest.UpdateFileDetails.CustomMetadata.Builder builder()
Returns a mutable builder for constructing an instance of CustomMetadata.
-
-
-
-