Class FolderCreateParams
-
- All Implemented Interfaces:
-
io.imagekit.core.Params
public final class FolderCreateParams implements Params
This will create a new folder. You can specify the folder name and location of the parent folder where this new folder should be created.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFolderCreateParams.BuilderA builder for FolderCreateParams.
public final classFolderCreateParams.Body
-
Method Summary
Modifier and Type Method Description final StringfolderName()The folder will be created with this name. final StringparentFolderPath()The folder where the new folder should be created, for root use /else the path e.g.final JsonField<String>_folderName()Returns the raw JSON value of folderName. final JsonField<String>_parentFolderPath()Returns the raw JSON value of parentFolderPath. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final FolderCreateParams.BuildertoBuilder()final FolderCreateParams.Body_body()Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static FolderCreateParams.Builderbuilder()Returns a mutable builder for constructing an instance of FolderCreateParams. -
-
Method Detail
-
folderName
final String folderName()
The folder will be created with this name.
All characters except alphabets and numbers (inclusive of unicode letters, marks, and numerals in other languages) will be replaced by an underscore i.e.
_.
-
parentFolderPath
final String parentFolderPath()
The folder where the new folder should be created, for root use
/else the path e.g.containing/folder/.Note: If any folder(s) is not present in the parentFolderPath parameter, it will be automatically created. For example, if you pass
/product/images/summer, thenproduct,images, andsummerfolders will be created if they don't already exist.
-
_folderName
final JsonField<String> _folderName()
Returns the raw JSON value of folderName.
Unlike folderName, this method doesn't throw if the JSON field has an unexpected type.
-
_parentFolderPath
final JsonField<String> _parentFolderPath()
Returns the raw JSON value of parentFolderPath.
Unlike parentFolderPath, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final FolderCreateParams.Builder toBuilder()
-
_body
final FolderCreateParams.Body _body()
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
builder
final static FolderCreateParams.Builder builder()
Returns a mutable builder for constructing an instance of FolderCreateParams.
The following fields are required:
.folderName() .parentFolderPath()
-
-
-
-