Class UploadPostTransformSuccessEvent
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEventTriggered when a post-transformation completes successfully. The transformed version of the file is now ready and can be accessed via the provided URL. Note that each post-transformation generates a separate webhook event.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformSuccessEvent.BuilderA builder for UploadPostTransformSuccessEvent.
public final classUploadPostTransformSuccessEvent.Datapublic final classUploadPostTransformSuccessEvent.Request
-
Method Summary
-
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp of when the event occurred in ISO8601 format.
-
data
final UploadPostTransformSuccessEvent.Data data()
-
request
final UploadPostTransformSuccessEvent.Request request()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<UploadPostTransformSuccessEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_request
final JsonField<UploadPostTransformSuccessEvent.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformSuccessEvent.Builder toBuilder()
-
validate
final UploadPostTransformSuccessEvent validate()
-
builder
final static UploadPostTransformSuccessEvent.Builder builder()
Returns a mutable builder for constructing an instance of UploadPostTransformSuccessEvent.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-