Package io.imagekit.models.webhooks
Class UploadPostTransformSuccessEvent.Data
-
- All Implemented Interfaces:
public final class UploadPostTransformSuccessEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPostTransformSuccessEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final StringfileId()Unique identifier of the originally uploaded file. final Stringname()Name of the file. final Stringurl()URL of the generated post-transformation. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final UploadPostTransformSuccessEvent.Data.BuildertoBuilder()final UploadPostTransformSuccessEvent.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPostTransformSuccessEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPostTransformSuccessEvent.Data.Builder toBuilder()
-
validate
final UploadPostTransformSuccessEvent.Data validate()
-
builder
final static UploadPostTransformSuccessEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.fileId() .name() .url()
-
-
-
-