Package io.imagekit.models.webhooks
Class UploadPreTransformErrorEvent.Data
-
- All Implemented Interfaces:
public final class UploadPreTransformErrorEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classUploadPreTransformErrorEvent.Data.BuilderA builder for Data.
public final classUploadPreTransformErrorEvent.Data.Transformation
-
Method Summary
Modifier and Type Method Description final Stringname()Name of the file. final Stringpath()Path of the file. final UploadPreTransformErrorEvent.Data.Transformationtransformation()final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_path()Returns the raw JSON value of path. final JsonField<UploadPreTransformErrorEvent.Data.Transformation>_transformation()Returns the raw JSON value of transformation. final Map<String, JsonValue>_additionalProperties()final UploadPreTransformErrorEvent.Data.BuildertoBuilder()final UploadPreTransformErrorEvent.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static UploadPreTransformErrorEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
transformation
final UploadPreTransformErrorEvent.Data.Transformation transformation()
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_path
final JsonField<String> _path()
Returns the raw JSON value of path.
Unlike path, this method doesn't throw if the JSON field has an unexpected type.
-
_transformation
final JsonField<UploadPreTransformErrorEvent.Data.Transformation> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final UploadPreTransformErrorEvent.Data.Builder toBuilder()
-
validate
final UploadPreTransformErrorEvent.Data validate()
-
builder
final static UploadPreTransformErrorEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.name() .path() .transformation()
-
-
-
-