Package io.imagekit.models.webhooks
Class VideoTransformationAcceptedEvent.Request
-
- All Implemented Interfaces:
public final class VideoTransformationAcceptedEvent.RequestInformation about the original request that triggered the video transformation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationAcceptedEvent.Request.BuilderA builder for Request.
-
Method Summary
Modifier and Type Method Description final Stringurl()Full URL of the transformation request that was submitted. final StringxRequestId()Unique identifier for the originating transformation request. final Optional<String>userAgent()User-Agent header from the original request that triggered the transformation. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_xRequestId()Returns the raw JSON value of xRequestId. final JsonField<String>_userAgent()Returns the raw JSON value of userAgent. final Map<String, JsonValue>_additionalProperties()final VideoTransformationAcceptedEvent.Request.BuildertoBuilder()final VideoTransformationAcceptedEvent.Requestvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationAcceptedEvent.Request.Builderbuilder()Returns a mutable builder for constructing an instance of Request. -
-
Method Detail
-
xRequestId
final String xRequestId()
Unique identifier for the originating transformation request.
-
userAgent
final Optional<String> userAgent()
User-Agent header from the original request that triggered the transformation.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_xRequestId
final JsonField<String> _xRequestId()
Returns the raw JSON value of xRequestId.
Unlike xRequestId, this method doesn't throw if the JSON field has an unexpected type.
-
_userAgent
final JsonField<String> _userAgent()
Returns the raw JSON value of userAgent.
Unlike userAgent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationAcceptedEvent.Request.Builder toBuilder()
-
validate
final VideoTransformationAcceptedEvent.Request validate()
-
builder
final static VideoTransformationAcceptedEvent.Request.Builder builder()
Returns a mutable builder for constructing an instance of Request.
The following fields are required:
.url() .xRequestId()
-
-
-
-