Class VideoTransformationErrorEvent
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEventTriggered when an error occurs during video encoding. Listen to this webhook to log error reasons and debug issues. Check your origin and URL endpoint settings if the reason is related to download failure. For other errors, contact ImageKit support.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.BuilderA builder for VideoTransformationErrorEvent.
public final classVideoTransformationErrorEvent.Datapublic final classVideoTransformationErrorEvent.RequestInformation about the original request that triggered the video transformation.
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp when the event was created in ISO8601 format. final VideoTransformationErrorEvent.Datadata()final VideoTransformationErrorEvent.Requestrequest()Information about the original request that triggered the video transformation. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<VideoTransformationErrorEvent.Data>_data()Returns the raw JSON value of data. final JsonField<VideoTransformationErrorEvent.Request>_request()Returns the raw JSON value of request. final Map<String, JsonValue>_additionalProperties()final VideoTransformationErrorEvent.BuildertoBuilder()final VideoTransformationErrorEventvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationErrorEvent.Builderbuilder()Returns a mutable builder for constructing an instance of VideoTransformationErrorEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp when the event was created in ISO8601 format.
-
data
final VideoTransformationErrorEvent.Data data()
-
request
final VideoTransformationErrorEvent.Request request()
Information about the original request that triggered the video transformation.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<VideoTransformationErrorEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_request
final JsonField<VideoTransformationErrorEvent.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent validate()
-
builder
final static VideoTransformationErrorEvent.Builder builder()
Returns a mutable builder for constructing an instance of VideoTransformationErrorEvent.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-