Class VideoTransformationErrorEvent.Data.Transformation
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.Transformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.Data.Transformation.BuilderA builder for Transformation.
public final classVideoTransformationErrorEvent.Data.Transformation.TypeType of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
public final classVideoTransformationErrorEvent.Data.Transformation.ErrorDetails about the transformation error.
public final classVideoTransformationErrorEvent.Data.Transformation.OptionsConfiguration options for video transformations.
-
Method Summary
-
-
Method Detail
-
type
final VideoTransformationErrorEvent.Data.Transformation.Type type()
Type of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
-
error
final Optional<VideoTransformationErrorEvent.Data.Transformation.Error> error()
Details about the transformation error.
-
options
final Optional<VideoTransformationErrorEvent.Data.Transformation.Options> options()
Configuration options for video transformations.
-
_type
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_error
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Error> _error()
Returns the raw JSON value of error.
Unlike error, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Data.Transformation.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent.Data.Transformation validate()
-
builder
final static VideoTransformationErrorEvent.Data.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.type()
-
-
-
-