Class VideoTransformationErrorEvent.Data.Transformation.Error
-
- All Implemented Interfaces:
public final class VideoTransformationErrorEvent.Data.Transformation.ErrorDetails about the transformation error.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationErrorEvent.Data.Transformation.Error.BuilderA builder for Error.
public final classVideoTransformationErrorEvent.Data.Transformation.Error.ReasonSpecific reason for the transformation failure:
encoding_failed: Error during video encoding processdownload_failed: Could not download source videointernal_server_error: Unexpected server error
-
Method Summary
Modifier and Type Method Description final VideoTransformationErrorEvent.Data.Transformation.Error.Reasonreason()Specific reason for the transformation failure: encoding_failed: Error during video encoding processdownload_failed: Could not download source videointernal_server_error: Unexpected server error
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Error.Reason>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final VideoTransformationErrorEvent.Data.Transformation.Error.BuildertoBuilder()final VideoTransformationErrorEvent.Data.Transformation.Errorvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationErrorEvent.Data.Transformation.Error.Builderbuilder()Returns a mutable builder for constructing an instance of Error. -
-
Method Detail
-
reason
final VideoTransformationErrorEvent.Data.Transformation.Error.Reason reason()
Specific reason for the transformation failure:
encoding_failed: Error during video encoding processdownload_failed: Could not download source videointernal_server_error: Unexpected server error
-
_reason
final JsonField<VideoTransformationErrorEvent.Data.Transformation.Error.Reason> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationErrorEvent.Data.Transformation.Error.Builder toBuilder()
-
validate
final VideoTransformationErrorEvent.Data.Transformation.Error validate()
-
builder
final static VideoTransformationErrorEvent.Data.Transformation.Error.Builder builder()
Returns a mutable builder for constructing an instance of Error.
The following fields are required:
.reason()
-
-
-