Class VideoTransformationReadyEvent
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEventTriggered when video encoding is finished and the transformed resource is ready to be served. This is the key event to listen for - update your database or CMS flags when you receive this so your application can start showing the transformed video to users.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationReadyEvent.BuilderA builder for VideoTransformationReadyEvent.
public final classVideoTransformationReadyEvent.Datapublic final classVideoTransformationReadyEvent.RequestInformation about the original request that triggered the video transformation.
public final classVideoTransformationReadyEvent.TimingsPerformance metrics for the transformation process.
-
Method Summary
Modifier and Type Method Description final BaseWebhookEventtoBaseWebhookEvent()final Stringid()Unique identifier for the event. final Stringtype()The type of webhook event. final OffsetDateTimecreatedAt()Timestamp when the event was created in ISO8601 format. final VideoTransformationReadyEvent.Datadata()final VideoTransformationReadyEvent.Requestrequest()Information about the original request that triggered the video transformation. final Optional<VideoTransformationReadyEvent.Timings>timings()Performance metrics for the transformation process. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_type()Returns the raw JSON value of type. final JsonField<OffsetDateTime>_createdAt()Returns the raw JSON value of createdAt. final JsonField<VideoTransformationReadyEvent.Data>_data()Returns the raw JSON value of data. final JsonField<VideoTransformationReadyEvent.Request>_request()Returns the raw JSON value of request. final JsonField<VideoTransformationReadyEvent.Timings>_timings()Returns the raw JSON value of timings. final Map<String, JsonValue>_additionalProperties()final VideoTransformationReadyEvent.BuildertoBuilder()final VideoTransformationReadyEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationReadyEvent.Builderbuilder()Returns a mutable builder for constructing an instance of VideoTransformationReadyEvent. -
-
Method Detail
-
toBaseWebhookEvent
final BaseWebhookEvent toBaseWebhookEvent()
-
createdAt
final OffsetDateTime createdAt()
Timestamp when the event was created in ISO8601 format.
-
data
final VideoTransformationReadyEvent.Data data()
-
request
final VideoTransformationReadyEvent.Request request()
Information about the original request that triggered the video transformation.
-
timings
final Optional<VideoTransformationReadyEvent.Timings> timings()
Performance metrics for the transformation process.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<OffsetDateTime> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_data
final JsonField<VideoTransformationReadyEvent.Data> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_request
final JsonField<VideoTransformationReadyEvent.Request> _request()
Returns the raw JSON value of request.
Unlike request, this method doesn't throw if the JSON field has an unexpected type.
-
_timings
final JsonField<VideoTransformationReadyEvent.Timings> _timings()
Returns the raw JSON value of timings.
Unlike timings, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationReadyEvent.Builder toBuilder()
-
validate
final VideoTransformationReadyEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VideoTransformationReadyEvent.Builder builder()
Returns a mutable builder for constructing an instance of VideoTransformationReadyEvent.
The following fields are required:
.id() .type() .createdAt() .data() .request()
-
-
-
-