Package io.imagekit.models.webhooks
Class VideoTransformationReadyEvent.Data
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEvent.Data
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationReadyEvent.Data.BuilderA builder for Data.
public final classVideoTransformationReadyEvent.Data.AssetInformation about the source video asset being transformed.
public final classVideoTransformationReadyEvent.Data.Transformation
-
Method Summary
Modifier and Type Method Description final VideoTransformationReadyEvent.Data.Assetasset()Information about the source video asset being transformed. final VideoTransformationReadyEvent.Data.Transformationtransformation()final JsonField<VideoTransformationReadyEvent.Data.Asset>_asset()Returns the raw JSON value of asset. final JsonField<VideoTransformationReadyEvent.Data.Transformation>_transformation()Returns the raw JSON value of transformation. final Map<String, JsonValue>_additionalProperties()final VideoTransformationReadyEvent.Data.BuildertoBuilder()final VideoTransformationReadyEvent.Datavalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VideoTransformationReadyEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
asset
final VideoTransformationReadyEvent.Data.Asset asset()
Information about the source video asset being transformed.
-
transformation
final VideoTransformationReadyEvent.Data.Transformation transformation()
-
_asset
final JsonField<VideoTransformationReadyEvent.Data.Asset> _asset()
Returns the raw JSON value of asset.
Unlike asset, this method doesn't throw if the JSON field has an unexpected type.
-
_transformation
final JsonField<VideoTransformationReadyEvent.Data.Transformation> _transformation()
Returns the raw JSON value of transformation.
Unlike transformation, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationReadyEvent.Data.Builder toBuilder()
-
validate
final VideoTransformationReadyEvent.Data validate()
-
builder
final static VideoTransformationReadyEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.asset() .transformation()
-
-
-
-