Class VideoTransformationReadyEvent.Data.Transformation
-
- All Implemented Interfaces:
public final class VideoTransformationReadyEvent.Data.Transformation
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoTransformationReadyEvent.Data.Transformation.BuilderA builder for Transformation.
public final classVideoTransformationReadyEvent.Data.Transformation.TypeType of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
public final classVideoTransformationReadyEvent.Data.Transformation.OptionsConfiguration options for video transformations.
public final classVideoTransformationReadyEvent.Data.Transformation.OutputInformation about the transformed output video.
-
Method Summary
-
-
Method Detail
-
type
final VideoTransformationReadyEvent.Data.Transformation.Type type()
Type of video transformation:
video-transformation: Standard video processing (resize, format conversion, etc.)gif-to-video: Convert animated GIF to video formatvideo-thumbnail: Generate thumbnail image from video
-
options
final Optional<VideoTransformationReadyEvent.Data.Transformation.Options> options()
Configuration options for video transformations.
-
output
final Optional<VideoTransformationReadyEvent.Data.Transformation.Output> output()
Information about the transformed output video.
-
_type
final JsonField<VideoTransformationReadyEvent.Data.Transformation.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_options
final JsonField<VideoTransformationReadyEvent.Data.Transformation.Options> _options()
Returns the raw JSON value of options.
Unlike options, this method doesn't throw if the JSON field has an unexpected type.
-
_output
final JsonField<VideoTransformationReadyEvent.Data.Transformation.Output> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VideoTransformationReadyEvent.Data.Transformation.Builder toBuilder()
-
validate
final VideoTransformationReadyEvent.Data.Transformation validate()
-
builder
final static VideoTransformationReadyEvent.Data.Transformation.Builder builder()
Returns a mutable builder for constructing an instance of Transformation.
The following fields are required:
.type()
-
-
-
-