Interface UsageService
-
- All Implemented Interfaces:
public interface UsageService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceUsageService.WithRawResponseA view of UsageService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract UsageService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract UsageServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. UsageGetResponseget(UsageGetParams params)Get the account usage information between two dates. abstract UsageGetResponseget(UsageGetParams params, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract UsageService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract UsageService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
get
UsageGetResponse get(UsageGetParams params)
Get the account usage information between two dates. Note that the API response includes data from the start date while excluding data from the end date. In other words, the data covers the period starting from the specified start date up to, but not including, the end date.
-
get
abstract UsageGetResponse get(UsageGetParams params, RequestOptions requestOptions)
-
-
-
-